<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Accordion extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_accordion'; }
	public function get_title()          { return esc_html__( 'Accordion', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-accordion'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return ['accordion','toggle','accordion','faq' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }
	public function get_script_depends() { return ['mk-main']; }

	protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_accordion_tabs', 'Tabs');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('unique_id', [
                'label'   => esc_html__( 'Unique Tab Id', 'orbius-core' ),
                'label_block' => false,
                'type'    => \Elementor\Controls_Manager::TEXT,
            ]);

            $repeater->add_control('tab_title', [
                'label'   => esc_html__( 'Title', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'Title Text', 'orbius-core' ),
            ]);

            $repeater->add_control('tab_subtitle', [
                'label'       => esc_html__( 'Subtitle', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'subtitle text here', 'orbius-core' ),
            ]);

            $repeater->add_control('title_prefix', [
                'label'   => esc_html__( 'Title Prefix Text', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::TEXT,
            ]);

            $repeater->add_control('title_icon',[
                'label' => esc_html__( 'Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]);

            $repeater->add_control( 'content_type', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Content Type', 'orbius-core' ),
                'default'    => 'content',
                'options'    => mk_arrays('content_type'),
            ]);

            $repeater->add_control('accordion_content',   [
                'label'       => esc_html__( 'Content', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::WYSIWYG,
                'default'     => 'lacus quam faucibus in aliquam vitae placerat pretium eros. Aliquam et pulvinar odio vitae imperdiet purus amet blandit eros.',
                'condition'   => ['content_type' => 'content']
            ]);

            $repeater->add_control('image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
                'condition' => ['content_type' => 'image'],
            ]);

            $repeater->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'      => 'image',
                'label'     => esc_html__( 'Image Size', 'orbius-core' ),
                'condition'  => ['content_type' => 'image'],
                'default'   => 'large',
                'exclude'    => [ 'custom' ],
            ]);

            $repeater->add_control('saved_widget', [
                'label'     => esc_html__( 'Choose Widget', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SELECT,
                'options'   => $this->get_page_template_options( 'section' ),
                'default'   => '-1',
                'condition' => ['content_type'=> 'widget']
            ]);

            $repeater->add_control('saved_section', [
                'label'     => esc_html__( 'Choose Section', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SELECT,
                'options'   => $this->get_page_template_options( 'section' ),
                'default'   => '-1',
                'condition' => ['content_type'=> 'section']
            ]);

            $repeater->add_control('templates', [
                'label'     => esc_html__( 'Choose Template', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SELECT,
                'options'   => $this->get_page_template_options( 'page' ),
                'default'   => '-1',
                'condition' => ['content_type'=> 'template']
            ]);

            $repeater->add_control('accordion_tab_default_active',[
                'label' => esc_html__( 'Active as Default', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('tabs', [
                'type'        => \Elementor\Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                                    [ 'unique_id' => 'id1' , 'tab_title' => 'Example Title One Text','title_prefix' => '01', 'tab_subtitle' => 'duis accumsan ipsum at lorem lacinia','accordion_tab_default_active' => 'yes' ],
                                    [ 'unique_id' => 'id2' , 'tab_title' => 'Example Title Two Text','title_prefix' => '02', 'tab_subtitle' => 'duis accumsan ipsum at lorem lacinia' ],
                                    [ 'unique_id' => 'id3' , 'tab_title' => 'Example Title Three Text','title_prefix' => '03', 'tab_subtitle' => 'duis accumsan ipsum at lorem lacinia' ]
                                ],
                'title_field' => '{{tab_title}}',
            ]);

  		$this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_accordion_toggle_icon', 'Toggle Icon');

            $this->add_control('toggle_icon_show',[
                'label' => esc_html__( 'Toggle Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'default'      => 'yes',
            ]);

            $this->add_control('toggle_icon_normal',[
                'label' => esc_html__( 'Normal Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [],
                'condition' => ['toggle_icon_show' => 'yes']
            ]);

            $this->add_control('toggle_icon_active',[
                'label' => esc_html__( 'Active Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [],
                'condition' => ['toggle_icon_show' => 'yes']
            ]);

  		$this->end_controls_section();

  		mk_elem_start_ctrl($this, 'section_accordion_settings', 'Settings');

            $this->add_control('accordion_type',[
                'label'                 => esc_html__( 'Accordion Type', 'estra-core' ),
                'type'                  => \Elementor\Controls_Manager::SELECT,
                'default'               => 'accordion',
                'label_block'           => false,
                'options'               => [
                    'accordion'     => esc_html__( 'Accordion', 'estra-core' ),
                    'toggle'        => esc_html__( 'Toggle', 'estra-core' ),
                ],
                'frontend_available'    => true,
              ]);

            $this->add_control('toggle_speed', [
                'label' => esc_html__( 'Toggle Speed (ms)', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 300,
                'step' => 10,
                'min' => 0,
                'max' => 500,
                'condition' => ['appear_delay' => 'ms','appear_animation!' => 'none'],
            ]);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'section_accordion_items_style', 'Items', true);

		$this->start_controls_tabs( 'accordion_item_style' );
			$this->start_controls_tab('accordion_item_normal', ['label' => esc_html__( 'Normal', 'orbius-core' )]);

                $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                    'name'        => 'accordion_items_border',
                    'label'       => esc_html__( 'Border', 'orbius-core' ),
                    'selector'    => '{{WRAPPER}} .mk-accordion-item',
                ]);

			$this->end_controls_tab();

			$this->start_controls_tab('accordion_item_active',[ 'label' => esc_html__( 'Active', 'orbius-core' ) ]);

                $this->add_control('accordion_items_active_border', [
                    'label'     => esc_html__( 'Border Color', 'orbius-core' ),
                    'type'      => \Elementor\Controls_Manager::COLOR,
                    'selectors' => [
                         '{{WRAPPER}} .mk-accordion .mk-accordion-item.mk-accordion-item-active' => 'border-color : {{VALUE}};',
                    ],
                ]);

			$this->end_controls_tab();

		$this->end_controls_tabs();


        $this->add_responsive_control('accordion_items_spacing', [
            'label'     => esc_html__( 'Spacing', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px' ],
            'range'     => ['px' => ['min' => -10, 'max' => 200 ] ],
            'selectors' => [
                '{{WRAPPER}} .mk-accordion-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ]
        ]);

		$this->add_responsive_control('accordion_items_border_radius', [
			'label'                 => esc_html__( 'Border Radius', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', 'em', '%' ],
			'selectors'             => [
 					'{{WRAPPER}} .mk-accordion-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
 			],
		]);

		$this->add_responsive_control('accordion_items_padding', [
			'label'                 => esc_html__( 'Padding', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', 'em', '%' ],
			'selectors'             => [
 					'{{WRAPPER}} .mk-accordion-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
 			],
		]);

		$this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
			'name'                  => 'accordion_items_box_shadow',
			'selector'              => '{{WRAPPER}} .mk-accordion-item',
		]);

  		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'section_title_style', 'Title', true);

		      $this->start_controls_tabs( 'accordion_tabs_style' );

        		$this->start_controls_tab('accordion_tab_normal', [
        			'label' => esc_html__( 'Normal', 'orbius-core' ),
        		]);

            		$this->add_control('tab_title_text_color', [
            			'label'                 => esc_html__( 'Color', 'orbius-core' ),
            			'type'                  => \Elementor\Controls_Manager::COLOR,
            			'selectors'             => [
            				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title,
            				{{WRAPPER}} .mk-accordion .mk-accordion-tab-title .mk-accordion-tab-icon.mk-icon' => 'color: {{VALUE}};',
            				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title .mk-accordion-tab-icon.mk-icon svg' => 'fill: {{VALUE}};',

            			],
            		]);

            		$this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            			'name'     => 'tab_title_bg_color',
            			'label' => esc_html__( 'Background Color', 'orbius-core' ),
            			'types'    => [ 'none','classic','gradient' ],
            			'selector' => '{{WRAPPER}} .mk-accordion .mk-accordion-tab-title',
            		]);

                    $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                        'name'     => 'tab_title_typography',
                        'selector' => '{{WRAPPER}} .mk-accordion-title-icon',
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                        'name'        => 'tab_title_border',
                        'label'       => esc_html__( 'Border', 'orbius-core' ),
                        'selector'    => '{{WRAPPER}} .mk-accordion .mk-accordion-tab-title',
                    ]);

                	$this->add_responsive_control('tab_title_border_radius',[
            			'label'       => esc_html__( 'Border Radius', 'orbius-core' ),
            			'type'        => \Elementor\Controls_Manager::DIMENSIONS,
            			'size_units'  => [ 'px', 'em', '%' ],
            			'selectors'   => [
             					'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             			],
            		]);

            		$this->add_responsive_control('tab_title_padding', [
            			'label'      => esc_html__( 'Padding', 'orbius-core' ),
            			'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            			'size_units' => [ 'px', 'em', '%' ],
            			'selectors'  => [
             					'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
             			],
            		]);

        $this->end_controls_tab();

		$this->start_controls_tab('accordion_tab_hover', [
			'label' => esc_html__( 'Hover', 'orbius-core' ),
		]);

		$this->add_control('tab_title_text_color_hover', [
			'label'     => esc_html__( 'Color', 'orbius-core' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title:hover,
				{{WRAPPER}} .mk-accordion .mk-accordion-tab-title:hover .mk-accordion-tab-icon.mk-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title:hover .mk-accordion-tab-icon.mk-icon svg' => 'fill: {{VALUE}};',
			],
		]);

		$this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
			'name'     => 'tab_title_bg_color_hover',
			'label' => esc_html__( 'Background Color', 'orbius-core' ),
			'types'    => [ 'none','classic','gradient' ],
			'selector' => '{{WRAPPER}} .mk-accordion .mk-accordion-tab-title:hover',
		]);

		$this->add_control('tab_title_border_color_hover', [
			'label'      => esc_html__( 'Border Color', 'orbius-core' ),
			'type'       => \Elementor\Controls_Manager::COLOR,
			'default'    => '',
			'selectors'  => [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title:hover' => 'border-color: {{VALUE}};',
			],
		]);

        $this->end_controls_tab();

		$this->start_controls_tab('accordion_tab_active', [
			'label'                 => esc_html__( 'Active', 'orbius-core' ),
		]);

		$this->add_control('tab_title_text_color_active', [
			'label'                 => esc_html__( 'Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title.mk-accordion-tab-active,
				{{WRAPPER}} .mk-accordion .mk-accordion-tab-title.mk-accordion-tab-active .mk-accordion-tab-icon.mk-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title.mk-accordion-tab-active .mk-accordion-tab-icon.mk-icon svg' => 'fill: {{VALUE}};',
			],
		]);

		$this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
			'name'     => 'tab_title_bg_color_active',
			'label' => esc_html__( 'Background Color', 'orbius-core' ),
			'types'    => [ 'none','classic','gradient' ],
			'selector' => '{{WRAPPER}} .mk-accordion .mk-accordion-tab-title.mk-accordion-tab-active',
		]);

		$this->add_control('tab_title_border_color_active', [
			'label'                 => esc_html__( 'Border Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title.mk-accordion-tab-active' => 'border-color: {{VALUE}};',
			],
		]);

        $this->end_controls_tab();

        $this->end_controls_tabs();

        mk_elem_heading_ctrl($this, 'title_prefix_heading', 'Title Prefix', 'before' );

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_prefix_typography',
            'selector' => '{{WRAPPER}} span.mk-accordion-title-prefix-text',
        ]);

        $this->add_control('title_prefix_color', [
            'label'                 => esc_html__( 'Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} span.mk-accordion-title-prefix-text' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_responsive_control('title_prefix_spacing', [
            'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'range'                 => [
                'px' => [
                    'max' => 150,
                ],
            ],
            'selectors'             => [
                '{{WRAPPER}} span.mk-accordion-title-prefix-text ' => 'margin-right: {{SIZE}}{{UNIT}};'
            ],
        ]);

		mk_elem_heading_ctrl($this, 'tab_icon_heading', 'Icon', 'before' );

		$this->add_responsive_control('tab_icon_size', [
			'label'                 => esc_html__( 'Icon Size', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SLIDER,
			'size_units'            => [ 'px' ],
			'range'                 => [
				'px'		=> [
					'min'	=> 0,
					'max'	=> 100,
					'step'	=> 1,
				]
			],
			'selectors'             => [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title .mk-accordion-tab-icon.mk-icon ' => 'font-size: {{SIZE}}{{UNIT}};',
			]
		]);
		$this->add_responsive_control('tab_icon_spacing', [
			'label'                 => esc_html__( 'Icon Spacing', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SLIDER,
			'default'               => [
				'size'	=> 10,
				'unit'	=> 'px',
			],
			'size_units'            => [ 'px' ],
			'range'                 => [
				'px'	=> [
					'min'	=> 0,
					'max'	=> 100,
					'step'	=> 1,
				]
			],
			'selectors'             => [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title .mk-accordion-tab-icon' => 'margin-right: {{SIZE}}{{UNIT}};',
			]
		]);

		$this->end_controls_section();


        mk_elem_start_ctrl($this, 'section_subtitle_style', 'Subtitle', true);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'tab_subtitle_typography',
            'selector' => '{{WRAPPER}} .mk-accordion .mk-accordion-subtitle-text',
        ]);

        $this->add_control('tab_subtitle_text_color', [
            'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'selectors'             => [
                '{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-subtitle-text' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_control('tab_subtitle_hover_text_color', [
            'label'                 => esc_html__( 'Hover Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'selectors'             => [
                '{{WRAPPER}} .mk-accordion .mk-accordion-item:hover .mk-accordion-subtitle-text' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_control('tab_subtitle_active_text_color', [
            'label'                 => esc_html__( 'Active Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'selectors'             => [
                '{{WRAPPER}} .mk-accordion .mk-accordion-item.mk-accordion-item-active .mk-accordion-subtitle-text' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_responsive_control('tab_subtitle_padding', [
            'label'                 => esc_html__( 'Padding', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', 'em', '%' ],
            'selectors'             => [
                    '{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-subtitle-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('tab_subtitle_margin', [
            'label'                 => esc_html__( 'Margin', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', 'em', '%' ],
            'selectors'             => [
                    '{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-subtitle-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

		mk_elem_start_ctrl($this, 'section_content_style', 'Content', true);

		$this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
			'name'     => 'tab_content_bg_color',
			'label' => esc_html__( 'Background Color', 'orbius-core' ),
			'types'    => [ 'none','classic','gradient' ],
			'selector' => '{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-tab-content',
		]);

		$this->add_control('tab_content_text_color', [
			'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'selectors'             => [
				'{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-tab-content' => 'color: {{VALUE}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'tab_content_typography',
            'selector' => '{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-tab-content',
        ]);

		$this->add_responsive_control('tab_content_border_radius', [
			'label'                 => esc_html__( 'Border Radius', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', 'em', '%' ],
			'selectors'             => [
 					'{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-tab-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
 			],
		]);

		$this->add_responsive_control('tab_content_padding', [
			'label'                 => esc_html__( 'Padding', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', 'em', '%' ],
			'selectors'             => [
 					'{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-tab-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
 			],
		]);

		$this->add_responsive_control('tab_content_margin', [
			'label'                 => esc_html__( 'Margin', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', 'em', '%' ],
			'selectors'             => [
 					'{{WRAPPER}} .mk-accordion .mk-accordion-item .mk-accordion-tab-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
 			],
		]);

  		$this->end_controls_section();

  		mk_elem_start_ctrl($this, 'section_toggle_icon_style', 'Toggle icon', true, ['toggle_icon_show' => 'yes']);

		$this->add_control('toggle_icon_color', [
			'label'                 => esc_html__( 'Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'selectors'	=> [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title .mk-accordion-toggle-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title .mk-accordion-toggle-icon.mk-icon svg' => 'fill: {{VALUE}};',
			],
			'condition'	=> [
				'toggle_icon_show' => 'yes'
			]
		]);

		$this->add_control('toggle_icon_hover_color', [
			'label'                 => esc_html__( 'Hover Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'	=> [
				'{{WRAPPER}} .mk-accordion .mk-accordion-item:hover .mk-accordion-tab-title .mk-accordion-toggle-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-accordion .mk-accordion-item:hover .mk-accordion-tab-title .mk-accordion-toggle-icon.mk-icon svg' => 'fill: {{VALUE}};',
			],
			'condition'             => [
				'toggle_icon_show' => 'yes'
			]
		]);

		$this->add_control('toggle_icon_active_color', [
			'label'                 => esc_html__( 'Active Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'	=> [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title.mk-accordion-tab-active .mk-accordion-toggle-icon,
				 {{WRAPPER}} .mk-accordion .mk-accordion-item:hover .mk-accordion-tab-title.mk-accordion-tab-active .mk-accordion-toggle-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title.mk-accordion-tab-active .mk-accordion-toggle-icon.mk-icon svg,
				 {{WRAPPER}} .mk-accordion .mk-accordion-item:hover .mk-accordion-tab-title.mk-accordion-tab-active .mk-accordion-toggle-icon.mk-icon svg' => 'fill: {{VALUE}};',
			],
			'condition'             => [
				'toggle_icon_show' => 'yes'
			]
		]);

		$this->add_responsive_control('toggle_icon_size', [
			'label'                 => esc_html__( 'Size', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SLIDER,
			'size_units'            => [ 'px' ],
			'range'	=> [
				'px'	=> [
					'min'	=> 0,
					'max'	=> 100,
					'step'	=> 1,
				]
			],
			'selectors'             => [
				'{{WRAPPER}} .mk-accordion .mk-accordion-tab-title .mk-accordion-toggle-icon' => 'font-size: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};line-height: {{SIZE}}{{UNIT}};',
			],
			'condition'             => [
				'toggle_icon_show' => 'yes'
			]
		]);

        $this->add_responsive_control('toggle_icon_spacing', [
            'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'size_units'            => [ 'px' ],
            'range' => [
                'px'    => [
                    'min'   => 0,
                    'max'   => 100,
                    'step'  => 1,
                ]
            ],
            'selectors'             => [
                '{{WRAPPER}} .mk-accordion .mk-accordion-tab-title .mk-accordion-toggle-icon' => 'margin-left: {{SIZE}}{{UNIT}};',
            ],
            'condition'             => [
                'toggle_icon_show' => 'yes'
            ]
        ]);

  		$this->end_controls_section();
	}

	protected function render() {

		$settings	= $this->get_settings_for_display();
		$id_int		= substr( $this->get_id_int(), 0, 3 );

		$this->add_render_attribute( 'accordion', [
            'class'                 => 'mk-accordion',
            'id'                    => 'mk-accordion-'.esc_attr( $this->get_id() ),
            'data-accordion-id'     => esc_attr( $this->get_id() )
        ] );
        ?>
        <div <?php echo $this->get_render_attribute_string('accordion'); ?>>
            <?php
                foreach( $settings['tabs'] as $index => $tab ) {

                    $tab_count = $index+1;
                    $tab_title_setting_key = $this->get_repeater_setting_key('tab_title', 'tabs', $index);
                    $tab_content_setting_key = $this->get_repeater_setting_key('accordion_content', 'tabs', $index);

                    $tab_title_class 	= ['mk-accordion-tab-title'];
                    $tab_content_class 	= ['mk-accordion-tab-content'];

                    if ( $tab['accordion_tab_default_active'] == 'yes' ) {
                        $tab_title_class[] 		= 'mk-accordion-tab-active-default';
                        $tab_content_class[] 	= 'mk-accordion-tab-active-default';
                    }

                    $this->add_render_attribute( $tab_title_setting_key, [
                        'id'                => 'mk-accordion-tab-title-' . $id_int . $tab_count,
                        'class'             => $tab_title_class,
                        'tabindex'          => $id_int . $tab_count,
                        'data-tab'          => $tab_count,
                        'role'              => 'tab',
                        'aria-controls'     => 'mk-accordion-tab-content-' . $id_int . $tab_count,
                    ]);

                    $this->add_render_attribute( $tab_content_setting_key, [
                        'id'                => 'mk-accordion-tab-content-' . $id_int . $tab_count,
                        'class'             => $tab_content_class,
                        'data-tab'          => $tab_count,
                        'role'              => 'tabpanel',
                        'aria-labelledby'   => 'mk-accordion-tab-title-' . $id_int . $tab_count,
                    ] );

                    if ( $tab['content_type'] == 'content' ) {
                        $this->add_inline_editing_attributes( $tab_content_setting_key, 'advanced' );
                    }

                    $unique_id = ( '' != $tab['unique_id'] ) ? ' id="'.$tab['unique_id'].'"' : '';

            ?>
            <div class="mk-accordion-item"<?php echo $unique_id; ?>>

                <div <?php echo $this->get_render_attribute_string($tab_title_setting_key); ?>>
                    <div class="mk-accordion-title-icon-holder">
                        <span class="mk-accordion-title-icon">
                            <?php
                            ob_start();
    						\Elementor\Icons_Manager::render_icon( $tab['title_icon'], [ 'aria-hidden' => 'true' ] );
    						$title_section_icon = ob_get_clean();

                            if ( '' != $title_section_icon ) { ?>
                                <span class="mk-accordion-tab-icon mk-icon">
                               		<?php echo $title_section_icon; ?>
                                </span>
                            <?php } ?><?php if ( '' != $tab['title_prefix'] ) { ?><span class="mk-accordion-title-prefix-text"><?php echo $tab['title_prefix']; ?></span><?php } ?><span class="mk-accordion-title-text">
                                <?php echo $tab['tab_title']; ?>
                            </span>
                        </span>
                        <?php if ( $settings['toggle_icon_show'] === 'yes' ) { ?>
                            <div class="mk-accordion-toggle-icon">
                                <?php if ( $settings['toggle_icon_normal'] ) {

                                    $inactive_toggle_icon = mk_get_elementor_icons($settings['toggle_icon_normal']);

                                    if ( '' === $inactive_toggle_icon ) {
                                        $inactive_toggle_icon = mk_get_svg_icon( 'plus-circle', 'swm-svg-off-canvas-close-icon' );
                                    }
                                    ?>
                                    <span class="mk-accordion-toggle-icon mk-accordion-toggle-icon-close mk-icon"><?php echo $inactive_toggle_icon; ?></span>
                                <?php } ?>
                                <?php if ( $settings['toggle_icon_active'] ) {

                                    $active_toggle_icon = mk_get_elementor_icons($settings['toggle_icon_active']);

                                    if ( '' === $active_toggle_icon ) {
                                        $active_toggle_icon = mk_get_svg_icon( 'minus-circle', 'swm-svg-off-canvas-close-icon' );
                                    }
                                    ?>
                                    <span class="mk-accordion-toggle-icon mk-accordion-toggle-icon-open mk-icon"><?php echo $active_toggle_icon; ?></span>
                                <?php } ?>
                            </div>
                        <?php } ?>
                    </div>
                    <?php if ( '' != $tab['tab_subtitle'] ) { ?>
                        <div class="mk-accordion-subtitle-text"><?php echo $tab['tab_subtitle']; ?></div>
                    <?php } ?>
                </div>

                <div <?php echo $this->get_render_attribute_string($tab_content_setting_key); ?>>
                    <?php
                        if ( $tab['content_type'] == 'content' ) {

                            echo do_shortcode( $tab['accordion_content'] );

                        } elseif ( $tab['content_type'] == 'image' && $tab['image']['url'] ) {

                            if (  $tab['image_size'] == 'full' ) {
                                $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $tab['image']['id'], 'full', $tab );
                                $imgSrcset = ' srcset="'. wp_get_attachment_image_srcset($tab['image']['id']) . '"';
                                $imgSizes = ' sizes="'.wp_get_attachment_image_sizes($tab['image']['id'], "full") . '"';
                            } else {
                                $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $tab['image']['id'], 'image', $tab );
                                $imgSrcset = '';
                                $imgSizes = '';
                            }

                            if ( ! $imgUrl ) {
                                $imgUrl = $tab['image']['url'];
                            }

                            $image_html = '<div class="mk-showcase-preview-image">';

                            $image_html .= '<img src="' . $imgUrl . '" ' . $imgSizes . $imgSrcset . ' alt="' . esc_attr( \Elementor\Control_Media::get_image_alt( $tab['image'] ) ) . '">';

                            $image_html .= '</div>';

                            echo $image_html;

                        } elseif ( $tab['content_type'] == 'section' && !empty( $tab['saved_section'] ) ) {

                            echo \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $tab['saved_section'] );

                        } elseif ( $tab['content_type'] == 'template' && !empty( $tab['templates'] ) ) {

                            echo \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $tab['templates'] );

                        } elseif ( $tab['content_type'] == 'widget' && !empty( $tab['saved_widget'] ) ) {

                            echo \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $tab['saved_widget'] );

                        }
                    ?>
                </div>

            </div>
            <?php } ?>
        </div>
	<?php
	}

	public function get_page_template_options( $type = '' ) {

		$page_templates = mk_get_page_templates( $type );

		$options[-1]   = esc_html__( 'Select', 'orbius-core' );

		if ( count( $page_templates ) ) {
			foreach ( $page_templates as $id => $name ) {
				$options[ $id ] = $name;
			}
		} else {
			$options['no_template'] = esc_html__( 'No saved templates found!', 'orbius-core' );
		}

		return $options;
	}

}