<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Animated_Content extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_animated_content'; }
	public function get_title()          { return esc_html__( 'Animated Content', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-text'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'theme', 'animated content', 'animated text', 'content','slide text','typing','text','animation','animated' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }
	public function get_script_depends() { return ['typed', 'mk-widgets', ]; }

	protected function register_controls() {

        mk_elem_start_ctrl($this, 'general_content', 'General Content');

        $this->add_control('title', [
            'label' => esc_html__( 'Text', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXTAREA,
            'default' => 'Sample Text',
        ]);

        $this->add_responsive_control('alignment', [
            'label' => esc_html__( 'Alignment', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::CHOOSE,
            'options' => mk_arrays('text_align'),
            'default' => 'left',
            'selectors' => [
                '{{WRAPPER}} .mk-animated-content' => 'text-align: {{VALUE}};',
            ],
        ]);

        $this->add_control('text_tag', [
            'label' => esc_html__( 'Select Tag', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'h1'         => 'H1',
                'h2'         => 'H2',
                'h3'         => 'H3',
                'h4'         => 'H4',
                'h5'         => 'H5',
                'h6'         => 'H6',
                'div'        => 'div',
                'p'          => 'p',
                'span'       => 'span',
                'blockquote' => 'blockquote',
            ],
            'default' => 'div',
        ]);

        $this->add_control( 'split_title', [
            'label' => esc_html__( 'Split Title', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                ''       => esc_html__( 'None', 'orbius-core' ),
                'word'   => esc_html__( 'By Word', 'orbius-core' ),
                'letter' => esc_html__( 'By Letter', 'orbius-core' ),
            ],
        ]);

        $this->add_control( 'appear_animation', [
            'label' => esc_html__( 'Appear Animation', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'none' => 'None',
                'from-bottom' => 'From Bottom',
                'from-top' => 'From Top',
                'from-left' => 'From Left',
                'from-right' => 'From Right',
                'fade' => 'Fade In',
            ],
            'default' => 'from-bottom',
        ]);

        $this->add_control( 'appear_delay', [
            'label' => esc_html__( 'Appear Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                ''       => esc_html__( 'Default', 'orbius-core' ),
                'random' => esc_html__( 'Random', 'orbius-core' ),
                'ms'     => esc_html__( 'Set ms', 'orbius-core' ),
            ],
            'condition' => ['appear_animation!' => 'none']
        ]);

        $this->add_control('appear_delay_in_ms', [
            'label' => esc_html__( 'Set Appear Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 100,
            'step' => 100,
            'min' => 100,
            'max' => 9999,
            'condition' => ['appear_delay' => 'ms','appear_animation!' => 'none'],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'general_style', 'Style', true);

            $this->add_control('title_tag', [
                'label' => esc_html__( 'Select Tag for Inner Text', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                    'div' => 'div',
                    'p' => 'p'
                ],
                'default' => 'div',
            ]);

            $this->add_control('title_color',[
                'label' => esc_html__( 'Text Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-animated-content .mk-ac-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-animated-content .mk-ac-title',
            ]);

            $this->add_responsive_control('title_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-ac-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

	}

	public function render() {

        $atts = $this->get_settings_for_display();

        $holder_classes = 'mk-animated-content';
        $holder_classes .= ! empty( $atts['split_title'] ) ? ' mk--animated-by-' . $atts['split_title'] : '';
        $holder_classes .= ! empty( $atts['alignment'] ) ? ' mk--alignment-' . $atts['alignment'] : '';
        $holder_classes .= ( 'none' !== $atts['appear_animation'] ) ? ' mk-scroll--load mk--appear-' . $atts['appear_animation'] : '';

        $title = $atts['title'];

        if ( ! empty( $title ) && $atts['split_title'] ) {
            if ( 'word' === $atts['split_title'] ) {
                $split_text = explode( ' ', $title );

                foreach ( $split_text as $key => $value ) {
                    $split_text[ $key ] = '<span class="mk-ac-word">' . $value . '</span>';
                }
            } elseif ( 'letter' === $atts['split_title'] ) {
                $split_text = explode( ' ', $title );
                foreach ( $split_text as $key => $value ) {
                    $split_text[ $key ] = '<span class="mk-ac-word-holder">' . $value . '</span>';
                }
            }

            $title = implode( ' ', $split_text );

        }

        $titleTagSelector = !empty($atts['title_tag']) ? $atts['title_tag'] : 'div';

        $title = !empty( $title ) ? '<'.$titleTagSelector.' class="mk-ac-title">'.$title.'</'.$titleTagSelector.'>' : '';

        // appear delay
        $appear_animation = '';
        if ('none' != $atts['appear_animation']) {
            if ( 'ms' === $atts['appear_delay'] && $atts['appear_delay_in_ms'] >= 0 ) {
                $appear_animation = ' data-appear-delay="'.$atts['appear_delay_in_ms'].'"';
            } elseif ( 'random' === $atts['appear_delay'] ) {
                $appear_animation = ' data-appear-delay="'.$atts['appear_delay'].'"';
            }
        }

        echo '<' . $atts['text_tag'] . ' class="'.$holder_classes.'"'.$appear_animation.'>'.$title.'</' . $atts['text_tag'] . '>';
    }

}