<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Awards extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_awards'; }
    public function get_title()          { return esc_html__( 'Awards', 'estra-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-background'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'mk', 'theme', 'awards', 'list','links' ]; }
    public function get_style_depends()  { return [ 'mk-core-main' ]; }
    public function get_script_depends() { return [ 'mk-widgets' ]; }

    protected function register_controls() {

        $this->start_controls_section('general_settings', [
            'label' => esc_html__( 'General', 'estra-core' ),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title_text', [
                'label'       => esc_html__( 'Title', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('digital infinity awards','estra-core')
            ]);

            $repeater->add_control('subtitle_text', [
                'label'       => esc_html__( 'Sub Title', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('best animation','estra-core')
            ]);

            $repeater->add_control('year', [
                'label'       => esc_html__( 'Year', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('2024','estra-core')
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'placeholder' => esc_html__( 'http://your-link.com', 'estra-core' ),
            ]);

            $repeater->add_control('set_active_item',[
                'label'   => esc_html__( 'Set Active Item', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $repeater->add_control('list_image', [
                'label'       => esc_html__( 'Image', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::MEDIA,
                'default'     => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                 ],
            ]);

            $this->add_control('list_items', [
                'label' => esc_html__( 'List Items', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['title_text' => "digital infinity awards",  'subtitle_text' => "best animation", 'year' => "2024", 'set_active_item' => 'yes',  'link' =>  ['url' => '#']],
                    ['title_text' => "best website of the year",  'subtitle_text' => "interactive design", 'year' => "2023", 'set_active_item' => 'no',  'link' =>  ['url' => '#']],
                    ['title_text' => "festival of digital culture", 'subtitle_text' => "photo contest", 'year' => "2022", 'set_active_item' => 'no',  'link' =>  ['url' => '#']],
                    ['title_text' => "crown digital agency site", 'subtitle_text' => "css design awards", 'year' => "2021", 'set_active_item' => 'no',  'link' =>  ['url' => '#']],
                    ['title_text' => "the journey of one project", 'subtitle_text' => "portfolio design", 'year' => "2020", 'set_active_item' => 'no',  'link' =>  ['url' => '#']],
                ],
                'title_field' => '{{{ title_text }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_items_style', 'Items', true);

            $this->add_responsive_control('item_bottom_spacing', [
                'label' => esc_html__( 'Bottom Space', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', '%' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_responsive_control('item_left_margin', [
                'label' => esc_html__( 'Left Margin', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', '%' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item' => 'margin-left: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_control('items_border_color', [
                'label'     => esc_html__( 'Border Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards-year-line' => 'background-color: {{VALUE}};',
                ],
            ]);


        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_titles_style', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'label'    => esc_html__( 'Typography', 'estra-core' ),
                'selector' => '{{WRAPPER}} .mk-awards .mk-awards-item .mk-awards-title',
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item .mk-awards-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('active_title_color', [
                'label'     => esc_html__( 'Active Title Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item.active-item .mk-awards-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                'label' => esc_html__( 'Margin', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'estra-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-awards-title' => 'margin:0;',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_subtitles_style', 'Sub Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'subtitle_typography',
                'label'    => esc_html__( 'Subtitle Typography', 'estra-core' ),
                'selector' => '{{WRAPPER}} .mk-awards-subtitle',
            ]);

            $this->add_control('subtitle_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item .mk-awards-subtitle' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('subtitle_active_color', [
                'label'     => esc_html__( 'Active Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item.active-item .mk-awards-subtitle' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('subtitle_margin', [
                'label' => esc_html__( 'Subtitle Margin', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_year_style', 'Year', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'year_typography',
                'label'    => esc_html__( 'Typography', 'estra-core' ),
                'selector' => '{{WRAPPER}} .mk-awards-year',
            ]);

            $this->add_responsive_control('active_year_font_size', [
                'label' => esc_html__( 'Active Item Font Size', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', '%' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item.active-item .mk-awards-year' => 'font-size: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_control('year_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item .mk-awards-year' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('year_active_color', [
                'label'     => esc_html__( 'Active Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item.active-item .mk-awards-year' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('year_bg_color', [
                'label'     => esc_html__( 'Background Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item .mk-awards-year' => 'background-color: {{VALUE}};',
                ],
            ]);

            $this->add_control('year_active_bg_color', [
                'label'     => esc_html__( 'Active Background Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-awards .mk-awards-item.active-item .mk-awards-year' => 'background-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();




        mk_elem_start_ctrl($this, 'section_image_style', 'Image', true);

            $this->add_control('image_section_height',[
                'label'       => esc_html__( 'Image Section Minimum Height', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', '%'  ],
                'range'       => ['px' => ['min' => 0, 'max' => 2000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-awards-images-holder' => 'min-height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'image',
                'label'   => esc_html__( 'Image Size', 'estra-core' ),
                'default' => 'full',
            ]);

            $this->add_control('image_width',[
                'label'       => esc_html__( 'Width', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', '%'  ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-awards .mk-awards-image' => 'width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('image_height',[
                'label'       => esc_html__( 'Height', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', '%'  ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-awards .mk-awards-image' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'subtitle_responsive_hide', 'Hide Subtitle At', 'none' );
            mk_elem_hide_ctrl($this, 'year_responsive_hide', 'Hide Year At', 'none' );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $i = 1;

        $articles_list = $awardsList = '';

        foreach ( $settings['list_items'] as $index => $item ) :

            $linkHTML = $titleSubtitle = $imgUrl = $title = $subTitle = $year = $link_start = $link_end = '';

            // Image
            if (  $settings['image_size'] == 'custom' ) {
                $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['list_image']['id'], 'image', $settings );
                $img_alt = get_post_meta( $item['list_image']['id'], '_wp_attachment_image_alt', true);

                if ('' != $imgUrl) {
                    $slideImageHtml = '<img src="' . $imgUrl . '" alt="' . $img_alt . '" loading="lazy" />';
                }

            } else {
                $slideImageHtml = wp_get_attachment_image( $item['list_image']['id'], $settings['image_size']);
            }

            // Link
            if ( ! empty( $item['link']['url'] ) ) {

                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'class', 'mk-awards-link' );

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $linkHTML = '<a ' . $this->get_render_attribute_string( $link_key ) . '></a>';
                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';

            }

            $tabNo = ( $i < 10 ) ? '0' . $i : $i;

            if ( ! empty( $item['year'] ) ) {
                $year .= '<div class="mk-awards-year-holder swm-anim swm-anim swm-hide-'. $settings['year_responsive_hide'] .'"><span class="mk-awards-year swm-anim">' . $item['year'] . '</span><span class="mk-awards-year-line swm-anim"></span></div>';
            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            if ( ! empty( $item['title_text'] ) ) {
                $title .= '<'.$titleTagSelector.' class="mk-awards-title swm-anim">' . $item['title_text'] . '</'.$titleTagSelector . '>';
            }

            $subTitle .= ( ! empty( $item['subtitle_text'] ) ) ? '<span class="mk-awards-subtitle swm-anim swm-hide-'. $settings['subtitle_responsive_hide'] .'">' . $item['subtitle_text'] . '</span>' : '';

            $active_item = ('yes' == $item['set_active_item']) ? ' active-item' : '';

            // List Image
            if ('' != $slideImageHtml) {
                $awardsList .= '<div id="tab-'.$i.'" class="mk-awards-image'.$active_item.'">' . $link_start . $slideImageHtml . $link_end . '</div>';
            }

            // List Text
            $articles_list .= '<article class="mk-awards-item swm-anim' . $active_item . '" data-index="tab-'.$i.'">
                                    ' . $linkHTML . '
                                    <div class="mk-awards-content">
                                        ' . $year . '
                                        <div class="mk-awards-titleSubtitle">
                                            <div class="mk-awards-text swm-anim">' . $title . $subTitle . '</div>
                                        </div>
                                    </div>
                                </article>';
            $i++;
        endforeach;

        echo '<div class="mk-awards-container">
                <div class="mk-awards">
                    <div class="mk-awards-images">
                        <div class="mk-awards-images-holder">
                            ' . $awardsList . '
                        </div>
                    </div>
                    <div class="mk-awards-items">
                        <div class="mk-awards-items-list">
                            <div class="mk-awards-items-list-holder">
                            ' . $articles_list . '
                            </div>
                        </div>
                    </div>
                </div>
            </div>';

    }

}