<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Basic_Slider extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_basic_slider'; }
    public function get_title()          { return esc_html__( 'Basic Slider', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return ['mk-sliders-elements']; }
    public function get_keywords()       { return [ 'theme','slider','slide show']; }
    public function get_style_depends()  { return ['swiper','mk-core-main']; }
    public function get_script_depends() { return ['swiper','mk-widgets']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_heading', 'Slider Items');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title_text', [
                'label'       => esc_html__( 'Title', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('infusing life into every frame','orbius-core')
            ]);

            $repeater->add_control('desc', [
                'label'       => esc_html__( 'Category', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => 'product photography'
            ]);

            $repeater->add_control('other_info', [
                'label'       => esc_html__( 'Other Info', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => 'new york, 2024'
            ]);

            $repeater->add_control('bg_image', [
                'label'     => esc_html__( 'Background Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'before',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $repeater->add_control('video_slide_on',[
                'label' => esc_html__( 'Video Slide', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'return_value' => 'yes',
            ]);

            $repeater->add_control('mp4_video_url', [
                'label'       => esc_html__( 'MP4 File URL', 'orbius-core' ),
                'label_block' => true,
                'condition'   => ['video_slide_on' => 'yes'],
                'type'        => \Elementor\Controls_Manager::TEXT,
            ]);

            $repeater->add_control('webm_video_url', [
                'label'       => esc_html__( 'WebM File URL', 'orbius-core' ),
                'label_block' => true,
                'condition'   => ['video_slide_on' => 'yes'],
                'type'        => \Elementor\Controls_Manager::TEXT,
            ]);

            $this->add_control('slider_items', [
                'label' => esc_html__( 'Slider Items', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['title_text' => "infusing life into every frame", 'desc' => "product photography", 'other_info' => "new york, 2024 photography",  'link' =>  ['url' => '#'] ],
                ],
                'title_field' => '{{{ title_text }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_items_settings', 'Slider Settings');

        $this->add_responsive_control('sliderheight',[
            'label'       => esc_html__( 'Slider Height', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em', 'vh' ],
            'default'     => ['unit' => 'vh', 'size' => 80, ],
            'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
            'selectors'   => [
                '{{WRAPPER}} .swiper-container' => 'height:{{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('top_spacing',[
            'label'       => esc_html__( 'Top Margin', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em', 'vh' ],
            'range'       => ['px' => ['min' => 0, 'max' => 300, ] ],
            'description' => esc_html__( 'If the slider height is set in "vh", utilize top margin adjustment for full-screen display optimization.', 'orbius-core' ),
            'selectors'   => [
                '{{WRAPPER}} .swiper-container' => 'height:calc(100vh - {{SIZE}}{{UNIT}});',
            ],
        ]);

        $this->add_control('effect', [
            'label'        => esc_html__( 'Effect', 'orbius-core' ),
            'type'         => \Elementor\Controls_Manager::SELECT,
            'default'      => 'slide',
            'options' => [  'fade' => esc_html__( 'Fade', 'orbius-core' ),
                            'slide' => esc_html__( 'Slide', 'orbius-core' ),
                         ]
        ]);

        $this->add_control('parallax_on',[
            'label'   => esc_html__( 'Parallax Effects', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'condition' => [ 'effect' => 'slide' ],
        ]);

        $this->add_control('arrows_on',[
            'label'   => esc_html__( 'Arrow Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('loop_on',[
            'label'   => esc_html__( 'Continuous Loop', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('mousewheel_on',[
            'label'   => esc_html__( 'Mousewheel Control', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_on',[
            'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('hover_pause_on',[
            'label'   => esc_html__( 'Pause on Hover', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'condition' => ['autoplay_on' => 'yes']
        ]);

        $this->add_control('drag_icon_on',[
            'label'   => esc_html__( 'Hover Drag Icon', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_speed', [
            'label' => esc_html__( 'Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 5000,
            'step' => 100,
            'min' => 100,
            'max' => 15000,
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_nav_style', 'Navigation', true );

            $this->add_control('nav_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#000000',
                'selectors' => [
                    '{{WRAPPER}} .mk-basic-slider .mk-slider-pn' => 'fill: {{VALUE}}; border-color:{{VALUE}}',
                ],
            ]);

            $this->add_responsive_control('nav_horizontal_offset',[
                'label'       => esc_html__( 'Horizontal Offset', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px','%' ],
                'range'       => ['px' => ['min' => -1000, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-basic-slider .mk-slider-prev' => 'right:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-basic-slider .mk-slider-next' => 'left:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_image_style', 'Image', true);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'                  => 'image',
                'label'                 => esc_html__( 'Background Image Size', 'orbius-core' ),
                'default'               => 'full',
            ]);

            $this->add_control('slide_img_animation', [
                'label'        => esc_html__( 'Animation', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'prefix_class' => 'mk-bs-img-',
                'default' => 'none',
                'condition' => [ 'effect' => 'slide','parallax_on!' => 'yes' ],
                'options' => [  'none'       => esc_html__( 'None', 'orbius-core' ),
                                'zoom-in'    => esc_html__( 'Zoom In', 'orbius-core' ),
                                'zoom-out-1' => esc_html__( 'Zoom Out - Style 1', 'orbius-core' ),
                                'zoom-out-2' => esc_html__( 'Zoom Out - Style 2', 'orbius-core' ),
                             ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'otherinfo_style', 'Content', true);

            $this->add_responsive_control('content_height',[
                'label'       => esc_html__( 'Section Height', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', 'vh' ],
                'range'       => ['px' => ['min' => 0, 'max' => 500, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-basic-slider .slide-inner,
                    {{WRAPPER}} .mk-basic-slider .mk-bs-img' => 'height:calc(100% - {{SIZE}}{{UNIT}});',
                    '{{WRAPPER}} .mk-basic-slider .mk-bs-content' => 'height:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-basic-slider .mk-slider-pn' => 'margin-top:calc( ({{SIZE}}{{UNIT}} / 2) * -1);',
                ],
            ]);

            $this->start_controls_tabs( 'tabs_icon_style' );

                $this->start_controls_tab('tab_title', [
                    'label' => esc_html__( 'Title', 'orbius-core' ),
                ]);

                    $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                        'name'     => 'title_typography',
                        'selector' => '{{WRAPPER}} .mk-basic-slider .mk-bs-title,
                        {{WRAPPER}} .mk-basic-slider .mk-bs-title a',
                    ]);

                    $this->add_control( 'title_tag', [
                        'type'       => \Elementor\Controls_Manager::SELECT,
                        'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
                        'options'    => mk_arrays('title_tag'),
                        'default' => 'h4',
                        'selectors' => [
                            '{{WRAPPER}} {{VALUE}}.mk-bs-title' => 'margin:0;',
                        ],
                    ]);

                    $this->add_control('title_color', [
                        'label'     => esc_html__( 'Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-bs-title a,{{WRAPPER}} .mk-bs-title' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('title_hover_color', [
                        'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-bs-title:hover a,{{WRAPPER}} .mk-bs-title:hover' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_responsive_control('title_margin', [
                            'label' => esc_html__( 'Margin', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::DIMENSIONS,
                            'selectors' => [
                                '{{WRAPPER}} .mk-basic-slider .mk-bs-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                        ]
                    );

                $this->end_controls_tab();

                $this->start_controls_tab('tab_category', [
                    'label' => esc_html__( 'Category', 'orbius-core' ),
                ]);

                    $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                        'name'     => 'desc_typography',
                        'selector' => '{{WRAPPER}} .mk-bs-desc',
                    ]);

                    $this->add_control('desc_color', [
                        'label'     => esc_html__( 'Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-bs-desc' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_responsive_control('desc_margin', [
                        'label' => esc_html__( 'Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'selectors' => [
                            '{{WRAPPER}} .mk-basic-slider .mk-bs-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                $this->end_controls_tab();

                $this->start_controls_tab('tab_otherinfo', [
                    'label' => esc_html__( 'Other Info', 'orbius-core' ),
                ]);

                    $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                        'name'     => 'otherinfo_typography',
                        'selector' => '{{WRAPPER}} .mk-bs-otherinfo',
                    ]);

                    $this->add_control('otherinfo_color', [
                        'label'     => esc_html__( 'Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-bs-otherinfo' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_responsive_control('otherinfo_margin', [
                        'label' => esc_html__( 'Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'selectors' => [
                            '{{WRAPPER}} .mk-basic-slider .mk-bs-otherinfo' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                $this->end_controls_tab();

            $this->end_controls_tabs();

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none' );
            mk_elem_hide_ctrl($this, 'desc_responsive_hide', 'Hide Category At', 'none' );
            mk_elem_hide_ctrl($this, 'otherinfo_responsive_hide', 'Hide Other Info At', 'none' );
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrows Navigation At', 'none' );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $sliderSettings = array(
            'direction'         => 'horizontal',
            'parallax'          => $settings['parallax_on'],
            'effect'            => $settings['effect'],
            'arrows_on'         => $settings['arrows_on'],
            'dots'              => 'no',
            'autoplay'          => $settings['autoplay_on'],
            'autoplay_speed'    => $settings['autoplay_speed'],
            'speed'             => 1000,
            'mousewheel'        => $settings['mousewheel_on'],
            'loop'              => $settings['loop_on'],
            'pause_on_hover'    => $settings['hover_pause_on'],
            'slides_to_show'    => 1,
            'slider_next'       => '.swiper-' . $this->get_id() . '-next',
            'slider_prev'       => '.swiper-' . $this->get_id() . '-prev',
            'slider_pagination' => '.swiper-' . $this->get_id() . '-dot',
            'video'             => 'yes'
        );

        $slider_classes = [ 'swiper', 'swiper-container','mk-basic-slider' ];
        $slider_classes[] .= ( 'yes' === $settings['drag_icon_on'] ) ? ' mk--drag-cursor' : '';

        $this->add_render_attribute( [
            'slider-attrs'  => [
                'class'          => $slider_classes,
                'data-settings'  => json_encode( $sliderSettings ),
                'id'             => 'swiper-' . $this->get_id()
            ]
        ] );

        $slideHTML = $parallax_data = '';

        if ('yes' === $settings['parallax_on']) {
            $parallax_data = ' data-swiper-parallax-x="50%"';
        }

        $i = 1;

        foreach ( $settings['slider_items'] as $index => $item ) :

            $other_info = $imgUrl = $category = $bg_image = $link_start = $link_end = $title = $video = $mp4Video = $webmVideo = '';

            // video
            if ( 'yes' == $item['video_slide_on'] ) {
                $video .= '<video muted autoplay loop playsinline>';

                if ( !empty($item['mp4_video_url']) ) {
                    $video .= '<source src="'.$item['mp4_video_url'].'" type="video/mp4">';
                }

                if ( !empty($item['webm_video_url']) ) {
                    $video .= '<source src="'.$item['webm_video_url'].'" type="video/webm">';
                }

                $video .= '</video>';
            }

            // image
            $imgUrl .= \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['bg_image']['id'], 'image', $settings );

            // link
            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';
            }

            if ('' != $imgUrl) {
                $bg_image .= '<div class="mk-bs-img"' . $parallax_data . ' style="background-image:url(' . $imgUrl . ');">' . $link_start . $link_end . '</div>';
            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            // title
            if ( ! empty( $item['title_text'] ) ) {
                $title .= '<'.$titleTagSelector.' class="mk-bs-title swm-hide-'. $settings['title_responsive_hide'] .'">' . $link_start . $item['title_text'] . $link_end . '</'.$titleTagSelector . '>';
            }

            // desc
            $category .= ( !empty( $item['desc'] ) ) ? '<div class="mk-bs-desc swm-hide-'. $settings['desc_responsive_hide'] .'">' . $item['desc'] . '</div>' : '';

            // otherinfo
            $other_info .= ( !empty( $item['other_info'] ) ) ? '<div class="mk-bs-otherinfo swm-hide-'. $settings['otherinfo_responsive_hide'] .'">' . $item['other_info'] . '</div>' : '';

            $slideHTML .= '<div class="mk-swiper-item swiper-slide">
                                <div class="slide-inner">
                                    ' . $bg_image . $video . '
                                </div>
                                <div class="mk-bs-content">' . $category . $title . $other_info . '</div>
                            </div>';

            $i++;
        endforeach;

        $navigation = '';

        if ( 'yes' === $settings['arrows_on'] ) {

            $arrowNext = $arrowPrev = '';

            if ('yes' === $settings['arrows_on']) {

                $arrowPrev = '<div class="mk-slider-pn mk-slider-prev swiper-' . $this->get_id() . '-prev swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>';

                $arrowNext = '<div class="mk-slider-pn mk-slider-next swiper-' . $this->get_id() . '-next swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>';
            }

            $navigation .= $arrowPrev . $arrowNext;
        }

        echo '<div ' . $this->get_render_attribute_string( 'slider-attrs' ) . '>
                    <div class="swiper-wrapper">
                        ' . $slideHTML . '
                    </div>
                    ' . $navigation . '
            </div>';

    }

}