<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Blog_Posts extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_blog_posts'; }
    public function get_title()          { return esc_html__( 'Blog Posts', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-gallery-grid'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'post grid', 'grid', 'post','blog','posts','posts grid','posts list' ]; }
    public function get_style_depends()  { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-gsap','mk-scroll-trigger','mk-modernizr','isotope','packery','mk-widgets' ]; }
    public function is_reload_preview_required() { return true; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'posts_content', 'Post Settings');

            $this->add_control( 'display_style', [
                'label' => esc_html__( 'Display Style', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'st1'       => esc_html__( 'Style 1', 'orbius-core' ),
                    'st2' => esc_html__( 'Style 2', 'orbius-core' ),
                ],
                'default' => 'st1'
            ]);

            $this->add_responsive_control('columns', [
                'label'              => esc_html__( 'Columns', 'orbius-core' ),
                'type'               => \Elementor\Controls_Manager::SELECT,
                'default'            => '3',
                'tablet_default'     => '2',
                'mobile_default'     => '1',
                'prefix_class'       => 'elementor-grid%s-',
                'frontend_available' => true,
                'options'            => mk_arrays('column4')
            ]);

            $this->add_control('masonry_on',[
                'label'   => esc_html__( 'Masonry', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => [ 'columns!' => '1' ]
            ]);

            $this->add_control('parallax_on',[
                'label'   => esc_html__( 'Parallax Scroll Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('posts_per_page', [
                'label' => esc_html__( 'Posts Per Page', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 6,
                'step' => 1,
                'min' => 1,
                'max' => 1000,
            ]);

            $this->add_control('orderby', [
                'label'   => esc_html__( 'Order by', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'date',
                'options' => mk_arrays('orderby')
            ]);

            $this->add_control('order', [
                'label'   => esc_html__( 'Order', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'DESC',
                'options' => mk_arrays('order')
            ]);

            $this->add_control('include_posts_cat',[
                'label'    => esc_html__( 'Include Categories', 'orbius-core' ),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => mk_get_categories('category')
            ]);

            $this->add_control('exclude_posts_cat',[
                'label'    => esc_html__( 'Exclude Categories', 'orbius-core' ),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => mk_get_categories('category')
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'item_style', 'Items');

            $this->add_responsive_control('column_gap', [
                'label'     => esc_html__( 'Columns Gap', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => ['size' => 30, ],
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-grid-item-wrap' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
                    '{{WRAPPER}} .mk-grid-inner' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
                ],
            ]);

            $this->add_responsive_control('row_gap', [
                'label'     => esc_html__( 'Rows Gap', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 70,
                ],
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-grid-item-wrap' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_responsive_control('blog_item_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .mk-post-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'     => 'item_border',
                'label'    => esc_html__( 'Border', 'orbius-core' ),
                'selector' => '{{WRAPPER}} .mk-post-wrap',
            ]);

            $this->add_responsive_control('item_radius', [
                'label' => esc_html__( 'Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-post-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('item_bg', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-post-wrap' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
                'name'      => 'item_shadow',
                'selector'  => '{{WRAPPER}} .mk-post-wrap',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'image_style', 'Image');

            $this->add_control('show_image',[
                'label'   => esc_html__( 'Show Post Image', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('image_hover_zoom',[
                'label'   => esc_html__( 'Hover Image Zoom Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => [ 'parallax_on!' => 'yes' ],
                'prefix_class' => 'mk-post-image-zoom-',
            ]);

            $this->add_control( 'appear_delay', [
                'label' => esc_html__( 'Appear Delay', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    ''       => esc_html__( 'Default', 'orbius-core' ),
                    'random' => esc_html__( 'Random', 'orbius-core' ),
                    'ms'     => esc_html__( 'Set ms', 'orbius-core' ),
                ],
                'condition' => ['appear_animation!' => '']
            ]);

            $this->add_control('appear_delay_in_ms', [
                'label' => esc_html__( 'Set Appear Delay', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 100,
                'step' => 5,
                'min' => 100,
                'max' => 9999,
                'condition' => ['appear_animation!' => '','appear_delay' => 'ms']
            ]);

            $this->add_responsive_control('image_radius', [
                    'label' => esc_html__( 'Radius', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'condition' => [
                                    'show_image' => 'yes',
                                    ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-post-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'      => 'post_img',
                'separator'  => 'before',
                'default'   => 'full',
                'condition'  => [ 'masonry_on!' => 'yes', 'show_image' => 'yes'],
            ]);

            $this->add_responsive_control('image_space', [
                'label'     => esc_html__( 'Space', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-post-image' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'content_style', 'Content');

            $this->add_control('content_bg', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-post-content' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'content_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-post-content',
            ]);

            $this->add_responsive_control('content_radius', [
                'label' => esc_html__( 'Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-post-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('content_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .mk-post-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'metas_style', 'Metas');

            $this->add_control('show_metas',[
                'label'   => esc_html__( 'Show Meta Section', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('show_date',[
                'label'   => esc_html__( 'Show Date', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition' => ['show_metas' => 'yes']
            ]);

            $this->add_control('show_author',[
                'label'   => esc_html__( 'Show Author Name', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => ['show_metas' => 'yes']
            ]);

            $this->add_control('show_comment_count',[
                'label'   => esc_html__( 'Show Comment Count', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => ['show_metas' => 'yes']
            ]);

            $this->add_control('show_category',[
                'label'   => esc_html__( 'Show Category', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition' => ['show_metas' => 'yes']
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(),[
                'name' => 'metas_typography',
                'selector' => '{{WRAPPER}} .mk-post-meta, {{WRAPPER}} .mk-post-meta span, {{WRAPPER}} .mk-post-meta a',
            ]);

            $this->add_control('meta_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-post-meta,{{WRAPPER}} .mk-post-meta a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('meta_space', [
                'label'     => esc_html__( 'Space', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-post-meta' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styling', 'Title');

            $this->add_control( 'title_tag', [
                'type'      => \Elementor\Controls_Manager::SELECT,
                'label'     => esc_html__( 'Title Tag', 'orbius-core' ),
                'options'   => mk_arrays('title_tag'),
                'default'   => 'h3',
                'separator' => 'before',
            ]);

            $this->add_control('title_length', [
                'label' => esc_html__( 'Title Text Length', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 100,
                'step' => 1,
                'min' => 1,
                'max' => 3000,
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-post-content .mk_post_title,{{WRAPPER}} .mk-post-content .mk_post_title a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color',[
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-post-content .mk_post_title a:hover' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('content_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%','em' ],
                'selectors'  => [
                    '{{WRAPPER}} .mk_post_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-post-content .mk_post_title',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'excerpt_styling', 'Excerpt');

            $this->add_control('show_excerpt',[
                'label'   => esc_html__( 'Show Excerpt', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('excerpt_length', [
                'label' => esc_html__( 'Excerpt Text Length', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 107,
                'step' => 1,
                'min' => 1,
                'max' => 1000,
                'condition' => ['show_excerpt' => 'yes'],
                'separator' => 'after',
            ]);

            $this->add_control('excerpt_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['show_excerpt' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-post-content .mk_post_excerpt' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'           => 'excerpt_typography',
                'condition' => ['show_excerpt' => 'yes'],
                'selector' => '{{WRAPPER}} .mk-post-content .mk_post_excerpt',
            ]);

            $this->add_responsive_control('excerpt_space', [
                'label'     => esc_html__( 'Space', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'condition' => ['show_excerpt' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk_post_excerpt' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'button_styling', 'Button', false );

            $this->add_control('button_text', [
                'label'   => esc_html__( 'Button Text', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Read More', 'orbius-core' ),
                'separator' => 'before',
            ]);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'           => 'button_typography',
                'selector' => '{{WRAPPER}} .mk-post-button a',
            ]);

            $this->add_control('button_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-post-button a .mk-post-button-text,
                    {{WRAPPER}} .mk-post-button:hover a .mk-post-button-text' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mk-post-button a,
                    {{WRAPPER}} .mk-post-button-arrow-start,
                    {{WRAPPER}} .mk-post-button-arrow-end' => 'border-color: {{VALUE}};',
                    '{{WRAPPER}} .mk-post-button-arrow-start:after,
                    {{WRAPPER}} .mk-post-button-arrow-end:after' => 'background: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        // Filter Styles
        mk_posts_filter_styles($this,false);

        // Pagination Styles
        mk_posts_pagination_styles($this,false);

    }

    public function get_holder_classes( $atts ) {

        $holder_classes   = array();
        $holder_classes[] = 'mk-p-grid';

        if ( isset($atts['parallax_on']) && '' !== $atts['parallax_on'] ) {
            $holder_classes[] = $atts['parallax_on'];
        }

        if ( isset($atts['enable_filter']) && 'yes' === $atts['enable_filter'] ) {
            $holder_classes[] = 'mk-filter--on';
        }

        if ( isset($atts['masonry_on']) && 'yes' === $atts['masonry_on'] ) {
            $holder_classes[] = 'mk-p-masonry-on';
        }

        if ( ! empty( $atts['pagination_type'] ) ) {
            if ( 'no-pagination' === $atts['pagination_type'] ) {
                $holder_classes[] = 'mk--no-bottom-space';
                $holder_classes[] = 'mk-pagination--off';
            } else {
                $holder_classes[] = 'mk-pagination--on';
                $holder_classes[] = 'mk-pagination-type--' . $atts['pagination_type'];
            }
        }

        $holder_classes = implode( ' ', $holder_classes );

        return $holder_classes;
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $atts = array();

        $atts['parallax_on'] = '';

        if ( isset($settings['parallax_on']) && 'yes' === $settings['parallax_on'] ) {
            $atts['parallax_on'] = 'mk-parallax-scroll-on';
        }

        $atts['masonry_on'] = $settings['masonry_on'];

        if ( '' !== $settings['enable_filter'] ) {
            $atts['enable_filter']   = $settings['enable_filter'];
            $atts['filter_all_text'] = $settings['filter_all_text'];
        }

        if ( '' !== $settings['button_text'] )   { $atts['button_text']   = $settings['button_text']; }

        $atts['pagination_type'] = !empty($settings['pagination_type']) ? $settings['pagination_type'] : 'no-pagination';
        $atts['loadmore_button_text'] = ( isset($settings['loadmore_button_text']) && '' !== $settings['loadmore_button_text'] ) ? $settings['loadmore_button_text'] : '';

        // content
        $atts['title_tag']      = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h3';
        $atts['title_length']   = $settings['title_length'];

        if ( 'yes' === $settings['show_excerpt'] ) {
            $atts['show_excerpt']   = $settings['show_excerpt'];
            $atts['excerpt_length'] = $settings['excerpt_length'];
        }

        // post meta
        if ( 'yes' === $settings['show_metas'] ) :
            $atts['show_metas'] = $settings['show_metas'];

            if ( 'yes' === $settings['show_date'] )          { $atts['show_date']          = $settings['show_date']; }
            if ( 'yes' === $settings['show_author'] )        { $atts['show_author']        = $settings['show_author']; }
            if ( 'yes' === $settings['show_comment_count'] ) { $atts['show_comment_count'] = $settings['show_comment_count']; }
            if ( 'yes' === $settings['show_category'] )      { $atts['show_category']      = $settings['show_category']; }

        endif;

        // image
        if ( 'yes' === $settings['show_image'] ) {
            $atts['show_image']                = $settings['show_image'];
            $atts['post_img_size']             = $settings['post_img_size'];
            $atts['post_img_custom_dimension'] = $settings['post_img_custom_dimension'];
        }

        // appear delay
        $atts['appear_animation'] = ( isset($settings['appear_animation']) && '' !== $settings['appear_animation'] ) ? $settings['appear_animation'] : '';
        $appear_animation = '';
        if ('' != $atts['appear_animation']) {
            if ( 'ms' === $settings['appear_delay'] && $settings['appear_delay_in_ms'] >= 0 ) {
                $appear_animation = ' data-appear-delay="'.$settings['appear_delay_in_ms'].'"';
            } elseif ( 'random' === $settings['appear_delay'] ) {
                $appear_animation = ' data-appear-delay="'.$settings['appear_delay'].'"';
            }
        }
        $atts['appear_delay'] = $appear_animation;
        $atts['display_style'] = $settings['display_style'];

        // query
        $atts['post_type']             = 'post';
        $atts['taxonomy_filter']       = 'category'; // tax_query [taxonomy => 'xxx']
        $atts['orderby']               = !empty($settings['orderby']) ? $settings['orderby'] : 'date';
        $atts['order']                 = !empty($settings['order']) ? $settings['order'] : 'DESC';
        $atts['posts_per_page']        = $settings['posts_per_page'];
        $atts['include_posts_cat']     = $settings['include_posts_cat'];
        $atts['exclude_posts_cat']     = $settings['exclude_posts_cat'];
        $atts['additional_query_args'] = array();

        $atts['holder_classes']        = $this->get_holder_classes($atts); //$holder_classes;
        $atts['query_result']          = new \WP_Query( mk_get_query_params( $atts ) );
        $atts['data_attr']             = mk_get_pagination_data( 'post', $atts );
        $atts['this_shortcode']        = $this;

        mk_list_sc_template_part( 'grid/post-main.php', $atts, true );

        if ( \Elementor\Plugin::instance()->editor->is_edit_mode() && 'yes' === $settings['masonry_on'] ) {
            $this->render_editor_script();
        }
    }

    protected function render_editor_script() { ?>
        <script type="text/javascript">
        (function ($) {
            "use strict";
            $(document).ready(function() {

                $('body').find('.mk-p-grid').each(function () {
                    var $this = $(this);
                    $this.find('.mk-grid-item').resize( function() {
                        mk.mkMasonryLayout.reInit();
                    });
                });

            });
        })(jQuery);
        </script>
            <?php
    }

}