<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
class Mk_Button extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_button'; }
	public function get_title()          { return esc_html__( 'Button', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-button'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'theme','buttons', 'buttons', 'link','icon']; }
	public function get_style_depends()  { return ['mk-core-main']; }

	protected function register_controls() {

		mk_elem_start_ctrl($this, 'section_buttons', 'Button');

			$this->add_control('button_text', [
				'label'       => esc_html__( 'Text', 'orbius-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => esc_html__( 'Click Me', 'orbius-core' ),
			]);

			$this->add_control('button_link', [
				'label'    => esc_html__( 'Link', 'orbius-core' ),
				'type'     => \Elementor\Controls_Manager::URL,
				'default'  => [
					'url'         => '#',
					'is_external' => '',
				],
			]);

			$this->add_control('button_icon', [
				'label' => esc_html__( 'Icon', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
			]);

			$this->add_control('icon_align', [
				'label'     => esc_html__( 'Icon Position', 'orbius-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'default'   => 'left',
                'prefix_class' => 'mk-button-align-',
				'options'   => [
					'left'  => esc_html__( 'Before', 'orbius-core' ),
					'right' => esc_html__( 'After', 'orbius-core' ),
				],
			]);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'general_colors', 'Styling', true);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'btn_text_typography',
                'selector' => '{{WRAPPER}} a.mk-button',
            ]);

            $this->add_responsive_control('padding', [
               'label'      => esc_html__( 'Padding', 'orbius-core' ),
               'type'       => \Elementor\Controls_Manager::DIMENSIONS,
               'size_units' => [ 'px', 'em', '%' ],
               'selectors'  => [
                   '{{WRAPPER}} a.mk-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
               ],
            ]);

            $this->add_responsive_control('icon_indent', [
                    'label'     => esc_html__( 'Icon Spacing', 'orbius-core' ),
                    'type'      => \Elementor\Controls_Manager::SLIDER,
                    'range'     => [
                        'px' => ['max' => 100, ], ],
                    'selectors' => [
                        '{{WRAPPER}}.mk-button-align-right a.mk-button .mk-button-icon' => 'margin-left: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}}.mk-button-align-left a.mk-button .mk-button-icon' => 'margin-right: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control('icon_size', [
                'label'      => esc_html__( 'Icon Size', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => ['min'  => 1, 'max'  => 200, 'step' => 1 ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-button .mk-button-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-button .mk-button-icon svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('rotate_icon_style', [
                'label'      => esc_html__( 'Rotate Icon', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => ['min'  => 0, 'max'  => 360, 'step' => 1 ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-button .mk-button-icon i,
                     {{WRAPPER}} .mk-button .mk-button-icon svg' => 'transform: rotate({{SIZE}}deg);',
                ],
            ]);

			$this->start_controls_tabs( '_button_style' );

				$this->start_controls_tab('_button_normal', [
					'label' => esc_html__( 'Normal', 'orbius-core' ),
				]);

					$this->add_control('all_text_color', [
						'label'     => esc_html__( 'Text Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '',
						'selectors' => [
							'{{WRAPPER}} a.mk-button' => 'color: {{VALUE}};',
							'{{WRAPPER}} a.mk-button svg' => 'fill: {{VALUE}};',
						],
					]);

					$this->add_control('all_background_color', [
						'label'     => esc_html__( 'Background Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} a.mk-button' => 'background-color: {{VALUE}};',
						],
					]);

                    $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                        'name'        => 'all_border',
                        'label'       => esc_html__( 'Border', 'orbius-core' ),
                        'selector'    => '{{WRAPPER}} a.mk-button',
                    ]);

					$this->add_control('all_border_radius', [
						'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
						'type'       => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', '%' ],
						'selectors'  => [
							'{{WRAPPER}} a.mk-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]);

					$this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
						'name'     => 'all_button_box_shadow',
						'selector' => '{{WRAPPER}} a.mk-button',
					]);

				$this->end_controls_tab();

				$this->start_controls_tab('all_button_hover', [
                    'label' => esc_html__( 'Hover', 'orbius-core' ),
                ] );

					$this->add_control('all_hover_color', [
						'label'     => esc_html__( 'Text Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} a.mk-button:hover' => 'color: {{VALUE}};',
							'{{WRAPPER}} a.mk-button:hover svg' => 'fill: {{VALUE}};',
						],
					]);

					$this->add_control('all_background_hover_color', [
						'label'     => esc_html__( 'Background Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} a.mk-button:hover' => 'background-color: {{VALUE}};',
						],
					]);

					$this->add_control('all_border_hover_color', [
						'label'     => esc_html__( 'Border Hover Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '',
						'selectors' => [
							'{{WRAPPER}} a.mk-button:hover' => 'border-color: {{VALUE}};',
						],
					]);

					$this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
						'name'      => 'all_button_hover_box_shadow',
						'selector'  => '{{WRAPPER}} a.mk-button:hover',
					]);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

	}

	protected function render() {

		 $settings = $this->get_settings_for_display();

         $button_link = '';

         if (!empty($settings['button_link']['url'])) {

            $button_link .= $settings['button_link']['url'];

            if ( $settings['button_link']['is_external'] ) {
                $this->add_render_attribute( 'btn_link', 'target', '_blank' );
            }

            if ( $settings['button_link']['nofollow'] ) {
                $this->add_render_attribute( 'btn_link', 'rel', 'nofollow' );
            }

         }

         $buttonText = ( !empty( $settings['button_text'] ) ) ? '<span class="mk-button-text">' . $settings['button_text'] . '</span>' : '';
         $buttonIcon = mk_get_elementor_icons($settings['button_icon']);
         $buttonIcon = ( !empty( $buttonIcon ) ) ? '<span class="mk-button-icon">' . $buttonIcon . '</span>' : '';

        echo '<a class="mk-button" href="' . $button_link . '" ' . $this->get_render_attribute_string('btn_link') . '>' . $buttonIcon . $buttonText . '</a>';

	}

}