<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Carousel_Slider extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_carousel_slider'; }
    public function get_title()          { return esc_html__( 'Carousel Slider', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return [ 'mk-sliders-elements' ]; }
    public function get_keywords()       { return [ 'theme','slider','slide show' ]; }
    public function get_style_depends()  { return [ 'swiper','mk-core-main' ]; }
    public function get_script_depends() { return [ 'swiper','mk-widgets' ]; }
    public function is_reload_preview_required() { return true; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_heading', 'Slider Items');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title_text', [
                'label'       => esc_html__( 'Title', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('Title','orbius-core')
            ]);

            $repeater->add_control('subtitle_text', [
                'label'       => esc_html__( 'Sub Title', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('Subtitle','orbius-core')
            ]);

            $repeater->add_control('bg_image', [
                'label'     => esc_html__( 'Background Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $repeater->add_control('slide_display_size', [
                'label'        => esc_html__( 'Slide Display Style', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'      => 'default',
                'separator'    => 'after',
                'description'  => esc_html__( 'Use this option for Slider Display style 3', 'orbius-core' ),
                'prefix_class' => 'mk-carousel-slider-img-style-',
                'options' => [  'default' => esc_html__( 'Default', 'orbius-core' ),
                                'wide' => esc_html__( 'Wide', 'orbius-core' ),
                             ]
            ]);

            $repeater->add_control('video_slide_on',[
                'label'   => esc_html__( 'Video Slide', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $repeater->add_control('mp4_video_url', [
                'label'       => esc_html__( 'MP4 - Video URL', 'orbius-core' ),
                'label_block' => true,
                'condition'   => ['video_slide_on' => 'yes'],
                'type'        => \Elementor\Controls_Manager::TEXT,
            ]);

            $repeater->add_control('webm_video_url', [
                'label'       => esc_html__( 'WebM File URL', 'orbius-core' ),
                'label_block' => true,
                'condition'   => ['video_slide_on' => 'yes'],
                'type'        => \Elementor\Controls_Manager::TEXT,
            ]);

            $this->add_control('slider_items', [
                'label' => esc_html__( 'Slider Items', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['title_text' => "Title", 'subtitle_text' => "Sub Title", 'link' => '#' ],
                    ['title_text' => "Title", 'subtitle_text' => "Sub Title", 'link' => '#' ],
                    ['title_text' => "Title", 'subtitle_text' => "Sub Title", 'link' => '#' ],
                ],
                'title_field' => '{{{ title_text }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_items_settings', 'Slider Settings');

        $this->add_control('arrows_on',[
            'label'   => esc_html__( 'Arrow Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('dots_on',[
            'label'   => esc_html__( 'Dots Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('loop_on',[
            'label'   => esc_html__( 'Continuous Loop', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('mousewheel_on',[
            'label'   => esc_html__( 'Mousewheel Control', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_on',[
            'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('hover_pause_on',[
            'label'   => esc_html__( 'Pause on Hover', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'condition' => ['autoplay_on' => 'yes']
        ]);

        $this->add_control('drag_icon_on',[
            'label'   => esc_html__( 'Hover Drag Icon', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_speed', [
            'label' => esc_html__( 'Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 5000,
            'step' => 100,
            'min' => 100,
            'max' => 15000,
        ]);

        $this->add_control('speed', [
            'label' => esc_html__( 'Animation Speed', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 1000,
            'step' => 100,
            'min' => 100,
            'max' => 5000,
        ]);

        $this->add_responsive_control('sliderheight',[
            'label'       => esc_html__( 'Slider Height', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em', 'vh' ],
            'default'     => ['unit' => 'vh', 'size' => 50, ],
            'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
            'separator'  => 'before',
            'selectors'   => [
                '{{WRAPPER}} .mk-carousel-slider-holder' => 'height:{{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_control('slider_display_type', [
            'label'        => esc_html__( 'Display Style', 'orbius-core' ),
            'type'         => \Elementor\Controls_Manager::SELECT,
            'default'      => 'st1',
            'description'  => esc_html__( 'Click on the "Apply" button after changing the Display Style.', 'orbius-core' ),
            'prefix_class' => 'mk-carousel-slider-',
            'options' => [  'st1' => esc_html__( 'Style 1', 'orbius-core' ),
                            'st2' => esc_html__( 'Style 2', 'orbius-core' ),
                            'st3' => esc_html__( 'Style 3', 'orbius-core' ),
                         ]
        ]);

        $slides_per_view = range( 1, 10 );
        $slides_per_view = array_combine( $slides_per_view, $slides_per_view );

        $this->add_responsive_control('slides_per_view',[
            'type'                  => \Elementor\Controls_Manager::SELECT,
            'label'                 => esc_html__( 'Slides Per View', 'orbius-core' ),
            'options'               => $slides_per_view,
            'default'               => '3',
            'tablet_default'        => '2',
            'mobile_default'        => '1',
            'condition'             => ['slider_display_type' => 'st1'],
            'frontend_available'    => true,
        ]);

        $this->add_control('slide_space', [
            'label' => esc_html__( 'Slide Space', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 0,
            'step' => 1,
            'min' => 0,
            'max' => 1000,
            'condition' => ['slider_display_type' => 'st1'],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_slider_style', 'Slider Holder', true);

            $this->add_control('slider_background', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-carousel-slider' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_control('slider_overlay', [
                'label'     => esc_html__( 'Overlay Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-carousel-slider-overlay' => 'background: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_nav_style', 'Navigation', true );

            $this->add_control('dots_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#000000',
                'selectors' => [
                    '{{WRAPPER}} .mk-carousel-slider .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-color: {{VALUE}};',
                '{{WRAPPER}} .mk-carousel-slider .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active,
                {{WRAPPER}}  .mk-carousel-slider .swiper-pagination-bullets .swiper-pagination-bullet:hover,
                {{WRAPPER}}  .mk-carousel-slider .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color: {{VALUE}};',
                '{{WRAPPER}} .mk-carousel-slider .mk-slider-pn' => 'fill: {{VALUE}};border-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();


        mk_elem_start_ctrl($this, 'section_image_style', 'Image', true);

        $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
            'name'                  => 'slider_image_size',
            'label'                 => esc_html__( 'Background Image Size', 'orbius-core' ),
            'default'               => 'full',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_content_style', 'Content Section', true);

            $this->add_control('content_location', [
                'label'        => esc_html__( 'Content Location', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'      => 'center',
                'prefix_class' => 'mk-carousel-slider-content-',
                'options' => [  'top' => esc_html__( 'Top', 'orbius-core' ),
                                'center' => esc_html__( 'Center', 'orbius-core' ),
                                'bottom' => esc_html__( 'Bottom', 'orbius-core' ),
                             ]
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'content_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-carousel-slider-content',
            ]);

            $this->add_responsive_control('content_border_radius', [
                'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-carousel-slider-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('content_padding', [
                    'label' => esc_html__( 'Padding', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-carousel-slider-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control('content_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-carousel-slider-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_control('content_background', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-carousel-slider-content' => 'background-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_style', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-carousel-slider-title',
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-carousel-slider-title' => 'margin:0;',
                ],
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-carousel-slider-title a,{{WRAPPER}} .mk-carousel-slider-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-carousel-slider-title:hover a,{{WRAPPER}} .mk-carousel-slider-title:hover' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mk-carousel-slider-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'subtitle_style', 'Sub Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .mk-carousel-slider-subtitle',
            ]);

            $this->add_control('subtitle_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-carousel-slider-subtitle' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('subtitle_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mk-carousel-slider-subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none' );
            mk_elem_hide_ctrl($this, 'subtitle_responsive_hide', 'Hide Subtitle At', 'none' );
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrows Navigation At', 'mobile' );
            mk_elem_hide_ctrl($this, 'dots_responsive_hide', 'Hide Dot Navigation At', 'mobile' );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $centered_slides = 'yes';
        $slides_to_show = 'auto';
        $slides_to_show_tablet = 1;
        $slides_to_show_mobile = 1;
        $slideSpace = 0;

        switch ( $settings['slider_display_type'] ) {
            case 'st1':
                $slideSpace = apply_filters('carsousel_slider_style_one_space', 0);
                $centered_slides = 'no';
                $slideSpace = $settings['slide_space'];

                $slides_to_show = ( $settings['slides_per_view'] !== '' ) ? absint( $settings['slides_per_view'] ) : 'auto';
                $slides_to_show_tablet = ( $settings['slides_per_view_tablet'] !== '' ) ? absint( $settings['slides_per_view_tablet'] ) : 2;
                $slides_to_show_mobile = ( $settings['slides_per_view_mobile'] !== '' ) ? absint( $settings['slides_per_view_mobile'] ) : 1;

                break;
            case 'st2':
                $slideSpace = apply_filters('carsousel_slider_style_two_space', 200);
                $centered_slides = 'yes';
                break;
            case 'st3':
                $slideSpace = apply_filters('carsousel_slider_style_four_space', 20);
                $centered_slides = 'yes';
                break;
        }

        $sliderSettings = array(
            'direction'             => 'horizontal',
            'parallax'              => 'no',
            'effect'                => 'slide',
            'arrows_on'             => $settings['arrows_on'],
            'dots'                  => $settings['dots_on'],
            'autoplay'              => $settings['autoplay_on'],
            'autoplay_speed'        => $settings['autoplay_speed'],
            'speed'                 => $settings['speed'],
            'mousewheel'            => $settings['mousewheel_on'],
            'loop'                  => $settings['loop_on'],
            'pause_on_hover'        => $settings['hover_pause_on'],
            'slides_to_show'        => $slides_to_show,
            'slides_to_show_tablet' => $slides_to_show_tablet,
            'slides_to_show_mobile' => $slides_to_show_mobile,
            'slider_next'           => '.swiper-' . $this->get_id() . '-next',
            'slider_prev'           => '.swiper-' . $this->get_id() . '-prev',
            'slider_pagination'     => '.swiper-pagination-' . $this->get_id(),
            'centered_slides'       => $centered_slides,
            'video'                 => 'yes',
            'image_spacing'         => array(
                                            'unit' => 'px',
                                            'size' => $slideSpace,
                                            'sizes' => []
                                        ),
        );

        $this->add_render_attribute( [
            'slider-attrs'  => [
                'class'          => [ 'swiper', 'swiper-container','mk-carousel-slider' ],
                'data-settings'  => json_encode( $sliderSettings ),
                'id'             => 'swiper-' .$this->get_id()
            ]
        ] );

        $sliderNavigation = $slideHTML = '';
        $i = 1;

        foreach ( $settings['slider_items'] as $index => $item ) :

            $bg_image = $link_start = $link_end = $title = $video = '';

            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start = '<a ' . $this->get_render_attribute_string( $link_key ) . '">';
            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            if ( ! empty( $item['title_text'] ) ) {
                $title = '<'.$titleTagSelector.' class="mk-carousel-slider-title swm-hide-'. $settings['title_responsive_hide'] .'">' . $link_start . $item['title_text'] . $link_end . '</'.$titleTagSelector . '>';
            }

            $subtitle = ( ! empty( $item['subtitle_text'] ) ) ? '<div class="mk-carousel-slider-subtitle swm-hide-'. $settings['subtitle_responsive_hide'] .'">' . $item['subtitle_text'] . '</div>' : '';

            if (  $settings['slider_image_size_size'] == 'custom' ) {
                $imageTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $item['bg_image'], $item['bg_image']['id'], 'slider_image_size', 'slider_img-'.$i).' />';
            } else {
                $imageTagHtml = wp_get_attachment_image( $item['bg_image']['id'], $settings['slider_image_size_size']);
            }
            $bg_image .= '<div class="mk-carousel-slider-img-holder"><div class="mk-carousel-slider-img">'.$imageTagHtml.'</div></div>';

            if ( 'yes' == $item['video_slide_on'] ) {
                $video .= '<video muted autoplay loop playsinline>';

                if ( !empty($item['mp4_video_url']) ) {
                    $video .= '<source src="'.$item['mp4_video_url'].'" type="video/mp4">';
                }

                if ( !empty($item['webm_video_url']) ) {
                    $video .= '<source src="'.$item['webm_video_url'].'" type="video/webm">';
                }

                $video .= '</video>';
            }
            $slideHTML .= '<div class="mk-swiper-item swiper-slide size-' . $item['slide_display_size'] . '">
                    <div class="mk-carousel-slider-overlay"></div>
                        ' . $bg_image . $video . '
                        <div class="mk-carousel-slider-content-wrap">
                            <div class="mk-carousel-slider-content">
                            ' . $title . $subtitle . '
                            </div>
                        </div>
                </div>';

            $i++;
        endforeach;

        $arrowNavigation = '';
        $dots            = ('yes' === $settings['dots_on'])  ? '<div class="swiper-pagination swiper-pagination-' . $this->get_id() . ' swm-hide-'. $settings['dots_responsive_hide'] .'"></div>' : '';

        if ('yes' === $settings['arrows_on']) {

            $arrowNavigation .= '<div class="mk-slider-pn mk-slider-prev swiper-' . $this->get_id() . '-prev swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>
                                <div class="mk-slider-pn mk-slider-next swiper-' . $this->get_id() . '-next swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>';
        }



        $drag_icon = ( 'yes' === $settings['drag_icon_on'] ) ? ' mk--drag-cursor' : '';

        echo '<div class="mk-carousel-slider-holder' . $drag_icon . '">
                <div ' . $this->get_render_attribute_string( 'slider-attrs' ) . '>
                    <div class="swiper-wrapper">
                    ' . $slideHTML . '
                    </div>
                    ' . $arrowNavigation . $dots . '
                </div>
        </div>';

    }

}