<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Cart extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_cart'; }
	public function get_title()      { return esc_html__( 'Cart', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-cart'; }
	public function get_categories() { return ['mk-sections-elements']; }
	public function get_keywords()   { return [ 'theme','cart','store','shop','woocommerce' ]; }
	public function get_style_depends() { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'wc-cart-fragments','mk-widgets' ]; }

	protected function register_controls() {

        mk_elem_start_ctrl($this, 'cart_icon_settings', 'Cart Icon');

        $this->add_control('display_cart_icon', [
            'label'   => esc_html__( 'Display Cart Icon', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'default' => 'all_pages',
            'options' => [  'all_pages' => esc_html__( 'All Pages', 'orbius-core' ),
                            'shop_pages' => esc_html__( 'Shop Pages', 'orbius-core' ),
                         ]
        ]);

        $this->add_control(
            'cart_icon',
            array(
                'label' => esc_html__( 'Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default' => [
                                'value' => 'fas fa-shopping-bag',
                                'library' => 'fa-solid',
                            ],
                'recommended' => array(
                    'fa-solid' => array(
                        'shopping-cart',
                        'shopping-basket',
                        'shopping-bag'
                    ),
                ),
                'file' => '',
            )
        );

        $this->add_responsive_control(
            'cart_icon_size',
            [
                'label' => esc_html__( 'Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 6,
                        'max' => 100
                    ]
                ],
                'default' => [
                    'size' => 20,
                    'unit' => 'px'
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-icon-trigger' => 'font-size: {{SIZE}}{{UNIT}}',
                    '{{WRAPPER}} .mk-cart-icon-trigger svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}}',
                ]
            ]
        );

        $this->add_control(
            'cart_icon_color',
            [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-icon .mk-cart-icon-trigger' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-cart-icon .mk-cart-icon-trigger svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'cart_icon_hover_color',
            [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-icon:hover .mk-cart-icon-trigger' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-cart-icon:hover .mk-cart-icon-trigger svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_padding',
            [
                'label'                 => esc_html__( 'Padding', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'            => [ 'px' ],
                'selectors'             => [
                    '{{WRAPPER}} .mk-cart-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_margin',
            [
                'label'                 => esc_html__( 'Margin', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'            => [ 'px' ],
                'selectors'             => [
                    '{{WRAPPER}} .mk-cart-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'cart_number_settings', 'Number');

            $this->add_control('cart_number',[
                'label'   => esc_html__( 'Number', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

        $this->add_responsive_control(
            'number_top_margin',
            [
                'label' => esc_html__( 'Top Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100
                    ]
                ],
                'default' => [
                    'size' => 10,
                    'unit' => 'px'
                ],
                'condition' => [
                    'cart_number' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-number' => 'top: {{SIZE}}{{UNIT}}',
                ]
            ]
        );

        $this->add_responsive_control(
            'number_left_margin',
            [
                'label' => esc_html__( 'Left Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100
                    ]
                ],
                'default' => [
                    'size' => 10,
                    'unit' => 'px'
                ],
                'condition' => [
                    'cart_number' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-number' => 'left: {{SIZE}}{{UNIT}}',
                ]
            ]
        );

        $this->add_responsive_control(
            'number_circle_size',
            [
                'label' => esc_html__( 'Circle Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 6,
                        'max' => 100
                    ]
                ],
                'default' => [
                    'size' => 16,
                    'unit' => 'px'
                ],
                'condition' => [
                    'cart_number' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-number' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
                ]
            ]
        );

        $this->add_responsive_control(
            'number_font-size',
            [
                'label' => esc_html__( 'Font Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 5,
                        'max' => 100
                    ]
                ],
                'default' => [
                    'size' => 12,
                    'unit' => 'px'
                ],
                'condition' => [
                    'cart_number' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-number' => 'font-size: {{SIZE}}{{UNIT}}',
                ]
            ]
        );

        $this->add_control('number_font_weight', [
            'label'        => esc_html__( 'Font Weight', 'orbius-core' ),
            'type'         => \Elementor\Controls_Manager::SELECT,
            'default'      => '400',
            'prefix_class' => 'mk-bg-switcher-',
            'options' => [  '100' => esc_html__( '100', 'orbius-core' ),
                            '200' => esc_html__( '200', 'orbius-core' ),
                            '300' => esc_html__( '300', 'orbius-core' ),
                            '400' => esc_html__( '400', 'orbius-core' ),
                            '500' => esc_html__( '500', 'orbius-core' ),
                            '600' => esc_html__( '600', 'orbius-core' ),
                            '700' => esc_html__( '700', 'orbius-core' ),
                            '800' => esc_html__( '800', 'orbius-core' ),
                            '900' => esc_html__( '900', 'orbius-core' ),
                         ],
            'selectors' => [
                            '{{WRAPPER}} .mk-cart-number' => 'font-weight: {{SIZE}};'
                        ],
        ]);


        $this->add_control(
            'number_color',
            [
                'label'     => esc_html__( 'Font Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => [
                    'cart_number' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-number' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'number_background',
            [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => [
                    'cart_number' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-cart-number' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

        // -----------------------------------------------------------------------------

        mk_elem_start_ctrl($this, 'panel_settings', 'Off-Canvas');

        $this->add_responsive_control(
            'off_canvas_width',
            [
                'label' => esc_html__( 'Off-Canvas Width', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 30,
                        'max' => 1920
                    ],
                ],
                'default' => [
                    'size' => 340,
                    'unit' => 'px'
                ],
                'selectors' => [
                    '.mk-cart-panel.mk-cart-panel-{{ID}}' => 'width: {{SIZE}}{{UNIT}}',
                ]
            ]
        );

        $this->add_control('position', [
            'label' => esc_html__( 'Off-Canvas Position', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::CHOOSE,
            'options' => mk_arrays('align_left_right'),
            'default' => 'right',
            'toggle' => false,
            'frontend_available' => true,
        ]);

        mk_elem_heading_ctrl($this, 'off_canvas_headig', 'Off-Canvas Heading', 'before' );

        $this->add_control('panel_heading', [
            'label' => esc_html__( 'Heading Text', 'orbius-core' ),
            'label_block' => true,
            'default' => 'Shopping Cart',
        ]);

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '.mk-cart-panel-{{ID}} .mk-cart-panel-heading h3' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name' => 'off_canvas_title_typography',
            'selector' => '.mk-cart-panel-{{ID}} .mk-cart-panel-heading h3',
        ]);

        mk_elem_heading_ctrl($this, 'close_heading', 'Close', 'before' );

        $this->add_control('close_button',[
            'label' => esc_html__( 'Show Close Button', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('overlay_close',[
            'label' => esc_html__( 'Close With Click on Overlay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'condition' => [ 'close_button' => 'yes' ],
            'default' => 'yes',
        ]);

        $this->add_control('esc_key_close',[
            'label' => esc_html__( 'Close by ESC Button Click', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
            'condition' => [ 'close_button' => 'yes' ],
        ]);

        $this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

        $cart_contents_count = '';

        if ( mk_check_installed( 'woocommerce' ) ) {
            if ( !empty( WC()->cart ) ) {
                $cart_contents_count = WC()->cart->cart_contents_count;
            }
        }

        // cart icon
        $random_id  = rand(10,100000);
        $cartEmpty  = ( $cart_contents_count == 0 ) ? ' mk-woo-cart-is-empty' : '';
        $hideNumber = ( $cart_contents_count == 0 ) ? ' hide-number' : '';
        $cartNumber = ( 'yes' == $settings['cart_number'] ) ? '<span class="mk-cart-number' . $hideNumber . '">' . $cart_contents_count . '</span>' : '';

        $cartIconHTML = '<div class="mk-wc-cart-icon-wrapper">
            <div class="mk-cart-icon-' . $this->get_id() . ' mk-cart-icon' . $cartEmpty . '">
                <a href="#cart-' . $this->get_id() . $random_id . '" class="mk-cart-panel-link"></a>
                <span class="mk-cart-icon-trigger"> ' . mk_get_elementor_icons($settings['cart_icon']) . '</span>
                ' . $cartNumber . '
                <div class="clear"></div>
            </div>
        </div>';

        if ( $settings['display_cart_icon'] === 'shop_pages' ) {
            if ( mk_check_shop_pages() || \Elementor\Plugin::instance()->editor->is_edit_mode() ) {
                echo $cartIconHTML;
            }
        } else {
            echo $cartIconHTML;
        }

        ob_start();

        // side panel
        $panelHeading = ( !empty($settings['panel_heading']) ) ? '<h3>' . $settings['panel_heading'] . '</h3>' : '';
        $panelClose = ( 'yes' == $settings['close_button'] ) ? '<span class="mk-cart-panel-close">' . mk_get_svg_icon( 'close', 'swm-svg-filterable-gallery-close' ) . '</span>' : '';

        $cartPanelPosition = !empty($settings['position']) ? $settings['position'] : 'right';

        echo '<div class="mk-cart-panel-overlay"></div>
                <div data-trigger-id="cart-' . $this->get_id() . $random_id .'"
                    class="mk-cart-panel mk-cart-panel-' . $this->get_id() . ' mk-cart-panel-' . $cartPanelPosition . '"
                    data-id="' . $this->get_id() . '"
                    data-esckey="' . $settings['esc_key_close'] . '"
                    data-panel-position="' . $cartPanelPosition . '"
                >
                <div class="mk-cart-panel-heading">' . $panelHeading . $panelClose . '</div>
                    <div class="mk-cart-panel-wrap">
                        <div class="widget_shopping_cart_content"></div>
                    </div>
                </div>';

        $output = ob_get_contents();
        ob_end_clean();

        mk_add_inline_html($output);

        echo '<div class="mk-hidden"></div>';

    }

}