<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Circle_Slider extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_circle_slider'; }
    public function get_title()          { return esc_html__( 'Circle Slider', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return ['mk-sliders-elements']; }
    public function get_keywords()       { return [ 'theme','slider','slide show','circle','animation']; }
    public function get_style_depends()  { return ['swiper','mk-core-main']; }
    public function get_script_depends() { return ['swiper','mk-widgets']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_heading', 'Slider Items');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title_text', [
                'label'       => esc_html__( 'Title 1', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('impact','orbius-core')
            ]);

            $repeater->add_control('title_two_text', [
                'label'       => esc_html__( 'Title 2', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('branding with','orbius-core')
            ]);

            $repeater->add_control('desc', [
                'label'       => esc_html__( 'Description', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => 'morbi tincidunt mauris vitae ultrices efficitur sed vel tortor purus ulla facilidisse potensque vel volutpat leo ullam at diam vel libero fermentum'
            ]);

            $repeater->add_control('slide_image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('btn_text', [
                'label'       => esc_html__( 'Button Text', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('read more','orbius-core')
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'before',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $this->add_control('slider_items', [
                'label' => esc_html__( 'Slider Items', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['title_text' => "branding with", 'title_two_text' => "impact", 'desc' => "morbi tincidunt mauris vitae ultrices efficitur sed vel tortor purus ulla facilidisse potensque vel volutpat leo ullam at diam vel libero fermentum", 'link' =>  ['url' => '#'] ],
                ],
                'title_field' => '{{{ title_text }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_items_settings', 'Slider Settings');

        $this->add_control('effect', [
            'label'        => esc_html__( 'Effect', 'orbius-core' ),
            'type'         => \Elementor\Controls_Manager::SELECT,
            'default'      => 'slide',
            'options' => [  'fade' => esc_html__( 'Fade', 'orbius-core' ),
                            'slide' => esc_html__( 'Slide', 'orbius-core' ),
                         ]
        ]);

        $this->add_control('arrows_on',[
            'label'   => esc_html__( 'Arrow Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('loop_on',[
            'label'   => esc_html__( 'Continuous Loop', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('mousewheel_on',[
            'label'   => esc_html__( 'Mousewheel Control', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_on',[
            'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('hover_pause_on',[
            'label'   => esc_html__( 'Pause on Hover', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'condition' => ['autoplay_on' => 'yes']
        ]);

        $this->add_control('drag_icon_on',[
            'label'   => esc_html__( 'Hover Drag Icon', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_speed', [
            'label' => esc_html__( 'Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 5000,
            'step' => 100,
            'min' => 100,
            'max' => 15000,
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'general_settings', 'General Settings', true);

        $this->add_responsive_control('slider_height',[
            'label'       => esc_html__( 'Slider Min Height', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em', 'vh' ],
            'range'       => ['px' => ['min' => 0, 'max' => 2000, ] ],
            'default' => ['unit' => 'px', 'size' => 950,],
            'tablet_default' => ['unit' => 'px', 'size' => 850],
            'mobile_default' => ['unit' => 'px', 'size' => 750],
            'selectors'   => [
                '{{WRAPPER}} .mk-circle-slider-slide' => 'min-height:{{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_control('slider_bg', [
            'label'     => esc_html__( 'Slider Background Color', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-circle-slider-slide' => 'background: {{VALUE}};',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_image_style', 'Image', true);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'                  => 'slide_image_size',
                'label'                 => esc_html__( 'Image Size', 'orbius-core' ),
                'default'               => 'full',
            ]);

            $this->add_responsive_control('image_section_width',[
                'label'       => esc_html__( 'Image Section Width', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', 'vh' ],
                'range'       => ['px' => ['min' => 0, 'max' => 2000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-circle-slider-img' => 'max-width:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'otherinfo_style', 'Content', true);

            $this->add_responsive_control('content_max_width',[
                'label'       => esc_html__( 'Content Max Width', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', 'vh', '%' ],
                'default'     => ['unit' => 'px', 'size' => 1100, ],
                'range'       => ['px' => ['min' => 0, 'max' => 2000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-circle-slider-content' => 'max-width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('content_min_height',[
                'label'       => esc_html__( 'Content Min Height', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', 'vh', '%' ],
                'default'     => ['unit' => 'px', 'size' => 650, ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-circle-slider-content' => 'min-height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->start_controls_tabs( 'tabs_icon_style' );

                $this->start_controls_tab('tab_title', [
                    'label' => esc_html__( 'Title 1', 'orbius-core' ),
                ]);

                    $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                        'name'     => 'title_typography',
                        'selector' => '{{WRAPPER}} .mk-circle-slider .mk-circle-slider-subtitle,
                        {{WRAPPER}} .mk-circle-slider .mk-circle-slider-subtitle a',
                    ]);

                    $this->add_control('title_color', [
                        'label'     => esc_html__( 'Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider-subtitle a,
                            {{WRAPPER}} .mk-circle-slider-subtitle' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('title_hover_color', [
                        'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider-subtitle:hover a,
                            {{WRAPPER}} .mk-circle-slider-subtitle:hover' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_responsive_control('title_margin', [
                            'label' => esc_html__( 'Margin', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::DIMENSIONS,
                            'selectors' => [
                                '{{WRAPPER}} .mk-circle-slider .mk-circle-slider-subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_control( 'title_tag', [
                        'type'       => \Elementor\Controls_Manager::SELECT,
                        'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
                        'options'    => mk_arrays('title_tag'),
                        'default' => 'h4',
                        'selectors' => [
                            '{{WRAPPER}} {{VALUE}}.mk-circle-slider-subtitle' => 'margin:0;',
                        ],
                    ]);

                    $this->add_control( 'subtitle_display_style', [
                        'label' => esc_html__( 'Display Style', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::SELECT,
                        'options' => [
                            'default' => 'Default',
                            'stroke'  => 'Stroke'
                        ],
                        'default' => 'stroke',
                    ]);
                    $this->add_responsive_control('subtitle_stroke_color',[
                        'label' => esc_html__( 'Stroke Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'default' => '#000000',
                        'condition'=> ['subtitle_display_style' => 'stroke'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider .mk-circle-slider-subtitle,
                            {{WRAPPER}} .mk-circle-slider .mk-circle-slider-subtitle a' => '-webkit-text-stroke-color: {{VALUE}};',
                        ],
                    ]);
                    $this->add_responsive_control('subtitle_stroke_width', [
                        'label' => esc_html__( 'Stroke Width', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px' ],
                        'default' => ['size' => '1', 'unit' => 'px'],
                        'condition'=> ['subtitle_display_style' => 'stroke'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider .mk-circle-slider-subtitle' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                        ],
                    ]);

                $this->end_controls_tab();

                $this->start_controls_tab('tab_title_two', [
                    'label' => esc_html__( 'Title 2', 'orbius-core' ),
                ]);

                    $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                        'name'     => 'desc_typography',
                        'selector' => '{{WRAPPER}} .mk-circle-slider-title',
                    ]);

                    $this->add_control('desc_color', [
                        'label'     => esc_html__( 'Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider-title, {{WRAPPER}} .mk-circle-slider-title a' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('desc_hover_color', [
                        'label'     => esc_html__( 'Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider-title a:hover' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_responsive_control('desc_margin', [
                        'label' => esc_html__( 'Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider .mk-circle-slider-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                $this->end_controls_tab();

                $this->start_controls_tab('tab_desc', [
                    'label' => esc_html__( 'Description', 'orbius-core' ),
                ]);

                    $this->add_responsive_control('desc_width',[
                        'label'       => esc_html__( 'Max Width', 'orbius-core' ),
                        'type'        => \Elementor\Controls_Manager::SLIDER,
                        'size_units'  => [ 'px', 'em', 'vh' ],
                        'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                        'selectors'   => [
                            '{{WRAPPER}} .mk-circle-slider-text' => 'max-width:{{SIZE}}{{UNIT}};',
                        ],
                    ]);

                    $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                        'name'     => 'otherinfo_typography',
                        'selector' => '{{WRAPPER}} .mk-circle-slider-text',
                    ]);

                    $this->add_control('otherinfo_color', [
                        'label'     => esc_html__( 'Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider-text, {{WRAPPER}} .mk-circle-slider-text a' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_responsive_control('otherinfo_margin', [
                        'label' => esc_html__( 'Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'selectors' => [
                            '{{WRAPPER}} .mk-circle-slider .mk-circle-slider-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                $this->end_controls_tab();

            $this->end_controls_tabs();

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'button_styling', 'Button', true );

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'           => 'button_typography',
                'selector' => '{{WRAPPER}} .mk-circle-slider-button a',
            ]);

            $this->add_control('button_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-circle-slider-button a .mk-circle-slider-button-text,
                    {{WRAPPER}} .mk-circle-slider-button:hover a .mk-circle-slider-button-text' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mk-circle-slider-button a,
                    {{WRAPPER}} .mk-circle-slider-button-arrow-start,
                    {{WRAPPER}} .mk-circle-slider-button-arrow-end' => 'border-color: {{VALUE}};',
                    '{{WRAPPER}} .mk-circle-slider-button-arrow-start:after,
                    {{WRAPPER}} .mk-circle-slider-button-arrow-end:after' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('btn_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-circle-slider-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'content_circle_style', 'Content Circle', true);

            $this->add_responsive_control('circle_size',[
                'label'       => esc_html__( 'Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', 'vh','%' ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-circle-slider-text-btn:before' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('circle_bg', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-circle-slider-text-btn:before' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_control('circle_bg_blur_level', [
                'label'      => esc_html__( 'Background Blur Level', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range'      => ['px' => ['min'  => 0, 'max'  => 50, 'step' => 1]],
                'selectors'  => ['
                    {{WRAPPER}} .mk-circle-slider-text-btn:before' => '-webkit-backdrop-filter: blur({{SIZE}}px); backdrop-filter: blur({{SIZE}}px);',
                ],
            ]);

            $this->add_responsive_control('circle_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mk-circle-slider-text-btn:before' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_nav_style', 'Navigation', true );

            $this->add_control('nav_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#000000',
                'selectors' => [
                    '{{WRAPPER}} .mk-circle-slider .mk-slider-pn' => 'fill: {{VALUE}}; border-color:{{VALUE}}',
                ],
            ]);

            $this->add_responsive_control('nav_horizontal_offset',[
                'label'       => esc_html__( 'Horizontal Offset', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px','%' ],
                'range'       => ['px' => ['min' => -1000, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-circle-slider .mk-slider-prev' => 'left:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-circle-slider .mk-slider-next' => 'right:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'subtitle_responsive_hide', 'Hide Title 1 At', 'none' );
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title 2 At', 'none' );
            mk_elem_hide_ctrl($this, 'desc_responsive_hide', 'Hide Description At', 'mobile' );
            mk_elem_hide_ctrl($this, 'button_responsive_hide', 'Hide Button At', 'mobile' );
            mk_elem_hide_ctrl($this, 'circle_responsive_hide', 'Hide Content Circle At', 'mobile' );
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrows Navigation At', 'mobile' );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $sliderSettings = array(
            'direction'         => 'horizontal',
            'parallax'          => 'no',
            'effect'            => $settings['effect'],
            'arrows_on'         => $settings['arrows_on'],
            'dots'              => 'no',
            'autoplay'          => $settings['autoplay_on'],
            'autoplay_speed'    => $settings['autoplay_speed'],
            'speed'             => 800,
            'mousewheel'        => $settings['mousewheel_on'],
            'loop'              => $settings['loop_on'],
            'pause_on_hover'    => $settings['hover_pause_on'],
            'slides_to_show'    => 1,
            'slider_next'       => '.swiper-' . $this->get_id() . '-next',
            'slider_prev'       => '.swiper-' . $this->get_id() . '-prev',
            'slider_pagination' => '.swiper-' . $this->get_id() . '-dot',
            'video'             => 'no'
        );

        $slider_classes = [ 'swiper', 'swiper-container','mk-circle-slider','mk-circle-slider-circle-hide-' . $settings['circle_responsive_hide'] ];
        $slider_classes[] .= ( 'yes' === $settings['drag_icon_on'] ) ? ' mk--drag-cursor' : '';

        $this->add_render_attribute( [
            'slider-attrs'  => [
                'class'          => $slider_classes,
                'data-settings'  => json_encode( $sliderSettings ),
                'id'             => 'swiper-' . $this->get_id()
            ]
        ] );

        $slideHTML = '';
        $i = 1;

        foreach ( $settings['slider_items'] as $index => $item ) :

            $text = $imgUrl = $desc = $slide_image = $link_start = $link_end = $title = $title_two = $button = '';

            // image
            if (  $settings['slide_image_size_size'] == 'custom' ) {
                $slide_image .= '<img '.mk_custom_image_size_html($this, $settings, $item['slide_image'], $item['slide_image']['id'], 'slide_image_size', 'slide_img_' . $i).' />';
            } else {
                $slide_image .= wp_get_attachment_image( $item['slide_image']['id'], $settings['slide_image_size_size']);
            }

            // link
            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';
            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            // title 1
            if ( ! empty( $item['title_text'] ) ) {
                $title .= '<'.$titleTagSelector.' class="mk-circle-slider-subtitle swm-hide-'. $settings['subtitle_responsive_hide'] .'">' . $link_start . $item['title_text'] . $link_end . '</'.$titleTagSelector . '>';
            }


            // title 2
            if ( ! empty( $item['title_two_text'] ) ) {
                $title_two .= '<'.$titleTagSelector.' class="mk-circle-slider-title swm-hide-'. $settings['title_responsive_hide'] .'">' . $link_start . $item['title_two_text'] . $link_end . '</'.$titleTagSelector . '>';
            }

            // desc
            $desc .= ( !empty( $item['desc'] ) ) ? '<div class="mk-circle-slider-text swm-hide-'. $settings['desc_responsive_hide'] .'">' . $link_start . $item['desc'] . $link_end . '</div>' : '';

            //button
            if ( !empty( $item['btn_text'] ) && '' !== $link_start ) {
                $button .= '<div class="mk-circle-slider-button swm-hide-'. $settings['button_responsive_hide'] .'">' . $link_start . '<span class="mk-circle-slider-button-arrow-start"></span><span class="mk-circle-slider-button-text">' . $item['btn_text'] . '</span><span class="mk-circle-slider-button-arrow-end"></span>' . $link_end . '</div>';
            }

            $slideHTML .= '<div class="mk-circle-slider-slide swiper-slide">

                            <div class="mk-circle-slider-image">
                                <div class="mk-circle-slider-img">' . $link_start . $slide_image . $link_end . '</div>
                            </div>

                            <div class="mk-circle-slider-content">
                                <div class="mk-circle-slider-top-content">' . $title . $title_two . '</div>
                                <div class="mk-circle-slider-bottom-content">
                                    <div class="mk-circle-slider-text-btn">' . $desc . $button . '</div>
                                </div>
                            </div>

                        </div>';

            $i++;
        endforeach;

        $navigation = '';

        if ('yes' === $settings['arrows_on']) {

            $navigation .= '<div class="mk-slider-pn mk-slider-prev swiper-' . $this->get_id() . '-prev swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>
                            <div class="mk-slider-pn mk-slider-next swiper-' . $this->get_id() . '-next swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>';
        }

        echo '<div ' . $this->get_render_attribute_string( 'slider-attrs' ) . '>
                ' . $navigation . '
                <div class="swiper-wrapper">' . $slideHTML . '</div>
            </div>';

    }

}