<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Circle_Text extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_circle_text'; }
	public function get_title()          { return esc_html__( 'Circle Text', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-circle-o'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'button','badge','icon','icon','circle','text','round','curve','svg']; }
	public function get_style_depends()  { return [ 'mk-magnific-popup','mk-core-main' ]; }
    public function get_script_depends() { return ['mk-widgets','magnific-popup']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_general', 'General');

            $this->add_control('info_circle_text_one', [
                'label' => esc_html__( 'Circle Text 1', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'play video &nbsp;&nbsp; - &nbsp;&nbsp;',
            ]);

            $this->add_control('info_circle_text_two', [
                'label' => esc_html__( 'Circle Text 2', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'play video &nbsp;&nbsp; - &nbsp;&nbsp;',
            ]);

            $this->add_control('info_circle_text_three', [
                'label' => esc_html__( 'Circle Text 3', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'play video &nbsp;&nbsp; - &nbsp;&nbsp;',
            ]);

            $this->add_control('info_circle_text_four', [
                'label' => esc_html__( 'Circle Text 4', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
            ]);

            $this->add_control('popup_section', [
                'type' => \Elementor\Controls_Manager::RAW_HTML,
                'raw' => __( 'You can use HTML entity/unicode to display different symbols.<br/>
                    <a href="https://www.w3schools.com/charsets/ref_html_entities_4.asp" target="_blank">Reference Site 1</a><br/>
                    <a href="https://www.w3schools.com/charsets/ref_utf_geometric.asp" target="_blank">Reference Site 2', 'orbius-core' ),
                'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
            ]);

            $this->add_control('link_type', [
                'label'   => esc_html__( 'Link Type', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'default' => esc_html__( 'Default', 'orbius-core' ),
                    'video' => esc_html__( 'Video', 'orbius-core' )
                ],
                'separator' => 'before',
                'default' => 'default',
            ]);

            $this->add_control('video_url', [
                'label' => esc_html__( 'YouTube/Vimeo Video URL', 'orbius-core' ),
                'label_block' => true,
                'condition' => ['link_type' => 'video'],
                'default' => 'https://www.youtube.com/watch?v=f8N2MDkgkpY',
                'type' => \Elementor\Controls_Manager::TEXT,
            ]);

            $this->add_control('text_link', [
                'label'    => esc_html__( 'Link', 'orbius-core' ),
                'type'     => \Elementor\Controls_Manager::URL,
                'default'  => [
                    'url'         => '#',
                    'is_external' => '',
                ],
                'dynamic'  => [
                    'active' => true,
                ],
                'selector' => '',
                'condition' => ['link_type' => 'default'],
            ]);

            $this->add_control('circle_icon', [
                'label' => esc_html__( 'Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'button_text_style', 'Circle', true);

            $this->add_responsive_control('circle_size', [
                'label'      => esc_html__( 'Circle Size', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', 'rem', 'vw'],
                'range'      => [
                    'px' => ['min'  => 0, 'max'  => 1000, 'step' => 1 ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-round-text' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('hover_pause',[
                'label' => esc_html__( 'Stop Text Rotation on Hover', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'prefix_class' => 'mk-round-text-hover-stop-'
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'info_button_typography',
                'fields_options' => [
                    'typography' => ['default' =>'custom', ],
                    'font_size'   => ['default' => ['unit' => 'px', 'size' => '15', ] ],
                    'font_weight' => ['default' => '500' ],
                ],
                'selector' => '{{WRAPPER}} .mk-round-text',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'     => 'info_button_border_color',
                'label'    => esc_html__( 'Border', 'orbius-core' ),
                'selector' => '{{WRAPPER}} .mk-round-text',
            ]);

            $this->add_control('circle_text_bg_blur_level', [
                'label'      => esc_html__( 'Background Blur Level', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range'      => ['px' => ['min'  => 0, 'max'  => 50, 'step' => 1]],
                'selectors'  => ['
                    {{WRAPPER}} .mk-round-text' => '-webkit-backdrop-filter: blur({{SIZE}}px); backdrop-filter: blur({{SIZE}}px);',
                ],
            ]);

            $this->start_controls_tabs( 'tabs_button_styles' );
                $this->start_controls_tab('tab_button_normal', array(
                    'label' => esc_html__( 'Normal', 'orbius-core' ),
                ));

                    $this->add_control('info_button_color_one', [
                        'label' => esc_html__( 'Text Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-round-text' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .mk-round-text svg' => 'fill: {{VALUE}};',
                        ],
                    ]);

                    $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
                        'name'     => 'info_button_background_color',
                        'label'    => esc_html__( 'Background', 'orbius-core' ),
                        'types'    => [ 'classic', 'gradient' ],
                        'selector' => '{{WRAPPER}} .mk-round-text',
                    ]);

                $this->end_controls_tab();
                $this->start_controls_tab('tab_button_hover_one', array(
                    'label' => esc_html__( 'Hover', 'orbius-core' ),
                ));

                    $this->add_control('info_button_hover_color', [
                        'label' => esc_html__( 'Text Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-round-text:hover' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .mk-round-text:hover svg' => 'fill: {{VALUE}};',
                        ],
                    ]);

                    $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
                        'name'     => 'icon_btn_hover_background_color',
                        'label'    => esc_html__( 'Background Color', 'orbius-core' ),
                        'types'    => [ 'classic', 'gradient' ],
                        'selector' => '{{WRAPPER}} .mk-round-text:hover',
                    ]);

                    $this->add_control('info_button_hover_border_color', [
                        'label' => esc_html__( 'Border Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-round-text:hover' => 'border-color: {{VALUE}};',
                        ],
                    ]);

                $this->end_controls_tab();
            $this->end_controls_tabs();

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'icon_styling', 'Icon', true);

            $this->add_responsive_control('circle_size_inside', [
                'label'      => esc_html__( 'Icon Holder Circle Size', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', 'rem', 'vw'],
                'range'      => [
                    'px' => ['min'  => 0, 'max'  => 1000, 'step' => 1 ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-round-text-icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('circle_icon_size', [
                'label'      => esc_html__( 'Icon Size', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', 'rem', 'vw'],
                'range'      => [
                    'px' => ['min'  => 0, 'max'  => 500, 'step' => 1 ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-round-text .mk-round-text-icon i,
                    {{WRAPPER}} .mk-round-text .mk-round-text-icon svg' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-round-text .mk-round-text-icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('rotate_icon_style', [
                'label'      => esc_html__( 'Rotate Icon', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => ['min'  => 0, 'max'  => 360, 'step' => 1 ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-round-text-icon svg,
                    {{WRAPPER}} .mk-round-text-icon i' => 'transform: rotate({{SIZE}}deg);',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'info_button_icon_border_color',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-round-text-icon',
            ]);

            $this->start_controls_tabs( 'tabs_button_styles_one' );
                $this->start_controls_tab('tab_button_normal_one', array(
                    'label' => esc_html__( 'Normal', 'orbius-core' ),
                ));

                    $this->add_control('circle_icon_color', [
                        'label' => esc_html__( 'Icon Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-round-text-icon i' => 'color: {{VALUE}} !important;',
                            '{{WRAPPER}} .mk-round-text-icon svg' => 'fill: {{VALUE}} !important;',
                        ],
                    ]);

                    $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
                        'name'     => 'circle_icon_bg',
                        'label'    => esc_html__( 'Icon Background', 'orbius-core' ),
                        'types'    => [ 'classic', 'gradient' ],
                        'selector' => '{{WRAPPER}} .mk-round-text-icon',
                    ]);

                $this->end_controls_tab();
                $this->start_controls_tab('tab_button_hover', array(
                    'label' => esc_html__( 'Hover', 'orbius-core' ),
                ));

                    $this->add_control('circle_icon_hover_color', [
                        'label' => esc_html__( 'Icon Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-round-text:hover .mk-round-text-icon i' => 'color: {{VALUE}} !important;',
                            '{{WRAPPER}} .mk-round-text:hover .mk-round-text-icon svg' => 'fill: {{VALUE}} !important;',
                        ],
                    ]);

                    $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
                        'name'     => 'circle_icon_hover_bg',
                        'label'    => esc_html__( 'Icon Background', 'orbius-core' ),
                        'types'    => [ 'classic', 'gradient' ],
                        'selector' => '{{WRAPPER}} .mk-round-text:hover .mk-round-text-icon',
                    ]);

                    $this->add_control('info_button_icon_hover_border_color', [
                        'label' => esc_html__( 'Border Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-round-text:hover .mk-round-text-icon' => 'border-color: {{VALUE}};',
                        ],
                    ]);


                $this->end_controls_tab();
            $this->end_controls_tabs();

        $this->end_controls_section();

    }

    public function render() {

        $settings = $this->get_settings_for_display();

        // link
        $button_link = '';

        if ( !empty($settings['video_url']) && $settings['link_type'] == 'video' ) {

            $button_link = '<a class="mk-round-text-link mk-video-lightbox" href="' . esc_url($settings['video_url']) . '"></a>';

        } elseif (!empty($settings['text_link']['url']) && $settings['link_type'] == 'default') {

            $button_url = $settings['text_link']['url'];

            if ( $settings['text_link']['is_external'] ) {
                $this->add_render_attribute( 'btn_link', 'target', '_blank' );
            }

            if ( $settings['text_link']['nofollow'] ) {
                $this->add_render_attribute( 'btn_link', 'rel', 'nofollow' );
            }

            $button_link = '<a class="mk-round-text-link" href="' . esc_url($button_url) . '" ' . $this->get_render_attribute_string('btn_link') . '></a>';

        }

        ob_start();
            \Elementor\Icons_Manager::render_icon( $settings['circle_icon'], array( 'aria-hidden' => 'true' ) );
            $icon_html = ob_get_clean();

            $circleText = '';
            $circleText .= ( !empty($settings['info_circle_text_one']) ) ? '<tspan class="circleTexts circleTextOne">'.$settings['info_circle_text_one'] .'</tspan>' :'';
            $circleText .= ( !empty($settings['info_circle_text_two']) ) ? '<tspan class="circleTexts circleTextTwo">'.$settings['info_circle_text_two'] .'</tspan>' :'';
            $circleText .= ( !empty($settings['info_circle_text_three']) ) ? '<tspan class="circleTexts circleTextThree">'.$settings['info_circle_text_three'] .'</tspan>' :'';
            $circleText .= ( !empty($settings['info_circle_text_four']) ) ? '<tspan class="circleTexts circleTextFour">'.$settings['info_circle_text_four'] .'</tspan>' :'';

            if ( '' === $icon_html ) {
                $icon_html = ( $settings['link_type'] === 'video' ) ? mk_get_svg_icon( 'play', 'swm-svg-round-text-play' ) : mk_get_svg_icon( 'arrow', 'swm-svg-round-text-arrow' );
            }


        echo '<div class="mk-round-text swm-anim">
                ' . $button_link . '
            <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="100%" height="100%" viewBox="0 0 180 180" enable-background="new 0 0 180 180" xml:space="preserve">
                <defs>
                    <path id="circlePath" d="M 90, 90 m -60, 0 a 60,60 0 0,1 120,0 a 60,60 0 0,1 -120,0 "></path>
                </defs>
                <circle cx="90" cy="90" r="75" fill="none"></circle>
                <g>
                    <use xlink:href="#circlePath" fill="none"></use>
                    <text>
                        <textPath xlink:href="#circlePath">' . $circleText . '</textPath>
                    </text>
                </g>
            </svg>
                <span class="mk-round-text-icon swm-anim">' . $icon_html . '</span>
        </div>';

    }

}