<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Contact_Form_Styler extends \Elementor\Widget_Base {

	public function get_name()          { return 'mk_contact_form_styler'; }
	public function get_title()         { return esc_html__( 'Contact Form 7 Styler', 'orbius-core' ); }
	public function get_icon()          { return 'mk-el-icon eicon-form-horizontal'; }
	public function get_categories()    { return ['mk-general-elements']; }
	public function get_keywords()      { return [ 'contact form', 'form', 'contact' ]; }
	public function get_style_depends() { return ['mk-core-main']; }
	public function get_script_depends() { return [ 'mk-widgets' ]; }


	protected function get_cf7_forms() {

		$field_options = array();

		if ( class_exists( 'WPCF7_ContactForm' ) ) {
			$args               = array(
				'post_type'      => 'wpcf7_contact_form',
				'posts_per_page' => -1,
			);
			$forms              = get_posts( $args );
			$field_options['0'] = 'Select';
			if ( $forms ) {
				foreach ( $forms as $form ) {
					$field_options[ $form->ID ] = $form->post_title;
				}
			}
		}

		if ( empty( $field_options ) ) {
			$field_options = array(
				'-1' => esc_html__( 'Contact Form not found. Please add contact form from Dashboard > Contact > Add New.', 'orbius-core' ),
			);
		}
		return $field_options;
	}

	protected function get_cf7_form_id() {
		if ( class_exists( 'WPCF7_ContactForm' ) ) {
			$args  = array(
				'post_type'      => 'wpcf7_contact_form',
				'posts_per_page' => -1,
			);
			$forms = get_posts( $args );

			if ( $forms ) {
				foreach ( $forms as $form ) {
					return $form->ID;
				}
			}
		}
		return -1;
	}

	protected function register_controls() {

		$this->register_general_content_controls();
		$this->register_input_style_controls();
        $this->register_textarea_style_controls();
		$this->register_radio_content_controls();
		$this->register_button_content_controls();
		$this->register_error_content_controls();
		$this->register_typography_style_controls();

	}

	protected function register_general_content_controls() {

		mk_elem_start_ctrl($this, 'section_general_field', 'General');

			$this->add_control(
				'select_form',
				[
					'label'   => esc_html__( 'Select Form', 'orbius-core' ),
					'type'    => \Elementor\Controls_Manager::SELECT,
					'options' => $this->get_cf7_forms(),
					'default' => '0'
				]
			);

			$this->add_control(
				'cf7_style',
				[
					'label'        => esc_html__( 'Field Style', 'orbius-core' ),
					'type'         => \Elementor\Controls_Manager::SELECT,
					'default'      => 'box',
					'options'      => [
						'box'       => esc_html__( 'Box', 'orbius-core' ),
						'underline' => esc_html__( 'Underline', 'orbius-core' ),
					],
					'prefix_class' => 'mk-cf7-style-',
				]
			);

			$this->add_responsive_control(
				'cf7_input_padding',
				[
					'label'      => esc_html__( 'Field Padding', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .mk-cf7-style input:not([type="submit"]):not([type="file"]),
						{{WRAPPER}} .mk-cf7-icon i,
						{{WRAPPER}} .mk-cf7-style select,
						{{WRAPPER}} .mk-cf7-style textarea' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style select[multiple="multiple"]'  => 'padding: 0px;',
						'{{WRAPPER}} .mk-cf7-style select[multiple="multiple"] option'  => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style input[type="checkbox"] + span:before,{{WRAPPER}} .mk-cf7-style input[type="radio"] + span:before' => 'height: {{TOP}}{{UNIT}}; width: {{TOP}}{{UNIT}};',
						'{{WRAPPER}}.mk-cf7-style-underline input[type="checkbox"] + span:before,{{WRAPPER}} .mk-cf7-style-underline input[type="radio"] + span:before' => 'height: {{TOP}}{{UNIT}}; width: {{TOP}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-underline input[type="checkbox"]:checked + span:before' => 'font-size: calc({{BOTTOM}}{{UNIT}} / 1.2);',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-webkit-slider-thumb' => 'font-size: {{BOTTOM}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-moz-range-thumb' => 'font-size: {{BOTTOM}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-thumb' => 'font-size: {{BOTTOM}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-webkit-slider-runnable-track' => 'font-size: {{BOTTOM}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-moz-range-track' => 'font-size: {{BOTTOM}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-fill-lower' => 'font-size: {{BOTTOM}}{{UNIT}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-fill-upper' => 'font-size: {{BOTTOM}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'cf7_input_bgcolor',
				[
					'label'     => esc_html__( 'Field Background Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'default'   => '#ffffff',
					'selectors' => [
						'{{WRAPPER}} .mk-cf7-style input:not([type=submit]):not([type="file"]), {{WRAPPER}} .mk-cf7-style select, {{WRAPPER}} .mk-cf7-style textarea, {{WRAPPER}} .mk-cf7-style .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}} .mk-cf7-style .wpcf7-acceptance input[type="checkbox"] + span:before, {{WRAPPER}} .mk-cf7-style .wpcf7-radio input[type="radio"]:not(:checked) + span:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-webkit-slider-runnable-track,{{WRAPPER}} .mk-cf7-style input[type=range]:focus::-webkit-slider-runnable-track' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-moz-range-track,{{WRAPPER}} input[type=range]:focus::-moz-range-track' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-fill-lower,{{WRAPPER}} .mk-cf7-style input[type=range]:focus::-ms-fill-lower' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-fill-upper,{{WRAPPER}} .mk-cf7-style input[type=range]:focus::-ms-fill-upper' => 'background-color: {{VALUE}};',
						'{{WRAPPER}}.mk-cf7-style-box .wpcf7-radio input[type="radio"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-underline .wpcf7-radio input[type="radio"]:checked + span:before' => 'box-shadow:inset 0px 0px 0px 4px {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'cf7_label_color',
				[
					'label'     => esc_html__( 'Label Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => [
						'{{WRAPPER}} .mk-cf7-style .wpcf7 form.wpcf7-form:not(input)' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'cf7_input_color',
				[
					'label'     => esc_html__( 'Input Text', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'default'   => '#000000',
					'selectors' => [
						'{{WRAPPER}} .mk-cf7-style .wpcf7 input:not([type=submit]),
						{{WRAPPER}} .mk-cf7-style .wpcf7 select,
						{{WRAPPER}} .mk-cf7-style .wpcf7 textarea,
						{{WRAPPER}} .mk-cf7-style .mk-cf7-select-custom:after' => 'color: {{VALUE}};',

						'{{WRAPPER}}.elementor-widget-mk-cf7-styler .wpcf7-checkbox input[type="checkbox"]:checked + span:before,
						{{WRAPPER}}.elementor-widget-mk-cf7-styler .wpcf7-acceptance input[type="checkbox"]:checked + span:before' => 'color: {{VALUE}};',

						'{{WRAPPER}}.mk-cf7-style-box .wpcf7-radio input[type="radio"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-underline .wpcf7-radio input[type="radio"]:checked + span:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-webkit-slider-thumb' => 'border: 1px solid {{VALUE}}; background: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-moz-range-thumb' => 'border: 1px solid {{VALUE}}; background: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-thumb' => 'border: 1px solid {{VALUE}}; background: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'cf7_input_placeholder_color',
				[
					'label'     => esc_html__( 'Placeholder Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'default'   => '#000000',
					'selectors' => [
						'{{WRAPPER}} .mk-cf7-style .wpcf7 input::placeholder,
						{{WRAPPER}} .mk-cf7-style .wpcf7 textarea::placeholder' => 'color: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style .wpcf7 input:not([type=submit])::-webkit-input-placeholder ' => 'color:{{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style .wpcf7 input:not([type=submit])::-moz-placeholder ' => 'color:{{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style .wpcf7 input:not([type=submit])::-ms-placeholder ' => 'color:{{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style .wpcf7 input:not([type=submit])::placeholder ' => 'color:{{VALUE}};',
					],
				]
			);

			$this->add_control(
				'input_border_style',
				[
					'label'       => esc_html__( 'Border Style', 'orbius-core' ),
					'type'        => \Elementor\Controls_Manager::SELECT,
					'default'     => 'solid',
					'label_block' => false,
					'options'     => [
						'none'   => esc_html__( 'None', 'orbius-core' ),
						'solid'  => esc_html__( 'Solid', 'orbius-core' ),
						'double' => esc_html__( 'Double', 'orbius-core' ),
						'dotted' => esc_html__( 'Dotted', 'orbius-core' ),
						'dashed' => esc_html__( 'Dashed', 'orbius-core' ),
					],
					'condition'   => [
						'cf7_style' => 'box',
					],
					'selectors'   => [
						'{{WRAPPER}} .mk-cf7-style input:not([type=submit]):not([type="file"]), {{WRAPPER}} .mk-cf7-style select,{{WRAPPER}} .mk-cf7-style textarea,{{WRAPPER}}.mk-cf7-style-box .wpcf7-checkbox input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-box .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-style-box .wpcf7-acceptance input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-box .wpcf7-acceptance input[type="checkbox"] + span:before, {{WRAPPER}}.mk-cf7-style-box .wpcf7-radio input[type="radio"] + span:before' => 'border-style: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'input_border_size',
				[
					'label'      => esc_html__( 'Border Width', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px' ],
					'default'    => [
						'top'    => '1',
						'bottom' => '1',
						'left'   => '1',
						'right'  => '1',
						'unit'   => 'px',
					],
					'condition'  => [
						'cf7_style'           => 'box',
						'input_border_style!' => 'none',
					],
					'selectors'  => [
						'{{WRAPPER}} .mk-cf7-style input:not([type=submit]):not([type="file"]), {{WRAPPER}} .mk-cf7-style select,{{WRAPPER}} .mk-cf7-style textarea,{{WRAPPER}}.mk-cf7-style-box .wpcf7-checkbox input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-box .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-style-box .wpcf7-acceptance input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-box .wpcf7-acceptance input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-style-box .wpcf7-radio input[type="radio"] + span:before' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'input_border_color',
				[
					'label'     => esc_html__( 'Border Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'condition' => [
						'cf7_style'           => 'box',
						'input_border_style!' => 'none',
					],
					'default'   => '#000000',
					'selectors' => [
						'{{WRAPPER}} .mk-cf7-style input:not([type=submit]), {{WRAPPER}} .mk-cf7-style select,{{WRAPPER}} .mk-cf7-style textarea,{{WRAPPER}}.mk-cf7-style-box .wpcf7-checkbox input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-box .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-style-box .wpcf7-acceptance input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-box .wpcf7-acceptance input[type="checkbox"] + span:before, {{WRAPPER}}.mk-cf7-style-box .wpcf7-radio input[type="radio"] + span:before' => 'border-color: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-webkit-slider-runnable-track' => 'border: 0.2px solid {{VALUE}}; box-shadow: 1px 1px 1px {{VALUE}}, 0px 0px 1px {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-moz-range-track' => 'border: 0.2px solid {{VALUE}}; box-shadow: 1px 1px 1px {{VALUE}}, 0px 0px 1px {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-fill-lower' => 'border: 0.2px solid {{VALUE}}; box-shadow: 1px 1px 1px {{VALUE}}, 0px 0px 1px {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-fill-upper' => 'border: 0.2px solid {{VALUE}}; box-shadow: 1px 1px 1px {{VALUE}}, 0px 0px 1px {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'cf7_border_bottom',
				[
					'label'      => esc_html__( 'Border Size', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', 'em', 'rem' ],
					'range'      => [
						'px' => [
							'min' => 1,
							'max' => 20,
						],
					],
					'default'    => [
						'size' => '1',
						'unit' => 'px',
					],
					'condition'  => [
						'cf7_style' => 'underline',
					],
					'selectors'  => [
						'{{WRAPPER}}.mk-cf7-style-underline input:not([type=submit]),{{WRAPPER}}.mk-cf7-style-underline select,{{WRAPPER}}.mk-cf7-style-underline textarea' => 'border-width: 0 0 {{SIZE}}{{UNIT}} 0; border-style: solid;',
						'{{WRAPPER}}.mk-cf7-style-underline .wpcf7-checkbox input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-underline .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-style-underline .wpcf7-acceptance input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-underline .wpcf7-acceptance input[type="checkbox"] + span:before,{{WRAPPER}} .wpcf7-radio input[type="radio"] + span:before' => 'border-width: {{SIZE}}{{UNIT}}; border-style: solid; box-sizing: content-box;',
					],
				]
			);

			$this->add_control(
				'cf7_border_color',
				[
					'label'     => esc_html__( 'Border Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'condition' => [
						'cf7_style' => 'underline',
					],
					'default'   => '#000000',
					'selectors' => [
						'{{WRAPPER}}.mk-cf7-style-underline input:not([type=submit]),{{WRAPPER}}.mk-cf7-style-underline select,{{WRAPPER}}.mk-cf7-style-underline textarea, {{WRAPPER}}.mk-cf7-style-underline .wpcf7-checkbox input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-underline .wpcf7-checkbox input[type="checkbox"] + span:before, {{WRAPPER}}.mk-cf7-style-underline .wpcf7-acceptance input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-style-underline .wpcf7-acceptance input[type="checkbox"] + span:before, {{WRAPPER}} .wpcf7-radio input[type="radio"] + span:before' => 'border-color: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style-underline input[type=range]::-webkit-slider-runnable-track' => 'border: 0.2px solid {{VALUE}}; box-shadow: 1px 1px 1px {{VALUE}}, 0px 0px 1px {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-moz-range-track' => 'border: 0.2px solid {{VALUE}}; box-shadow: 1px 1px 1px {{VALUE}}, 0px 0px 1px {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-fill-lower' => 'border: 0.2px solid {{VALUE}}; box-shadow: 1px 1px 1px {{VALUE}}, 0px 0px 1px {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-fill-upper' => 'border: 0.2px solid {{VALUE}}; box-shadow: 1px 1px 1px {{VALUE}}, 0px 0px 1px {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'cf7_ipborder_active',
				[
					'label'     => esc_html__( 'Border Active Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'default'   => '#000000',
					'selectors' => [
						'{{WRAPPER}} .mk-cf7-style .wpcf7 form input:not([type=submit]):focus, {{WRAPPER}} .mk-cf7-style select:focus, {{WRAPPER}} .mk-cf7-style .wpcf7 textarea:focus, {{WRAPPER}} .mk-cf7-style .wpcf7-checkbox input[type="checkbox"]:checked + span:before,{{WRAPPER}} .mk-cf7-style .wpcf7-acceptance input[type="checkbox"]:checked + span:before, {{WRAPPER}} .mk-cf7-style .wpcf7-radio input[type="radio"]:checked + span:before' => 'border-color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'cf7_input_radius',
				[
					'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .mk-cf7-style input:not([type="submit"]), {{WRAPPER}} .mk-cf7-style select, {{WRAPPER}} .mk-cf7-style textarea, {{WRAPPER}} .wpcf7-checkbox input[type="checkbox"] + span:before, {{WRAPPER}} .wpcf7-acceptance input[type="checkbox"] + span:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
	}

	protected function register_radio_content_controls() {

		mk_elem_start_ctrl($this, 'cf7_radio_check_style', 'Radio & Checkbox');

            $this->add_control('cf7_radio_check_adv',[
                'label' => esc_html__( 'Override Current Style', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'prefix_class' => 'mk-cf7-check-'
            ]);

			$this->add_control(
				'cf7_radio_check_size',
				[
					'label'      => esc_html__( 'Size', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', 'em', 'rem' ],
					'condition'  => [
						'cf7_radio_check_adv!' => '',
					],
					'default'    => [
						'unit' => 'px',
						'size' => 20,
					],
					'range'      => [
						'px' => [
							'min' => 15,
							'max' => 50,
						],
					],
					'selectors'  => [
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-check-yes .wpcf7-radio input[type="radio"] + span:before' => 'width: {{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"]:checked + span:before,{{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"]:checked + span:before'  => 'font-size: calc( {{SIZE}}{{UNIT}} / 1.2 );',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-webkit-slider-thumb' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-moz-range-thumb' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-ms-thumb' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-webkit-slider-runnable-track' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-moz-range-track' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-ms-fill-lower' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-ms-fill-upper' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'cf7_radio_check_bgcolor',
				[
					'label'     => esc_html__( 'Background Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'default'   => '#f2f2f2',
					'condition' => [
						'cf7_radio_check_adv!' => '',
					],
					'selectors' => [
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"] + span:before, {{WRAPPER}}.mk-cf7-check-yes .wpcf7-radio input[type="radio"]:not(:checked) + span:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-webkit-slider-runnable-track,{{WRAPPER}}.mk-cf7-check-yes input[type=range]:focus::-webkit-slider-runnable-track' => 'background-color: {{VALUE}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-moz-range-track,{{WRAPPER}} input[type=range]:focus::-moz-range-track' => 'background-color: {{VALUE}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-ms-fill-lower,{{WRAPPER}}.mk-cf7-check-yes input[type=range]:focus::-ms-fill-lower' => 'background-color: {{VALUE}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-ms-fill-upper,{{WRAPPER}}.mk-cf7-check-yes input[type=range]:focus::-ms-fill-upper' => 'background-color: {{VALUE}};',
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-radio input[type="radio"]:checked + span:before' => 'box-shadow:inset 0px 0px 0px 4px {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'cf7_selected_color',
				[
					'label'     => esc_html__( 'Selected Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'condition' => [
						'cf7_radio_check_adv!' => '',
					],
					'selectors' => [
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"]:checked + span:before,{{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"]:checked + span:before' => 'color: {{VALUE}};',
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-radio input[type="radio"]:checked + span:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}}.mk-cf7-check-yes input[type=range]::-webkit-slider-thumb' => 'border: 1px solid {{VALUE}}; background: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-moz-range-thumb' => 'border: 1px solid {{VALUE}}; background: {{VALUE}};',
						'{{WRAPPER}} .mk-cf7-style input[type=range]::-ms-thumb' => 'border: 1px solid {{VALUE}}; background: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'cf7_radio_label_color',
				[
					'label'     => esc_html__( 'Label Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'default'   => '',
					'condition' => [
						'cf7_radio_check_adv!' => '',
					],
					'selectors' => [
						'{{WRAPPER}} .mk-cf7-style input[type="checkbox"] + span, .mk-cf7-style input[type="radio"] + span' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'cf7_check_border_color',
				[
					'label'     => esc_html__( 'Border Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'default'   => '#000000',
					'condition' => [
						'cf7_radio_check_adv!' => '',
					],
					'selectors' => [
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"] + span:before, {{WRAPPER}}.mk-cf7-check-yes .wpcf7-radio input[type="radio"] + span:before' => 'border-color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'cf7_check_border_width',
				[
					'label'      => esc_html__( 'Border Width', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range'      => [
						'px' => [
							'min' => 1,
							'max' => 20,
						],
					],
					'default'    => [
						'size' => '1',
						'unit' => 'px',
					],
					'condition'  => [
						'cf7_radio_check_adv!' => '',
					],
					'selectors'  => [
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"] + span:before,{{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"]:checked + span:before, {{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"] + span:before, {{WRAPPER}}.mk-cf7-check-yes .wpcf7-radio input[type="radio"] + span:before, {{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"]:checked + span:before' => 'border-width: {{SIZE}}{{UNIT}}; border-style: solid;',
					],
				]
			);

			$this->add_control(
				'cf7_check_border_radius',
				[
					'label'      => esc_html__( 'Checkbox Rounded Corners', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%' ],
					'condition'  => [
						'cf7_radio_check_adv!' => '',
					],
					'selectors'  => [
						'{{WRAPPER}}.mk-cf7-check-yes .wpcf7-checkbox input[type="checkbox"] + span:before, {{WRAPPER}}.mk-cf7-check-yes .wpcf7-acceptance input[type="checkbox"] + span:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'default'    => [
						'top'    => '0',
						'bottom' => '0',
						'left'   => '0',
						'right'  => '0',
						'unit'   => 'px',
					],
				]
			);

		$this->end_controls_section();
	}

	protected function register_button_content_controls() {

		mk_elem_start_ctrl($this, 'cf7_submit_button', 'Submit Button');

			$this->add_responsive_control('cf7_button_align', [
				'label'        => esc_html__( 'Button Alignment', 'orbius-core' ),
				'type'         => \Elementor\Controls_Manager::CHOOSE,
				'options'      => mk_arrays('text_align_all'),
				'default'      => 'left',
				'prefix_class' => 'mk%s-cf7-button-',
				'toggle'       => false,
                'condition'    => ['btn_abs_position!' => 'yes']
			]);

			$this->add_responsive_control('cf7_button_padding', [
				'label'      => esc_html__( 'Padding', 'orbius-core' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .mk-cf7-style button.wpcf7-submit' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]);

			$this->add_responsive_control(
				'cf7_button_margin',
				[
					'label'      => esc_html__( 'Margin', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .mk-cf7-style button.wpcf7-submit' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

            $this->add_control('btn_text_hide',[
                'label' => esc_html__( 'Hide Button Text', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'prefix_class'  => 'mk-cf7-hide-button-text-',
            ]);

            $this->add_control('btn_arrow_icon',[
                'label' => esc_html__( 'Arrow Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'prefix_class'  => 'mk-cf7-arrow-icon-',
            ]);

            $this->add_responsive_control('btn_arrow_icon_size', [
                'label'      => esc_html__( 'Icon Size', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'rem' ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'condition' => ['btn_arrow_icon' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}}.mk-cf7-arrow-icon-yes button.wpcf7-submit .swm-cf7-btn-icon' => 'font-size:{{SIZE}}{{UNIT}};',
                ],
            ]);
            $this->add_responsive_control('btn_arrow_icon_spacing', [
                'label'      => esc_html__( 'Spacing', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'rem' ],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'condition' => ['btn_arrow_icon' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}}.mk-cf7-arrow-icon-yes button.wpcf7-submit .swm-cf7-btn-icon' => 'margin-left:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('btn_abs_position',[
                'label' => esc_html__( 'Absolute Position', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

			$this->start_controls_tabs( 'tabs_button_style' );

				$this->start_controls_tab(
					'tab_button_normal',
					[
						'label' => esc_html__( 'Normal', 'orbius-core' ),
					]
				);

					$this->add_control(
						'button_text_color',
						[
							'label'     => esc_html__( 'Text Color', 'orbius-core' ),
							'type'      => \Elementor\Controls_Manager::COLOR,
							'default'   => '#000000',
							'selectors' => [
								'{{WRAPPER}} .mk-cf7-style button.wpcf7-submit' => 'color: {{VALUE}};',
                                '{{WRAPPER}}.mk-cf7-arrow-icon-yes button.wpcf7-submit .swm-cf7-btn-icon' => 'stroke: {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Background::get_type(),
						[
							'name'           => 'btn_background_color',
							'label'          => esc_html__( 'Background Color', 'orbius-core' ),
							'types'          => [ 'classic', 'gradient' ],
							'fields_options' => [
								'background' => [
									'default' =>'classic',
								],
								'color' => [
									'default' => '#ffffff',
								],
							],
							'selector'       => '{{WRAPPER}} .mk-cf7-style button.wpcf7-submit',
						]
					);

					$this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
						'name'        => 'btn_border',
						'label'       => esc_html__( 'Border', 'orbius-core' ),
						'placeholder' => '1px',
						'default'     => '1px',
						'selector'    => '{{WRAPPER}} .mk-cf7-style button.wpcf7-submit',
					]);

					$this->add_responsive_control(
						'btn_border_radius',
						[
							'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
							'type'       => \Elementor\Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%' ],
							'selectors'  => [
								'{{WRAPPER}} .mk-cf7-style button.wpcf7-submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Box_Shadow::get_type(),
						[
							'name'     => 'button_box_shadow',
							'selector' => '{{WRAPPER}} .mk-cf7-style button.wpcf7-submit',
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'tab_button_hover',
					[
						'label' => esc_html__( 'Hover', 'orbius-core' ),
					]
				);

					$this->add_control(
						'btn_hover_color',
						[
							'label'     => esc_html__( 'Text Color', 'orbius-core' ),
							'type'      => \Elementor\Controls_Manager::COLOR,
							'default'   => '#ffffff',
							'selectors' => [
								'{{WRAPPER}} .mk-cf7-style button.wpcf7-submit:hover' => 'color: {{VALUE}};',
                                '{{WRAPPER}}.mk-cf7-arrow-icon-yes button.wpcf7-submit:hover .swm-cf7-btn-icon' => 'stroke: {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'button_hover_border_color',
						[
							'label'     => esc_html__( 'Border Hover Color', 'orbius-core' ),
							'type'      => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .mk-cf7-style button.wpcf7-submit:hover' => 'border-color: {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Background::get_type(),
						[
							'name'     => 'button_background_hover_color',
							'label'    => esc_html__( 'Background Color', 'orbius-core' ),
							'types'    => [ 'classic', 'gradient' ],
							'fields_options' => [
								'background' => [
									'default' =>'classic',
								],
								'color' => [
									'default' => '#000000',
								],
							],
							'selector' => '{{WRAPPER}} .mk-cf7-style button.wpcf7-submit:hover',
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function register_error_content_controls() {

		mk_elem_start_ctrl($this, 'cf7_error_field', 'Success / Error Message');

			mk_elem_heading_ctrl($this, 'cf7_field_message', 'Field Validation', 'before' );

				$this->add_control(
					'cf7_highlight_style',
					[
						'label'        => esc_html__( 'Message Position', 'orbius-core' ),
						'type'         => \Elementor\Controls_Manager::SELECT,
						'default'      => 'default',
						'options'      => [
							'default'      => esc_html__( 'Default', 'orbius-core' ),
							'bottom_right' => esc_html__( 'Bottom Right Side of Field', 'orbius-core' ),
						],
						'prefix_class' => 'mk-cf7-highlight-style-',
					]
				);

				$this->add_control(
					'cf7_message_color',
					[
						'label'     => esc_html__( 'Message Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '#000000',
						'condition' => [
							'cf7_highlight_style' => 'default',
						],
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style span.wpcf7-not-valid-tip' => 'color: {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'cf7_message_highlight_color',
					[
						'label'     => esc_html__( 'Message Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '#000000',
						'condition' => [
							'cf7_highlight_style' => 'bottom_right',
						],
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style span.wpcf7-not-valid-tip' => 'color: {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'cf7_message_bgcolor',
					[
						'label'     => esc_html__( 'Message Background Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => 'rgba(255, 0, 0, 0.6)',
						'condition' => [
							'cf7_highlight_style' => 'bottom_right',
						],
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style span.wpcf7-not-valid-tip' => 'background-color: {{VALUE}}; padding: 0.1em 0.8em;',
						],
					]
				);

                $this->add_control('cf7_highlight_border',[
                    'label'   => esc_html__( 'Highlight Borders', 'orbius-core' ),
                    'type'    => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'no',
                    'prefix_class' => 'mk-cf7-highlight-',
                ]);

				$this->add_control(
					'cf7_highlight_border_color',
					[
						'label'     => esc_html__( 'Highlight Border Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '#000000',
						'condition' => [
							'cf7_highlight_border' => 'yes',
						],
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style .wpcf7-form-control.wpcf7-not-valid, {{WRAPPER}} .mk-cf7-style .wpcf7-form-control.wpcf7-not-valid .wpcf7-list-item-label:before' => 'border-color: {{VALUE}};',
						],
					]
				);

				$this->add_responsive_control(
					'cf7_valid_message_margin',
					[
						'label'      => esc_html__( 'Margin', 'orbius-core' ),
						'type'       => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors'  => [
							'{{WRAPPER}} .mk-cf7-style span.wpcf7-not-valid-tip' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

				$this->add_group_control(
					\Elementor\Group_Control_Typography::get_type(),
					[
						'name'     => 'cf7_message_typo',
						'selector' => '{{WRAPPER}} .mk-cf7-style span.wpcf7-not-valid-tip',
					]
				);

			mk_elem_heading_ctrl($this, 'cf7_validation_message', 'Form Success / Error Validation', 'before' );

				$this->add_control(
					'cf7_success_message_color',
					[
						'label'     => esc_html__( 'Success Message Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '',
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style .sent .wpcf7-response-output, {{WRAPPER}} .mk-cf7-style .wpcf7-mail-sent-ok' => 'color: {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'cf7_success_message_bgcolor',
					[
						'label'     => esc_html__( 'Success Message Background Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '',
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style .sent .wpcf7-response-output, {{WRAPPER}} .mk-cf7-style .wpcf7-mail-sent-ok' => 'background-color: {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'cf7_success_border_color',
					[
						'label'     => esc_html__( 'Success Border Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '#008000',
						'condition' => [
							'cf7_valid_border_size!' => '',
						],
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style .sent .wpcf7-response-output, {{WRAPPER}} .mk-cf7-style .wpcf7-mail-sent-ok' => 'border-color: {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'cf7_error_message_color',
					[
						'label'     => esc_html__( 'Error Message Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '',
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style .invalid .wpcf7-response-output, {{WRAPPER}} .mk-cf7-style .wpcf7 .wpcf7-validation-errors, {{WRAPPER}} .mk-cf7-style div.wpcf7-mail-sent-ng,{{WRAPPER}} .mk-cf7-style .wpcf7-acceptance-missing' => 'color: {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'cf7_error_message_bgcolor',
					[
						'label'     => esc_html__( 'Error Message Background Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '',
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style .invalid .wpcf7-response-output, {{WRAPPER}} .mk-cf7-style .wpcf7 .wpcf7-validation-errors, {{WRAPPER}} .mk-cf7-style div.wpcf7-mail-sent-ng,{{WRAPPER}} .mk-cf7-style .wpcf7-acceptance-missing' => 'background-color: {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'cf7_error_border_color',
					[
						'label'     => esc_html__( 'Error Border Color', 'orbius-core' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'default'   => '#000000',
						'condition' => [
							'cf7_valid_border_size!' => '',
						],
						'selectors' => [
							'{{WRAPPER}} .mk-cf7-style .wpcf7 .wpcf7-validation-errors, {{WRAPPER}} .mk-cf7-style div.wpcf7-mail-sent-ng,{{WRAPPER}} .mk-cf7-style .wpcf7-acceptance-missing' => 'border-color: {{VALUE}};',
						],
					]
				);

				$this->add_responsive_control(
					'cf7_valid_border_size',
					[
						'label'      => esc_html__( 'Border Size', 'orbius-core' ),
						'type'       => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'default'    => [
							'top'    => '2',
							'bottom' => '2',
							'left'   => '2',
							'right'  => '2',
							'unit'   => 'px',
						],
						'selectors'  => [
							'{{WRAPPER}} .mk-cf7-style .wpcf7 .wpcf7-validation-errors, {{WRAPPER}} .mk-cf7-style div.wpcf7-mail-sent-ng,{{WRAPPER}} .mk-cf7-style .wpcf7-acceptance-missing' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}; border-style: solid;',
						],
					]
				);

				$this->add_responsive_control(
					'cf7_valid_message_radius',
					[
						'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
						'type'       => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors'  => [
							'{{WRAPPER}} .mk-cf7-style .wpcf7 .wpcf7-validation-errors, {{WRAPPER}} .mk-cf7-style div.wpcf7-mail-sent-ng, {{WRAPPER}} .mk-cf7-style .wpcf7-acceptance-missing' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

				$this->add_responsive_control(
					'cf7_valid_message_padding',
					[
						'label'      => esc_html__( 'Padding', 'orbius-core' ),
						'type'       => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors'  => [
							'{{WRAPPER}} .mk-cf7-style .wpcf7 .wpcf7-validation-errors, {{WRAPPER}} .mk-cf7-style div.wpcf7-mail-sent-ng, {{WRAPPER}} .mk-cf7-style .wpcf7-acceptance-missing' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

				$this->add_responsive_control(
					'cf7_valid_message_box_margin',
					[
						'label'      => esc_html__( 'Margin', 'orbius-core' ),
						'type'       => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors'  => [
							'{{WRAPPER}} .mk-cf7-style .wpcf7 .wpcf7-validation-errors,
                            {{WRAPPER}} .mk-cf7-style div.wpcf7-mail-sent-ng,
                            {{WRAPPER}} .mk-cf7-style .wpcf7-acceptance-missing,
                            {{WRAPPER}} .mk-cf7-style .wpcf7 div.wpcf7-response-output' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

						],
						'separator'  => 'after',
					]
				);

				$this->add_group_control(
					\Elementor\Group_Control_Typography::get_type(),
					[
						'name'     => 'cf7_validation_typo',
						'selector' => '{{WRAPPER}} .mk-cf7-style .wpcf7 .wpcf7-validation-errors, {{WRAPPER}} .mk-cf7-style div.wpcf7-mail-sent-ng,{{WRAPPER}} .mk-cf7-style .wpcf7-mail-sent-ok,{{WRAPPER}} .mk-cf7-style .wpcf7-acceptance-missing',
					]
				);

		$this->end_controls_section();
	}

	protected function register_input_style_controls() {

		mk_elem_start_ctrl($this, 'cf7_input_spacing', 'Spacing & Height');

			$this->add_responsive_control(
				'cf7_input_margin_top',
				[
					'label'      => esc_html__( 'Between Label & Input', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', 'em', 'rem' ],
					'range'      => [
						'px' => [
							'min' => 1,
							'max' => 60,
						],
					],
					'default'    => [
						'unit' => 'px',
						'size' => 5,
					],
					'selectors'  => [
						'{{WRAPPER}} .mk-cf7-style input:not([type=submit]):not([type=checkbox]):not([type=radio]),
						{{WRAPPER}} .mk-cf7-style .mk-cf7-icon i,
						{{WRAPPER}} .mk-cf7-style select,
						{{WRAPPER}} .mk-cf7-style textarea,
						{{WRAPPER}} .mk-cf7-style span.wpcf7-list-item' => 'margin-top: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'cf7_input_margin_bottom',
				[
					'label'      => esc_html__( 'Between Fields', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', 'em', 'rem' ],
					'range'      => [
						'px' => [
							'min' => -50,
							'max' => 100,
						],
					],
					'default'    => [
						'unit' => 'px',
						'size' => 10,
					],
					'selectors'  => [
						'{{WRAPPER}} .mk-cf7-style input:not([type=submit]):not([type=checkbox]):not([type=radio]),
						{{WRAPPER}} .mk-cf7-style .mk-cf7-icon i,
						{{WRAPPER}} .mk-cf7-style select,
						{{WRAPPER}} .mk-cf7-style textarea,
						{{WRAPPER}} .mk-cf7-style span.wpcf7-list-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'cf7_textarea_height',
				[
					'label'      => esc_html__( 'Textarea Height', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', 'em', 'rem' ],
					'range'      => [
						'px' => [
							'min' => 1,
							'max' => 500,
						],
					],
					'default'    => [
						'unit' => 'px',
						'size' => 150,
					],
					'selectors'  => [
						'{{WRAPPER}} .mk-cf7-style .wpcf7 textarea' => 'height:{{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
	}

    protected function register_textarea_style_controls() {

        mk_elem_start_ctrl($this, 'cf7_textarea_style', 'Textarea');

            $this->add_control('cf7_textarea_override',[
                'label' => esc_html__( 'Override Current Style', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('cf7_textarea_bgcolor',[
                'label'     => esc_html__( 'Field Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#ffffff',
                'condition' => ['cf7_textarea_override' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-cf7-style textarea' => 'background-color: {{VALUE}};',
                ],
            ]);

            $this->add_control('cf7_textarea_color', [
                'label'     => esc_html__( 'Text Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#000000',
                'condition' => ['cf7_textarea_override' => 'yes'],
                'selectors' => [ '{{WRAPPER}} .mk-cf7-style .wpcf7 textarea' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('cf7_textarea_placeholder_color', [
                'label'     => esc_html__( 'Placeholder Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#000000',
                'condition' => ['cf7_textarea_override' => 'yes'],
                'selectors' => ['{{WRAPPER}} .mk-cf7-style .wpcf7 textarea::placeholder' => 'color: {{VALUE}};',],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'border_textarea',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-cf7-style .wpcf7 textarea',
                'condition' => ['cf7_textarea_override' => 'yes'],
            ]);

            $this->add_responsive_control('cf7_textarea_padding', [
                'label'      => esc_html__( 'Field Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'condition' => ['cf7_textarea_override' => 'yes'],
                'selectors'  => [ '{{WRAPPER}} .mk-cf7-style textarea' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};', ]
            ]);

            $this->add_responsive_control('cf7_textarea_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'allowed_dimensions' => ['top', 'bottom'],
                'condition' => ['cf7_textarea_override' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-cf7-style textarea' => 'margin: {{TOP}}{{UNIT}} 0 {{BOTTOM}}{{UNIT}} 0;',
                ],
            ]);

        $this->end_controls_section();
    }

	protected function register_typography_style_controls() {

		mk_elem_start_ctrl($this, 'cf7_typo', 'Typography');

			mk_elem_heading_ctrl($this, 'cf7_label_typo', 'Form Label', 'before' );

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name'     => 'form_label_typography',
					'selector' => '{{WRAPPER}} .mk-cf7-style .wpcf7 form.wpcf7-form label',
				]
			);

			mk_elem_heading_ctrl($this, 'cf7_input_typo', 'Input Text / Placeholder', 'before' );

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name'     => 'input_typography',
					'fields_options' => [
					    'typography' => [
					        'default' =>'custom',
					    ],
					    'font_size'   => [
					        'default' => [
					            'unit' => 'px',
					            'size' => '15',
					        ],
					    ],
					    'font_weight' => [
					        'default' => '400',
					    ],
					],
					'selector' => '{{WRAPPER}} .mk-cf7-style .wpcf7 input:not([type=submit]),
					{{WRAPPER}} .mk-cf7-style .wpcf7 .mk-cf7-icon,
					{{WRAPPER}} .mk-cf7-style .wpcf7 input::placeholder,
					{{WRAPPER}} .wpcf7 select,
					{{WRAPPER}} .mk-cf7-style .wpcf7 textarea,
					{{WRAPPER}} .mk-cf7-style .wpcf7 textarea::placeholder,
					{{WRAPPER}} .mk-cf7-style input[type=range]::-webkit-slider-thumb,{{WRAPPER}} .mk-cf7-style .mk-cf7-select-custom',
				]
			);

			mk_elem_heading_ctrl($this, 'btn_typography_label', 'Button', 'before' );

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name'     => 'btn_typography',
					'label'    => esc_html__( 'Typography', 'orbius-core' ),
					'selector' => '{{WRAPPER}} .mk-cf7-style button[type=submit]',
				]
			);

			mk_elem_heading_ctrl($this, 'cf7_radio_check_typo', 'Radio Button & Checkbox', 'before', ['cf7_radio_check_adv!' => ''] );

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name'      => 'radio_check_typography',
					'condition' => [
						'cf7_radio_check_adv!' => '',
					],
					'selector'  => '{{WRAPPER}} .mk-cf7-style input[type="checkbox"] + span, .mk-cf7-style input[type="radio"] + span',
				]
			);

		$this->end_controls_section();
	}

	protected function render_editor_script() {

		if ( \Elementor\Plugin::instance()->editor->is_edit_mode() === false ) {
			return;
		}

		$pre_url = wpcf7_get_request_uri();

		if ( strpos( $pre_url, 'admin-ajax.php' ) === false ) {
			return;
		}

		?><script type="text/javascript">
			jQuery( document ).ready( function( $ ) {

				$( '.mk-cf7-container' ).each( function() {

					var $node_id 	= '<?php echo $this->get_id(); ?>';
					var	scope 		= $( '[data-id="' + $node_id + '"]' );
					var selector 	= $(this);

					if ( selector.closest( scope ).length < 1 ) {
						return;
					}

					if ( selector.find( 'div.wpcf7 > form' ).length < 1 ) {
						return;
					}

					selector.find( 'div.wpcf7 > form' ).each( function() {
						var $form = $( this );
						wpcf7.initForm( $form );
					} );
				});
			});
		</script>
		<?php
	}

	protected function render() {

		if ( ! class_exists( 'WPCF7_ContactForm' ) ) {
			return;
		}

		$settings      = $this->get_settings();
		$node_id       = $this->get_id();
		$field_options = array();
		$classname     = '';

		$args = array(
			'post_type'      => 'wpcf7_contact_form',
			'posts_per_page' => -1,
		);

		$forms              = get_posts( $args );
		$field_options['0'] = 'select';
		if ( $forms ) {
			foreach ( $forms as $form ) {
				$field_options[ $form->ID ] = $form->post_title;
			}
		}

		$this->add_inline_editing_attributes( 'mk_cf7_title' );
		$forms = $this->get_cf7_forms();

		$html = '';

		if ( ! empty( $forms ) && ! isset( $forms[-1] ) ) {
			if ( 0 == $settings['select_form'] ) {
				$html = esc_html__( 'Please select a Contact Form 7 from dropdown.', 'orbius-core' );
			} else {
				?>
				<div class = "mk-cf7-container mk-cf7-btn-abs-<?php echo $settings['btn_abs_position']; ?>">
						<div class = "mk-cf7 mk-cf7-style elementor-clickable">
						<?php
						if ( $settings['select_form'] ) {
							echo do_shortcode( '[contact-form-7 id=' . $settings['select_form'] . ']' );
						}
						?>
					</div>
				</div>
				<?php
			}
		} else {
			$html = esc_html__( 'Contact Form not found. Please add contact form from Dashboard > Contact > Add New.', 'orbius-core' );
		}
		echo $html;

		$this->render_editor_script();
	}

}