<?php

if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Countdown extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_countdown'; }
	public function get_title()          { return esc_html__( 'Countdown', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-countdown'; }
	public function get_categories()     { return ['mk-advanced-addons' ]; }
	public function get_keywords()       { return ['countdown', 'count down', 'timer' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }
	public function get_script_depends() { return ['countdown', 'mk-widgets']; }

	protected function register_controls() {

		mk_elem_start_ctrl($this, 'countdown_content', 'Countdown');

		$this->add_control(
			'countdown_time',
			[
				'label'	=> esc_html__( 'Due Date', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
				'picker_options' => [
					'format' => 'Ym/d H:m:s'
				],
				'default' => date( "Y/m/d H:m:s", strtotime("+ 25 Day") ),
			]
		);

        $this->add_control('standard_countdown',[
            'label' => esc_html__( 'Standard Countdown', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

		$this->add_control(
			'units',
			[
				'label' => esc_html__( 'Time Units', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => [
					'year' => esc_html__( 'Years', 'orbius-core' ),
					'month' => esc_html__( 'Month', 'orbius-core' ),
					'week' => esc_html__( 'Week', 'orbius-core' ),
					'day' => esc_html__( 'Day', 'orbius-core' ),
					'hour' => esc_html__( 'Hours', 'orbius-core' ),
					'minute' => esc_html__( 'Minutes', 'orbius-core' ),
					'second' => esc_html__( 'Second', 'orbius-core' ),
				],
				'default' => [
					'year',
					'month',
					'week',
					'day',
					'hour',
					'minute',
					'second',
				],
				'multiple' => true,
				'condition' => [
					'standard_countdown!' => 'yes'
				]
			]
		);
		$this->add_responsive_control('alignment', [
			'label' => esc_html__( 'Alignment', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::CHOOSE,
			'options' => mk_arrays('text_align'),
			'default' => 'center',
			'separator' => 'after',
			'selectors' => [
				'{{WRAPPER}} .mk-countdown' => 'text-align: {{VALUE}};',
			],
		]);

        $this->add_control('text_state',[
            'label' => esc_html__( 'Text', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
            'return_value' => 'yes',
        ]);

		$this->add_control(
			'action',
			[
				'label' => esc_html__('Action', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'text' => esc_html__('Message', 'orbius-core'),
					'url' => esc_html__('Redirection Link', 'orbius-core')
				],
				'description' => esc_html__('Choose whether if you want to set a message or a redirect link', 'orbius-core'),
				'default'		=> 'text'
			]
		);
		$this->add_control(
			'message',
			[
				'label'	=> esc_html__('Message', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => 'Countdown is finished!',
				'condition' => [
					'action' => 'text'
				]
			]
		);
		$this->add_control(
			'redirect',
			[
				'label'	=> esc_html__('Redirect To', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'action' => 'url'
				],
				'default' => get_permalink( 1 )
			]
		);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'counter_translation', 'Translation', false, ['text_state' => 'yes' ]);

		$this->add_control(
			'text_year',
			[
				'label'	=> esc_html__('Year', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Year',
				'condition' => [
					'standard_countdown!' => 'yes'
				]
			]
		);

		$this->add_control(
			'text_years',
			[
				'label'	=> esc_html__('Years', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Years',
				'condition' => [
					'standard_countdown!' => 'yes'
				]
			]
		);

		$this->add_control(
			'text_month',
			[
				'label'	=> esc_html__('Month', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Month',
				'condition' => [
					'standard_countdown!' => 'yes'
				]
			]
		);

		$this->add_control(
			'text_months',
			[
				'label'	=> esc_html__('Months', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Months',
				'condition' => [
					'standard_countdown!' => 'yes'
				]
			]
		);

		$this->add_control(
			'text_week',
			[
				'label'	=> esc_html__('Week', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Week',
				'condition' => [
					'standard_countdown!' => 'yes'
				]
			]
		);

		$this->add_control(
			'text_weeks',
			[
				'label'	=> esc_html__('Weeks', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Weeks',
				'condition' => [
					'standard_countdown!' => 'yes'
				]
			]
		);

		$this->add_control(
			'text_day',
			[
				'label'	=> esc_html__('Day', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Day',
			]
		);

		$this->add_control(
			'text_days',
			[
				'label'	=> esc_html__('Days', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Days',
			]
		);

		$this->add_control(
			'text_hour',
			[
				'label'	=> esc_html__('Hour', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Hour',
			]
		);

		$this->add_control(
			'text_hours',
			[
				'label'	=> esc_html__('Hours', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Hours',
			]
		);

		$this->add_control(
			'text_minute',
			[
				'label'	=> esc_html__('Minute', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Minute',
			]
		);

		$this->add_control(
			'text_minutes',
			[
				'label'	=> esc_html__('Minutes', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Minutes',
			]
		);

		$this->add_control(
			'text_second',
			[
				'label'	=> esc_html__('Second', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Second',
			]
		);

		$this->add_control(
			'text_seconds',
			[
				'label'	=> esc_html__('Seconds', 'orbius-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Seconds',
			]
		);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'box_style', 'Box', true);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => esc_html__( 'Background', 'orbius-core' ),
				'types' => [ 'classic', 'gradient' ],
				'fields_options' => [
					'background' => [
						'default' =>'classic',
					],
					'color' => [
						'default' => '#d83030',
					],
				],
				'selector' => '{{WRAPPER}} .mk-cd',
			]
		);

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name'        => 'box_border',
            'label'       => esc_html__( 'Border', 'orbius-core' ),
            'selector'    => '{{WRAPPER}} .mk-cd',
        ]);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'selector' => '{{WRAPPER}} .mk-cd',
			]
		);
		$this->add_responsive_control(
			'width',
			[
				'label' => esc_html__( 'Width', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 200,
					],
				],
				'default' => [
					'size' => '100',
				],
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .mk-cd' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'height',
			[
				'label' => esc_html__( 'Height', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 200,
					],
				],
				'default' => [
					'size' => '110',
				],
				'selectors' => [
					'{{WRAPPER}} .mk-cd' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'box_radius',
			[
				'label' => esc_html__( 'Radius', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'top' => '6',
					'right' => '6',
					'bottom' => '6',
					'left' => '6',
					'isLinked' => true,
				],
				'selectors' => [
					'{{WRAPPER}} .mk-cd' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'box_padding',
			[
				'label' => esc_html__( 'Padding', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'top' => '10',
					'right' => '10',
					'bottom' => '10',
					'left' => '10',
					'isLinked' => true,
				],
				'selectors' => [
					'{{WRAPPER}} .mk-cd' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'box_margin',
			[
				'label' => esc_html__( 'Margin', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'top' => '6',
					'right' => '6',
					'bottom' => '6',
					'left' => '6',
					'isLinked' => true,
				],
				'selectors' => [
					'{{WRAPPER}} .mk-cd' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'digit_style', 'Digit', true);

		$this->add_control(
			'digit_color',
			[
				'label' => esc_html__( 'Text Color', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#fff',
				'selectors' => [
					'{{WRAPPER}} .mk-cd' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'digit_typography',
				'fields_options' => [
					'typography' => [
						'default' =>'custom',
					],
					'font_size'   => [
						'default' => [
							'size' => '50',
						],
					],
					'line_height'   => [
						'default' => [
							'size' => '60',
						],
					],
				],
				'selector' => '{{WRAPPER}} .mk-cd',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'digit_shadow',
				'selector' => '{{WRAPPER}} .mk-cd',
			]
		);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'text_style', 'Text', true, ['text_state!' => '' ]);

		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#fff',
				'selectors' => [
					'{{WRAPPER}} .mk-cd .mk-cd-text' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'fields_options' => [
					'typography' => [
						'default' =>'custom',
					],
					'font_size'   => [
						'default' => [
							'size' => '16',
						],
					],
					'line_height'   => [
						'default' => [
							'size' => '24',
						],
					],
				],
				'selector' => '{{WRAPPER}} .mk-cd .mk-cd-text',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'text_shadow',
				'selector' => '{{WRAPPER}} .mk-cd .mk-cd-text',
			]
		);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'message_style', 'Message', true);

		$this->add_control(
			'message_color',
			[
				'label' => esc_html__( 'Text Color', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#d83030',
				'selectors' => [
					'{{WRAPPER}} .mk-cd-message' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'message_typography',
				'fields_options' => [
					'typography' => [
						'default' =>'custom',
					],
					'font_size'   => [
						'default' => [
							'size' => '32',
						],
					],
					'line_height'   => [
						'default' => [
							'size' => '40',
						],
					],
				],
				'selector' => '{{WRAPPER}} .mk-cd-message',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'message_shadow',
				'selector' => '{{WRAPPER}} .mk-cd-message',
			]
		);

		$this->end_controls_section();

        mk_elem_start_ctrl($this, 'dots_style', 'Dots', true);

            $this->add_control('dots_on',[
                'label' => esc_html__( 'Show Dots', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'return_value' => 'yes',
            ]);

            $this->add_responsive_control('dot_size', [
                'label' => esc_html__( 'Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'range' => ['px' => ['min' => 1, 'max' => 100, ] ],
                'default' => ['size' => '40'],
                'condition' => ['dots_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-cd-dots' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('vertical_offset', [
                    'label' => esc_html__( 'Vertical Offset', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::SLIDER,
                    'range' => ['px' => ['min' => -100, 'max' => 100, ] ],
                    'condition' => ['dots_on' => 'yes'],
                    'selectors' => [
                        '{{WRAPPER}} .mk-cd-dots' => 'margin-top: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_control('dots_color', [
                'label' => esc_html__( 'Dots Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['dots_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-cd-dots' => 'color: {{VALUE}};'
                ]
            ]);

        $this->end_controls_section();

	}

	protected function render() {
		$data = $this->get_settings_for_display();

		$countunit = $data['units'];

		if ( 'yes' == $data['standard_countdown'] ) {
			$countunit = array( 'day','hour','minute','second' );
		}

		?>
		<div class="mk-countdown" <?php

		if ( 'yes' != $data['standard_countdown'] ) { ?>

			data-text-year="<?php echo esc_attr( $data['text_year'] ); ?>"
			data-text-years="<?php echo esc_attr( $data['text_years'] ); ?>"
			data-text-month="<?php echo esc_attr( $data['text_month'] ); ?>"
			data-text-months="<?php echo esc_attr( $data['text_months'] ); ?>"
			data-text-week="<?php echo esc_attr( $data['text_week'] ); ?>"
			data-text-weeks="<?php echo esc_attr( $data['text_weeks'] ); ?>"

		<?php } ?>
		data-text-day="<?php echo esc_attr( $data['text_day'] ); ?>"
		data-text-days="<?php echo esc_attr( $data['text_days'] ); ?>"
		data-text-hour="<?php echo esc_attr( $data['text_hour'] ); ?>"
		data-text-hours="<?php echo esc_attr( $data['text_hours'] ); ?>"
		data-text-minute="<?php echo esc_attr( $data['text_minute'] ); ?>"
		data-text-minutes="<?php echo esc_attr( $data['text_minutes'] ); ?>"
		data-text-second="<?php echo esc_attr( $data['text_second'] ); ?>"
		data-text-seconds="<?php echo esc_attr( $data['text_seconds'] ); ?>"
		data-time="<?php echo esc_attr( $data['countdown_time'] ); ?>"
		data-text="<?php echo esc_attr( $data['text_state'] ); ?>"
		data-standard-countdown="<?php echo esc_attr( $data['standard_countdown'] ); ?>"
		data-link="<?php echo esc_attr( $data['redirect'] ); ?>"
		data-message="<?php echo esc_attr( $data['message'] ); ?>">
			<?php
			if( date_timestamp_get( date_create( $data['countdown_time'] ) ) > time() ) :
				foreach ($countunit as $value) :
				?><div class="mk-cd">
						<div class="mk-cd-<?php echo esc_attr($value); ?>">00</div>
						<?php if ( 'yes' == $data['text_state'] ) : ?>
							<div class="mk-cd-text">
								<?php echo esc_html( ucfirst($value) ); ?>
							</div>
						<?php endif; ?>
					</div><?php
                        if ('yes' == $data['dots_on'] ) {
                            echo '<span class="mk-cd-dots">:</span>';
                        }
				endforeach;
			endif;
			?>
		</div>
		<?php
	}

}