<?php
if ( ! defined( 'ABSPATH' ) ) {	exit; }

class Mk_Counter extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_counter'; }
	public function get_title()          { return esc_html__( 'Counter', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-counter'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'counter', 'number', 'timer' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }
	public function get_script_depends() { return ['jquery-numerator', 'mk-widgets']; }

	protected function register_controls() {

		mk_elem_start_ctrl($this, 'counter_content', 'Counter');

		$this->add_control('title', [
			'label'       => esc_html__( 'Title', 'orbius-core' ),
			'type'        => \Elementor\Controls_Manager::TEXTAREA,
			'label_block' => true,
			'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
			'description' => esc_html__( 'You can use HTML.', 'orbius-core' ),
			'default'     => 'photography',
		]);

        $this->add_control('start_number', [
            'label' => esc_html__( 'Start Number', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 1,
            'step' => 1,
            'min' => 0,
            'max' => 10000000,
        ]);

        $this->add_control('stop_number', [
            'label' => esc_html__( 'Stop Number', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 99,
            'step' => 1,
            'min' => 0,
            'max' => 10000000,
        ]);

		$this->add_control('delimiter', [
			'label'   => esc_html__( 'Thousand Delimiter', 'orbius-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'' => esc_html__( 'None', 'orbius-core' ),
				',' => esc_html__( 'Comma', 'orbius-core' ),
				'.' => esc_html__( 'Dot', 'orbius-core' ),
				'|' => esc_html__( 'Pipe', 'orbius-core' ),
				' ' => esc_html__( 'space', 'orbius-core' ),
			],
			'default' => '',
		]);

        $this->add_control('speed', [
            'label' => esc_html__( 'Counting Duration', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 2000,
            'step' => 100,
            'min' => 100,
            'max' => 10000,
        ]);

		$this->add_control('prefix', [
			'label' => esc_html__( 'Prefix', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::TEXT,
			'placeholder' => esc_html__( 'Enter Prefix', 'orbius-core' ),
		]);

		$this->add_control('suffix', [
			'label' => esc_html__( 'Suffix', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::TEXT,
			'placeholder' => esc_html__( 'Enter Suffix', 'orbius-core' ),
            'default' => '+',
		]);

		$this->end_controls_section();

        mk_elem_start_ctrl($this, 'counter_box_style', 'Counter Box', true);

            $this->add_control('content_position', [
                'label'     => esc_html__( 'Content Position', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::CHOOSE,
                'options'   => mk_arrays('align_flex'),
                'default'   => 'center',
                'selectors' => [
                    '{{WRAPPER}} .mk-counter' => 'align-items: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('counter_box_size', [
                'label' => esc_html__( 'Content Box Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ '%', 'px','vw','em' ],
                'range' => ['px' => ['max' => 1000, ], ],
                'condition' =>  ['content_position' => 'center'],
                'selectors' => [
                    '{{WRAPPER}} .mk-counter' => 'width: {{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}}',
                ],
            ]);

            $this->add_control('counter_box_bg_color', [
                'label' => esc_html__( 'Background Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' =>  ['content_position' => 'center'],
                'selectors' => [
                    '{{WRAPPER}} .mk-counter' => 'background-color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'     => 'counter_box_border',
                'label'    => esc_html__( 'Border', 'orbius-core' ),
                'condition' =>  ['content_position' => 'center'],
                'selector' => '{{WRAPPER}} .mk-counter',
            ]);

            $this->add_responsive_control('counter_box_radius', [
                'label' => esc_html__( 'Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-counter' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'number_style', 'Number', true);


		$this->add_control('number_color', [
			'label' => esc_html__( 'Color', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .mk-counter-number-wrap' => 'color: {{VALUE}};',
			],
		]);

        $this->add_control('gradient_number',[
            'label'   => esc_html__( 'Gradient Text', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
            'name'     => 'number_color_gradient',
            'label'    => esc_html__( 'Gradient Color', 'orbius-core' ),
            'types'    => [ 'gradient' ],
            'condition' => ['gradient_number' => 'yes'],
            'selector' => '{{WRAPPER}} .mk-counter-number-wrap .mk-counter-gradient',
        ]);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(), [
                'name' => 'number_typography',
				'selector' => '{{WRAPPER}} .mk-counter-number-wrap,{{WRAPPER}} .mk-counter-number-wrap .mk-counter-number ',
		]);

		$this->add_responsive_control('number_margin', [
			'label' => esc_html__( 'Margin', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .mk-counter-number-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

        $this->add_control( 'title_display_style', [
            'label' => esc_html__( 'Display Style', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'default' => 'Default',
                'stroke'  => 'Stroke'
            ],
            'default' => 'default',
        ]);

        $this->add_responsive_control('title_stroke_width', [
            'label' => esc_html__( 'Stroke Width', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px' ],
            'default' => ['size' => '1', 'unit' => 'px'],
            'condition'=> ['title_display_style' => 'stroke'],
            'selectors' => [
                '{{WRAPPER}} .mk-counter-number-wrap' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_control('title_stroke_color',[
            'label' => esc_html__( 'Stroke Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'condition'=> ['title_display_style' => 'stroke'],
            'selectors' => [
                '{{WRAPPER}} .mk-counter-number-wrap' => '-webkit-text-stroke-color: {{VALUE}};',
            ],
        ]);

		$this->add_group_control(\Elementor\Group_Control_Text_Shadow::get_type(), [
            'name' => 'number_shadow',
			'selector' => '{{WRAPPER}} .mk-counter-number-wrap',
		]);

        mk_elem_heading_ctrl($this, 'prefix_heading', 'Prefix', 'before' );

        $this->add_control('prefix_color', [
            'label' => esc_html__( 'Text Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-counter-prefix' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'prefix_typography',
            'selector' => '{{WRAPPER}} .mk-counter-prefix',
        ]);

        $this->add_responsive_control('prefix_margin', [
            'label' => esc_html__( 'Margin', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-counter-prefix' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_control('horizontal_align_prefix', [
            'label'   => esc_html__( 'Horizontal Align', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'flex-start' => esc_html__( 'Top', 'orbius-core' ),
                'center'     => esc_html__( 'Center', 'orbius-core' ),
                'flex-end'   => esc_html__( 'Bottom', 'orbius-core' ),
            ],
            'default' => 'center',
            'selectors' => [
                '{{WRAPPER}} .mk-counter-prefix' => 'align-self: {{VALUE}};',
            ],
        ]);

        mk_elem_heading_ctrl($this, 'suffix_heading', 'Suffix', 'before' );

        $this->add_control('suffix_color', [
            'label' => esc_html__( 'Text Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-counter-suffix' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'suffix_typography',
            'selector' => '{{WRAPPER}} .mk-counter-suffix',
        ]);

        $this->add_responsive_control('suffix_margin', [
            'label' => esc_html__( 'Margin', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-counter-suffix' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_control('horizontal_align_suffix', [
            'label'   => esc_html__( 'Horizontal Align', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'flex-start' => esc_html__( 'Top', 'orbius-core' ),
                'center'     => esc_html__( 'Center', 'orbius-core' ),
                'flex-end'   => esc_html__( 'Bottom', 'orbius-core' ),
            ],
            'default' => 'center',
            'selectors' => [
                '{{WRAPPER}} .mk-counter-suffix' => 'align-self: {{VALUE}};',
            ],
        ]);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'title_style', 'Title', true, ['title!' => '' ]);

        $this->add_control('title_position', [
            'label'   => esc_html__( 'Title Position ( For Display Style : Standard )', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'above_number' => esc_html__( 'Above Number', 'orbius-core' ),
                'below_number' => esc_html__( 'Below Number', 'orbius-core' ),
            ],
            'default' => 'below_number',
        ]);

        $this->add_responsive_control('title_max_width', [
            'label' => esc_html__( 'Max Width', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => ['px'],
            'range' => [
                'px' => [
                    'max' => 2000,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-counter-title' => 'max-width: {{SIZE}}{{UNIT}};',
            ],
        ]);

		$this->add_control('title_color', [
			'label' => esc_html__( 'Text Color', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .mk-counter-title' => 'color: {{VALUE}};',
			],
		]);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(), [
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .mk-counter-title',
		]);

        $this->add_control('title_text_align', [
            'label'   => esc_html__( 'Text Align', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::CHOOSE,
            'options' => mk_arrays('text_align'),
            'selectors' => [
                '{{WRAPPER}} .mk-counter-title' => 'text-align: {{VALUE}};',
            ],
        ]);

		$this->add_control('title_html_tag', [
			'label'   => esc_html__( 'Title HTML Tag', 'orbius-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'div',
			'options' => [
				'h1'   => esc_html__( 'H1', 'orbius-core' ),
				'h2'   => esc_html__( 'H2', 'orbius-core' ),
				'h3'   => esc_html__( 'H3', 'orbius-core' ),
				'h4'   => esc_html__( 'H4', 'orbius-core' ),
				'h5'   => esc_html__( 'H5', 'orbius-core' ),
				'h6'   => esc_html__( 'H6', 'orbius-core' ),
				'div'  => esc_html__( 'div', 'orbius-core' ),
				'span' => esc_html__( 'span', 'orbius-core' ),
				'p'    => esc_html__( 'p', 'orbius-core' ),
			],
		]);

        $this->add_group_control(
            \Elementor\Group_Control_Text_Shadow::get_type(), [
                'name' => 'title_shadow',
                'selector' => '{{WRAPPER}} .mk-counter-title',
        ]);

        $this->add_responsive_control('tittle_bot_margin', [
            'label' => esc_html__( 'Bottom Margin', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => ['px'],
            'range' => [
                'px' => [
                    'max' => 200,
                ],
            ],
            'default' => [
                'size' => '10'
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-counter-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
        ]);

		$this->end_controls_section();

	}


	protected function render() {
		$settings = $this->get_settings_for_display();
        $contentPosition = !empty($settings['content_position']) ? $settings['content_position'] : 'center';
		?>

        <div class="mk-counter content-box-align-<?php echo $contentPosition; ?>">

            <?php if ( '' != $settings['title'] && $settings['title_position'] === 'above_number' ) : ?>
                <<?php echo $settings['title_html_tag']; ?> class="mk-counter-title">
                    <?php echo $settings['title']; ?>
                </<?php echo $settings['title_html_tag']; ?>>
            <?php endif; ?>

            <?php if ( $settings['start_number'] && $settings['stop_number'] ): ?>

                <div class="mk-counter-number-wrap">

                    <?php if ( $settings['prefix']) { ?>
                        <span class="mk-counter-prefix"><?php echo esc_html($settings['prefix']); ?></span>
                    <?php } ?>

                    <span class="mk-counter-number<?php
                        if ( 'yes' == $settings['gradient_number'] ) {
                            echo ' mk-counter-gradient';
                        } ?>"
                    data-duration="<?php echo esc_attr($settings['speed']); ?>"
                    data-to-value="<?php echo esc_attr($settings['stop_number']); ?>"
                    data-delimiter="<?php echo esc_attr($settings['delimiter']); ?>">
                        <?php echo esc_html($settings['start_number']); ?>
                    </span>

                    <?php if ( $settings['suffix']) { ?>
                        <span class="mk-counter-suffix">
                            <?php echo esc_html($settings['suffix']); ?>
                        </span>
                    <?php } ?>

                </div>

            <?php endif; ?>

            <?php if ( '' != $settings['title'] && $settings['title_position'] === 'below_number' ) : ?>
                <<?php echo $settings['title_html_tag']; ?> class="mk-counter-title">
                    <?php echo $settings['title']; ?>
                </<?php echo $settings['title_html_tag']; ?>>
            <?php endif; ?>

        </div>

		<?php
	}


}