<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Dual_Slider extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_dual_slider'; }
    public function get_title()          { return esc_html__( 'Dual Slider', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return ['mk-sliders-elements']; }
    public function get_keywords()       { return [ 'theme','slider','slide show','dual','video','two','images']; }
    public function get_style_depends()  { return ['swiper','mk-core-main']; }
    public function get_script_depends() { return ['swiper','mk-widgets']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_heading', 'Slider Items');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title_text', [
                'label'       => esc_html__( 'Title', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('creating next level digital products','orbius-core')
            ]);

            $repeater->add_control('left_image', [
                'label'     => esc_html__( 'Left Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('right_image', [
                'label'     => esc_html__( 'Right Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'before',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $this->add_control('slider_items', [
                'label' => esc_html__( 'Slider Items', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title_text }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_items_settings', 'Slider Settings');

        $this->add_control('item_layout',[
            'label'       => esc_html__( 'Sections Size', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ '%' ],
            'selectors'   => [
                '{{WRAPPER}} .mk-dual-slider .mk-dual-slider-left-holder' => 'width:{{SIZE}}%;',
                '{{WRAPPER}} .mk-dual-slider .mk-dual-slider-right-holder' => 'width:calc(100% - {{SIZE}}%);'
            ],
        ]);

        $this->add_control('effect', [
            'label'        => esc_html__( 'Effect', 'orbius-core' ),
            'type'         => \Elementor\Controls_Manager::SELECT,
            'default'      => 'slide',
            'options' => [  'fade' => esc_html__( 'Fade', 'orbius-core' ),
                            'slide' => esc_html__( 'Slide', 'orbius-core' ),
                         ]
        ]);


        $this->add_control('dots_on',[
            'label'   => esc_html__( 'Bullet Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('autoplay_on',[
            'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('autoplay_speed', [
            'label' => esc_html__( 'Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 5000,
            'step' => 100,
            'min' => 100,
            'max' => 15000,
        ]);

        $this->add_control('speed', [
            'label' => esc_html__( 'Animation Speed', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 1000,
            'step' => 100,
            'min' => 100,
            'max' => 5000,
        ]);

        $this->add_control('appear_animation_on',[
            'label'   => esc_html__( 'Appear Animation (Fade In)', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_image_style', 'Image', true);

            mk_elem_heading_ctrl($this, 'left_image_heading', 'Left Image', );

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'                  => 'left_image_size',
                'label'                 => esc_html__( 'Left Image', 'orbius-core' ),
                'default'               => 'full',
            ]);

            mk_elem_heading_ctrl($this, 'right_image_heading', 'Right Image' );

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'                  => 'right_image_size',
                'label'                 => esc_html__( 'Right Image', 'orbius-core' ),
                'default'               => 'full',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'otherinfo_style', 'Content', true);

           $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
               'name'     => 'title_typography',
               'selector' => '{{WRAPPER}} .mk-dual-slider .mk-dual-slider-title,
               {{WRAPPER}} .mk-dual-slider .mk-dual-slider-title a',
           ]);

           $this->add_responsive_control('title_max_width', [
               'label'      => esc_html__( 'Title Max Width', 'orbius-core' ),
               'type'       => \Elementor\Controls_Manager::SLIDER,
               'size_units' => [ 'px', '%','vw' ],
               'range' => ['px' => ['min' => 1, 'max' => 2000, ] ],
               'selectors' => [
                   '{{WRAPPER}} .mk-dual-slider-content-large .mk-dual-slider-title' => 'max-width: {{SIZE}}{{UNIT}};',
               ],
           ]);

           $this->add_control( 'title_tag', [
               'type'       => \Elementor\Controls_Manager::SELECT,
               'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
               'options'    => mk_arrays('title_tag'),
               'default' => 'h4',
               'selectors' => [
                   '{{WRAPPER}} {{VALUE}}.mk-dual-slider-title' => 'margin:0;',
               ],
           ]);

           $this->add_control('title_color', [
               'label'     => esc_html__( 'Color', 'orbius-core' ),
               'type'      => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .mk-dual-slider-title a,{{WRAPPER}} .mk-dual-slider-title' => 'color: {{VALUE}};',
               ],
           ]);

           $this->add_control('title_hover_color', [
               'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
               'type'      => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .mk-dual-slider-title:hover a,{{WRAPPER}} .mk-dual-slider-title:hover' => 'color: {{VALUE}};',
               ],
           ]);

           $this->add_responsive_control('content_box_margin', [
                   'label' => esc_html__( 'Content Box Margin', 'orbius-core' ),
                   'type' => \Elementor\Controls_Manager::DIMENSIONS,
                   'size_units' => [ 'px', 'em','%' ],
                   'selectors' => [
                       '{{WRAPPER}} .mk-dual-slider .mk-dual-slider-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                   ],
               ]
           );

           $this->add_responsive_control('title_margin', [
                   'label' => esc_html__( 'Title Margin', 'orbius-core' ),
                   'type' => \Elementor\Controls_Manager::DIMENSIONS,
                   'size_units' => [ 'px', 'em','%' ],
                   'selectors' => [
                       '{{WRAPPER}} .mk-dual-slider .mk-dual-slider-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                   ],
               ]
           );

           $this->add_responsive_control('title_padding', [
                   'label' => esc_html__( 'Padding', 'orbius-core' ),
                   'type' => \Elementor\Controls_Manager::DIMENSIONS,
                   'size_units' => [ 'px', 'em','%' ],
                   'selectors' => [
                       '{{WRAPPER}} .mk-dual-slider .mk-dual-slider-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                   ],
               ]
           );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_nav_style', 'Navigation', true );

            $this->add_control('nav_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-color:{{VALUE}}',
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color:{{VALUE}}',
                ],
            ]);

            $this->add_responsive_control('nav_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em','%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-dual-slider .swiper-pagination' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none' );
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrows Navigation At', 'none' );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $sliderSettings = array(
            'effect'        => $settings['effect'],
            'dots_on'        => $settings['dots_on'],
            'autoplay'       => $settings['autoplay_on'],
            'autoplay_speed' => $settings['autoplay_speed'],
            'speed'          => $settings['speed'],
        );

        $this->add_render_attribute( [
            'slider-attrs'  => [
                'data-settings'  => json_encode( $sliderSettings ),
            ]
        ] );

        $i = 1;
        $leftContent = $rightContent = '';

        foreach ( $settings['slider_items'] as $index => $item ) :

            $other_info = $rightImgUrl = $leftImgUrl = $left_image = $right_image = $link_start = $link_end = $title = $leftImg = $rightImg = '';

            if ( '' !== $item['left_image']['id'] ) {
                if (  $settings['left_image_size_size'] == 'custom' ) {
                    $leftImg = '<img ' . mk_custom_image_size_html($this, $settings, $item['left_image'], $item['left_image']['id'], 'left_image_size', 'left_image' . $i) . ' />';
                } else {
                    $leftImg = wp_get_attachment_image( $item['left_image']['id'], $settings['left_image_size_size']);
                }
            }

            if ( '' !== $item['right_image']['id'] ) {
                if (  $settings['right_image_size_size'] == 'custom' ) {
                    $rightImg = '<img ' . mk_custom_image_size_html($this, $settings, $item['right_image'], $item['right_image']['id'], 'right_image_size', 'right_image' . $i) . ' />';
                } else {
                    $rightImg = wp_get_attachment_image( $item['right_image']['id'], $settings['right_image_size_size']);
                }
            }

            // link
            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';
            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            // title
            if ( ! empty( $item['title_text'] ) ) {
                $title .= '<'.$titleTagSelector.' class="mk-dual-slider-title">' . $link_start . $item['title_text'] . $link_end . '</'.$titleTagSelector . '>';
            }

            $leftContent .= '<div class="mk-dual-slider-item swiper-slide">
                                    <div class="mk-dual-slider-item-inner">
                                        <div class="mk-dual-slider-image">' . $link_start . $leftImg . $link_end . '</div>
                                        <div class="mk-dual-slider-content">' . $title . '</div>
                                    </div>
                                </div>';

            $rightContent .= '<div class="mk-dual-slider-item swiper-slide">' . $link_start . $rightImg . $link_end . '</div>';

            $i++;
        endforeach;

        $navigation = '';

        if ( 'yes' === $settings['dots_on'] ) {
            $navigation .= '<div class="swiper-pagination"></div>';
        }

        $appearAnimation = ( 'yes' === $settings['appear_animation_on'] ) ? ' mk-scroll--load' : '';

        echo '<div class="mk-dual-slider mk-dual-slider-autoplay-' . $settings['autoplay_on'] . $appearAnimation . '">
                    <div class="mk-dual-slider-top">
                        <div class="mk-dual-slider-content-large swm-hide-'. $settings['title_responsive_hide'] .'"></div>
                    </div>
                    <div class="mk-dual-slider-inner">

                        <div class="mk-dual-slider-left-holder">
                            ' . $navigation . '
                            <div class="mk-dual-slider-left mk-dual-slider-swiper-container" '.$this->get_render_attribute_string( 'slider-attrs' ).'>
                            <div class="swiper-wrapper">'.$leftContent.'</div>
                            </div>
                        </div>

                        <div class="mk-dual-slider-right-holder">
                            ' . $navigation . '
                            <div class="mk-dual-slider-right mk-dual-slider-swiper-container" '.$this->get_render_attribute_string( 'slider-attrs' ).'>
                            <div class="swiper-wrapper">'.$rightContent.'</div>
                           </div>
                        </div>

                    </div>
                </div>';
    }

}