<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Filterable_Gallery extends \Elementor\Widget_Base {

    public function get_name() {return 'mk_filterable_gallery'; }
    public function get_title() {return esc_html__( 'Filterable Gallery', 'orbius-core' ); }
    public function get_icon() { return 'mk-el-icon eicon-gallery-grid'; }
    public function get_categories() {return [ 'mk-general-elements' ]; }
    public function get_keywords() {return [ 'filterable gallery', 'filterable gallery','portfolio', 'image','gallery' ]; }
    public function get_style_depends() { return ['e-swiper','mk-core-main']; }
    public function get_script_depends() { return [ 'mk-modernizr','imagesLoaded', 'isotope','packery','mk-resize','mk-widgets', ]; }
    public function is_reload_preview_required() { return true; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'items_section', 'Items');

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('item_name', [
            'label' => esc_html__( 'Item Name', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
            'placeholder' => esc_html__( 'Enter Item Name', 'orbius-core' ),
            'default' => 'Lorem ipsum dolor sit amet',
        ]);
        $repeater->add_control('category', [
            'label' => esc_html__( 'Category', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
            'description' => esc_html__( 'Multiple category must be comma separated. Do not give blank SPACE after comma.', 'orbius-core' ),
            'default' => 'Web Design',
        ]);

        $repeater->add_control('gallery_image', [
            'label'     => esc_html__( 'Choose Image', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::MEDIA,
        ]);

        $repeater->add_control('link', [
            'label' => esc_html__( 'Link', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::URL,
            'placeholder' => esc_html__( 'https://your-link.com', 'orbius-core' ),
            'default' => [
                'url' => '#',
            ],
        ]);

        $repeater->add_control('image_orientation', [
            'label'   => esc_html__( 'Image Orientation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'description' => esc_html__( 'Select image orientation for "Packery" layout.', 'orbius-core' ),
            'default' => 'full',
            'separator' => 'before',
            'options' => [
                'full'         => 'Default',
                'horizontal'   => 'Horizontal',
                'vertical'     => 'Vertical',
                'square'       => 'Square',
                'large-square' => 'Large Square'
            ],
        ]);

        $this->add_control('filterable_gallery', [
                'label' => esc_html__( 'Add Image', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ item_name }}}',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'filterable_gallery_content', 'Gallery Settings');

        $this->add_control('image_apply_btn', [
            'type' => \Elementor\Controls_Manager::RAW_HTML,
            'raw' => sprintf( esc_html__( 'NOTICE: When you change columns, don\'t forget to click the %s"Apply"%s button to see the actual result!', 'orbius-core' ), '<strong>','</strong>' ),
            'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
        ]);

        $this->add_responsive_control('columns', [
                'label'                 => esc_html__( 'Columns', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::SELECT,
                'default'               => '3',
                'tablet_default'        => '2',
                'mobile_default'        => '1',
                'options'               => [
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                    '5' => '5',
                    '6' => '6',
                    '7' => '7',
                    '8' => '8'
                ],
                'prefix_class'          => 'elementor-grid%s-',
                'frontend_available'    => true
        ]);

        $this->add_control('layout', [
            'label' => esc_html__( 'Layout', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'grid' => esc_html__( 'Grid', 'orbius-core' ),
                'masonry' => esc_html__( 'Masonry', 'orbius-core' )
            ],
            'default' => 'grid',
        ]);

        $this->add_control('masonry_image_size', [
            'label'     => esc_html__( 'Image Size', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'original' => esc_html__( 'Original', 'orbius-core' ),
                'packery' => esc_html__( 'Packery', 'orbius-core' )
            ],
            'default'   => 'original',
            'condition' => ['layout' => 'masonry']
        ]);

        $this->add_group_control(\Elementor\Group_Control_Image_Size::get_type(), [
            'name'                  => 'gallery_image_size',
            'label'                 => esc_html__( 'Image Size', 'orbius-core' ),
            'default'               => 'full',
            'condition'             => ['layout' => 'grid']
        ]);

        $this->add_control('show_filter_tabs',[
            'label'   => esc_html__( 'Show Filterable Tabs', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('all_tab_label', [
            'label' => esc_html__( '"All" Tab Label', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
            'default' => 'All',
            'condition'             => [
                'show_filter_tabs'      => 'yes'
            ],
        ]);

        $this->add_control('show_overlay',[
            'label'   => esc_html__( 'Overlay', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('click_action', [
            'label'   => esc_html__( 'Click Action', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'default' => 'lightbox',
             'condition'             => [
                'show_overlay'      => 'yes'
            ],
            'options' => [
                'lightbox'   => esc_html__( 'Lightbox', 'orbius-core' ),
                'file'       => esc_html__( 'Media File', 'orbius-core' ),
                'attachment' => esc_html__( 'Attachment Page', 'orbius-core' ),
                'custom'     => esc_html__( 'Custom Link', 'orbius-core' ),
                ''           => esc_html__( 'None', 'orbius-core' ),
            ],
        ]);

        $this->add_control('overlay_effects', [
            'label' => esc_html__( 'Overlay Effects', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'mk-filterable-gallery-effect-fade' => esc_html__( 'Fade', 'orbius-core' ),
                'mk-filterable-gallery-effect-zoom' => esc_html__( 'Zoom', 'orbius-core' ),
                'mk-filterable-gallery-effect-move' => esc_html__( 'Fade & Buttons Move', 'orbius-core' ),
                'mk-filterable-gallery-effect-zoom mk-filterable-gallery-effect-move' => esc_html__( 'Zoom & Buttons Move', 'orbius-core' ),
            ],
            'default' => 'mk-filterable-gallery-effect-move',
             'condition'             => [
                'show_overlay'      => 'yes'
            ],
        ]);

        $this->add_control('show_zoom_icon',[
            'label'   => esc_html__( 'Show Zoom Icon', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
            'condition' => ['show_overlay' => 'yes' ],
        ]);

        $this->add_control('show_link_icon',[
            'label'   => esc_html__( 'Show Link Icon', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'condition' => ['show_overlay' => 'yes' ],
        ]);

        $this->add_control('show_image_caption',[
            'label'   => esc_html__( 'Show Image Caption', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('image_caption_source', [
            'label' => esc_html__( 'Image Caption Source', 'orbius-core' ),
            'description' => esc_html__( 'The caption will not display in the "Image Size" -> "Packery". ', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'item_name' => esc_html__( 'Item Name', 'orbius-core' ),
                'image_caption' => esc_html__( 'Image Caption', 'orbius-core' ),
                'image_title' => esc_html__( 'Image Title', 'orbius-core' )
            ],
            'default' => 'item_name',
             'condition' => [
                'show_image_caption' => 'yes',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'filter_styling', 'Filter', true, ['show_filter_tabs' => 'yes']);

        $this->add_control('filter_color', [
            'label'     => esc_html__( 'Color', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} a.mk-filterable-gallery-btn' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_control('filter_hover_color',[
            'label'     => esc_html__( 'Hover/Active Color', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} a.mk-filterable-gallery-btn:hover,
                {{WRAPPER}} a.mk-filterable-gallery-btn.is-checked,
                {{WRAPPER}} a.mk-filterable-gallery-btn.is-checked:before,
                {{WRAPPER}} a.mk-filterable-gallery-btn:hover:before' => 'color: {{VALUE}};',
                '{{WRAPPER}} a.mk-filterable-gallery-btn:before' => 'background: {{VALUE}};',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'filter_typography',
            'selector' => '{{WRAPPER}} a.mk-filterable-gallery-btn',
        ]);

        $this->add_responsive_control('item_padding', [
            'label'      => esc_html__( 'Items Margin', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%' ],
            'selectors'  => [
                '{{WRAPPER}} a.mk-filterable-gallery-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('filter_padding', [
            'label'      => esc_html__( 'Padding', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%' ],
            'selectors'  => [
                '{{WRAPPER}} .mk-filterable-gallery-btns' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('filter_margin', [
            'label'      => esc_html__( 'Margin', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%' ],
            'selectors'  => [
                '{{WRAPPER}} .mk-filterable-gallery-btns' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'item_style', 'Items', true);

        $this->add_control('item_apply_btn', [
            'type' => \Elementor\Controls_Manager::RAW_HTML,
            'raw' => sprintf( esc_html__( 'NOTICE: When you edit item gap, don\'t forget to click the %s"Apply"%s button to see the actual result!', 'orbius-core' ), '<strong>','</strong>' ),
            'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
        ]);

        $this->add_responsive_control('column_gap', [
            'label'     => esc_html__( 'Columns Gap', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::SLIDER,
            'default'   => [
                'size' => 20,
            ],
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-item.mk-grid-item-wrap' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
                '{{WRAPPER}} .mk-filterable-gallery-grid' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
            ],
        ]);

        $this->add_responsive_control('row_gap', [
            'label'     => esc_html__( 'Rows Gap', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::SLIDER,
            'default'   => [
                'size' => 20,
            ],
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-grid-item-wrap' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ]
        ]);

        $this->add_responsive_control('items_radius', [
            'label' => esc_html__( 'Radius', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-img-holder,
                {{WRAPPER}} .mk-filterable-gallery-overlay' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'animation_style', 'Animation', true);

            $this->add_control('parallax_on',[
                'label'   => esc_html__( 'Parallax Scroll Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('image_hover_zoom',[
                'label'   => esc_html__( 'Hover Zoom Image Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'prefix_class' => 'mk-gallery-image-zoom-'
            ]);

            $this->add_control('appear_animation', [
                'label'   => esc_html__( 'Image Appear Animation', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'condition' => ['layout!' => 'masonry'],
                'default' => '',
                'options' => [
                                ''              => 'None',
                                'fade'          => 'Fade'
                            ],
                'prefix_class' => 'mk-custom-image-appear-'
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'overlay_background', 'Overlay Background', true, [ 'show_overlay' => 'yes']);

        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name' => 'overlay_bg',
            'types' => [ 'classic', 'gradient' ],
            'fields_options' => [
                'background' => [
                    'default' =>'classic',
                ],
                'color' => [
                    'default' => 'rgba(0,0,0,0.8)',
                ],
            ],
            'selector' => '{{WRAPPER}} .mk-filterable-gallery-overlay',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'icons_style', 'Overlay Icons', true, ['show_overlay' => 'yes']);

        $this->start_controls_tabs( 'icons_tabs' );

        $this->start_controls_tab('icons_normal', [
            'label' => esc_html__( 'Normal', 'orbius-core' ),
        ]);

        $this->add_control('icons_color', [
            'label' => esc_html__( 'Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a svg' => 'fill: {{VALUE}}'
            ],
        ]);
        $this->add_control('icons_bg', [
            'label' => esc_html__( 'Background', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a' => 'background: {{VALUE}}'
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name'        => 'icons_border',
            'label'       => esc_html__( 'Border', 'orbius-core' ),
            'selector'    => '{{WRAPPER}} .mk-filterable-gallery-overlay a',
        ]);

        $this->end_controls_tab();

        $this->start_controls_tab('icons_hover', [
            'label' => esc_html__( 'Hover', 'orbius-core' ),
        ]);

        $this->add_control('icons_hover_color', [
            'label' => esc_html__( 'Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a:hover svg' => 'fill: {{VALUE}}'
            ],
        ]);
        $this->add_control('icons_hover_bg', [
            'label' => esc_html__( 'Background', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a:hover' => 'background: {{VALUE}}'
            ],
        ]);
        $this->add_control('icons_hover_border', [
            'label' => esc_html__( 'Border Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a:hover' => 'border-color: {{VALUE}}'
            ],
        ]);

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_responsive_control('icons_gap', [
            'label' => esc_html__( 'Icons Gap', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'default' => [
                'size' => '20',
            ],
            'separator' => 'before',
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-zoom' => 'margin-right: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('icons_size', [
            'label' => esc_html__( 'Icon Size', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px', 'em', '%' ],
            'default' => [
                'size' => '16',
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a' => 'font-size: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('icons_width', [
            'label' => esc_html__( 'Width', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px', 'em', '%' ],
            'default' => [
                'size' => '44',
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a' => 'width: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('icons_height', [
            'label' => esc_html__( 'Height', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px', 'em', '%' ],
            'default' => [
                'size' => '44',
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a' => 'height: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('icons_radius', [
            'label' => esc_html__( 'Radius', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'default' => [
                'unit' => '%',
                'top' => '50',
                'right' => '50',
                'bottom' => '50',
                'left' => '50',
                'isLinked' => true,
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-overlay a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'image_caption_styling', 'Caption', true, [ 'show_image_caption' => 'yes']);

        $this->add_control('image_caption_color', [
            'label' => esc_html__( 'Text Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-caption' => 'color: {{VALUE}};',
            ],
        ]);
        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name' => 'image_caption_bg_color',
            'label' => esc_html__( 'Background', 'orbius-core' ),
            'types' => [ 'classic', 'gradient' ],
            'fields_options' => [
                'background' => [
                    'default' =>'classic',
                ],
                'color' => [
                    'default' => '#f2f2f2',
                ],
            ],
            'selector' => '{{WRAPPER}} .mk-filterable-gallery-caption',
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'image_caption_typography',
            'selector' => '{{WRAPPER}} .mk-filterable-gallery-caption',
        ]);

        $this->add_group_control(\Elementor\Group_Control_Text_Shadow::get_type(), [
            'name' => 'image_caption_shadow',
            'selector' => '{{WRAPPER}} .mk-filterable-gallery-caption',
        ]);

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name'        => 'image_caption_border',
            'label'       => esc_html__( 'Border', 'orbius-core' ),
            'selector'    => '{{WRAPPER}} .mk-filterable-gallery-caption',
        ]);

        $this->add_responsive_control('image_caption_radius', [
            'label' => esc_html__( 'Radius', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-caption' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('image_caption_margin', [
            'label' => esc_html__( 'Margin', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-caption' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('image_caption_padding', [
            'label' => esc_html__( 'Padding', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-filterable-gallery-caption' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        $settings_rtl = is_rtl() ? 'true' : 'false';
        $all_label = esc_html($settings['all_tab_label']);

        $scroll_load_animation = ( 'fade' === $settings['appear_animation'] || 'simple-reveal' === $settings['appear_animation'] ) ? ' mk-scroll--load' : '';

        // parallax scroll
        $parallax_on = $parallax_item = '';

        if ( isset($settings['parallax_on']) && 'yes' === $settings['parallax_on'] ) {
            $parallax_on   = ' mk-parallax-scroll-item-on';
            $parallax_item = ' mk-parallax-item';
        }
        ?>
        <div class="mk-filterable-gallery <?php echo esc_attr( 'mk-filterable-gallery-'.$this->get_id() ) . $parallax_on; ?>"
        data-layout="<?php echo esc_attr( $settings['layout'] ); ?>" data-rtl="<?php echo $settings_rtl; ?>">

            <?php if ( 'yes' === $settings['show_filter_tabs'] ) :  ?>

                <div class="mk-filterable-gallery-btns">
                    <?php
                    if ( '' != $all_label ) { ?>
                        <a class="mk-filterable-gallery-btn is-checked" data-filter="*"><?php echo $all_label; ?></a>
                    <?php
                    }
                        $categories = mk_get_filterable_gallery_cat( $settings['filterable_gallery'] );
                        foreach ( $categories as $cat ) :
                            ?><a class="mk-filterable-gallery-btn" data-filter=".<?php echo esc_attr( $cat ); ?>"><?php
                            printf('%s', ucwords(str_replace('_', ' ', trim( $cat, '_'))));
                            ?></a><?php
                        endforeach; ?>
                </div>

            <?php endif; ?>

            <div class="mk-filterable-gallery-grid <?php // add class ---- mk-elementor-grid
                if ( 'masonry' === $settings['layout'] ) {
                    echo ' mk-gal-masonry-on';

                    if ( 'packery' === $settings['masonry_image_size'] ) {
                        echo ' mk-items--packery';
                    }
                }
            ?>">
                <div class="mk-gallery-grid-inner clear">
                    <?php

                    if ( 'masonry' === $settings['layout'] ) { ?>
                        <div class="mk-gallery-grid-masonry-sizer"></div>
                        <div class="mk-gallery-grid-masonry-gutter"></div>
                        <?php
                    }

                    $click_action = $settings['click_action'];
                    $index=0;

                    foreach ( $settings['filterable_gallery'] as $item ) :
                        $category = strtolower( str_replace( ' ', '_', $item['category'] ) );
                        $category =  str_replace( ',', ' ', $category );
                        $imageTagHtml = $img_link = '';

                        if ( $item['gallery_image']['url'] ):

                            $gallery_image_size = $settings['gallery_image_size_size'];

                            if ( 'masonry' === $settings['layout'] ) {
                                if ( 'packery' === $settings['masonry_image_size'] ) {
                                    $gallery_image_size = 'mk_image_size_' . $item['image_orientation'];
                                    $img_link      = wp_get_attachment_image_src( $item['gallery_image']['id'], $gallery_image_size );

                                    if ( !empty($img_link) ) {
                                        $img_link = $img_link[0];
                                    }

                                } else {
                                    $gallery_image_size = 'full';
                                }
                            }

                            if (  $gallery_image_size == 'custom' ) {
                                $imageTagHtml .= '<img '.mk_custom_image_size_html($this, $settings, $item['gallery_image'], $item['gallery_image']['id'], 'gallery_image_size', 'gallery_img_attrs-'.$index).' />';
                            } else {
                                $imageTagHtml .= wp_get_attachment_image( $item['gallery_image']['id'], $gallery_image_size);
                            }


                            if ( '' !== $click_action ) {

                                $item_link    = '';
                                $lightbox     = 'no';

                                switch ($click_action) {
                                    case "lightbox":

                                        if ( $item['gallery_image']['id'] ) {
                                            $item_link = wp_get_attachment_image_src( $item['gallery_image']['id'], 'full' );
                                            $item_link = $item_link[0];
                                        } else {
                                            $item_link = $item['gallery_image']['url'];
                                        }

                                        $lightbox = 'yes';

                                        break;

                                    case "file":

                                        if ( $item['gallery_image']['id'] ) {
                                            $item_link = wp_get_attachment_image_src( $item['gallery_image']['id'], 'full' );
                                            $item_link = $item_link[0];
                                        } else {
                                            $item_link = $item['gallery_image']['url'];
                                        }

                                        break;

                                    case "attachment":

                                        $item_link = get_permalink( $item['gallery_image']['id'] );

                                        break;
                                    case "custom":

                                        if ( ! empty( $item['link']['url'] ) ) {
                                            $item_link = $item['link']['url'];
                                        }

                                        break;
                                }

                                $this->add_render_attribute('grid-media-' . $index, [
                                    'class'                             => 'elementor-clickable mk-filterable-gallery-zoom',
                                    'data-elementor-open-lightbox'      => $lightbox,
                                    'data-elementor-lightbox-slideshow' => $this->get_id(),
                                    'data-elementor-lightbox-index'     => $index,
                                    'title'                             => esc_attr( $item['item_name'] )
                                ]);

                                $this->add_render_attribute( 'grid-media-' . $index, 'href', $item_link );
                            }

                            ?>
                            <div class="mk-filterable-gallery-item mk-item--<?php

                            if ( $settings['layout'] == 'masonry') {
                                echo $item['image_orientation'];
                            }

                            ?> mk-grid-item-wrap <?php echo esc_attr( $category ) . $parallax_item . $scroll_load_animation; ?>">
                                <div class="mk-filterable-gallery-item-inner animate-in" data-anim-type="fade-in" data-anim-delay="200">  <!--  add class ---- mk-elementor-grid -->

                                    <div class="mk-filterable-gallery-img-holder">

                                        <div <?php
                                            if ( $settings['layout'] === 'masonry' && $settings['masonry_image_size'] === 'packery' ) {
                                                echo 'class="mk-gallery-image mk-gallery-packery-bg-img" style="background-image:url('.$img_link.');"';
                                            } else {
                                                echo 'class="mk-gallery-image"';
                                            }
                                            ?> >
                                            <?php
                                            echo $imageTagHtml;

                                            if ( 'yes' === $settings['show_overlay'] ) :  ?>

                                                <div class="mk-filterable-gallery-overlay mk-overlay mk-flex <?php echo esc_attr( $settings['overlay_effects'] ); ?>">
                                                    <div class="mk-filterable-gallery-icons mk-flex">

                                                        <?php if ( 'yes' === $settings['show_zoom_icon'] ) :
                                                            echo '<a ' . $this->get_render_attribute_string( 'grid-media-' . $index ) .' >' . mk_get_svg_icon( 'search', 'swm-svg-filterable-gallery-search' ) . '</a>';
                                                         endif;

                                                         if ( 'yes' === $settings['show_link_icon'] ) :  ?>
                                                            <a href="<?php echo esc_url( $item['link']['url'] ); ?>"
                                                            <?php if ( 'on' == $item['link']['is_external'] ): ?>
                                                                target="_blank"
                                                            <?php endif; ?>
                                                            <?php if ( 'on' == $item['link']['nofollow'] ): ?>
                                                                rel="nofollow"
                                                            <?php endif; ?> class="mk-filterable-gallery-link">
                                                                <?php echo mk_get_svg_icon( 'link', 'swm-svg-filterable-gallery-link' ); ?>
                                                            </a>
                                                         <?php endif; ?>
                                                    </div>
                                                </div>
                                                    <?php
                                            endif; ?>
                                        </div>

                                    </div>

                                     <?php if ( 'yes' === $settings['show_image_caption'] ) :

                                        if ( 'item_name' === $settings['image_caption_source'] ) {

                                            $caption_text = $item['item_name'];

                                        } elseif ( 'image_caption' === $settings['image_caption_source'] ) {

                                            $attachment = $item['gallery_image']['id'];
                                            $caption_text = get_image_caption( $attachment, 'caption' );

                                        } else {
                                            $attachment = $item['gallery_image']['id'];
                                            $caption_text = get_image_caption( $attachment, 'title' );
                                        }

                                        echo '<div class="mk-filterable-gallery-caption">' . esc_html($caption_text) . '</div>';

                                    endif; ?>

                                </div>
                            </div>
                            <?php
                        endif;
                        $index++; ?>
                        <?php
                    endforeach; ?>

                </div> <!-- end-mk-grid-inner -->

            </div> <!-- mk-filterable-gallery-grid -->

        </div> <!-- mk-filterable-gallery -->
        <?php
        if ( \Elementor\Plugin::instance()->editor->is_edit_mode() ) {
        }
    }

    protected function render_editor_script() {
        ?>
        <script type="text/javascript">
        jQuery( document ).ready(function( $ ) {
            var mkPFClass = '.mk-filterable-gallery-'+'<?php echo $this->get_id(); ?>',
                $this = $(mkPFClass),
                $isoGrid = $this.children('.mk-filterable-gallery-grid'),
                $btns = $this.children('.mk-filterable-gallery-btns'),
                is_rtl = $this.data('rtl') ? false : true,
                layout = $this.data('layout');

            $this.imagesLoaded( function() {
                if ( 'masonry' == layout ) {
                    var $grid = $isoGrid.isotope({
                        itemSelector: '.mk-filterable-gallery-item',
                        percentPosition: true,
                        originLeft: is_rtl,
                        masonry: {
                            columnWidth: '.mk-filterable-gallery-item',
                        }
                    });
                } else{
                    var $grid = $isoGrid.isotope({
                        itemSelector: '.mk-filterable-gallery-item',
                        layoutMode: 'fitRows',
                        originLeft: is_rtl,
                    });

                }

                $btns.on('click', 'a', function () {
                    var filterValue = $(this).attr('data-filter');
                    $grid.isotope({
                        filter: filterValue,
                        originLeft: is_rtl
                    });

                    return false;
                });

                $this.find('.mk-filterable-gallery-item').resize( function() {
                    $grid.isotope( 'layout' );
                });

                $btns.each(function (i, btns) {
                    var btns = $(btns);

                    btns.on('click', '.mk-filterable-gallery-btn', function () {
                        btns.find('.is-checked').removeClass('is-checked');
                        $(this).addClass('is-checked');
                    });
                });

            });

        });
        </script>
        <?php
    }

}