<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Full_Screen_Menu extends \Elementor\Widget_Base {

    public function get_name()       { return 'mk_full_screen_menu'; }
    public function get_title()      { return esc_html__( 'Full Screen Menu', 'orbius-core' ); }
    public function get_icon()       { return 'mk-el-icon eicon-menu-toggle'; }
    public function get_categories() { return ['mk-sections-elements']; }
    public function get_keywords()   { return [ 'theme','menu','navigation','mega','dropdown','overlay','mobile' ]; }
    public function get_style_depends() { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-widgets' ]; }

    protected function register_controls() {

        // menu
        mk_elem_start_ctrl($this, 'main_links_style', 'Menu');

            $this->add_control('menu_list_select', [
                'label' => esc_html__( 'Select Menu', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => mk_wp_menu_names_list(),
            ]);

            $this->start_controls_tabs( 'menu_links_tab_styles' );

                $this->start_controls_tab('menu_links_tab', [ 'label' => esc_html__( 'Main Links', 'orbius-core' ) ]);

                    $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                        'name' => 'main_links_typography',
                        'label' => esc_html__( 'Typography', 'orbius-core' ),
                        'selector' => '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li > a',
                    ]);

                    $this->add_responsive_control('main_links_space', [
                        'label' => esc_html__( 'Space Between Two Items', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px','em','%' ],
                        'range'      => ['px' => ['min'  => 0, 'max'  => 100, 'step' => 1]],
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li > a' => 'margin-top: {{SIZE}}{{UNIT}}; margin-bottom: {{SIZE}}{{UNIT}};',
                        ],
                    ]);

                    $this->add_control('links_color',[
                        'label' => esc_html__( 'Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li > a' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('links_hover_color',[
                        'label' => esc_html__( 'Hover/Active Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li:hover > a,
                             #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li.swm-m-active > a,
                             #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li.mk-fs-active > a' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_responsive_control('underline_size', [
                        'label' => esc_html__( 'Hover Text Underline Size', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px' ],
                        'range'      => ['px' => ['min'  => 0, 'max'  => 10, 'step' => 1]],
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li a span span' => 'background-size: 0 {{SIZE}}{{UNIT}};',
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li a:hover span span,
                            #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li.swm-m-active > a span span,
                            #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li.mk-fs-active > a span span' => 'background-size: 100% {{SIZE}}{{UNIT}};',
                        ],
                    ]);

                $this->end_controls_tab();

                $this->start_controls_tab('sub_links_tab', [ 'label' => esc_html__( 'Sub Links', 'orbius-core' ) ]);

                    $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                        'name' => 'sub_links_typography',
                        'label' => esc_html__( 'Typography', 'orbius-core' ),
                        'selector' => '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li > a',
                    ]);

                    $this->add_responsive_control('sublinks_space', [
                        'label' => esc_html__( 'Space', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px','em','%' ],
                        'range'      => ['px' => ['min'  => 0, 'max'  => 100, 'step' => 1]],
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li > a' => 'margin-top: {{SIZE}}{{UNIT}}; margin-bottom: {{SIZE}}{{UNIT}};',
                        ],
                    ]);

                    $this->add_control('sublinks_color',[
                        'label' => esc_html__( 'Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li > a' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('sublinks_hover_color',[
                        'label' => esc_html__( 'Hove/Active Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li:hover > a,
                             #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li.active a,
                             #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li.swm-m-active li.current-menu-item a' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_responsive_control('sub_underline_size', [
                        'label' => esc_html__( 'Hover Text Underline Size', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px' ],
                        'range'      => ['px' => ['min'  => 0, 'max'  => 10, 'step' => 1]],
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li a span span' => 'background-size: 0 {{SIZE}}{{UNIT}};',
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li a:hover span span,
                            #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li.swm-m-active > a span span,
                            #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li.mk-fs-active > a span span' => 'background-size: 100% {{SIZE}}{{UNIT}};',
                        ],
                    ]);

                $this->end_controls_tab();
            $this->end_controls_tabs();

        $this->end_controls_section();

        // left section image
        mk_elem_start_ctrl($this, 'left_image_style', 'Left Section');

            $this->add_control('left_section_on',[
                'label'   => esc_html__( 'Left Section', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_responsive_control('left_section_width', [
                'label'      => esc_html__( 'Section Width (%)', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ '%' ],
                'range'      => ['px' => ['min'  => 0, 'max'  => 100, 'step' => 1]],
                'selectors'  => ['#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay.mk-fs-menu-left-section-yes .mk-fs-menu-left-image' => 'width:{{SIZE}}%;',
                                '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay.mk-fs-menu-left-section-yes .mk-fs-menu-content' => 'width:calc(100% - {{SIZE}}%);',
                ],
            ]);

            $this->add_control('left_image', [
                'label'     => esc_html__( 'Left Section Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'      => 'left_image_size',
                'label'     => esc_html__( 'Image Size', 'orbius-core' ),
                'default'   => 'full',
            ]);

        $this->end_controls_section();

        // logo image
        mk_elem_start_ctrl($this, 'image_style', 'Logo Image');

            $this->add_control('logo_image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $this->add_control('image_width', [
                'label'      => esc_html__( 'Image Width', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range'      => ['px' => ['min'  => 0, 'max'  => 300, 'step' => 1]],
                'selectors'  => ['#mk-full-screen-menu-{{ID}} .mk-fs-menu-logo' => 'width:{{SIZE}}{{UNIT}};'],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'      => 'logo_image_size',
                'label'     => esc_html__( 'Image Size', 'orbius-core' ),
                'default'   => 'full',
            ]);

        $this->end_controls_section();

        // social icons
        mk_elem_start_ctrl($this, 'social_icon_style', 'Social Sites');

            $this->add_control('social_sites_on',[
                'label'   => esc_html__( 'Social Sites', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $repeater = new \Elementor\Repeater();
            $repeater->add_control('sitename', [
                'label'       => esc_html__( 'Social Site', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('fb','orbius-core')
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'before',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $this->add_control('social_sites', [
                'label' => esc_html__( 'Slider Items', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['sitename' => "fb", 'link' =>  ['url' => '#'] ],
                    ['sitename' => "tw", 'link' =>  ['url' => '#'] ],
                    ['sitename' => "ln", 'link' =>  ['url' => '#'] ],
                    ['sitename' => "pi", 'link' =>  ['url' => '#'] ],
                ],
                'title_field' => '{{{ sitename }}}',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name' => 'social_sites_typography',
                'label' => esc_html__( 'Typography', 'orbius-core' ),
                'selector' => '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fullscreen-menu-overlay-inner .mk-fs-menu-sm-icons ul li a',
            ]);

            $this->add_control('social_sites_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fullscreen-menu-overlay-inner .mk-fs-menu-sm-icons ul li a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('social_sites_hover_color',[
                'label' => esc_html__( 'Hover Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fullscreen-menu-overlay-inner .mk-fs-menu-sm-icons ul li a:hover' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('social_sites_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fullscreen-menu-overlay-inner .mk-fs-menu-sm-icons ul li a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]);

        $this->end_controls_section();


        // email id
        mk_elem_start_ctrl($this, 'email_icon_style', 'Email Address');

            $this->add_control('email_address', [
                'label'       => esc_html__( 'Email Address', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('info@sitename.com','orbius-core')
            ]);

            $this->add_control('email_link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'before',
                'placeholder' => esc_html__( 'mailto:info@sitename.com', 'orbius-core' ),
                'description' => esc_html__( 'Please use the "mailto:xyz@email.com" format for the email address link.', 'orbius-core' ),
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name' => 'email_typography',
                'label' => esc_html__( 'Typography', 'orbius-core' ),
                'selector' => '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fullscreen-menu-overlay-inner .mk-fs-menu-email a',
            ]);

            $this->add_control('email_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fullscreen-menu-overlay-inner .mk-fs-menu-email a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('email_hover_color',[
                'label' => esc_html__( 'Hover Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fullscreen-menu-overlay-inner .mk-fs-menu-email a:hover' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('email_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fullscreen-menu-overlay-inner .mk-fs-menu-email' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]);

        $this->end_controls_section();


        // overlay holder
        mk_elem_start_ctrl($this, 'overlay_holder_style', 'Overlay Holder');

            $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
                'name'     => 'overlay_background',
                'label'    => esc_html__( 'Overlay Background', 'orbius-core' ),
                'types'    => [ 'classic', 'gradient' ],
                'selector' => '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay',
            ]);

            $this->add_control('background_blur_level', [
                'label'      => esc_html__( 'Background Blur Level', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range'      => ['px' => ['min'  => 0, 'max'  => 50, 'step' => 1]],
                'selectors'  => ['#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay' => '-webkit-backdrop-filter: blur({{SIZE}}px); backdrop-filter: blur({{SIZE}}px);'],
            ]);

            $this->add_responsive_control('overlay_padding', [
                'label' => esc_html__( 'Overlay Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '#mk-full-screen-menu-{{ID}} .mk-fullscreen-menu-overlay-inner .mk-fs-menu-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        // hamburger icon
        mk_elem_start_ctrl($this, 'hamburger_icon_style', 'Hamburger Icon');

            $this->add_control('icon_style', [
                'label'     => esc_html__( 'Icon Style', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SELECT,
                'default'   => 'default',
                'options'   => [
                    'default'  => esc_html__( 'Default', 'orbius-core' ),
                    'custom' => esc_html__( 'Custom', 'orbius-core' ),
                ],
            ]);

            $this->add_control('full_screen_icon_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-fullscreen-menu-icon' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-fullscreen-menu-icon svg' => 'fill: {{VALUE}};',
                '{{WRAPPER}} .mk-hamburger-icon .mk-hamburger-icon-line' => 'background: {{VALUE}}',
                ],
            ]);

            $this->add_control('full_screen_default_icon_bg_color', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['icon_style' => 'default'],
                'selectors' => [
                '{{WRAPPER}} .mk-hamburger-icon-holder' => 'background: {{VALUE}}',
                ],
            ]);

            $this->add_control('full_screen_icon_bg_color', [
                'label'     => esc_html__( 'Background', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['icon_style' => 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .mk-fullscreen-menu-icon' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_control('full_screen_icon', [
                'label' => esc_html__( 'Off-Canvas Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default' => [
                    'value' => 'fas fa-bars',
                    'library' => 'fa-solid',
                ],
                'condition' => ['icon_style' => 'custom'],
                'recommended' => [
                    'fa-solid' => ['bars', 'grip-lines','ellipsis-v','ellipsis-h','sliders-h','list-alt','list','stream'],
                    'fa-regular' => ['times-circle'],
                ],
                'file' => '',
            ]);

            $this->add_responsive_control('full_screen_icon_size', [
                    'label' => esc_html__( 'Size', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::SLIDER,
                    'size_units' => ['px'],
                    'range' => [
                        'px' => ['min' => 6, 'max' => 100 ]
                    ],
                    'default' => ['size' => 14, 'unit' => 'px'],
                    'condition' => ['icon_style' => 'custom'],
                    'selectors' => [
                        '{{WRAPPER}} .mk-fullscreen-menu-icon,
                        {{WRAPPER}} .mk-fullscreen-menu-icon svg' => 'font-size: {{SIZE}}{{UNIT}}']
                ]);

            $this->add_responsive_control('full_screen_icon_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'condition' => ['icon_style' => 'custom'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-fullscreen-menu-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]);

            $this->add_responsive_control('full_screen_icon_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'condition' => ['icon_style' => 'custom'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-fullscreen-menu-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]);

            $this->add_control('full_screen_icon_border_radius', [
                'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'condition' => ['icon_style' => 'custom'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-fullscreen-menu-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                    'name'        => 'full_screen_icon_border',
                    'label'       => esc_html__( 'Border', 'orbius-core' ),
                    'selector'    => '{{WRAPPER}} .mk-fullscreen-menu-icon',
                    'condition' => ['icon_style' => 'custom'],
                ]);

        $this->end_controls_section();

        // close button
        mk_elem_start_ctrl($this, 'close_button_style', 'Close Button');

            $this->add_responsive_control('close_icon_size', [
                'label'      => esc_html__( 'Size', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                 // 'default'     => ['size' => 50],
                'range'      => ['px' => ['min'  => 1, 'max'  => 200, 'step' => 1, ]],
                'selectors'  => [
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close' => 'width:{{SIZE}}px; height:{{SIZE}}px;',
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close:before,
                     #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close:after' => 'height:calc({{SIZE}}px / 2); left:calc({{SIZE}}px / 2); top:calc({{SIZE}}px / 4);'
                ]
            ]);

            $this->add_responsive_control('line_width', [
                'label'      => esc_html__( 'Line Width', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'default'     => ['size' => 2, 'unit' => 'px'],
                'range'      => ['px' => ['min'  => 1, 'max'  => 6, 'step' => 1]],
                'selectors'  => ['#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close:before,
                                  #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close:after' => 'width:{{SIZE}}px;']
            ]);

            $this->add_control('close_icon_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close,' => 'color: {{VALUE}};',
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close:before,
                     #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close:after' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('close_btn_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay .mk-fs-menu-close' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        // dropdown indicator
        mk_elem_start_ctrl($this, 'dropdown_indicator_style', 'Dropdown Indicator');

            $this->add_control('indicator_on',[
                'label'   => esc_html__( 'Dropdown Indicator', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->start_controls_tabs( 'menu_links_indicator_tab_styles' );

                $this->start_controls_tab('menu_links_indicator_tab', [ 'label' => esc_html__( 'Main Links', 'orbius-core' ), 'condition'  => ['indicator_on' => 'yes'] ]);

                    $this->add_responsive_control('main_links_indicator_size', [
                        'label'      => esc_html__( 'Size', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px','em' ],
                        'range'      => ['px' => ['min'  => 0, 'max'  => 150, 'step' => 1]],
                        'condition'  => ['indicator_on' => 'yes'],
                        'selectors'  => ['#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu li a.menu-indicator-icon span span svg.swm-svg-submenu-indicator' => 'font-size: {{SIZE}}{{UNIT}};'],
                    ]);

                    $this->add_responsive_control('indicator_margin', [
                        'label' => esc_html__( 'Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', 'em', '%' ],
                        'condition'  => ['indicator_on' => 'yes'],
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu li a.menu-indicator-icon span span svg.swm-svg-submenu-indicator' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                    $this->add_control('overlay_indicator_color',[
                        'label' => esc_html__( 'Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li > a.menu-indicator-icon span span svg.swm-svg-submenu-indicator' => 'fill: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('overlay_indicator_hover_color',[
                        'label' => esc_html__( 'Hover/Active Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li:hover > a.menu-indicator-icon span span svg.swm-svg-submenu-indicator,
                             #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li.swm-m-active > a.menu-indicator-icon span span svg.swm-svg-submenu-indicator,
                             #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu > li.mk-fs-active > a.menu-indicator-icon span span svg.swm-svg-submenu-indicator' => 'fill: {{VALUE}};',
                        ],
                    ]);

                $this->end_controls_tab();

                $this->start_controls_tab('sub_links_indicator_tab', [ 'label' => esc_html__( 'Sub Links', 'orbius-core' ), 'condition'  => ['indicator_on' => 'yes'] ]);

                    $this->add_responsive_control('sub_links_indicator_size', [
                        'label'      => esc_html__( 'Size', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px','em' ],
                        'range'      => ['px' => ['min'  => 0, 'max'  => 150, 'step' => 1]],
                        'condition'  => ['indicator_on' => 'yes'],
                        'selectors'  => ['#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li.menu-item-has-children a.menu-indicator-icon span span svg.swm-svg-submenu-indicator' => 'font-size: {{SIZE}}{{UNIT}};'],
                    ]);

                    $this->add_responsive_control('indicator_sublevel_margin', [
                        'label' => esc_html__( 'Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', 'em', '%' ],
                        'condition'  => ['indicator_on' => 'yes'],
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li.menu-item-has-children a.menu-indicator-icon span span svg.swm-svg-submenu-indicator' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                    $this->add_control('overlay_indicator_sub_color',[
                        'label' => esc_html__( 'Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li.menu-item-has-children > a.menu-indicator-icon span span svg.swm-svg-submenu-indicator' => 'fill: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('overlay_indicator_sub_hover_color',[
                        'label' => esc_html__( 'Hover/Active Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '#mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li:hover > a.menu-indicator-icon span span svg.swm-svg-submenu-indicator,
                             #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li.swm-m-active > a.menu-indicator-icon span span svg.swm-svg-submenu-indicator,
                             #mk-full-screen-menu-{{ID}}.mk-fullscreen-menu-overlay ul.mk-fullscreen-menu-overlay-menu ul li.mk-fs-active > a.menu-indicator-icon span span svg.swm-svg-submenu-indicator' => 'fill: {{VALUE}};',
                        ],
                    ]);

                $this->end_controls_tab();

            $this->end_controls_tabs();

          $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Off-canvas icon
        if ( $settings['icon_style'] === 'custom' ) {
            $iconHTML = mk_get_elementor_icons($settings['full_screen_icon']);
        } else {
            $iconHTML = '<div class="mk-hamburger-icon-holder"><span class="mk-hamburger-icon-lines"><span class="mk-hamburger-icon-line"></span><span class="mk-hamburger-icon-line mk-hamburger-icon-line-m"></span><span class="mk-hamburger-icon-line"></span></span></div>';
        }

        $randomNumber = rand(10,1000);
        $uniqueId = $this->get_id() . $randomNumber;

        echo '<div data-id="mk-full-screen-menu-'.$uniqueId.'" class="mk-fullscreen-menu-icon mk-hamburger-icon">' . $iconHTML . '</div>';

        ob_start();

            $menu_list_items = $settings['menu_list_select'];

            if ( $menu_list_items != '' ) {

                $nav_menu = ! empty( $settings['menu_list_select'] ) ? wp_get_nav_menu_object( $settings['menu_list_select'] ) : false;
                if ( ! $nav_menu ) { return; }

                $nav_menu_args = array(
                    'fallback_cb' => '',
                    'menu_class'  => 'mk-fullscreen-menu-overlay-menu',
                    'menu'        => $nav_menu,
                    'depth'       => 0,
                    'echo'        => false,
                    'link_before' => '<span><span>',
                    'link_after' => '</span></span>'
                );

                // Logo Image
                $logoImageHtml = '';
                if (  $settings['logo_image_size_size'] == 'custom' ) {
                    $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $settings['logo_image']['id'], 'logo_image_size', $settings );
                    $img_alt = get_post_meta( $settings['logo_image']['id'], '_wp_attachment_image_alt', true);

                    if ('' != $imgUrl) {
                        $logoImageHtml = '<div class="mk-fs-menu-logo"><a href="' . esc_url(home_url( '/' )) . '" title="' . esc_attr(get_bloginfo('name')) . '"><img src="' . $imgUrl . '" alt="' . $img_alt . '" loading="lazy" /></a></div>';
                    }

                } else {
                    $logoImageHtml = '<div class="mk-fs-menu-logo"><a href="' . esc_url(home_url( '/' )) . '" title="' . esc_attr(get_bloginfo('name')) . '">' . wp_get_attachment_image( $settings['logo_image']['id'], $settings['logo_image_size_size']) . '</a></div>';
                }

                // Section Image
                $leftSectionImage = '';
                $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $settings['left_image']['id'], 'left_image_size', $settings );
                if ( '' != $imgUrl && 'yes' === $settings['left_section_on'] ) {
                     $leftSectionImage = '<div class="mk-fs-menu-left-image"><span style="background-image:url(' . $imgUrl . ');"></span></div>';
                }

                $socialSitesHTML = '';

                if ( 'yes' === $settings['social_sites_on'] ) {

                    // Social Sites
                    $i = 1;
                    $social_sites_html = '';

                    foreach ( $settings['social_sites'] as $index => $item ) :

                        $link_start = $link_end = '';

                        // link
                        if ( ! empty( $item['link']['url'] ) ) {
                            $link_key = 'link_' . $i;

                            $this->add_link_attributes( $link_key, $item['link'] );

                            $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                            $link_end .= '</a>';
                        }

                        $social_sites_html .= '<li>' . $link_start . $item['sitename'] . $link_end . '</li>';

                    $i++;
                    endforeach;

                    $socialSitesHTML .= '<div class="mk-fs-menu-sm-icons highlight-text">
                                            <ul>'.$social_sites_html.'</ul>
                                        </div>';

                }

                // email address
                $emailHTML = $email_link_start = $email_link_end = '';
                if ( '' !== $settings['email_address'] ) {

                    // link
                    if ( ! empty( $settings['email_link']['url'] ) ) {
                        $email_link_key = 'link_' . $i;

                        $this->add_render_attribute( $email_link_key, 'href', $settings['email_link']['url'] );

                        if ( $settings['email_link']['is_external'] ) {
                            $this->add_render_attribute( $email_link_key, 'target', '_blank' );
                        }

                        if ( $settings['email_link']['nofollow'] ) {
                            $this->add_render_attribute( $email_link_key, 'rel', 'nofollow' );
                        }

                        $email_link_start .= '<a ' . $this->get_render_attribute_string( $email_link_key ) . '>';
                        $email_link_end .= '</a>';
                    }

                    $emailHTML .= '<div class="mk-fs-menu-email">' . $email_link_start . $settings['email_address'] . $email_link_end . '</div>';
                }

                echo '<div id="mk-full-screen-menu-'. $uniqueId .'" class="mk-full-screen-menu-'. $uniqueId .' mk-fullscreen-menu-overlay mk-fs-menu-left-section-' . $settings['left_section_on'] . ' mk-fullscreen-menu-indicator-' . $settings['indicator_on'] . '">
                        <div class="mk-fullscreen-menu-overlay-inner">

                            <div class="mk-fs-menu-close" data-close-id="mk-full-screen-menu-'.$uniqueId.'"></div>

                            ' . $leftSectionImage . '

                            <div class="mk-fs-menu-content">
                                ' . $logoImageHtml . '
                                <div class="mk-fullscreen-menu-holder">
                                    ' . wp_nav_menu( $nav_menu_args ) . '
                                </div>

                                <div class="mk-fs-menu-bottom">
                                    ' . $socialSitesHTML . $emailHTML . '
                                </div>
                            </div>

                        </div>
                    </div>';

            }

        $output = ob_get_contents();
        ob_end_clean();
        mk_add_inline_html($output);
        echo '<div class="mk_hidden"></div>';

    }

}