<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Google_Map extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_google_map'; }
	public function get_title()      { return esc_html__( 'Google Map', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-google-maps'; }
	public function get_categories() { return ['mk-general-elements']; }
	public function get_keywords()   { return [ 'theme','google map', 'map', 'location']; }
	public function get_style_depends() { return ['mk-core-main']; }

	public function get_script_depends() {
		return [ 'mk-widgets', 'mk-google-maps-api', 'mk-google-maps-cluster' ];
	}

	protected function register_controls() {

		$this->register_addresses_controls();
		$this->register_layout_controls();
		$this->register_controls_controls();
		$this->register_info_window_controls();
	}

	protected function register_addresses_controls() {

		mk_elem_start_ctrl($this, 'section_map_addresses', 'Addresses');

		if (  '' == mk_get_ts_option( 'mk_map_apikey' ) ) {

			$admin_link = "admin.php?page=swm-advanced-settings";
			$this->add_control(
				'err_msg',
				[
					'type'            => \Elementor\Controls_Manager::RAW_HTML,
					'raw'             => sprintf( __( 'Google Map API is required to display customized Google Map without an issue. Please add Google Map API key from <a href="%s" target="_blank" rel="noopener">HERE</a>.', 'orbius-core' ), $admin_link ),
					'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
				]
			);
		}

			$repeater = new \Elementor\Repeater();

            $latlongLink_start = '<a href="https://www.latlong.net/" target="_blank">';
            $latlongLink_end = '</a>';

			$repeater->add_control(
			   'latitude',
			   [
					'label'       => esc_html__( 'Latitude', 'orbius-core' ),
					'description' => sprintf(esc_html__('%sClick%s here to find Latitude of your location','orbius-core'),$latlongLink_start, $latlongLink_end),
					'type'        => \Elementor\Controls_Manager::TEXT,
					'default'     => '',
					'label_block' => true,
					'dynamic'     => [
						'active' => true,
					],
			   ]
			);

			$repeater->add_control(
			   'longitude',
			   [
					'label'       => esc_html__( 'Longitude', 'orbius-core' ),
					'description' => sprintf(esc_html__('%sClick%s here to find Longitude of your location','orbius-core'),$latlongLink_start, $latlongLink_end),
					'type'        => \Elementor\Controls_Manager::TEXT,
					'default'     => '',
					'label_block' => true,
					'dynamic'     => [
						'active' => true,
					],
			   ]
			);

			$repeater->add_control(
			   'map_title',
			   [
					'label'       => esc_html__( 'Address Title', 'orbius-core' ),
					'type'        => \Elementor\Controls_Manager::TEXT,
					'default'     => '',
					'label_block' => true,
					'dynamic'     => [
						'active' => true,
					],
			   ]
			);

			$repeater->add_control(
			   'marker_infowindow',
			   [
					'label'       => esc_html__( 'Display Info Window', 'orbius-core' ),
					'type'        => \Elementor\Controls_Manager::SELECT,
					'default'     => 'none',
					'label_block' => true,
					'options'     => [
						'none'  => esc_html__( 'None', 'orbius-core' ),
						'click' => esc_html__( 'On Mouse Click', 'orbius-core' ),
						'load'  => esc_html__( 'On Page Load', 'orbius-core' ),
					],
			   ]
			);

			$repeater->add_control(
			   'map_description',
			   [
					'label'       => esc_html__( 'Address Information', 'orbius-core' ),
					'type'        => \Elementor\Controls_Manager::TEXTAREA,
					'label_block' => true,
					'conditions'  => [
						'terms' => [
							[
								'name'     => 'marker_infowindow',
								'operator' => '!=',
								'value'    => 'none',
							],
						],
					],
					'dynamic'     => [
						'active' => true,
					],
			   ]
			);

			$repeater->add_control(
			   'marker_icon_type',
			   [
					'label'   => esc_html__( 'Marker Icon', 'orbius-core' ),
					'type'    => \Elementor\Controls_Manager::SELECT,
					'default' => 'default',
					'options' => [
						'default' => esc_html__( 'Default', 'orbius-core' ),
						'custom'  => esc_html__( 'Custom', 'orbius-core' ),
					],
			   ]
			);

            $repeater->add_control('marker_icon', [
                'label'     => esc_html__( 'Select Marker', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
                'condition' => ['marker_icon_type' => 'custom'],
            ]);

			$repeater->add_control(
			   'custom_marker_size',
			   [
					'label'       => esc_html__( 'Marker Size', 'orbius-core' ),
					'type'        => \Elementor\Controls_Manager::SLIDER,
					'size_units'  => [ 'px' ],
					'description' => esc_html__( 'Note: Leave above size field blank to display Marker image with original size.', 'orbius-core' ),
					'default'     => [
						'size' => 30,
						'unit' => 'px',
					],
					'range'       => [
						'px' => [
							'min' => 5,
							'max' => 100,
						],
					],
					'conditions'  => [
						'terms' => [
							[
								'name'     => 'marker_icon_type',
								'operator' => '==',
								'value'    => 'custom',
							],
						],
					],
			   ]
			);


			$this->add_control(
				'addresses',
				[
					'label'       => '',
					'type'        => \Elementor\Controls_Manager::REPEATER,
					'fields' 		=> $repeater->get_controls(),
					'default'     => [
						[
							'latitude'        => 40.721810,
							'longitude'       => -73.995540,
							'map_title'       => esc_html__( 'Canal Street, New York', 'orbius-core' ),
							'map_description' => '',
						],
					],
					'title_field' => '<i class="fa fa-map-marker"></i> {{{ map_title }}}',
				]
			);

		$this->end_controls_section();
	}

	protected function register_layout_controls() {

		mk_elem_start_ctrl($this, 'section_map_settings', 'Layout');

			$this->add_control(
				'type',
				[
					'label'   => esc_html__( 'Map Type', 'orbius-core' ),
					'type'    => \Elementor\Controls_Manager::SELECT,
					'default' => 'roadmap',
					'options' => [
						'roadmap'   => esc_html__( 'Road Map', 'orbius-core' ),
						'satellite' => esc_html__( 'Satellite', 'orbius-core' ),
						'hybrid'    => esc_html__( 'Hybrid', 'orbius-core' ),
						'terrain'   => esc_html__( 'Terrain', 'orbius-core' ),
					],
				]
			);

			$this->add_control(
				'skin',
				[
					'label'     => esc_html__( 'Map Skin', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::SELECT,
					'default'   => 'standard',
					'options'   => [
						'standard'     => esc_html__( 'Default', 'orbius-core' ),
						'aqua'         => esc_html__( 'Aqua', 'orbius-core' ),
						'aubergine'    => esc_html__( 'Aubergine', 'orbius-core' ),
						'classic_blue' => esc_html__( 'Classic Blue', 'orbius-core' ),
						'dark'         => esc_html__( 'Dark', 'orbius-core' ),
						'earth'        => esc_html__( 'Earth', 'orbius-core' ),
						'magnesium'    => esc_html__( 'Magnesium', 'orbius-core' ),
						'night'        => esc_html__( 'Night', 'orbius-core' ),
						'retro'        => esc_html__( 'Retro', 'orbius-core' ),
						'silver'       => esc_html__( 'Silver', 'orbius-core' ),
						'custom'       => esc_html__( 'Custom', 'orbius-core' ),
					],
					'condition' => [
						'type!' => 'satellite',
					],
				]
			);

            $mapStyleLink_start = '<a href="https://mapstyle.withgoogle.com/" target="_blank">';
            $mapStyleLink_end = '</a>';

			$this->add_control(
				'map_custom_style',
				[
					'label'       => esc_html__( 'Custom Style', 'orbius-core' ),
					'description' => sprintf(esc_html__('%sClick here%s to get custom style Google Map JSON code.','orbius-core'),$mapStyleLink_start, $mapStyleLink_end),
					'type'        => \Elementor\Controls_Manager::TEXTAREA,
					'condition'   => [
						'skin'  => 'custom',
						'type!' => 'satellite',
					],
				]
			);

			$this->add_control(
				'animate',
				[
					'label'   => esc_html__( 'Marker Animation', 'orbius-core' ),
					'type'    => \Elementor\Controls_Manager::SELECT,
					'default' => '',
					'options' => [
						''       => esc_html__( 'None', 'orbius-core' ),
						'drop'   => esc_html__( 'On Load', 'orbius-core' ),
						'bounce' => esc_html__( 'Continuous', 'orbius-core' ),
					],
				]
			);

			$this->add_control(
				'zoom',
				[
					'label'   => esc_html__( 'Map Zoom', 'orbius-core' ),
					'type'    => \Elementor\Controls_Manager::SLIDER,
					'default' => [
						'size' => 12,
					],
					'range'   => [
						'px' => [
							'min' => 1,
							'max' => 22,
						],
					],
				]
			);

			$this->add_responsive_control(
				'height',
				[
					'label'      => esc_html__( 'Height', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'default'    => [
						'size' => 500,
						'unit' => 'px',
					],
					'range'      => [
						'px' => [
							'min' => 80,
							'max' => 1200,
						],
					],
					'selectors'  => [
						'{{WRAPPER}} .mk-google-map' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
	}

	protected function register_controls_controls() {

		mk_elem_start_ctrl($this, 'section_map_controls', 'Controls');

            $this->add_control('option_streeview',[
                'label'   => esc_html__( 'Street View Controls', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('type_control',[
                'label'   => esc_html__( 'Map Type Control', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('zoom_control',[
                'label'   => esc_html__( 'Zoom Control', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('fullscreen_control',[
                'label'   => esc_html__( 'Fullscreen Control', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('scroll_zoom',[
                'label'   => esc_html__( 'Street View Controls', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

			$this->add_control(
				'auto_center',
				[
					'label'       => esc_html__( 'Map Alignment', 'orbius-core' ),
					'type'        => \Elementor\Controls_Manager::SELECT,
					'default'     => 'center',
					'options'     => [
						'center'   => esc_html__( 'Center', 'orbius-core' ),
						'moderate' => esc_html__( 'Moderate', 'orbius-core' ),
					],
					'description' => esc_html__( 'Default setting of map is center align. You can switch to moderate mode when you have multiple locations. Moderate mode will make first location center point.', 'orbius-core' ),
				]
			);

            $this->add_control('cluster',[
                'label'   => esc_html__( 'Cluster the Markers', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

			$this->add_control(
				'cluster_doc',
				[
					'type'            => \Elementor\Controls_Manager::RAW_HTML,
					'raw'             => esc_html__( 'Enable this If you have a lot of markers on the map and they are close to each other. This utility helps you to manage multiple markers at different zoom levels.', 'orbius-core' ),
					'content_classes' => 'mk-editor-doc',
					'condition'       => [ 'cluster' => 'yes' ],
				]
			);


		$this->end_controls_section();
	}

	protected function register_info_window_controls() {

		mk_elem_start_ctrl($this, 'section_info_window_style', 'Info Window');

			$this->add_control(
				'info_window_size',
				[
					'label'       => esc_html__( 'Maximum Width', 'orbius-core' ),
					'type'        => \Elementor\Controls_Manager::SLIDER,
					'default'     => [
						'size' => 250,
						'unit' => 'px',
					],
					'range'       => [
						'px' => [
							'min'  => 50,
							'max'  => 1000,
							'step' => 1,
						],
					],
					'size_units'  => [ 'px' ],
					'label_block' => true,
				]
			);

			$this->add_responsive_control(
				'info_padding',
				[
					'label'      => esc_html__( 'Padding', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .gm-style .mk-infowindow-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'title_spacing',
				[
					'label'      => esc_html__( 'Spacing Between Title & Description', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'range'      => [
						'px' => [
							'min'  => 0,
							'max'  => 100,
							'step' => 1,
						],
					],
					'default'    => [
						'size' => 5,
						'unit' => 'px',
					],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .gm-style .mk-infowindow-description' => 'margin-top: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .gm-style .mk-infowindow-title' => 'font-weight: bold;',
					],
				]
			);

			mk_elem_heading_ctrl($this, 'title_heading', 'Title Text' );

			$this->add_control(
				'title_color',
				[
					'label'     => esc_html__( 'Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .gm-style .mk-infowindow-title' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name'     => 'title_typography',
					'selector' => '{{WRAPPER}} .gm-style .mk-infowindow-title',
				]
			);

			mk_elem_heading_ctrl($this, 'description_heading', 'Description Text' );

			$this->add_control(
				'description_color',
				[
					'label'     => esc_html__( 'Color', 'orbius-core' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .gm-style .mk-infowindow-description' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name'     => 'description_typography',
					'selector' => '{{WRAPPER}} .gm-style .mk-infowindow-description',
				]
			);

		$this->end_controls_section();

	}

	protected function get_locations() {

		$settings = $this->get_settings_for_display();

		$locations = array();

		foreach ( $settings['addresses'] as $index => $item ) {

			$latitude  = apply_filters( 'mk_google_map_latitude', $item['latitude'] );
			$longitude = apply_filters( 'mk_google_map_longitude', $item['longitude'] );

			$location_object = array(
				$latitude,
				$longitude,
			);

			$location_object[] = ( 'none' != $item['marker_infowindow'] ) ? true : false;
			$location_object[] = apply_filters( 'mk_google_map_title', $item['map_title'] );
			$location_object[] = apply_filters( 'mk_google_map_description', $item['map_description'] );

			if (
				'custom' == $item['marker_icon_type'] && is_array( $item['marker_icon'] ) &&
				'' != $item['marker_icon']['url']
			) {
				$location_object[] = 'custom';
				$location_object[] = $item['marker_icon']['url'];
				$location_object[] = $item['custom_marker_size']['size'];
			} else {
				$location_object[] = '';
				$location_object[] = '';
				$location_object[] = '';
			}

			$location_object[] = ( 'load' == $item['marker_infowindow'] ) ? 'iw_open' : '';

			$locations[] = $location_object;
		}

		return $locations;
	}

	protected function get_map_options() {

		$settings = $this->get_settings_for_display();

		return array(
			'zoom'              => ( ! empty( $settings['zoom']['size'] ) ) ? $settings['zoom']['size'] : 4,
			'mapTypeId'         => ( ! empty( $settings['type'] ) ) ? $settings['type'] : 'roadmap',
			'mapTypeControl'    => ( 'yes' == $settings['type_control'] ) ? true : false,
			'streetViewControl' => ( 'yes' == $settings['option_streeview'] ) ? true : false,
			'zoomControl'       => ( 'yes' == $settings['zoom_control'] ) ? true : false,
			'fullscreenControl' => ( 'yes' == $settings['fullscreen_control'] ) ? true : false,
			'gestureHandling'   => ( 'yes' == $settings['scroll_zoom'] ) ? true : false,
		);
	}

	protected function render() {

		$settings = $this->get_settings_for_display();

		ob_start();

		$map_options = $this->get_map_options();
		$locations   = $this->get_locations();

		$this->add_render_attribute(
			'google-map',
			[
				'id'               => 'mk-google-map-' . esc_attr( $this->get_id() ),
				'class'            => 'mk-google-map',
				'data-map_options' => wp_json_encode( $map_options ),
				'data-cluster'     => $settings['cluster'],
				'data-max-width'   => $settings['info_window_size']['size'],
				'data-locations'   => wp_json_encode( $locations ),
				'data-animate'     => $settings['animate'],
				'data-auto-center' => $settings['auto_center'],
			]
		);

		if ( 'standard' != $settings['skin'] ) {
			if ( 'custom' != $settings['skin'] ) {
				$this->add_render_attribute( 'google-map', 'data-predefined-style', $settings['skin'] );
			} elseif ( ! empty( $settings['map_custom_style'] ) ) {
				$this->add_render_attribute( 'google-map', 'data-custom-style', $settings['map_custom_style'] );
			}
		}

		?>
		<div class="mk-google-map-wrap">
			<div <?php echo $this->get_render_attribute_string( 'google-map' ); ?>></div>
		</div>
		<?php
		$html = ob_get_clean();
		echo $html;
	}

}