<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Horizontal_Menu extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_horizontal_menu'; }
	public function get_title()      { return esc_html__( 'Horizontal Menu', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-nav-menu'; }
	public function get_categories() { return ['mk-sections-elements']; }
	public function get_keywords()   { return [ 'theme','menu','navigation','horizontal','mega','dropdown' ]; }
	public function get_style_depends() { return ['mk-core-main']; }

	protected function register_controls() {

        mk_elem_start_ctrl($this, 'parent_menu', 'Main Menu');

        $this->add_control('menu_list_select', [
            'label' => esc_html__( 'Select Menu', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => mk_wp_menu_names_list(),
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'parent_typography',
            'selector' => '{{WRAPPER}} .mk-nav-menu > li > a > span',
        ]);

        $this->add_responsive_control('parent_margin', [
            'label' => esc_html__( 'Margin', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ]
        ]);

        $this->add_responsive_control('parent_padding', [
            'label' => esc_html__( 'Padding', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li > a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ]
        ]);

        $this->add_control('parent_color', [
            'label' => esc_html__( 'Font Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li,
                {{WRAPPER}} .mk-nav-menu > li > a' => 'color: {{VALUE}}',
                '{{WRAPPER}} .mk-nav-menu > li > a span:before' => 'border-color: {{VALUE}}',
                '{{WRAPPER}}.mk-nav-menu-indicator1-yes .mk-nav-menu > li.menu-item-has-children > a .swm-svg-submenu-indicator' => 'fill: {{VALUE}}',
            ],
        ]);

        $this->add_control('parent_hover_color', [
            'label' => esc_html__( 'Active/Hover Font Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:hover,
                 {{WRAPPER}} .mk-nav-menu > li:hover > a,
                 {{WRAPPER}} .mk-nav-menu > li.swm-m-active > a' => 'color: {{VALUE}}',

                '{{WRAPPER}} .mk-nav-menu > li.swm-m-active > a span:before,
                 {{WRAPPER}} .mk-nav-menu > li:hover > a span:before' => 'border-color: {{VALUE}}',

                '{{WRAPPER}} .mk-nav-menu > li > a span:after' => 'background: {{VALUE}}',
                '{{WRAPPER}}.mk-nav-menu-indicator1-yes .mk-nav-menu > li.menu-item-has-children:hover > a .swm-svg-submenu-indicator' => 'fill: {{VALUE}}',
            ],
        ]);

        $this->add_control('sublevel_indicator',[
            'label' => esc_html__( 'Sublevel Indicator', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'prefix_class' => 'mk-nav-menu-indicator1-'
        ]);

        $this->add_control('sublevel_indicator1_icon_size', [
            'label' => esc_html__( 'Icon Size', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'range'     => [
                'px' => [
                    'min' => 1,
                    'max' => 100,
                ],
            ],
            'condition' => ['sublevel_indicator' => 'yes'],
            'selectors' => [
                '{{WRAPPER}}.mk-nav-menu-indicator1-yes .mk-nav-menu > li.menu-item-has-children > a .swm-svg-submenu-indicator' => 'font-size: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_control('sublevel_indicator1_icon_spacing', [
            'label' => esc_html__( 'Icon Spacing', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'range'     => [
                'px' => [
                    'min' => 1,
                    'max' => 100,
                ],
            ],
            'condition' => ['sublevel_indicator' => 'yes'],
            'selectors' => [
                '{{WRAPPER}}.mk-nav-menu-indicator1-yes .mk-nav-menu > li.menu-item-has-children > a .swm-svg-submenu-indicator' => 'margin-left: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_control('hover_small_corcle',[
            'label' => esc_html__( 'Active/Hover Small Circle', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
            'prefix_class' => 'mk-nav-menu-hover-circle-'
        ]);

        $this->add_control('small_circle_color', [
            'label' => esc_html__( 'Small Circle Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'condition' => ['hover_small_corcle' => 'yes'],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li a span:before' => 'background-color: {{VALUE}}',
            ],
        ]);

		$this->end_controls_section();


        // Dropdown Menu -------------------------------------------------------------------------------------------------------------------

        mk_elem_start_ctrl($this, 'sub_menu', 'Dropdown Menu');

        mk_elem_heading_ctrl($this, 'subbitems_title', 'Dropdown Menu Items', 'before' );

        $this->add_control('sub_color', [
            'label' => esc_html__( 'Font Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul li,
                {{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul li a' => 'color: {{VALUE}}',
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) li.menu-item-has-children > a svg' => 'fill: {{VALUE}}',
            ],
        ]);

        $this->add_control('sub_hover_color', [
            'label' => esc_html__( 'Hover Font Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) ul > ul li:hover,
                {{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul li:hover>a,
                {{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > .sub-menu a:hover,
                {{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > .sub-menu .current-menu-item > a,
                {{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > .sub-menu .current-menu-ancestor > a' => 'color: {{VALUE}}',
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) li.menu-item-has-children:hover > a svg' => 'fill: {{VALUE}}',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(),[
            'name' => 'sub_typography',
            'selector' => '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul li > a span,{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) li.menu-item-has-children > a svg',
        ]);

        $this->add_responsive_control('sub_margin', [
            'label' => esc_html__( 'Margin', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px' ],
            'allowed_dimensions' => 'vertical',
            'placeholder' => [
                'top' => '',
                'right' => 'auto',
                'bottom' => '',
                'left' => 'auto',
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul li' => 'margin-top: {{TOP}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('sub_padding', [
            'label' => esc_html__( 'Padding', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) li.menu-item-has-children:after' => 'right: {{RIGHT}}{{UNIT}}'
            ]
        ]);

        $this->add_control('sublevel_indicator_dropdown',[
            'label' => esc_html__( 'Sublevel Indicator Icon', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
            'prefix_class' => 'mk-nav-menu-indicator2-'
        ]);

        mk_elem_heading_ctrl($this, 'subbox_title', 'Dropdown Menu Box', 'before' );

        $this->add_control('subbox_width', [
            'label' => esc_html__( 'Width', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'default' =>[
                'size' => '300',
            ],
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 1200,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) ul.sub-menu' => 'width: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_control('subbox_left_position', [
            'label' => esc_html__( 'Left Position', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'default' =>[
                'size' => '0',
            ],
            'range'     => [
                'px' => [
                    'min' => -100,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > .sub-menu' => 'left: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_control('subbox_bg_color', [
            'label' => esc_html__( 'Background Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul.sub-menu,
                {{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul ul.sub-menu' => 'background-color: {{VALUE}}',
            ],
        ]);

        $this->add_control('subbox_padding', [
            'label' => esc_html__( 'Padding', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) ul.sub-menu' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ]
        ]);

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name'        => 'subbox_border',
            'label'       => esc_html__( 'Border', 'orbius-core' ),
            'selector'    => '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) ul.sub-menu',
        ]);

        $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
            'name'      => 'sub_shadow',
            'selector'  => '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul.sub-menu,
                            {{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) > ul ul.sub-menu',
        ]);

        mk_elem_heading_ctrl($this, 'sublevel_title', 'Sublevel', 'before' );

        $this->add_control('sublevel_position', [
            'label' => esc_html__( 'Top Position', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'default' =>[
                'size' => '-34',
            ],
            'range'     => [
                'px' => [
                    'min' => -200,
                    'max' => 200,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) ul.sub-menu ul.sub-menu' => 'top: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name'        => 'sub_subbox_border',
            'label'       => esc_html__( 'Border', 'orbius-core' ),
            'selector'    => '{{WRAPPER}} .mk-nav-menu > li:not(.swm-megamenu-item) ul.sub-menu ul.sub-menu',
        ]);

        $this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

        $menu_list_items = $settings['menu_list_select'];

        if ( $menu_list_items != '' ) {

            $nav_menu = ! empty( $settings['menu_list_select'] ) ? wp_get_nav_menu_object( $settings['menu_list_select'] ) : false;
            if ( ! $nav_menu ) { return; }

            $nav_menu_args = array(
                'fallback_cb' => '',
                'menu_class'  => 'mk-nav-menu swm-primary-nav',
                'menu'        => $nav_menu,
                'depth'       => 0,
                'echo'        => false,
                'link_before' => '<span>',
                'link_after' => '</span>',
            );

            echo '<div class="mk-navigation-menu-container">
                    <div class="swm-primary-nav-wrap">' . wp_nav_menu( $nav_menu_args ) . '</div>
                </div>';
        }


	}

}