<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Icon_Button extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_icon_button'; }
	public function get_title()          { return esc_html__( 'Icon Button', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-button'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'button', 'icon button','icon','action','marketing']; }
	public function get_style_depends()  { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_general', 'General');

        $this->add_control('info_button_layout', [
            'label' => esc_html__( 'Layout', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'filled' => esc_html__( 'Filled', 'orbius-core' ),
                'outlined' => esc_html__( 'Outlined', 'orbius-core' ),
            ],
            'default' => 'filled',
        ]);

        $this->add_control('info_button_type', [
            'label' => esc_html__( 'Type', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'standard' => esc_html__( 'Standard', 'orbius-core' ),
                'icon-boxed' => esc_html__( 'Icon Boxed', 'orbius-core' ),
            ],
            'default' => 'standard',
        ]);

        $this->add_control('info_button_text', [
            'label' => esc_html__( 'Button Text', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
            'default' => 'Join Us Now',
        ]);

        $this->add_control('info_button_subtext', [
            'label' => esc_html__( 'Button Subtext', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
            'default' => 'Get your discount',
        ]);

        $this->add_control('info_button_link', [
            'label'    => esc_html__( 'Button Link', 'orbius-core' ),
            'type'     => \Elementor\Controls_Manager::URL,
            'default'  => [
                'url'         => '#',
                'is_external' => '',
            ],
            'dynamic'  => [
                'active' => true,
            ],
            'selector' => '',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'button_text_style', 'Button Text', true);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'info_button_typography',
                'selector' => '{{WRAPPER}} .mk-icon-button',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'info_button_subtext_typography',
                'label'     => esc_html__( 'Subtext Typography', 'orbius-core' ),
                'selector' => '{{WRAPPER}} .mk-icon-button-subtext',
            ]);

            $this->add_responsive_control('info_button_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-icon-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .mk-icon-button.mk-icon-button-type--icon-boxed .mk-icon-button-text-holder' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .mk-icon-button.mk-icon-button-type--icon-boxed .mk-icon-button-icon' => 'padding: {{TOP}}{{UNIT}} 0 {{BOTTOM}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('info_button_border_radius', [
                'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-icon-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'info_button_border_color',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-icon-button',
            ]);

            $this->start_controls_tabs( 'tabs_button_styles' );
                $this->start_controls_tab('tab_button_normal', array(
                    'label' => esc_html__( 'Normal', 'orbius-core' ),
                ));

                    $this->add_control('info_button_color', [
                        'label' => esc_html__( 'Text Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('info_button_subtext_color', [
                        'label' => esc_html__( 'Sub Text Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button-subtext' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
                        'name'     => 'info_button_background_color',
                        'label'    => esc_html__( 'Background', 'orbius-core' ),
                        'types'    => [ 'classic', 'gradient' ],
                        'selector' => '{{WRAPPER}} .mk-icon-button.mk-icon-button-layout--filled',
                    ]);

                $this->end_controls_tab();
                $this->start_controls_tab('tab_button_hover', array(
                    'label' => esc_html__( 'Hover', 'orbius-core' ),
                ));

                    $this->add_control('info_button_hover_color', [
                        'label' => esc_html__( 'Text Hover Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button:hover' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('info_button_subtext_hover_color', [
                        'label' => esc_html__( 'Sub Hover Text Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button:hover .mk-icon-button-subtext' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
                        'name'     => 'icon_btn_hover_background_color',
                        'label'    => esc_html__( 'Background Hover Color', 'orbius-core' ),
                        'types'    => [ 'classic', 'gradient' ],
                        'selector' => '{{WRAPPER}} .mk-icon-button.mk-icon-button-layout--filled:hover,
                            {{WRAPPER}} .mk-icon-button.mk-icon-button-layout--outlined:hover',
                    ]);

                    $this->add_control('info_button_hover_border_color', [
                        'label' => esc_html__( 'Border Hover Text Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button:hover' => 'border-color: {{VALUE}};',
                        ],
                    ]);

                $this->end_controls_tab();
            $this->end_controls_tabs();

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'button_icon_style', 'Icon', true);

            $this->add_control('info_button_icon', [
                'label' => esc_html__( 'Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-arrow-right',
                    'library' => 'fa-solid',
                ],
            ]);

            $this->add_control('info_button_icon_position', [
                'label' => esc_html__( 'Icon Position', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'left' => esc_html__( 'Left', 'orbius-core' ),
                    'right' => esc_html__( 'Right', 'orbius-core' ),
                ],
                'default' => 'right',
            ]);

            $this->add_responsive_control('info_button_icon_size', [
                'label'      => esc_html__( 'Icon Size', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', 'rem', 'vw'],
                'range'      => [
                    'px' => ['min'  => 0, 'max'  => 100, 'step' => 1 ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-icon-button-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-icon-button-icon svg' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('info_button_icon_enable_side_border',[
                'label'   => esc_html__( 'Enable Icon Side Border', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition'    => ['info_button_type' => 'icon-boxed']
            ]);

            $this->add_responsive_control('info_button_icon_margin', [
                'label'      => esc_html__( 'Icon Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'allowed_dimensions' => ['left', 'right'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-icon-button-icon' => 'margin: 0 {{RIGHT}}{{UNIT}} 0 {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('info_button_icon_side_height', [
                'label'      => esc_html__( 'Icon Side Border Height', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => ['min'  => 0, 'max'  => 200, 'step' => 1, ],
                ],
                'default' => [
                                'unit' => 'px',
                                'size' => '45',
                            ],
                'condition' => ['info_button_icon_enable_side_border' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-icon-button-border' => 'height: {{SIZE}}{{UNIT}}; align-self: center;',
                ],
            ]);

            $this->add_responsive_control('info_button_icon_side_width', [
                'label'      => esc_html__( 'Icon Side Border Width', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => ['min'  => 0, 'max'  => 20, 'step' => 1, ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '1',
                ],
                'condition'    => ['info_button_icon_enable_side_border' => 'yes'],
                'selectors' => [
                   '{{WRAPPER}} .mk-icon-button-border' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->start_controls_tabs( 'tabs_icon_styles' );
                $this->start_controls_tab('tab_icon_normal', array(
                    'label' => esc_html__( 'Normal', 'orbius-core' ),
                ));

                    $this->add_control('info_button_icon_color', [
                        'label' => esc_html__( 'Icon Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button-icon' => 'color: {{VALUE}};',
                        ],
                    ]);
                    $this->add_control('info_button_icon_background_color', [
                        'label' => esc_html__( 'Icon Background Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'condition' => ['info_button_type' => 'icon-boxed'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button.mk-icon-button-type--icon-boxed .mk-icon-button-icon' => 'background-color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('info_button_icon_side_color', [
                        'label' => esc_html__( 'Icon Side Border Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'condition'    => ['info_button_icon_enable_side_border' => 'yes'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button-border' => 'background-color: {{VALUE}};',
                        ],
                    ]);

                $this->end_controls_tab();
                $this->start_controls_tab('tab_icon_hover', array(
                    'label' => esc_html__( 'Hover', 'orbius-core' ),
                ));

                    $this->add_control('info_button_icon_hover_color', [
                        'label' => esc_html__( 'Icon Hover Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button:hover .mk-icon-button-icon' => 'color: {{VALUE}};',
                        ],
                    ]);
                    $this->add_control('info_button_icon_background_hover_color', [
                        'label' => esc_html__( 'Icon Background Hover Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'condition' => ['info_button_type' => 'icon-boxed'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button.mk-icon-button-type--icon-boxed:hover .mk-icon-button-icon' => 'background-color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('info_button_icon_side_hover_color', [
                        'label' => esc_html__( 'Icon Side Border Hover Color', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::COLOR,
                        'condition'    => ['info_button_icon_enable_side_border' => 'yes'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-icon-button.mk-icon-button-type--icon-boxed:hover .mk-icon-button-border' => 'background-color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('info_button_icon_hover_move', [
                        'label' => esc_html__( 'Move Icon', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::SELECT,
                        'default' => 'scale',
                        'options' => [
                            'none'          => esc_html__( 'None', 'orbius-core' ),
                            'scale'         => esc_html__( 'Scale', 'orbius-core' ),
                            'rotate'        => esc_html__( 'Rotate', 'orbius-core' ),
                            'bounce-right'  => esc_html__( 'Bounce Right', 'orbius-core' ),
                            'bounce-bottom' => esc_html__( 'Bounce Bottom', 'orbius-core' ),
                            'wiggle'        => esc_html__( 'Wiggle', 'orbius-core' ),
                            'spin'          => esc_html__( 'Spin', 'orbius-core' ),
                        ],
                    ]);

                $this->end_controls_tab();
            $this->end_controls_tabs();

        $this->end_controls_section();

    }

    public function render() {

        $atts = $this->get_settings_for_display();

        // link
        $button_link = '#';

        if (!empty($atts['info_button_link']['url'])) {

            $button_link = $atts['info_button_link']['url'];

            if ( $atts['info_button_link']['is_external'] ) {
                $this->add_render_attribute( 'btn_link', 'target', '_blank' );
            }

            if ( $atts['info_button_link']['nofollow'] ) {
                $this->add_render_attribute( 'btn_link', 'rel', 'nofollow' );
            }
        }

        $container_classes = array();

        $container_classes[] = 'mk-icon-button';
        $container_classes[] = 'mk-icon-button-html--link';
        $container_classes[] = ! empty( $atts['info_button_layout'] ) ? 'mk-icon-button-layout--' . $atts['info_button_layout'] : '';
        $container_classes[] = ! empty( $atts['info_button_type'] ) ? 'mk-icon-button-type--' . $atts['info_button_type'] : '';
        $container_classes[] = ! empty( $atts['info_button_icon_position'] ) ? 'mk-icon-button-icon--' . $atts['info_button_icon_position'] : '';
        $container_classes[] = ! empty( $atts['info_button_icon_hover_move'] ) ? 'mk-icon-button-anim-' . $atts['info_button_icon_hover_move'] : '';
        $container_classes = implode( ' ', $container_classes );

        // icon
        $iconContent = '';
        if ( ! empty($atts['info_button_icon']) && ! empty( array_values($atts['info_button_icon'])[0] ) ) {

            ob_start();
            \Elementor\Icons_Manager::render_icon( $atts['info_button_icon'], array( 'aria-hidden' => 'true' ) );
            $icon_html = ob_get_clean();

            $icon_classes = 'mk-icon-button-icon';
            $icon_classes .= ! empty( $atts['info_button_icon_color'] ) ? ' mk-icon-button--icon-color-set' : '';

            $iconContent = '<span class="'.$icon_classes.'">
                                <span class="mk-icon-button-icon-inner">'.$icon_html;
            if ( ! empty($info_button_icon_hover_move) && ($info_button_icon_hover_move !=='move-horizontal-short')){
                $iconContent .= $icon_html ;
            }
            $iconContent .= '</span>
                        </span>';
        }

        $subtext_classes = 'mk-icon-button-subtext';
        $subtext_classes .= ! empty( $atts['info_button_subtext_color'] ) ? ' mk-icon-button--subtext-color-set' : '';

        $buttonText = !empty($atts['info_button_text']) ? '<span class="mk-icon-button-text">' . esc_html( $atts['info_button_text'] ) .' </span>' : '';
        $buttonSubText = !empty($atts['info_button_subtext']) ? '<span class="'.$subtext_classes.'">' . esc_html( $atts['info_button_subtext'] ) .' </span>' : '';
        $sideBorder = 'yes' === $atts['info_button_icon_enable_side_border'] ? '<span class="mk-icon-button-border"></span>' : '';
        $buttonContent = '';

        if ( 'icon-boxed' == $atts['info_button_type']) {
            $buttonContent .= '<div class="mk-icon-button-text-holder">' . $buttonText . $buttonSubText . '</div> '. $sideBorder . $iconContent;
        } else {
            $buttonContent .= '<div class="mk-icon-button-text-holder">' . $buttonText . $iconContent . '</div> '. $buttonSubText;
        }

        echo '<a class="' . $container_classes. '" href="' . $button_link . '" ' . $this->get_render_attribute_string('btn_link') . '>'.$buttonContent.'</a>';

    }

}