<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Icon_List extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_icon_list'; }
	public function get_title()          { return esc_html__( 'Icon List', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-bullet-list'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'icon list', 'list', 'icon','image list' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_list', 'List');

		$this->add_control('view', [
			'label'                 => esc_html__( 'Layout', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::CHOOSE,
			'default'               => 'traditional',
			'options'               => [
				'traditional'  => ['title' => esc_html__( 'Default', 'orbius-core' ), 'icon' => 'eicon-editor-list-ul', ],
				'inline'       => ['title' => esc_html__( 'Inline', 'orbius-core' ),  'icon' => 'eicon-ellipsis-h', ],
			],
			'render_type'           => 'template',
			'prefix_class'          => 'mk-icon-list-',
			'label_block'           => false,
		]);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control('text', [
			'label'       => esc_html__( 'Text', 'orbius-core' ),
			'label_block' => true,
			'type'        => \Elementor\Controls_Manager::TEXT,
            'dynamic'     => [
                'active'  => true,
            ],
            'default'     => esc_html__('List Item #1','orbius-core')
		]);

		$repeater->add_control('mk_icon_type', [
			'label'       => esc_html__( 'Icon Type', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::CHOOSE,
            'label_block' => false,
            'options'     => [
                'none'   => ['title' => esc_html__( 'None', 'orbius-core' ),   'icon'  => 'eicon-ban', ],
                'icon'   => ['title' => esc_html__( 'Icon', 'orbius-core' ),   'icon'  => 'eicon-star-o', ],
                'image'  => ['title' => esc_html__( 'Image', 'orbius-core' ),  'icon'  => 'eicon-image', ],
                'number' => ['title' => esc_html__( 'Number', 'orbius-core' ), 'icon'  => 'eicon-number-field', ],
            ],
            'default' => 'icon',
		]);

        $repeater->add_control('list_number', [
            'label'       => esc_html__( 'Text', 'orbius-core' ),
            'label_block' => true,
            'type'        => \Elementor\Controls_Manager::TEXT,
            'dynamic'     => ['active'  => true, ],
            'condition'   => ['mk_icon_type' => 'number', ],
            'default'     => esc_html__('01.','orbius-core')
        ]);

		$repeater->add_control('list_icon', [
			'label'      => esc_html__( 'Icon', 'orbius-core' ),
			'type'       => \Elementor\Controls_Manager::ICONS,
			'default'    => ['value' => 'fas fa-check', 'library' => 'fa-solid', ],
	        'condition'  => ['mk_icon_type' => 'icon', ],
		]);

        $repeater->add_control('list_image', [
            'label'     => esc_html__( 'Image', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::MEDIA,
            'condition' => ['mk_icon_type' => 'image'],
        ]);

		$repeater->add_control('link', [
			'label'       => esc_html__( 'Link', 'orbius-core' ),
			'type'        => \Elementor\Controls_Manager::URL,
			'label_block' => true,
            'dynamic'     => [
                'active'  => true,
            ],
			'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
		]);

		$this->add_control('list_items', [
			'label' => esc_html__( 'List Items', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::REPEATER,
			'fields' => $repeater->get_controls(),
			'default' => [
                ['text' => esc_html__( 'List Item #1', 'orbius-core' ), 'list_icon' => esc_html__('fa fa-check','orbius-core') ],
                ['text' => esc_html__( 'List Item #2', 'orbius-core' ), 'list_icon' => esc_html__('fa fa-check','orbius-core') ],
			],
			'title_field' => '<i class="{{ list_icon }}" aria-hidden="true"></i> {{{ text }}}',
		]);

		$this->add_group_control(\Elementor\Group_Control_Image_Size::get_type(), [
			'name'      => 'icon_image_size',
            'label'     => esc_html__( 'Image Size', 'orbius-core' ),
            'default'   => 'full',
			'separator' => 'before',
		]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_list_style', 'List', true);

        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name'                  => 'items_background',
            'label'                 => esc_html__( 'Background', 'orbius-core' ),
            'types'                 => [ 'classic','gradient' ],
            'selector'              => '{{WRAPPER}} .mk-ilist-items li',
        ]);

        if ( is_rtl() ) {

			$this->add_responsive_control('items_spacing', [
				'label'                 => esc_html__( 'List Items Gap', 'orbius-core' ),
				'type'                  => \Elementor\Controls_Manager::SLIDER,
				'range'                 => [
					'px' => ['max' => 1000, ],
				],
                'size_units'  => [ 'px', 'em', '%' ],
				'separator'   => 'before',
				'selectors'   => [
					'{{WRAPPER}} .mk-ilist-items:not(.mk-inline-items) li:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mk-ilist-items.mk-inline-items li:not(:last-child)' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
			]);

		} else {

			$this->add_responsive_control('items_spacing', [
				'label' => esc_html__( 'List Items Gap', 'orbius-core' ),
				'type'  => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => ['max' => 1000, ],
				],
                'size_units'  => [ 'px', 'em', '%' ],
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .mk-ilist-items:not(.mk-inline-items) li:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mk-ilist-items.mk-inline-items li:not(:last-child)' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]);

		}

		$this->add_responsive_control('list_items_padding', [
			'label'      => esc_html__( 'Padding', 'orbius-core' ),
			'type'       => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors'  => [
				'{{WRAPPER}} .mk-ilist-items li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

        $this->add_responsive_control('list_items_alignment', [
			'label'     => esc_html__( 'Alignment', 'orbius-core' ),
			'type'      => \Elementor\Controls_Manager::CHOOSE,
			'options'   => mk_arrays('horizontal_alignment'),
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}}.mk-icon-list-traditional .mk-ilist-items li, {{WRAPPER}}.mk-icon-list-inline .mk-ilist-items' => 'justify-content: {{VALUE}};',
			],
			'selectors_dictionary' => [
				'left' => 'flex-start',
				'right' => 'flex-end',
			],
		]);

        $this->add_control('item_middle',[
            'label'   => esc_html__( 'Item Center', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'prefix_class' => 'mk-icon-center-',
        ]);

        $this->add_control('divider',[
            'label'   => esc_html__( 'Divider', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

		if ( is_rtl() ) {

			$this->add_control('divider_style', [
				'label'        => esc_html__( 'Style', 'orbius-core' ),
				'type'         => \Elementor\Controls_Manager::SELECT,
				'options'      => [
					'solid'    => esc_html__( 'Solid', 'orbius-core' ),
					'double'   => esc_html__( 'Double', 'orbius-core' ),
					'dotted'   => esc_html__( 'Dotted', 'orbius-core' ),
					'dashed'   => esc_html__( 'Dashed', 'orbius-core' ),
					'groove'   => esc_html__( 'Groove', 'orbius-core' ),
					'ridge'    => esc_html__( 'Ridge', 'orbius-core' ),
				],
				'default'   => 'solid',
				'condition' => [
					'divider' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .mk-ilist-items:not(.mk-inline-items) li:not(:last-child)' => 'border-bottom-style: {{VALUE}};',
					'{{WRAPPER}} .mk-ilist-items.mk-inline-items li:not(:last-child)' => 'border-left-style: {{VALUE}};',
				],
			]);

			$this->add_control('divider_weight', [
				'label'    => esc_html__( 'Weight', 'orbius-core' ),
				'type'     => \Elementor\Controls_Manager::SLIDER,
				'default'  => ['size' => 1, ],
				'range'    => [
					'px'   => ['min' => 1, 'max' => 10, ],
				],
				'condition'  => ['divider' => 'yes', ],
				'selectors'  => [
					'{{WRAPPER}} .mk-ilist-items:not(.mk-inline-items) li:not(:last-child)' => 'border-bottom-width: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mk-ilist-items.mk-inline-items li:not(:last-child)' => 'border-left-width: {{SIZE}}{{UNIT}};',
				],
			]);

			$this->add_control('divider_color', [
				'label'     => esc_html__( 'Color', 'orbius-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => ['divider'  => 'yes', ],
				'selectors' => [
					'{{WRAPPER}} .mk-ilist-items:not(.mk-inline-items) li:not(:last-child)' => 'border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .mk-ilist-items.mk-inline-items li:not(:last-child)' => 'border-left-color: {{VALUE}};',
				],
			]);

		} else {

			$this->add_control('divider_style', [
				'label'   => esc_html__( 'Style', 'orbius-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'solid'    => esc_html__( 'Solid', 'orbius-core' ),
					'double'   => esc_html__( 'Double', 'orbius-core' ),
					'dotted'   => esc_html__( 'Dotted', 'orbius-core' ),
					'dashed'   => esc_html__( 'Dashed', 'orbius-core' ),
					'groove'   => esc_html__( 'Groove', 'orbius-core' ),
					'ridge'    => esc_html__( 'Ridge', 'orbius-core' ),
				],
				'default'               => 'solid',
				'condition'             => ['divider' => 'yes', ],
				'selectors'             => [
					'{{WRAPPER}} .mk-ilist-items:not(.mk-inline-items) li:not(:last-child)' => 'border-bottom-style: {{VALUE}};',
					'{{WRAPPER}} .mk-ilist-items.mk-inline-items li:not(:last-child)' => 'border-right-style: {{VALUE}};',
				],
			]);

			$this->add_control('divider_weight', [
				'label'   => esc_html__( 'Weight', 'orbius-core' ),
				'type'    => \Elementor\Controls_Manager::SLIDER,
				'default' => ['size' => 1, ],
				'range' => [
					'px'   => ['min' => 1, 'max' => 10, ],
				],
				'condition' => ['divider' => 'yes', ],
				'selectors'             => [
					'{{WRAPPER}} .mk-ilist-items:not(.mk-inline-items) li:not(:last-child)' => 'border-bottom-width: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mk-ilist-items.mk-inline-items li:not(:last-child)' => 'border-right-width: {{SIZE}}{{UNIT}};',
				],
			]);

			$this->add_control('divider_color', [
				'label'     => esc_html__( 'Color', 'orbius-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => ['divider'  => 'yes', ],
				'selectors' => [
					'{{WRAPPER}} .mk-ilist-items:not(.mk-inline-items) li:not(:last-child)' => 'border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .mk-ilist-items.mk-inline-items li:not(:last-child)' => 'border-right-color: {{VALUE}};',
				],
			]);
		}


        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_icon_style', 'Icon', true);

		$this->add_control('icon_position', [
            'label'                 => esc_html__( 'Position', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::CHOOSE,
            'label_block'           => false,
            'toggle'                => false,
            'default'               => 'left',
            'options'               => mk_arrays('align_left_right'),
			'prefix_class'          => 'mk-icon-',
		]);

        $this->add_control('icon_vertical_align', [
			'label'                 => esc_html__( 'Vertical Alignment', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::CHOOSE,
            'label_block'           => false,
			'default'               => 'middle',
			'options'               => mk_arrays('vertical_alignment'),
			'selectors_dictionary'  => [
				'top'          => 'flex-start',
				'middle'       => 'center',
				'bottom'       => 'flex-end',
			],
			'selectors'             => [
				'{{WRAPPER}} .mk-icon-list-wrap .mk-ilist-items li'   => 'align-items: {{VALUE}};',
			],
		]);

        $this->start_controls_tabs( 'tabs_icon_style' );

        $this->start_controls_tab('tab_icon_normal', [
            'label' => esc_html__( 'Normal', 'orbius-core' ),
        ]);

		$this->add_control('icon_color', [
			'label'     => esc_html__( 'Color', 'orbius-core' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .mk-ilist-items .mk-icon-list-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-ilist-items .mk-icon-list-icon svg' => 'fill: {{VALUE}};',
			],
		]);

		$this->add_control('icon_bg_color', [
			'label'      => esc_html__( 'Background Color', 'orbius-core' ),
			'type'       => \Elementor\Controls_Manager::COLOR,
			'default'    => '',
			'selectors'  => [
				'{{WRAPPER}} .mk-ilist-items .mk-icon-wrapper' => 'background: {{VALUE}};',
			],
		]);

		$this->add_responsive_control('icon_size', [
			'label'   => esc_html__( 'Size', 'orbius-core' ),
			'type'    => \Elementor\Controls_Manager::SLIDER,
			'default' => ['size' => 14, ],
			'range'   => [
				'px' => ['min' => 6, 'max' => 100, ],
			],
			'selectors' => [
				'{{WRAPPER}} .mk-ilist-items .mk-icon-list-icon' => 'font-size: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; width: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}} .mk-ilist-items .mk-icon-list-image img' => 'width: {{SIZE}}{{UNIT}};',
			],
		]);

		if ( is_rtl() ) {

			$this->add_responsive_control('icon_spacing', [
				'label'   => esc_html__( 'Spacing', 'orbius-core' ),
				'type'    => \Elementor\Controls_Manager::SLIDER,
				'default' => ['size' => 8, ],
				'range'      => ['px' => ['min'  => 0, 'max'  => 50, 'step' => 1]],
				'selectors' => [
					'{{WRAPPER}}.mk-icon-left .mk-ilist-items .mk-icon-wrapper' => 'margin-left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}}.mk-icon-right .mk-ilist-items .mk-icon-wrapper' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]);

		} else {

			$this->add_responsive_control('icon_spacing', [
				'label'   => esc_html__( 'Spacing', 'orbius-core' ),
				'type'    => \Elementor\Controls_Manager::SLIDER,
				'default' => ['size' => 8, ],
                'range'   => ['px' => ['min'  => 0, 'max'  => 50, 'step' => 1]],
				'selectors' => [
					'{{WRAPPER}}.mk-icon-left .mk-ilist-items .mk-icon-wrapper' => 'margin-right: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}}.mk-icon-right .mk-ilist-items .mk-icon-wrapper' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
			]);

		}

		$this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
			'name'        => 'icon_border',
			'label'       => esc_html__( 'Border', 'orbius-core' ),
			'placeholder' => '1px',
			'default'     => '1px',
			'selector'    => '{{WRAPPER}} .mk-ilist-items .mk-icon-wrapper',
		]);

		$this->add_control('icon_border_radius', [
			'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
			'type'       => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors'  => [
				'{{WRAPPER}} .mk-ilist-items .mk-icon-wrapper, {{WRAPPER}} .mk-ilist-items .mk-icon-list-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

		$this->add_responsive_control('icon_padding', [
			'label'      => esc_html__( 'Padding', 'orbius-core' ),
			'type'       => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors'  => [
				'{{WRAPPER}} .mk-ilist-items .mk-icon-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

        mk_elem_heading_ctrl($this, 'icon_number_styles', 'Number', 'before' );

        $this->add_control( 'number_font_family', [
            'label' => esc_html__( 'Font Family', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'default'      => 'default',
            'options' => [
                'default'          => esc_html__( 'Default', 'orbius-core' ),
                'swm-heading-text' => esc_html__( 'Headings', 'orbius-core' ),
            ],
        ]);

        $this->add_control('number_font_weight', [
            'label'        => esc_html__( 'Font Weight', 'orbius-core' ),
            'type'         => \Elementor\Controls_Manager::SELECT,
            'default'      => '400',
            'prefix_class' => 'mk-bg-switcher-',
            'condition'    => ['number_font_family' => 'default'],
            'options' => [  '100' => esc_html__( '100', 'orbius-core' ),
                            '200' => esc_html__( '200', 'orbius-core' ),
                            '300' => esc_html__( '300', 'orbius-core' ),
                            '400' => esc_html__( '400', 'orbius-core' ),
                            '500' => esc_html__( '500', 'orbius-core' ),
                            '600' => esc_html__( '600', 'orbius-core' ),
                            '700' => esc_html__( '700', 'orbius-core' ),
                            '800' => esc_html__( '800', 'orbius-core' ),
                            '900' => esc_html__( '900', 'orbius-core' ),
                         ],
            'selectors' => [
                            '{{WRAPPER}} .mk-icon-list-icon' => 'font-weight: {{SIZE}};'
                        ],
        ]);

        $this->add_responsive_control('number_box_size', [
            'label' => esc_html__( 'Box Size', 'orbius-core' ),
            'type'  => \Elementor\Controls_Manager::SLIDER,
            'range' => [
                'px' => ['min' => 0, 'max' => 200, ],
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-ilist-items .mk-icon-list-icon' => 'height: {{SIZE}}{{UNIT}}; width: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_tab();

        $this->start_controls_tab('tab_icon_hover', [
            'label' => esc_html__( 'Hover', 'orbius-core' ),
        ]);

		$this->add_control('icon_color_hover', [
			'label'                 => esc_html__( 'Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-ilist-items .mk-icon-wrapper:hover .mk-icon-list-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-ilist-items .mk-icon-wrapper:hover .mk-icon-list-icon svg' => 'fill: {{VALUE}};',
			],
		]);

		$this->add_control('icon_bg_color_hover', [
			'label'                 => esc_html__( 'Background Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-ilist-items .mk-icon-wrapper:hover' => 'background: {{VALUE}};',
			],
		]);

		$this->add_control('icon_border_color_hover', [
			'label'                 => esc_html__( 'Border Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-ilist-items .mk-icon-wrapper:hover' => 'border-color: {{VALUE}};',
			],
		]);

		$this->add_control('icon_hover_animation', [
			'label'  => esc_html__( 'Animation', 'orbius-core' ),
			'type'   => \Elementor\Controls_Manager::HOVER_ANIMATION,
		]);

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_text_style', 'Text', true);

		$this->add_control('text_color', [
			'label'     => esc_html__( 'Color', 'orbius-core' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} .mk-icon-list-text' => 'color: {{VALUE}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'text_typography',
            'label'    => esc_html__( 'Typography', 'orbius-core' ),
            'selector' => '{{WRAPPER}} .mk-icon-list-text',
        ]);

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute( 'icon-list', 'class', 'mk-ilist-items' );

        $this->add_render_attribute( 'icon', 'class', 'mk-icon-list-icon' );

        $this->add_render_attribute( 'icon-wrap', 'class', 'mk-icon-wrapper' );

        if ( 'inline' === $settings['view'] ) {
			$this->add_render_attribute( 'icon-list', 'class', 'mk-inline-items' );
		}

        $i = 1;
        ?>
        <div class="mk-icon-list-wrap">
            <ul <?php echo $this->get_render_attribute_string( 'icon-list' ); ?>>
                <?php foreach ( $settings['list_items'] as $index => $item ) : ?>
                    <?php if ( $item['text'] ) { ?>
                        <li>
                            <?php
                                $text_key = $this->get_repeater_setting_key( 'text', 'list_items', $index );
                                $this->add_render_attribute( $text_key, 'class', 'mk-icon-list-text' );
                                $this->add_inline_editing_attributes( $text_key, 'none' );

                                if ( ! empty( $item['link']['url'] ) ) {
                                    $link_key = 'link_' . $i;

                                    $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                                    if ( $item['link']['is_external'] ) {
                                        $this->add_render_attribute( $link_key, 'target', '_blank' );
                                    }

                                    if ( $item['link']['nofollow'] ) {
                                        $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                                    }

                                    echo '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                                }
                                if ( $item['mk_icon_type'] != 'none' ) {
                                    $icon_key = 'icon_' . $i;
                                    $this->add_render_attribute( $icon_key, 'class', 'mk-icon-wrapper' );

                                    if ( $item['mk_icon_type'] == 'number' ) {
                                        $this->add_render_attribute( $icon_key, 'class', 'mk-icon-list-number' );
                                    }

                                    if ( $settings['icon_hover_animation'] != '' ) {
                                        $icon_animation = 'elementor-animation-' . $settings['icon_hover_animation'];
                                    } else {
                                        $icon_animation = '';
                                    }
                                    ?>
                                    <span <?php echo $this->get_render_attribute_string( $icon_key ); ?>>
                                        <?php
                                            if ( $item['mk_icon_type'] == 'icon' ) { ?>
                                                <span class="mk-icon-list-icon mk-icon <?php echo $icon_animation; ?>"><?php \Elementor\Icons_Manager::render_icon( $item['list_icon'], [ 'aria-hidden' => 'true' ] ); ?></span>
												<?php
                                            } elseif ( $item['mk_icon_type'] == 'image' ) {

                                        		// responsive image
                                                if (  $settings['icon_image_size_size'] == 'custom' ) {
                                                    $imageTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $item['list_image'], $item['list_image']['id'], 'icon_image_size', 'icon_img-'.$i).' />';
                                                } else {
                                                    $imageTagHtml = wp_get_attachment_image( $item['list_image']['id'], $settings['icon_image_size_size']);
                                                }

                                                printf( '<span class="mk-icon-list-image %2$s">%1$s</span>', $imageTagHtml, $icon_animation );
                                            } elseif ( $item['mk_icon_type'] == 'number' ) { ?>

                                                <span class="mk-icon-list-icon <?php

                                                    echo $icon_animation;
                                                    if ( 'swm-heading-text' === $settings['number_font_family'] ) {
                                                        echo ' swm-heading-text';
                                                    }

                                                ?>"><?php echo $item['list_number']; ?></span>
                                                <?php
                                            }
                                        ?>
                                    </span>
                                    <?php
                                }

                                printf( '<span %1$s>%2$s</span>', $this->get_render_attribute_string( $text_key ), $item['text'] );

                                if ( ! empty( $item['link']['url'] ) ) {
                                    echo '</a>';
                                }
                            ?>
                        </li>
                    <?php } ?>
                <?php $i++; endforeach; ?>
            </ul>
        </div>
        <?php
    }

}