<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Image_Carousel_Slider extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_image_carousel_slider'; }
    public function get_title()          { return esc_html__( 'Image Carousel Slider', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return [ 'mk-sliders-elements' ]; }
    public function get_keywords()       { return [ 'theme','slider','slide show','carousel','image' ]; }
    public function get_style_depends()  { return [ 'swiper','mk-core-main' ]; }
    public function get_script_depends() { return [ 'swiper','mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_heading', 'Slider Items');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('slide_image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'after',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $this->add_control('images', [
                'label' => esc_html__( 'Add Image', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_items_settings', 'Slider Settings');

        $this->add_responsive_control('sliderheight',[
                'label'       => esc_html__( 'Slider Height', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', 'vh' ],
                'default'     => ['unit' => 'vh', 'size' => 50, ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-image-carousel-slider-holder' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->add_control('arrows_on',[
            'label'   => esc_html__( 'Arrow Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('dots_on',[
            'label'   => esc_html__( 'Dots Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('loop_on',[
            'label'   => esc_html__( 'Continuous Loop', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('mousewheel_on',[
            'label'   => esc_html__( 'Mousewheel Control', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_on',[
            'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('center_slides_on',[
            'label'   => esc_html__( 'Center Slides', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('gray_to_color',[
            'label'   => esc_html__( 'Gray to hover Color Image', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'prefix_class' => 'mk-image-carousel-slider-g2c-'
        ]);

        $this->add_control('autoplay_speed', [
            'label' => esc_html__( 'Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 5000,
            'step' => 100,
            'min' => 100,
            'max' => 15000,
        ]);

        $this->add_control('speed', [
            'label' => esc_html__( 'Animation Speed', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 1000,
            'step' => 100,
            'min' => 100,
            'max' => 5000,
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_slider_style', 'Slider Holder', true);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'                  => 'slider_image_size',
                'label'                 => esc_html__( 'Image Size', 'orbius-core' ),
                'default'               => 'full',
            ]);

            $slides_per_view = range( 1, 10 );
            $slides_per_view = array_combine( $slides_per_view, $slides_per_view );

            $this->add_responsive_control('slides_per_view',[
                'type'                  => \Elementor\Controls_Manager::SELECT,
                'label'                 => esc_html__( 'Slides Per View', 'orbius-core' ),
                'options'               => $slides_per_view,
                'default'               => '3',
                'tablet_default'        => '2',
                'mobile_default'        => '1',
                'frontend_available'    => true,
            ]);

            $this->add_control('slide_space', [
                'label' => esc_html__( 'Slide Space', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 0,
                'step' => 1,
                'min' => 0,
                'max' => 1000,
            ]);

            $this->add_responsive_control('content_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-image-carousel-slider .swiper-slide .swipe-slide-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'content_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-image-carousel-slider .swiper-slide .swipe-slide-inner',
            ]);

            $this->add_responsive_control('content_border_radius', [
                    'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-image-carousel-slider .swiper-slide .swipe-slide-inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_control('slider_background', [
                'label'     => esc_html__( 'Slider Holder Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-carousel-slider' => 'background: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_nav_style', 'Navigation', true );

            $this->add_control('dots_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#000000',
                'selectors' => [
                    '{{WRAPPER}} .mk-image-carousel-slider-holder .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-color: {{VALUE}};',
                '{{WRAPPER}} .mk-image-carousel-slider-holder .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active,
                {{WRAPPER}}  .mk-image-carousel-slider-holder .swiper-pagination-bullets .swiper-pagination-bullet:hover,
                {{WRAPPER}}  .mk-image-carousel-slider-holder .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color: {{VALUE}};',
                '{{WRAPPER}} .mk-image-carousel-slider-holder .mk-slider-pn' => 'fill: {{VALUE}};border-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrows Navigation At', 'mobile' );
            mk_elem_hide_ctrl($this, 'dots_responsive_hide', 'Hide Dot Navigation  At', 'mobile' );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $sliderSettings = array(
            'direction'                  => 'horizontal',
            'parallax'                   => 'no',
            'effect'                     => 'slide',
            'arrows_on'                  => $settings['arrows_on'],
            'dots'                       => $settings['dots_on'],
            'autoplay'                   => $settings['autoplay_on'],
            'autoplay_speed'             => $settings['autoplay_speed'],
            'speed'                      => $settings['speed'],
            'mousewheel'                 => $settings['mousewheel_on'],
            'loop'                       => $settings['loop_on'],
            'slides_to_show'             => $settings['slides_per_view'],
            'slides_to_show_tablet'      => $settings['slides_per_view_tablet'],
            'slides_to_show_mobile'      => $settings['slides_per_view_mobile'],
            'slider_next'                => '.swiper-' . $this->get_id() . '-next',
            'slider_prev'                => '.swiper-' . $this->get_id() . '-prev',
            'slider_pagination'          => '.swiper-pagination-' . $this->get_id(),
            'centered_slides'            => $settings['center_slides_on'],
            'image_spacing'              => array(
                                            'unit' => 'px',
                                            'size' => $settings['slide_space'],
                                            'sizes' => []
                                        ),
        );

        $this->add_render_attribute( [
            'slider-attrs'  => [
                'class'          => [ 'swiper', 'swiper-container','mk-image-carousel-slider' ],
                'data-settings'  => json_encode( $sliderSettings ),
                'id'             => 'swiper-' . $this->get_id()
            ]
        ] );

        $slideHTML = $navigation = '';

        $i = 1;

        foreach ( $settings['images'] as $index => $item ) :

            $slide_image = $link_start = $link_end = '';

            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start = '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end = '</a>';
            }

            if (  $settings['slider_image_size_size'] == 'custom' ) {
                $slide_image = '<img '.mk_custom_image_size_html($this, $settings, $item['slide_image'], $item['slide_image']['id'], 'slider_image_size', 'carousel_img_' . $i).' />';
            } else {
                $slide_image = wp_get_attachment_image( $item['slide_image']['id'], $settings['slider_image_size_size']);
            }

            $slideHTML .= '<div class="swiper-slide"><div class="swipe-slide-inner"><span>' . $link_start . $slide_image . $link_end . '</span></div></div>';

            $i++;
        endforeach;

        $arrowNavigation = '';
        $dots            = ('yes' === $settings['dots_on'])  ? '<div class="swiper-pagination swiper-pagination-' . $this->get_id() . ' swm-hide-'. $settings['dots_responsive_hide'] .'"></div>' : '';

        if ('yes' === $settings['arrows_on']) {

            $arrowNavigation .= '<div class="mk-slider-pn mk-slider-prev swiper-' . $this->get_id() . '-prev swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>
                                <div class="mk-slider-pn mk-slider-next swiper-' . $this->get_id() . '-next swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>';
        }

        echo '<div class="mk-image-carousel-slider-holder">
                <div ' . $this->get_render_attribute_string( 'slider-attrs' ) . '>
                    <div class="swiper-wrapper">' . $slideHTML . '</div>

                </div>' . $arrowNavigation . $dots . '
             </div>';

    }

}