<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Image_Slider extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_image_slider'; }
    public function get_title()          { return esc_html__( 'Image Slider', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return [ 'mk-sliders-elements' ]; }
    public function get_keywords()       { return [ 'theme','slider','slide show' ]; }
    public function get_style_depends()  { return [ 'swiper','mk-core-main' ]; }
    public function get_script_depends() { return [ 'swiper','mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_settings', 'Image Slider');

        $this->add_control('gallery_images',[
            'label'   => esc_html__( 'Add Images', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::GALLERY,
            'dynamic' => [
                'active' => true
            ],
        ]);

        $this->add_control('effect', [
            'label'   => esc_html__( 'Effect', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'default' => 'fade',
            'options' => [  'fade' => esc_html__( 'Fade', 'orbius-core' ),
                            'slide' => esc_html__( 'Slide', 'orbius-core' ),
                         ]
        ]);

        $this->add_control('direction', [
            'label'     => esc_html__( 'Direction', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::SELECT,
            'default'   => 'horizontal',
            'condition' => [ 'effect' => 'slide' ],
            'options'   => [  'horizontal' => esc_html__( 'Horizontal', 'orbius-core' ),
                            'vertical' => esc_html__( 'Vertical', 'orbius-core' ),
                         ]
        ]);

        $this->add_control('arrows_on',[
            'label'   => esc_html__( 'Arrow Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('dots_on',[
            'label'   => esc_html__( 'Dots Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('loop_on',[
            'label'   => esc_html__( 'Continuous Loop', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('mousewheel_on',[
            'label'   => esc_html__( 'Mousewheel Control', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_on',[
            'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('hover_pause_on',[
            'label'   => esc_html__( 'Pause on Hover', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'condition' => ['autoplay_on' => 'yes']
        ]);

        $this->add_control('autoplay_speed', [
            'label' => esc_html__( 'Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 5000,
            'step' => 100,
            'min' => 100,
            'max' => 15000,
        ]);

        $this->add_control('speed', [
            'label' => esc_html__( 'Animation Speed', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 1000,
            'step' => 100,
            'min' => 100,
            'max' => 5000,
        ]);

        $this->add_control('feature_image_caption',[
            'type'      => \Elementor\Controls_Manager::SELECT,
            'label'     => esc_html__( 'Large Image Caption', 'orbius-core' ),
            'default'   => '',
            'options'   => [ ''        => esc_html__( 'None', 'orbius-core' ),
                            'caption' => esc_html__( 'Caption', 'orbius-core' ),
                            'title'   => esc_html__( 'Title', 'orbius-core' ),
                        ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_slider_style', 'Slider Holder', true);

            $this->add_control('slider_background', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-slider' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_control('slider_overlay', [
                'label'     => esc_html__( 'Overlay Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-slider-overlay' => 'background: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_nav_style', 'Navigation', true );

                    $this->add_control('dots_color', [
                        'label'     => esc_html__( 'Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'default'   => '#000000',
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-slider .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-color: {{VALUE}};',
                        '{{WRAPPER}} .mk-image-slider .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active,
                        {{WRAPPER}}  .mk-image-slider .swiper-pagination-bullets .swiper-pagination-bullet:hover,
                        {{WRAPPER}}  .mk-image-slider .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color: {{VALUE}};',
                        '{{WRAPPER}} .mk-image-slider .mk-slider-pn' => 'fill: {{VALUE}};border-color: {{VALUE}};',
                        ],
                    ]);

                $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_image_style', 'Large Images', true);

            $this->add_responsive_control('sliderheight',[
                'label'      => esc_html__( 'Slider Height', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'vh' ],
                'default'    => ['unit' => 'vh', 'size' => 50, ],
                'range'      => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'  => [
                    '{{WRAPPER}} .swiper-container' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'large_image_size',
                'label'   => esc_html__( 'Image Size', 'orbius-core' ),
                'default' => 'full',
            ]);

            $this->add_control('content_overlay', [
                'label'     => esc_html__( 'Overlay', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-slider-content-holder:after' => 'background-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'thumb_image_style', 'Thumb Images', true);

            mk_elem_heading_ctrl($this, 'thumbimages_section_style', 'Thumb Images Section' );

            $this->add_responsive_control('thumb_sliderheight',[
                'label'      => esc_html__( 'Height', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'vh' ],
                'default'    => ['unit' => 'px', 'size' => 100, ],
                'range'      => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'  => [
                    '{{WRAPPER}} .mk-image-slider-thumbs' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('thumb_slider_top_margin',[
                'label'      => esc_html__( 'Top Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'vh' ],
                'default'    => ['unit' => 'px', 'size' => 20, ],
                'range'      => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors'  => [
                    '{{WRAPPER}} .mk-image-slider-thumbs' => 'margin-top:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('thumb_img_section_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-image-slider-thumbs' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('thumb_img_section_background', [
                'label'     => esc_html__( 'Background', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-slider-thumbs' => 'background: {{VALUE}};',
                ],
            ]);

            $slides_per_view = range( 1, 10 );
            $slides_per_view = array_combine( $slides_per_view, $slides_per_view );

            $this->add_responsive_control('slides_per_view',[
                'type'               => \Elementor\Controls_Manager::SELECT,
                'label'              => esc_html__( 'Slides Per View', 'orbius-core' ),
                'options'            => $slides_per_view,
                'default'            => '4',
                'tablet_default'     => '2',
                'mobile_default'     => '1',
                'frontend_available' => true,
            ]);

            mk_elem_heading_ctrl($this, 'thumbimages_style', 'Thumb Images', 'before', 'condition' );

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'thumb_image_size',
                'label'   => esc_html__( 'Image Size', 'orbius-core' ),
                'default' => 'full',
            ]);

            $this->add_control('slide_space', [
                'label' => esc_html__( 'Space Between Slides', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 10,
                'step' => 1,
                'min' => 0,
                'max' => 1000,
            ]);

            $this->add_responsive_control('thumb_img_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide .mk-image-thumb-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->start_controls_tabs( 'thumbs_tab_styles' );
                $this->start_controls_tab('thumbs_tab_normal', [ 'label' => esc_html__( 'Normal', 'orbius-core' ) ]);

                    $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                        'name'        => 'thumb_img_border',
                        'label'       => esc_html__( 'Border', 'orbius-core' ),
                        'selector'    => '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide .mk-image-thumb-inner',
                    ]);

                    $this->add_responsive_control('thumb_img_border_radius', [
                        'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', 'em', '%' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide .mk-image-thumb-inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                    $this->add_responsive_control('thumbnails_scale', [
                        'label' => esc_html__( 'Scale', 'orbius-core' ),
                        'type'  => \Elementor\Controls_Manager::SLIDER,
                        'range' => [
                            'px' => ['min' => 1, 'max' => 2, 'step' => 0.01],
                        ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide img' => 'transform: scale({{SIZE}});',
                        ],
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
                        'name'     => 'thumbnails_box_shadow',
                        'selector' => '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide .mk-image-thumb-inner',
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Css_Filter::get_type(), [
                        'name'     => 'thumbnails_css_filters',
                        'selector' => '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide img',
                    ]);

                    $this->add_control('thumb_overlay_col', [
                        'label'     => esc_html__( 'Overlay', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide .mk-image-thumb-inner:after' => 'background: {{VALUE}};',
                        ],
                    ]);

                $this->end_controls_tab();

                $this->start_controls_tab('thumbs_tab_normal_hover', [ 'label' => esc_html__( 'Hover / Actice', 'orbius-core' ) ]);

                    $this->add_control('thumbnails_border_color_hover',[
                        'label'                 => esc_html__( 'Border Color', 'orbius-core' ),
                        'type'                  => \Elementor\Controls_Manager::COLOR,
                        'default'               => '',
                        'selectors'             => [
                            '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide .mk-image-thumb-inner:hover,
                            {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-thumb-active .mk-image-thumb-inner,
                            {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-duplicate.swiper-slide-thumb-active .mk-image-thumb-inner' => 'border-color: {{VALUE}}',
                        ],
                    ]);

                    $this->add_responsive_control('thumbnails_hover_scale', [
                        'label' => esc_html__( 'Scale', 'orbius-core' ),
                        'type'  => \Elementor\Controls_Manager::SLIDER,
                        'range' => [
                            'px' => ['min' => 1, 'max' => 2, 'step' => 0.01],
                        ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide:hover img,
                            {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-thumb-active img' => 'transform: scale({{SIZE}});',
                        ],
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
                        'name'     => 'thumbnails_hover_box_shadow',
                        'selector' => '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide .mk-image-thumb-inner:hover,
                                       {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-thumb-active .mk-image-thumb-inner,
                                       {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-duplicate.swiper-slide-thumb-active .mk-image-thumb-inner',
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Css_Filter::get_type(), [
                        'name'     => 'thumbnails_hover_css_filters',
                        'selector' => '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide:hover img,
                                       {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-thumb-active img,
                                       {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-duplicate.swiper-slide-thumb-active img',
                    ]);

                    $this->add_control('thumb_overlay_hover_col', [
                        'label'     => esc_html__( 'Overlay', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-slider-thumbs .swiper-slide:hover .mk-image-thumb-inner:after,
                            {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-thumb-active .mk-image-thumb-inner:after,
                            {{WRAPPER}} .mk-image-slider-thumbs .swiper-slide-duplicate.swiper-slide-thumb-active .mk-image-thumb-inner:after ' => 'background: {{VALUE}};',
                        ],
                    ]);

                $this->end_controls_tab();
            $this->end_controls_tabs();

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrows Navigation At', 'mobile' );
            mk_elem_hide_ctrl($this, 'dots_responsive_hide', 'Hide Dot Navigation At', 'mobile' );
        $this->end_controls_section();


        mk_elem_start_ctrl($this, 'section_content_style', 'Caption', true);

            $this->add_responsive_control('content_width',[
                    'label'       => esc_html__( 'Minimum Width', 'orbius-core' ),
                    'type'        => \Elementor\Controls_Manager::SLIDER,
                    'size_units'  => [ 'px', 'em' ],
                    'default'     => ['unit' => 'px', 'size' => 250, ],
                    'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                    'selectors'   => [
                        '{{WRAPPER}} .mk-image-slider-content' => 'min-width:{{SIZE}}{{UNIT}};',
                    ],
                ]);

            $this->add_control('content_animation', [
                'label'        => esc_html__( 'Content Animation', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default' => 'none',
                'prefix_class' => 'mk-image-slider-content-',
                'options' => [  'none' => esc_html__( 'None', 'orbius-core' ),
                                'fade' => esc_html__( 'Fade', 'orbius-core' ),
                                'bt'   => esc_html__( 'Bottom to Top', 'orbius-core' ),
                             ]
            ]);

            $this->add_responsive_control('content_origin', [
                'label'   => esc_html__( 'Caption Display Position', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'center',
                'prefix_class' => 'mk-image-slider-cbox-',
                'options' => mk_position(),
            ]);

            $this->add_responsive_control('items_alignment', [
                'label'        => esc_html__( 'Text Align', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::CHOOSE,
                'options'      => mk_arrays('text_align'),
                'default'      => 'center',
                'prefix_class' => 'mk-image-slider-text-',
            ]);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'caption_typography',
                'selector' => '{{WRAPPER}} .mk-image-slider-content',
            ]);

            $this->add_group_control( \Elementor\Group_Control_Border::get_type(), [
                'name'     => 'content_border',
                'label'    => esc_html__( 'Border', 'orbius-core' ),
                'selector' => '{{WRAPPER}} .mk-image-slider-content',
            ]);

            $this->add_responsive_control('content_border_radius', [
                    'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-image-slider-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control('content_padding', [
                    'label' => esc_html__( 'Padding', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-image-slider-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control('content_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-image-slider-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_control('caption_color', [
                'label'     => esc_html__( 'Font Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .mk-image-slider-caption' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('content_background', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-slider-content' => 'background-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $slideHtml = $navigation = $slideThumbs = '';

        $sliderSettings = array(
            'direction'      => $settings['direction'],
            'parallax'       => 'no',
            'effect'         => $settings['effect'],
            'arrows_on'      => $settings['arrows_on'],
            'dots'           => $settings['dots_on'],
            'autoplay'       => $settings['autoplay_on'],
            'autoplay_speed' => $settings['autoplay_speed'],
            'speed'          => $settings['speed'],
            'mousewheel'     => $settings['mousewheel_on'],
            'loop'           => $settings['loop_on'],
            'slides_to_show' => 1,
            'slider_next'    => '.mk-slider-next',
            'slider_prev'    => '.mk-slider-prev',
            'slider_pagination' => '.swiper-pagination',
            'pause_on_hover' => $settings['hover_pause_on']
        );

        $this->add_render_attribute( [
            'slider-attrs' => [
                'class'                => [ 'swiper', 'swiper-container','mk-image-slider','mk-preview-slider' ],
                'data-settings'           => json_encode( $sliderSettings ),
                'data-thumb-items'        => $settings['slides_per_view'],
                'data-thumb-items-tablet' => $settings['slides_per_view_tablet'],
                'data-thumb-items-mobile' => $settings['slides_per_view_mobile'],
                'data-thumb-space'        => $settings['slide_space'],
                'data-thumb-effect'       => 'slide',
                'data-thumb-slider-id'    => '.mk-preview-slider-thumbs-' . $this->get_id(),
                'id'                      => 'swiper-' . $this->get_id()
            ]
        ] );

        $i = 1;

        foreach ( $settings['gallery_images'] as $index => $item ) :

            $slideImageHtml = $imageCaption = '';

            if ( $settings['feature_image_caption'] != '' ) {
                $imageCaption .= $this->render_image_caption( $item['id'], $settings['feature_image_caption'] );
            }

            if (  $settings['large_image_size_size'] == 'custom' ) {
                $slideImageHtml = '<img '.mk_custom_image_size_html($this, $settings, $item, $item['id'], 'large_image_size', 'large_img-'.$i).' />';
            } else {
                $slideImageHtml = wp_get_attachment_image( $item['id'], $settings['large_image_size_size']);
            }

            if (  $settings['thumb_image_size_size'] == 'custom' ) {
                $thumbImageHtml = '<img '.mk_custom_image_size_html($this, $settings, $item, $item['id'], 'thumb_image_size', 'thumb_img-'.$i).' />';
            } else {
                $thumbImageHtml = wp_get_attachment_image( $item['id'], $settings['thumb_image_size_size']);
            }

            $slideHtml   .= '<div class="mk-swiper-item swiper-slide">' . $imageCaption . $slideImageHtml . '</div>';
            $slideThumbs .= '<div class="swiper-slide"><span class="mk-image-thumb-inner">'.$thumbImageHtml.'</span></div>';

            $i++;

        endforeach;

            $arrowNavigation = '';
            $dots            = ('yes' === $settings['dots_on'])  ? '<div class="swiper-pagination swm-hide-'. $settings['dots_responsive_hide'] .'"></div>' : '';

            if ('yes' === $settings['arrows_on']) {

                $arrowNavigation .= '<div class="mk-slider-pn mk-slider-prev swiper-' . $this->get_id() . '-prev swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>
                                    <div class="mk-slider-pn mk-slider-next swiper-' . $this->get_id() . '-next swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . '</div>';
            }



        echo '<div ' . $this->get_render_attribute_string( 'slider-attrs' ) . '>
                <div class="swiper-wrapper">
                    ' . $slideHtml . '
                </div>
                ' . $arrowNavigation . $dots . '
              </div>
              <div class="mk-image-slider-thumbs mk-preview-slider-thumbs mk-preview-slider-thumbs-' . $this->get_id() . ' swiper">
                <div class="swiper-wrapper">' . $slideThumbs . '</div>
              </div>';

    }

    protected function render_image_caption( $id, $caption_type = 'caption' ) {
        $settings = $this->get_settings_for_display();

        $caption = get_image_caption( $id, $caption_type );

        if ( $caption == '' ) {
            return '';
        }

        ob_start();
        ?>
        <div class="mk-image-slider-content-holder">
            <div class="mk-image-slider-content">
                <div class="mk-image-slider-caption">
                    <?php echo $caption; ?>
                </div>
            </div>
        </div>
        <?php
        $html = ob_get_contents();
        ob_end_clean();
        return $html;
    }

}