<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Image extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_image'; }
	public function get_title()      { return esc_html__( 'Image', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-image'; }
	public function get_categories() { return ['mk-general-elements']; }
	public function get_keywords()   { return [ 'theme','image','photo' ]; }
	public function get_style_depends() { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-modernizr','mk-anime','mk-scroll-monitor','mk-block-reveal','mk-widgets' ]; }

	protected function register_controls() {

        mk_elem_start_ctrl($this, 'general_content', 'General');

            $this->add_control('theme_image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $this->add_control('theme_hover_image', [
                'label'     => esc_html__( 'Hover Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $this->add_group_control(\Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'theme_image_size',
                'label'   => esc_html__( 'Image Size', 'orbius-core' ),
                'separator' => 'before',
                'default' => 'full'
            ]);

            $this->add_control('lightbox_on',[
                'label'   => esc_html__( 'Lightbox', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('img_link', [
                'label'       => esc_html__( 'Image Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'orbius-core' ),
                'default'     => [
                    'url' => '',
                    'is_external' => '',
                 ],
                'show_external' => true,
            ]);

        $this->end_controls_section();

        // Image Styles
        mk_elem_start_ctrl($this, 'image_styles', 'Image Styles', true);

            $this->add_responsive_control('image_alignment',[
                'label' => esc_html__( 'Alignment', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => mk_arrays('text_align'),
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .mk-image' => 'text-align: {{VALUE}};',
                ],
            ]);

            $this->add_control('image_overflow', [
                'label'   => esc_html__( 'Overflow', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'hidden',
                'options' => [  'visible' => esc_html__( 'Visible', 'orbius-core' ),
                                'hidden' => esc_html__( 'Hidden', 'orbius-core' ),
                             ],
                'selectors' => [
                    '{{WRAPPER}} .mk-image-wrapper' => 'overflow: {{VALUE}}'
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'image_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-image-wrapper',
            ]);

            $this->add_responsive_control('image_radius',[
                'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-image-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            // NORMAL / HOVER TABS

            $this->start_controls_tabs( 'icons_style' );

                $this->start_controls_tab('tab_icons_normal', [
                    'label' => esc_html__( 'Normal', 'orbius-core' ),
                ]);

                    $this->add_control('image_opacity',[
                          'label'   => esc_html__( 'Opacity (%)', 'orbius-core' ),
                          'type'    => \Elementor\Controls_Manager::SLIDER,
                          'range' => [
                              'px' => ['max'  => 1, 'step' => 0.01, ],
                          ],
                          'condition' => ['appear_animation!' => 'fade'],
                          'selectors' => [
                              '{{WRAPPER}} .mk-image-wrapper figure' => 'opacity: {{SIZE}};',
                          ],
                      ]);

                    $this->add_control('image_scale', [
                        'label' => esc_html__( 'Scale', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px' ],
                        'range' => [
                            'px' => ['min' => 1, 'max' => 5, 'step' => 0.05, ],
                        ],
                        'condition' => ['enable_side_label!' => 'yes'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-wrapper figure' => 'transform: scale({{SIZE}});',
                        ],
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(),[
                        'name'      => 'image_shadow',
                        'label'      => esc_html__( 'Box Shadow', 'orbius-core' ),
                        'selector'  => '{{WRAPPER}} .mk-image-wrapper',
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Css_Filter::get_type(), [
                        'name' => 'image_css_filter',
                        'label' => esc_html__( 'CSS filters', 'orbius-core' ),
                        'selector' => '{{WRAPPER}} .mk-image-wrapper img',
                    ]);


                $this->end_controls_tab();

                $this->start_controls_tab('tab_icons_hover',[
                    'label' => esc_html__( 'Hover', 'orbius-core' ),
                ]);

                    $this->add_control('image_hover_opacity',[
                        'label'   => esc_html__( 'Opacity (%)', 'orbius-core' ),
                        'type'    => \Elementor\Controls_Manager::SLIDER,
                        'range' => [
                            'px' => ['max'  => 1, 'step' => 0.01, ],
                        ],
                        'condition' => ['appear_animation!' => 'fade'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-wrapper:hover figure' => 'opacity: {{SIZE}};',
                        ],
                    ]);

                    $this->add_control('image_hover_scale', [
                        'label' => esc_html__( 'Scale', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::SLIDER,
                        'size_units' => [ 'px' ],
                        'range' => [
                            'px' => ['min' => 1, 'max' => 5, 'step' => 0.05, ],
                        ],
                        'condition' => ['enable_side_label!' => 'yes'],
                        'selectors' => [
                            '{{WRAPPER}} .mk-image-wrapper:hover figure' => 'transform: scale({{SIZE}});',
                        ],
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(),[
                        'name'      => 'image_hover_shadow',
                        'label'      => esc_html__( 'Box Shadow', 'orbius-core' ),
                        'selector'  => '{{WRAPPER}} .mk-image-wrapper:hover',
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Css_Filter::get_type(), [
                        'name' => 'image_hover_css_filter',
                        'label' => esc_html__( 'CSS filters', 'orbius-core' ),
                        'selector' => '{{WRAPPER}} .mk-image-wrapper img:hover',
                    ]);

                $this->end_controls_tab();
            $this->end_controls_tabs();

        $this->end_controls_section();

        // Over Lines
        mk_elem_start_ctrl($this, 'image_lines_styles', 'Over Lines', true);

            $this->add_control('lines_on',[
                'label'   => esc_html__( 'Add lines', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('lines_count',[
                'label' => esc_html__( 'Lines Count', 'orbius-core' ),
                'default' => '3',
                'type' => \Elementor\Controls_Manager::TEXT,
                'condition' => ['lines_on' => 'yes']
            ]);

            $this->add_control('lines_color',[
                'label' => esc_html__( 'Lines color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-line div' => 'background: {{VALUE}}',
                ],
                'condition' => ['lines_on' => 'yes']
            ]);

        $this->end_controls_section();


        // Overlay Bg

        mk_elem_start_ctrl($this, 'image_overlay_bg', 'Overlay Background', true);

            $this->add_control('overlay_bg_on',[
                'label'   => esc_html__( 'Add overlay background', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
                'name' => 'overlay_bg',
                'label' => esc_html__( 'Overlay Color', 'orbius-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .mk-image-overlay-bg',
                'condition' => ['overlay_bg_on' => 'yes']
            ]);

            $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
                'name' => 'overlay_hover_bg',
                'label' => esc_html__( 'Hover Overlay Color', 'orbius-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .mk-image figure:hover .mk-image-overlay-bg',
                'condition' => ['overlay_bg_on' => 'yes']
            ]);

        $this->end_controls_section();

        // Reveal Effect

        mk_elem_start_ctrl($this, 'reveal_effect_style', 'Appear Effect', true);

            $this->add_control('appear_animation', [
                'label'   => esc_html__( 'Image Appear Animation', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                                ''              => 'None',
                                'fade'          => 'Fade',
                                'reveal'        => 'Reveal',
                                'simple-reveal' => 'Simple Reveal'
                            ],
                'prefix_class' => 'mk-custom-image-appear-'
            ]);

            $this->add_control('reveal_color',[
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => "#ffffff",
                'condition' => ['appear_animation' => 'reveal']
            ]);

            $this->add_control('reveal_direction',[
                'label' => esc_html__( 'Direction', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'lr',
                'options' => [
                    'lr' => esc_html__( 'Left to Right', 'orbius-core' ),
                    'rl' => esc_html__( 'Right to Left', 'orbius-core' ),
                    'tb' => esc_html__( 'Top to Bottom', 'orbius-core' ),
                    'bt' => esc_html__( 'Bottom to Top', 'orbius-core' ),
                ],
                'condition' => ['appear_animation' => 'reveal']
            ]);

            $this->add_control('reveal_duration',[
                'label'      => esc_html__( 'Duration (mili seconds)', 'renix-core' ),
                'description' => esc_html__( 'Total Time taken for animation to take place','renix-core'),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'min'        => 0,
                'max'        => 10000,
                'step'       => 400,
                'condition'  => ['appear_animation' => 'reveal'],
            ]);

            $this->add_control('reveal_delay',[
                'label'      => esc_html__( 'Delay (mili seconds)', 'renix-core' ),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'min'        => 0,
                'max'        => 10000,
                'step'       => 100,
                'condition'  => ['appear_animation' => 'reveal'],
            ]);

            $this->add_control('reveal_viewport',[
                'label'      => esc_html__( 'Animation start view port', 'renix-core' ),
                'description' => esc_html__( 'Set bottom view port scroll size to start animation.','renix-core'),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'min'        => 1,
                'max'        => 1000,
                'step'       => 1,
                'default'    => 300,
                'condition'  => ['appear_animation' => 'reveal'],
            ]);

        $this->end_controls_section();

        // Floating Effect
        mk_elem_start_ctrl($this, 'float_effect', 'Floating Effect', true);

            $this->add_control('enable_float_effect',[
                'label'   => esc_html__( 'Floating effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('float_easing',[
                'label' => esc_html__( 'Float easing', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'ease',
                'options' => [
                    'ease'        => esc_html__( 'Ease', 'orbius-core' ),
                    'ease-in'     => esc_html__( 'Ease In', 'orbius-core' ),
                    'ease-out'    => esc_html__( 'Ease Out', 'orbius-core' ),
                    'ease-in-out' => esc_html__( 'Ease In Out', 'orbius-core' ),
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-image[data-float]' => '--float-animation-ease: {{VALUE}}'
                ],
                'condition' => ['enable_float_effect' => 'yes']
            ]);

            $this->add_control('float_animate_from',[
                'label'      => esc_html__( 'Float animate from (%)', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'min'        => 0,
                'max'        => 100,
                'step'       => 1,
                'default'    => 0,
                'size_units' => [ '%' ],
                'condition'  => ['enable_float_effect' => 'yes'],
                'selectors'  => [
                  '{{WRAPPER}} .mk-image[data-float]' => '--float-animate-from: {{VALUE}}%'
                ],
            ]);

            $this->add_control('float_animate_to',[
                'label'      => esc_html__( 'Float animate to (%)', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'min'        => 0,
                'max'        => 100,
                'step'       => 1,
                'default'    => 5,
                'size_units' => [ '%' ],
                'condition'  => ['enable_float_effect' => 'yes'],
                'selectors'  => [
                  '{{WRAPPER}} .mk-image[data-float]' => '--float-animate-to: {{VALUE}}%'
                ],
            ]);

            $this->add_control('float_delay',[
                'label'        => esc_html__( 'Float starting delay (seconds)', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::NUMBER,
                'min'          => 0,
                'max'          => 120,
                'step'         => 0.1,
                'default'      => 0,
                'size_units'   => [ '%' ],
                'condition'    => ['enable_float_effect' => 'yes'],
                'selectors'    => [
                  '{{WRAPPER}} .mk-image[data-float]' => '--float-delay: {{VALUE}}s'
                ],
            ]);

        $this->end_controls_section();

        // Parallax Effects
        mk_elem_start_ctrl($this, 'parallax_effect_style', 'Parallax Effect', true);

            $this->add_control('parallax_on',[
                'label'   => esc_html__( 'Parallax Scroll Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

        $this->end_controls_section();

        // Cursor
        mk_elem_start_ctrl($this, 'cursor_icon_style', 'Cursor Image', true);

            $this->add_control('cursor_image_on', [
                'label'        => esc_html__( 'Cursor Image', 'orbius-core' ),
                'description'  => esc_html__( 'Replace the default hover "hand" icon with a custom image. This option will work if the "Lightbox" option is enabled or an image has a link.', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'default'      => 'no',
                'return_value' => 'yes',
            ]);

            $this->add_control('cursor_image',[
                'label' => esc_html__( 'Image', 'renix-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => ['cursor_image_on' => 'yes']
            ]);

        $this->end_controls_section();

        // Label
        mk_elem_start_ctrl($this, 'image_label', 'Label', true);

            $this->add_control('enable_side_label',[
                'label'   => esc_html__( 'Add label', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('label', [
                'label' => esc_html__( 'Label', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'enable_side_label' => 'yes'
                ]
            ]);

            $this->add_control('label_side',[
                'label' => esc_html__( 'Content alignment', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'mk-image-label-fixed-left' => [
                        'title' => esc_html__( 'Left', 'orbius-core' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'mk-image-label-bottom' => [
                        'title' => esc_html__( 'Bottom', 'orbius-core' ),
                        'icon' => 'eicon-v-align-bottom',
                    ],
                    'mk-image-label-fixed-right' => [
                        'title' => esc_html__( 'Right', 'orbius-core' ),
                        'icon' => 'eicon-h-align-right',
                    ],

                ],
                'default' => 'mk-image-label-fixed-left',
                'toggle' => false,
                'condition' => [
                    'enable_side_label' => 'yes'
                ]
            ]);

            $this->add_control('label_pos', [
                'label' => esc_html__( 'Content position', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => mk_arrays('vertical_alignment'),
                'default' => 'center',
                'toggle' => false,
                'condition' => [
                    'enable_side_label' => 'yes',
                    'label_side!' => 'mk-image-label-bottom',
                ]
            ]);

            $this->add_responsive_control('label_bottom_pos',[
                'label' => esc_html__( 'Content Position', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => mk_arrays('text_align'),
                'default' => 'center',
                'condition' => [
                    'enable_side_label' => 'yes',
                    'label_side'        => 'mk-image-label-bottom',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-image-label' => 'text-align: {{VALUE}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'label_typography',
                'label' => esc_html__( 'Typography', 'orbius-core' ),
                'selector' => '{{WRAPPER}} .mk-image-label',
                'condition' => ['enable_side_label' => 'yes']
            ]);

            $this->add_control('label_color',[
                'label' => esc_html__( 'Label color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-label' => 'color: {{VALUE}}',
                ],
                'condition' => ['enable_side_label' => 'yes']
            ]);

            $this->add_control('label_overlay_bgcolor', [
                'label' => esc_html__( 'Overlay background color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-image-label' => 'background: {{VALUE}}',
                ],
                'condition' => [
                    'enable_side_label' => 'yes',
                    'label_side' => 'mk-image-label-bottom'
                ]
            ]);

            $this->add_responsive_control('label_padding', [
                    'label' => esc_html__( 'Padding', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'default'    => [
                        'top'    => 10,
                        'bottom' => 10,
                        'left'   => 10,
                        'right'  => 10,
                        'unit'   => 'px',
                    ],
                    'condition' => [
                        'enable_side_label' => 'yes',
                        'label_side'        => 'mk-image-label-bottom',
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-image-label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control('label_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'condition' => [
                        'enable_side_label' => 'yes',
                        'label_side'        => 'mk-image-label-bottom',
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-image-label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name' => 'label_border',
                'condition' => [
                    'enable_side_label' => 'yes',
                    'label_side'        => 'mk-image-label-bottom',
                ],
                'selector' => '{{WRAPPER}} .mk-image-label',
            ]);

        $this->end_controls_section();

    }

    protected function get_lines($lines_count) {
        $settings = $this->get_settings_for_display();

        $html = '<div class="mk-image-lines">
                    <div class="mk-image-lines-wrap"><div></div></div>';
        for( $i = 1; $i <= $lines_count; $i++ ) {
            $html .= '<div class="mk-image-line"><div></div></div>';
        }
        $html .= '</div>';

        echo $html;
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        if (  $settings['theme_image_size_size'] == 'custom' ) {
            $imageTagHtml      = '<img '.mk_custom_image_size_html($this, $settings, $settings['theme_image'], $settings['theme_image']['id'], 'theme_image_size', 'theme_img').' />';
            $imageHoverTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $settings['theme_hover_image'], $settings['theme_hover_image']['id'], 'theme_image_size', 'theme_hover_img','mk-image-hover').' />';
        } else {
            $imageTagHtml      = wp_get_attachment_image( $settings['theme_image']['id'], $settings['theme_image_size_size']);
            $imageHoverTagHtml = wp_get_attachment_image( $settings['theme_hover_image']['id'], $settings['theme_image_size_size'], false, array('class' => 'mk-image-hover'));
        }

        $cursorIconData = '';

        if( !empty($settings['cursor_image']['id']) && 'yes' == $settings['cursor_image_on'] ) {
            $cursorIconURL = wp_get_attachment_image_src($settings['cursor_image']['id'], 'full');

            if ( '' != $cursorIconURL[0] ) {
                $cursorIconData = ' data-cursor-icon="'.esc_url($cursorIconURL[0]).'"';
            }
        }

        // mk-image attributes
        $this->add_render_attribute( 'mk_image_attrs', 'class', 'mk-image' );
        if ( 'yes' === $settings['parallax_on'] ) {
            $this->add_render_attribute( 'mk_image_attrs', 'class', 'mk-parallax-scroll-item-on' );
        }
        if ( 'simple-reveal' === $settings['appear_animation'] ) {
            $this->add_render_attribute( 'mk_image_attrs', 'class', 'mk-scroll--load' );
        }
        if ( 'yes' == $settings['enable_float_effect'] ) {
            $this->add_render_attribute( 'mk_image_attrs', 'data-float', $settings['float_easing'] );
        }

        //mk-img-wrapper attributes
        $align_items = ( !empty($settings['label_pos']) ) ? 'align-items-' . $settings['label_pos'] : 'align-items-center';
        $this->add_render_attribute( 'mk_image_wrapper_attrs', 'class', ['mk-image-wrapper','swm-anim', $align_items] );

        if ( 'yes' === $settings['parallax_on'] ) {
            $this->add_render_attribute( 'mk_image_wrapper_attrs', 'class', 'mk-parallax-item' );
        }

        // <figure> attributes
        $this->add_render_attribute( 'figure_attrs', 'class', 'swm-anim' );

        if ( 'fade' === $settings['appear_animation'] ) {
            $this->add_render_attribute( 'figure_attrs', 'class', 'mk-scroll--load' );
        }

        if ( 'reveal' == $settings['appear_animation'] ) {
            $reveal_color      = ( '' != $settings['reveal_color'] )     ? ( $settings['reveal_color'] )     : '#ffffff';
            $reveal_direction  = ( '' != $settings['reveal_direction'] ) ? ( $settings['reveal_direction'] ) : 'lr';
            $reveal_duration   = ( '' != $settings['reveal_duration'] )  ? (  $settings['reveal_duration'] ) : '400';
            $reveal_delay      = ( '' != $settings['reveal_delay'] )     ? (  $settings['reveal_delay'] )    : '0';
            $reveal_viewport   = ( '' != $settings['reveal_viewport'] )  ? (  $settings['reveal_viewport'] )    : '300';

            $this->add_render_attribute( 'figure_attrs', 'data-reveal-color', $reveal_color );
            $this->add_render_attribute( 'figure_attrs', 'data-reveal-direction', $reveal_direction );
            $this->add_render_attribute( 'figure_attrs', 'data-reveal-duration', $reveal_duration );
            $this->add_render_attribute( 'figure_attrs', 'data-reveal-delay', $reveal_delay );
            $this->add_render_attribute( 'figure_attrs', 'data-reveal-viewport', $reveal_viewport );
        }

        // label
        $label = $settings['label'];
        $labelHtml = '';
        if( !empty( $label ) ) {
            $labelHtml .= '<div class="mk-image-label '.$settings['label_side'] .'">
                                <div class="mk-image-label-inner">
                                    <p>'.wp_kses_post( $label ).'</p>
                                </div>
                            </div>';
        }
        ?>

        <div <?php echo $this->get_render_attribute_string( 'mk_image_attrs' ); ?>>
            <div <?php echo $this->get_render_attribute_string( 'mk_image_wrapper_attrs' ); ?>>

                    <?php if ( 'mk-image-label-bottom' !== $settings['label_side'] ) { echo $labelHtml; } ?>

                    <figure <?php echo $this->get_render_attribute_string( 'figure_attrs' ); ?>>

                    <?php
                        $img_link = $settings['img_link']['url'];

                        if ( 'yes' == $settings['lightbox_on'] ) {
                            echo '<a class="mk-image-lightbox" href="' . \Elementor\Group_Control_Image_Size::get_attachment_image_src( $settings['theme_image']['id'], 'theme_image_size', $settings ) . '" data-elementor-open-lightbox="yes"'.$cursorIconData.'></a>';
                        } elseif (!empty($img_link)) {

                            $link_key = 'img_link';

                            $this->add_render_attribute( $link_key, 'href', $settings['img_link']['url'] );

                            if ( $settings['img_link']['is_external'] ) {
                                $this->add_render_attribute( $link_key, 'target', '_blank' );
                            }

                            if ( $settings['img_link']['nofollow'] ) {
                                $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                            }

                            $this->add_render_attribute( $link_key, 'class', 'mk-image-link' );

                            $img_link = '<a ' . $this->get_render_attribute_string( $link_key ) . ' '.$cursorIconData.'></a>';

                            echo $img_link;
                        }


                        if (!empty($imageTagHtml)) { echo $imageTagHtml; }
                        if (!empty($imageHoverTagHtml)) { echo $imageHoverTagHtml; }

                        if( 'yes' == $settings['overlay_bg_on'] ) { echo '<span class="mk-image-overlay-bg swm-anim"></span>'; }
                        if ( 'mk-image-label-bottom' === $settings['label_side'] ) { echo $labelHtml; }
                        if( 'yes' == $settings['lines_on'] ) { $this->get_lines($settings['lines_count']); }
                        ?>

                    </figure>

            </div>

        </div> <!-- end -.mk-image -->

        <?php
    }

}