<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Interactive_Links extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_interactive_links'; }
    public function get_title()          { return esc_html__( 'Interactive LInks', 'estra-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-call-to-action'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'mk', 'theme', 'showcase', 'gallery', 'showcase wall','interactive','links','projects','portfolio' ]; }
    public function get_style_depends()   { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'general_settings', 'General');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control( 'display_style', [
                'label' => esc_html__( 'Display Style', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'ltr' => esc_html__( 'Left to Right', 'orbius-core' ),
                    'rtl' => esc_html__( 'Right to Left', 'orbius-core' ),
                ],
                'default' => 'rtl'
            ]);

            $repeater->add_control('title', [
                'label'       => esc_html__( 'Title', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('nexatron','estra-core')
            ]);

            $repeater->add_control('category', [
                'label' => esc_html__( 'Category', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter Summery Text', 'orbius-core' ),
                'default' => 'web design',
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'placeholder' => esc_html__( 'http://your-link.com', 'estra-core' ),
            ]);

            $repeater->add_control('project_image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $this->add_control('list_items', [
                'label' => esc_html__( 'List Items', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_items_style', 'Items', true);

            $this->add_responsive_control('items_spacing',[
                'label'       => esc_html__( 'Spacing', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', '%' ],
                'range'       => ['px' => ['min' => 0, 'max' => 300, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-interactive-links-item' => 'margin:{{SIZE}}{{UNIT}} 0;',
                ],
            ]);

            $this->add_control('items_border_color', [
                'label'     => esc_html__( 'Border Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-int-links-border:before,{{WRAPPER}} .mk-int-links-border:after' => 'background: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_titles_style', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'label'    => esc_html__( 'Typography', 'estra-core' ),
                'selector' => '{{WRAPPER}} .mk-services-reel .mk-services-reel-count,
                    {{WRAPPER}} .mk-interactive-links-title',
            ]);

            $this->add_responsive_control('title_margin', [
                'label' => esc_html__( 'Margin', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-links-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'estra-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-interactive-links-title' => 'margin:0;',
                ],
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-links-item .mk-interactive-links-title,
                    {{WRAPPER}} .mk-interactive-links-item .mk-interactive-links-title a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('hover_title_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-links-item:hover .mk-interactive-links-title,
                    {{WRAPPER}} .mk-interactive-links-item:hover .mk-interactive-links-title a' => 'color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'category_style', 'Category', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'category_typography',
                'label'    => esc_html__( 'Typography', 'estra-core' ),
                'selector' => '{{WRAPPER}} .mk-services-reel .mk-services-reel-count,
                    {{WRAPPER}} .mk-interactive-links-category',
            ]);

            $this->add_responsive_control('category_margin', [
                'label' => esc_html__( 'Margin', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-links-category' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

            $this->add_control('category_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-links-item .mk-interactive-links-category,
                    {{WRAPPER}} .mk-interactive-links-item .mk-interactive-links-category a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('category_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-links-item:hover .mk-interactive-links-category,
                    {{WRAPPER}} .mk-interactive-links-item:hover .mk-interactive-links-category a' => 'color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_image_style', 'Image', true);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'image',
                'label'   => esc_html__( 'Image Size', 'estra-core' ),
                'default' => 'mk_image_size_square',
            ]);

            $this->add_responsive_control('reel_image_width',[
                'label'       => esc_html__( 'Width', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', '%' ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-interactive-links-image' => 'width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('img_border_radius', [
                'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-links-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'items_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'category_responsive_hide', 'Hide Category At', 'none' );
            mk_elem_hide_ctrl($this, 'image_responsive_hide', 'Hide Image At', 'none' );
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none' );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $i = 1;
        $all_content = '';

        foreach ( $settings['list_items'] as $index => $item ) :

            $imageTagHtml = $linkHTML = $imgUrl = $title = $link_start = $link_end = '';

            // Image
            if (  $settings['image_size'] == 'custom' ) {
                $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['project_image']['id'], 'image', $settings );
                $img_alt = get_post_meta( $item['project_image']['id'], '_wp_attachment_image_alt', true);

                if ('' != $imgUrl) {
                    $imageTagHtml .= '<img src="' . $imgUrl . '" alt="' . $img_alt . '" loading="lazy" />';
                }

            } else {
                $imageTagHtml .= wp_get_attachment_image( $item['project_image']['id'], $settings['image_size']);
            }

            // Link
            if ( ! empty( $item['link']['url'] ) ) {

                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'class', 'mk-interactive-links-link' );

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';

            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            $titleHTML = ( '' !== $item['title'] ) ? '<' . $titleTagSelector . ' class="mk-interactive-links-title swm-hide-'. $settings['title_responsive_hide'] .'"><span class="mk-int-links-border mk-int-links-border-right"></span>' . $link_start . $item['title'] . $link_end . '<span class="mk-int-links-border mk-int-links-border-left"></span></' . $titleTagSelector . '>' : '';
            $categoryHTML = ( '' !== $item['category'] ) ? '<div class="mk-interactive-links-category swm-hide-'. $settings['category_responsive_hide'] .'">' . $link_start . $item['category'] . $link_end . '</div>' : '';
            $imageHtml = '<div class="mk-interactive-links-image swm-hide-'. $settings['image_responsive_hide'] .'">' . $link_start . $imageTagHtml . $link_end . '</div>';

            $all_content .= '<div class="mk-interactive-links-item-holder"><div class="mk-interactive-links-item mk-int-links-'. $item['display_style'] .'">' .$categoryHTML . $imageHtml . $titleHTML . '</div></div>';

            $i++;
        endforeach;

        echo '<div class="mk-interactive-links">' . $all_content . '</div>';

    }

}