<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
class Mk_Interactive_Portfolio extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_interactive_portfolio'; }
	public function get_title()          { return esc_html__( 'Interactive Portfolio', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-gallery-grid'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'theme','image','animation','scroll','portfolio','interactive','work','photos','project','slider','circle']; }
	public function get_style_depends()  { return [ 'swiper-circles','mk-core-main']; }
    public function get_script_depends() { return [ 'swiper-circles', 'mk-splittext', 'mk-gsap', 'mk-scroll-trigger', 'mk-widgets' ]; }

	protected function register_controls() {

		mk_elem_start_ctrl($this, 'pf_item_content', 'Portfolio Items');

            $this->add_control('edit_info_elementor', [
                'type' => \Elementor\Controls_Manager::ALERT,
                'alert_type' => 'info',
                'content' => esc_html__( 'For live content viewing and precise image positioning, drag items to the first row.', 'orbius-core' ),
            ]);

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title', [
                'label' => esc_html__( 'Project Title', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
                'default' => 'Title One',
            ]);

            $repeater->add_control('category', [
                'label' => esc_html__( 'Category', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'web design', 'orbius-core' ),
                'default' => 'web design',
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'dynamic'     => ['active'  => true, ],
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $repeater->start_controls_tabs( 'tabs_icon_style' );

                $repeater->start_controls_tab('tab_img_one', [
                    'label' => esc_html__( 'Image 1', 'orbius-core' ),
                ]);

                    $repeater->add_control('media_image_one', [
                        'label'      => esc_html__( 'Image One', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::MEDIA,
                    ]);

                    $repeater->add_control('origin_img_one', [
                        'label'   => esc_html__( 'Image Position', 'orbius-core' ),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'default' => 'center-right',
                        'options' => mk_position(),
                    ]);
                    $repeater->add_responsive_control('margin_img_one', [
                        'label' => esc_html__( 'Image Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', 'em', '%' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-interactive-portfolio {{CURRENT_ITEM}}.mk-int-pf-image.mk-interactive-portfolio-image-one' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                $repeater->end_controls_tab();

                $repeater->start_controls_tab('tab_img_two', [
                    'label' => esc_html__( 'Image 2', 'orbius-core' ),
                ]);

                    $repeater->add_control('media_image_two', [
                        'label'      => esc_html__( 'Image Two', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::MEDIA,
                    ]);

                    $repeater->add_control('origin_img_two', [
                        'label'   => esc_html__( 'Image Position', 'orbius-core' ),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'default' => 'center-left',
                        'options' => mk_position(),
                    ]);
                    $repeater->add_responsive_control('margin_img_two', [
                        'label' => esc_html__( 'Image Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', 'em', '%' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-interactive-portfolio {{CURRENT_ITEM}}.mk-int-pf-image.mk-interactive-portfolio-image-two' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                $repeater->end_controls_tab();

                $repeater->start_controls_tab('tab_img_three', [
                    'label' => esc_html__( 'Image 3', 'orbius-core' ),
                ]);

                    $repeater->add_control('media_image_three', [
                        'label'      => esc_html__( 'Image Three', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::MEDIA,
                    ]);

                    $repeater->add_control('origin_img_three', [
                        'label'   => esc_html__( 'Image Position', 'orbius-core' ),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'default' => 'center-left',
                        'options' => mk_position(),
                    ]);
                    $repeater->add_responsive_control('margin_img_three', [
                        'label' => esc_html__( 'Image Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', 'em', '%' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-interactive-portfolio {{CURRENT_ITEM}}.mk-int-pf-image.mk-interactive-portfolio-image-three' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                $repeater->end_controls_tab();

                $repeater->start_controls_tab('tab_img_four', [
                    'label' => esc_html__( 'Image 4', 'orbius-core' ),
                ]);

                    $repeater->add_control('media_image_four', [
                        'label'      => esc_html__( 'Image Four', 'orbius-core' ),
                        'type'       => \Elementor\Controls_Manager::MEDIA,
                    ]);

                    $repeater->add_control('origin_img_four', [
                        'label'   => esc_html__( 'Image Position', 'orbius-core' ),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'default' => 'center-right',
                        'options' => mk_position(),
                    ]);
                    $repeater->add_responsive_control('margin_img_four', [
                        'label' => esc_html__( 'Image Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', 'em', '%' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-interactive-portfolio {{CURRENT_ITEM}}.mk-int-pf-image.mk-interactive-portfolio-image-four' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

                $repeater->end_controls_tab();

            $repeater->end_controls_tabs();


            $this->add_control('all_projects', [
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]);

		$this->end_controls_section();

        mk_elem_start_ctrl($this, 'image_styling', 'Image', true);

        $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
            'name'    => 'media_image_size',
            'label'   => esc_html__( 'Image Size', 'orbius-core' ),
            'default' => 'full',
        ]);

        $this->add_responsive_control('img_width_one', [
                        'label'     => esc_html__( 'Image One Width', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::SLIDER,
                        'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                        'size_units'  => [ '%', 'px','vw','em' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-interactive-portfolio .mk-interactive-portfolio-image-one' => 'width:{{SIZE}}{{UNIT}};',
                        ],
                    ]);
        $this->add_responsive_control('img_width_two', [
                        'label'     => esc_html__( 'Image Two Width', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::SLIDER,
                        'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                        'size_units'  => [ '%', 'px','vw','em' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-interactive-portfolio .mk-interactive-portfolio-image-two' => 'width:{{SIZE}}{{UNIT}};',
                        ],
                    ]);
        $this->add_responsive_control('img_width_three', [
                        'label'     => esc_html__( 'Image Three Width', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::SLIDER,
                        'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                        'size_units'  => [ '%', 'px','vw','em' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-interactive-portfolio .mk-interactive-portfolio-image-three' => 'width:{{SIZE}}{{UNIT}};',
                        ],
                    ]);
        $this->add_responsive_control('img_width_four', [
                        'label'     => esc_html__( 'Image Four Width', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::SLIDER,
                        'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                        'size_units'  => [ '%', 'px','vw','em' ],
                        'selectors' => [
                            '{{WRAPPER}} .mk-interactive-portfolio .mk-interactive-portfolio-image-four' => 'width:{{SIZE}}{{UNIT}};',
                        ],
                    ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styling', 'Title', true);


            $this->add_responsive_control('word_space', [
                'label'     => esc_html__( 'Space Between Two Words', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-portfolio .mk-in-pf-word:not(:first-child)' => 'margin-left:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-interactive-portfolio .mk-interactive-portfolio-content .mk-interactive-portfolio-title-holder',
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-portfolio .mk-interactive-portfolio-content .mk-interactive-portfolio-title-holder' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_tag', [
                'label' => esc_html__( 'Select Tag', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ],
                'default' => 'h4',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'category_styling', 'Category', true);

            $this->add_control('category_on',[
                'label' => esc_html__( 'Category', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'category_typography',
                'selector' => '{{WRAPPER}} .mk-interactive-portfolio-category',
            ]);

            $this->add_control('category_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-portfolio-category' => 'color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'counter_styling', 'Counter', true);

            $this->add_control('counter_on',[
                'label' => esc_html__( 'Counter', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'counter_typography',
                'selector' => '{{WRAPPER}} .mk-interactive-portfolio-counter',
            ]);

            $this->add_control('counter_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-portfolio-counter' => 'color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'items_styling', 'Items', true);

            $this->add_control('invert_filter_on',[
                'label' => esc_html__( 'Invert Filter', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'prefix_class' => 'mk-in-pf-filter-',
                'description' => esc_html__( 'If images overlap with title text, apply the invert filter property; otherwise, keep it turned off.', 'orbius-core' ),
            ]);

            $this->add_control('items_bg_color', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['invert_filter_on!' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-portfolio' => 'background: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'category_responsive_hide', 'Hide Category At', 'tablet');
            mk_elem_hide_ctrl($this, 'counter_responsive_hide', 'Hide Counter At', 'tablet');
        $this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings_for_display();
        $all_images = $all_content = '';
        $i = 0;

        foreach ( $settings['all_projects'] as $index => $item ) :

            $counter = $category = $link = $imgOneHtml = $imgTwoHtml = $imgThreeHtml = $imgFourHtml = $link_start = $link_end = '';

            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );
                ;

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';

                $this->add_render_attribute( $link_key, 'class', 'mk-interactive-portfolio-link' );

                $link .= '<a ' . $this->get_render_attribute_string( $link_key ) . '></a>';

            }

           if (  $settings['media_image_size_size'] == 'custom' ) {
               $media_image_one   = '<img '.mk_custom_image_size_html($this, $settings, $item['media_image_one'], $item['media_image_one']['id'], 'media_image_size', 'int_pf_img_' . $i).' />';
               $media_image_two   = '<img '.mk_custom_image_size_html($this, $settings, $item['media_image_two'], $item['media_image_two']['id'], 'media_image_size', 'int_pf_img_' . $i).' />';
               $media_image_three = '<img '.mk_custom_image_size_html($this, $settings, $item['media_image_three'], $item['media_image_three']['id'], 'media_image_size', 'int_pf_img_' . $i).' />';
               $media_image_four  = '<img '.mk_custom_image_size_html($this, $settings, $item['media_image_four'], $item['media_image_four']['id'], 'media_image_size', 'int_pf_img_' . $i).' />';
           } else {
               $media_image_one   = wp_get_attachment_image( $item['media_image_one']['id'], $settings['media_image_size_size']);
               $media_image_two   = wp_get_attachment_image( $item['media_image_two']['id'], $settings['media_image_size_size']);
               $media_image_three = wp_get_attachment_image( $item['media_image_three']['id'], $settings['media_image_size_size']);
               $media_image_four  = wp_get_attachment_image( $item['media_image_four']['id'], $settings['media_image_size_size']);
           }

           $imgOneUrl   = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['media_image_one']['id'], 'media_image_size', $settings );
           $imgTwoUrl   = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['media_image_two']['id'], 'media_image_size', $settings );
           $imgThreeUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['media_image_three']['id'], 'media_image_size', $settings );
           $imgFourUrl  = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['media_image_four']['id'], 'media_image_size', $settings );

           if ( '' !== $imgOneUrl ) {
               $imgOneHtml .= '<div class="mk-int-pf-image mk-interactive-portfolio-image-one elementor-repeater-item-' . $item['_id'] .' mk-position-' . $item['origin_img_one'] . '" data-image-index="'.$i.'">' . $link_start . '<span>'.$media_image_one.'</span>' . $link_end . '</div>';
           }

           if ( '' !== $imgTwoUrl ) {
               $imgTwoHtml .= '<div class="mk-int-pf-image mk-interactive-portfolio-image-two elementor-repeater-item-' . $item['_id'] .' mk-position-' . $item['origin_img_two'] . '" data-image-index="'.$i.'">' . $link_start . '<span>'.$media_image_two.'</span>' . $link_end . '</div>';
           }

           if ( '' !== $imgThreeUrl ) {
               $imgThreeHtml .= '<div class="mk-int-pf-image mk-interactive-portfolio-image-three elementor-repeater-item-' . $item['_id'] .' mk-position-' . $item['origin_img_three'] . '" data-image-index="'.$i.'">' . $link_start . '<span>'.$media_image_three.'</span>' . $link_end . '</div>';
           }

           if ( '' !== $imgFourUrl ) {
               $imgFourHtml .= '<div class="mk-int-pf-image mk-interactive-portfolio-image-four elementor-repeater-item-' . $item['_id'] .' mk-position-' . $item['origin_img_four'] . '" data-image-index="'.$i.'">' . $link_start . '<span>'.$media_image_four.'</span>' . $link_end . '</div>';
           }

           $counter_number = intval($i) + 1;

           if ( $i < 10 ) {
                $counter_number = '00' . $counter_number;
           }

           if ( $i > 10 && $i < 99 ) {
                $counter_number = '0' . $counter_number;
           }

            if ( '' !== $item['category'] && $settings['category_on'] ) { $category .= '<div class="mk-interactive-portfolio-category swm-hide-'. $settings['category_responsive_hide'] .'">'.$item['category'].'</div>'; }
            if ( 'yes' === $settings['counter_on'] ) { $counter .= '<div class="mk-interactive-portfolio-counter swm-hide-'. $settings['counter_responsive_hide'] .'">'.$counter_number.'</div>'; }


            if ( '' !== $item['title'] ) {

                $all_images .= $imgOneHtml . $imgTwoHtml . $imgThreeHtml . $imgFourHtml;

                $split_text = explode( ' ', $item['title'] );$title = implode( ' ', $split_text );

                foreach ( $split_text as $key => $value ) {
                    $split_text[ $key ] = '<span class="mk-in-pf-word">' . $value . '</span>';
                }

                $title = implode( ' ', $split_text );

                $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

                $all_content .= '<article class="swiper-slide mk-interactive-portfolio-item">
                                    ' . $category . $counter . $link . '
                                  <div class="mk-interactive-portfolio-inner">
                                    <div class="mk-interactive-portfolio-content">
                                      <div class="mk-interactive-portfolio-title"><' . $titleTagSelector . ' class="mk-interactive-portfolio-title-holder"><span class="mk-interactive-portfolio-split-text">' . $title . '</span></' . $titleTagSelector . '></div>
                                    </div>
                                  </div>

                                </article>';
            }

            $i++;

        endforeach;

        $this->add_render_attribute( [ 'slider-attrs'  => [
                'class' => [ 'swiper', 'swiper-container','mk-interactive-portfolio' ],
                'id'    => 'swiper-' . $this->get_id()
            ]
        ]);


        echo '<div ' . $this->get_render_attribute_string( 'slider-attrs' ) . '">
                  <div class="mk-interactive-portfolio-images">' . $all_images . '</div>
                  <div class="swiper-wrapper">'.$all_content.'</div>
                </div>';

	}

}