<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Interactive_Services extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_interactive_services'; }
    public function get_title()          { return esc_html__( 'Interactive Services', 'estra-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-call-to-action'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'mk', 'theme', 'showcase','interactive','services','tab','hover','list','solution' ]; }
    public function get_style_depends()   { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'general_settings', 'General');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title', [
                'label'       => esc_html__( 'Title', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('Title','estra-core')
            ]);

            $repeater->add_control('desc', [
                'label'       => esc_html__( 'Description', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'placeholder' => esc_html__( 'http://your-link.com', 'estra-core' ),
            ]);

            $repeater->add_control('set_active_item',[
                'label'   => esc_html__( 'Set Active Item', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $repeater->add_control('list_image', [
                'label'       => esc_html__( 'Large Image', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::MEDIA,
                'default'     => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                 ],
            ]);

            $this->add_control('list_items', [
                'label' => esc_html__( 'List Items', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['title' => "digital printing",  'desc' => "fusce accumsan tincidunt erat et convallis risus ullamcorper", 'set_active_item' => 'yes'],
                    ['title' => "brand identity",  'desc' => "fusce accumsan tincidunt erat et convallis risus ullamcorper", 'set_active_item' => 'no'],
                    ['title' => "logo design", 'desc' => "fusce accumsan tincidunt erat et convallis risus ullamcorper",  'set_active_item' => 'no'],
                    ['title' => "product design", 'desc' => "fusce accumsan tincidunt erat et convallis risus ullamcorper",  'set_active_item' => 'no'],
                    ['title' => "social media", 'desc' => "fusce accumsan tincidunt erat et convallis risus ullamcorper",  'set_active_item' => 'no'],
                ],
                'title_field' => '{{{ title }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_items_style', 'Items', true);

            $this->add_control('heading_container_style', [
                'label'      => esc_html__( 'Container', 'estra-core' ),
                'type'       => \Elementor\Controls_Manager::HEADING,
            ]);

            $this->add_control('fullscreen_height_on',[
                'label'   => esc_html__( 'Fullscreen Height', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_responsive_control('sliderheight',[
                'label'       => esc_html__( 'Showcase Container Height', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px' ],
                'range'       => ['px' => ['min' => 0, 'max' => 2000, ] ],
                'default'     => ['unit' => 'px', 'size' => 700, ],
                'condition'   => ['fullscreen_height_on!' => 'yes'],
                'selectors'   => [
                    '{{WRAPPER}} .mk-itsr-images' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('heading_items_style', [
                'label'      => esc_html__( 'Items', 'estra-core' ),
                'type'       => \Elementor\Controls_Manager::HEADING,
                'separator'  => 'before',
            ]);

            $this->add_responsive_control('item_padding', [
                'label' => esc_html__( 'List Item Padding', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

            $this->add_control('items_border_color', [
                'label'     => esc_html__( 'Border Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-itsr-item,
                    {{WRAPPER}} .mk-interactive-services' => 'border-color: {{VALUE}};',
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-item.active-item:after' => 'background-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_titles_style', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'label'    => esc_html__( 'Typography', 'estra-core' ),
                'selector' => '{{WRAPPER}} .mk-interactive-services .mk-itsr-item .mk-itsr-title',
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-itsr-item .mk-itsr-title,
                    {{WRAPPER}} .mk-itsr-item .mk-itsr-title a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('active_title_color', [
                'label'     => esc_html__( 'Active Title Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-itsr-item.active-item .mk-itsr-title,
                    {{WRAPPER}} .mk-itsr-item.active-item .mk-itsr-title a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                'label' => esc_html__( 'Margin', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'estra-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-itsr-title' => 'margin:0;',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_decs_style', 'Description', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'desc_typography',
                'label'    => esc_html__( 'Typography', 'estra-core' ),
                'selector' => '{{WRAPPER}} .mk-itsr-desc',
            ]);

            $this->add_control('desc_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-item .mk-itsr-desc' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('desc_active_color', [
                'label'     => esc_html__( 'Active Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-item.active-item .mk-itsr-desc' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('desc_margin', [
                'label' => esc_html__( 'Margin', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_image_style', 'Image', true);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'image',
                'label'   => esc_html__( 'Image Size', 'estra-core' ),
                'default' => 'full',
            ]);

            $this->add_control('image_width',[
                'label'       => esc_html__( 'Width', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', '%'  ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-images' => 'width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('image_padding', [
                'label' => esc_html__( 'Padding', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-images' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'counter_styles', 'Counter', true);

            $this->add_control('counter_on',[
                'label'   => esc_html__( 'Counter', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('counter_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => [ 'counter_on' => 'yes' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-item .mk-itsr-counter' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('counter_active_color', [
                'label'     => esc_html__( 'Active Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => [ 'counter_on' => 'yes' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-item.active-item .mk-itsr-counter' => 'color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'arrow_styles', 'Arrow', true);

            $this->add_control('arrow_on',[
                'label'   => esc_html__( 'Arrow', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('arrow_color', [
                'label'     => esc_html__( 'Color', 'estra-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => [ 'arrow_on' => 'yes' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-interactive-services .mk-itsr-item .mk-itsr-arrow' => 'color: {{VALUE}}; fill:{{VALUE}}; border-color:{{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'desc_responsive_hide', 'Hide Description At', 'none' );
            mk_elem_hide_ctrl($this, 'counter_responsive_hide', 'Hide Counter At', 'none' );
            mk_elem_hide_ctrl($this, 'arrow_responsive_hide', 'Hide Arrow At', 'none' );
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $i = 1;

        $articles_list = $interactiveList = '';

        foreach ( $settings['list_items'] as $index => $item ) :

            $counter = $link_start = $link_end = $linkHTML = $content = $imgUrl = $title = $desc = $arrow = '';

            // Image
            if (  $settings['image_size'] == 'custom' ) {
                $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['list_image']['id'], 'image', $settings );
                $img_alt = get_post_meta( $item['list_image']['id'], '_wp_attachment_image_alt', true);

                if ('' != $imgUrl) {
                    $slideImageHtml = '<img src="' . $imgUrl . '" alt="' . $img_alt . '" loading="lazy" />';
                }

            } else {
                $slideImageHtml = wp_get_attachment_image( $item['list_image']['id'], $settings['image_size']);
            }

            // Link
            if ( ! empty( $item['link']['url'] ) ) {

                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'class', 'mk-itsr-link' );

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $linkHTML = '<a ' . $this->get_render_attribute_string( $link_key ) . '></a>';

                $link_start = '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end   = '</a>';

            }

            $tabNo = ( $i < 10 ) ? '0' . $i : $i;

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            if ( ! empty( $item['title'] ) ) {
                $title .= '<'.$titleTagSelector.' class="mk-itsr-title swm-anim">' . $link_start . $item['title'] . $link_end . '</'.$titleTagSelector . '>';
            }

            $desc .= ( ! empty( $item['desc'] ) ) ? '<span class="mk-itsr-desc swm-anim swm-hide-'. $settings['desc_responsive_hide'] .'">' . $item['desc'] . '</span>' : '';

            $active_item = ('yes' == $item['set_active_item']) ? ' active-item' : '';

            // List Image
            if ('' != $slideImageHtml) {
                $interactiveList .= '<div id="tab-'.$i.'" class="mk-itsr-image'.$active_item.'">' . $linkHTML . '' . $slideImageHtml . '</div>';
            }

            if ( 'yes' === $settings['counter_on'] ) {
                $counter .= '<div class="mk-itsr-counter swm-hide-'. $settings['counter_responsive_hide'] .'">' . $tabNo . '</div>';
            }

            if ( 'yes' === $settings['arrow_on'] ) {
                $arrow .= '<div class="mk-itsr-arrow swm-hide-'. $settings['arrow_responsive_hide'] .'">' . $link_start . mk_get_svg_icon( 'arrow', 'swm-svg-filterable-bs-slider-arrow' ) . $link_end . '</div>';
            }

            // List Text
            $articles_list .= '<article class="mk-itsr-item swm-anim' . $active_item . '" data-index="tab-'.$i.'">
                                    ' . $counter . '
                                    <div class="mk-itsr-content">' . $title . $desc . '</div>
                                    '.$arrow.'
                                </article>';
            $i++;
        endforeach;

        $textMargin  = 0;
        $linksNumber = '--mk-interactive-services-number:' . count($settings['list_items']) . ';';

        echo '<div class="mk-interactive-services-container mk-itsr-fs-height-' . $settings['fullscreen_height_on'] . '" style="' . $linksNumber . '">
                <div class="mk-interactive-services">
                    <div class="mk-itsr-images">
                        <div class="mk-itsr-images-holder">
                            ' . $interactiveList . '
                        </div>
                    </div>
                    <div class="mk-itsr-items">
                        <div class="mk-itsr-items-list">
                            <div class="mk-itsr-items-list-holder">
                            ' . $articles_list . '
                            </div>
                        </div>
                    </div>
                </div>
            </div>';

    }

}