<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
class Mk_Media_Reveal extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_media_reveal'; }
	public function get_title()          { return esc_html__( 'Media Reveal', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-image'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'theme','image', 'video', 'media','reveal','animation','scroll','expand']; }
	public function get_style_depends()  { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'imagesLoaded', 'mk-gsap', 'mk-scroll-trigger', 'mk-widgets' ]; }

	protected function register_controls() {

		mk_elem_start_ctrl($this, 'content', 'Content');

            $this->add_control('media_type', [
                'label' => esc_html__( 'Media Type', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'image' => 'Image',
                    'video' => 'Video',
                ],
                'default' => 'image',
            ]);

            $this->add_control('media_image', [
                'label'      => esc_html__( 'Image', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::MEDIA,
                'condition'  => [ 'media_type' => 'image']
            ]);

            $this->add_control('video_url', [
                'label'       => esc_html__( 'MP4 File URL', 'anant-core' ),
                'label_block' => true,
                'condition'   => [ 'media_type' => 'video'],
                'type'        => \Elementor\Controls_Manager::TEXT,
            ]);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'media_image_size',
                'label'   => esc_html__( 'Image Size', 'orbius-core' ),
                'default' => 'full',
                'condition'  => [ 'media_type' => 'image']
            ]);

            $this->add_responsive_control('initial_width',[
                'label'       => esc_html__( 'Initial Width', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'default'     => ['size' => 30, ],
                'range'       => ['px' => ['min' => 0, 'max' => 40, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-reveal-image' => 'clip-path: inset(0% {{SIZE}}% 0% {{SIZE}}%);',
                ],
            ]);

		$this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings_for_display();
        $media = '';

        if ( $settings['media_type'] == 'video' && '' !== $settings['video_url'] ) {
            $media = '<div class="mk-media-reveal-video">
                    <video loop muted playsinline><source src="' . $settings['video_url'] . '" type="video/mp4" /></video>
                </div>';
        } else {

            $imgStyle = '';
            $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $settings['media_image']['id'], 'media_image_size', $settings );

            if (  $settings['media_image_size_size'] == 'custom' ) {
                $imageTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $settings['media_image'], $settings['media_image']['id'], 'media_image_size', 'media_image').' />';
            } else {
                $imageTagHtml = wp_get_attachment_image( $settings['media_image']['id'], $settings['media_image_size_size']);
            }

            if ( '' !== $imgUrl ) {
                $media = $imageTagHtml;
            }
        }

        echo '<div class="mk-reveal-image-wrapper" id="mk-reveal-image-id-'.$this->get_id().'">
                <div class="mk-reveal-image-pin">
                    <div class="mk-reveal-image">' . $media . '</div>
                </div>
                <div class="mk-reveal-image-content"></div>
            </div>';
	}

}