<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Metro_Portfolio extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_metro_portfolio'; }
    public function get_title()          { return esc_html__( 'Metro Portfolio', 'estra-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-gallery-grid'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'theme','grid', 'portfolio','gallery','images','portfolio','photo','metro','zig zag' ]; }
   public function get_style_depends()   { return ['mk-core-main']; }
    public function get_script_depends() { return ['mk-gsap','mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'general_settings', 'General');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control( 'display_style', [
                'label' => esc_html__( 'Display Style', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'st1' => 'Style 1',
                    'st2' => 'Style 2',
                    'st3' => 'Style 3',
                    'st4' => 'Style 4',
                ],
                'default' => 'st1',
            ]);

            $repeater->add_control('title_text', [
                'label'       => esc_html__( 'Title', 'estra-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('ocean shine','estra-core')
            ]);

            $repeater->add_control('services_list', [
                'label'       => esc_html__( 'Services', 'orbius-core' ),
                'description' => esc_html__( 'List the services separated by commas.', 'orbius-core' ),
                'default'     => esc_html__('animation, branding, logo design','orbius-core'),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'placeholder' => esc_html__( 'http://your-link.com', 'estra-core' ),
            ]);

            $repeater->add_control('square_image', [
                'label'       => esc_html__( 'Square Image', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('horizontal_image', [
                'label'       => esc_html__( 'Horizontal Image', 'estra-core' ),
                'type'        => \Elementor\Controls_Manager::MEDIA,
            ]);

            $this->add_control('list_items', [
                'label' => esc_html__( 'List Items', 'estra-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title_text }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'items_styling', 'General', true);

            mk_elem_heading_ctrl($this, 'items_heading', 'Items' );

            $this->add_responsive_control('items_spacing',[
                'label'       => esc_html__( 'Items Spacing', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px' ],
                'range'       => ['px' => ['min' => 0, 'max' => 200, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-metro-portfolio-item' => 'grid-gap:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-metro-pf-separator' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('separator_on',[
                'label'   => esc_html__( 'Separator Line', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('separator_color', [
                'label'     => esc_html__( 'Separator Line Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-metro-pf-separator span' => 'background: {{VALUE}};',
                ],
            ]);

            $this->end_controls_section();

            mk_elem_start_ctrl($this, 'image_style', 'Image', true);

            $this->add_control('hover_cursor_on',[
                'label'   => esc_html__( 'Hover Cursor Box', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_responsive_control('hover_img_opacity',[
                'label'       => esc_html__( 'Hover Image Opacity', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'range'       => ['px' => ['min' => 0, 'max' => 1, 'step'  => 0.01] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-metro-portfolio-item .mk-metro-pf-img:hover img' => 'opacity:{{SIZE}};',
                ],
            ]);

            mk_elem_heading_ctrl($this, 'sq_image_size_heading', 'Square Image Size','before' );

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'projects_image_size_sq',
                'label'   => esc_html__( 'Square Image Size', 'orbius-core' ),
                'default' => 'mk_image_size_square',
            ]);

            mk_elem_heading_ctrl($this, 'hor_image_size_heading', 'Horizontal Image Size', 'before' );

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'projects_image_size_hor',
                'label'   => esc_html__( 'Horizontal Image Size', 'orbius-core' ),
                'default' => 'mk_image_size_landscape',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_style', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'label'      => esc_html__( 'Title Typography', 'orbius-core' ),
                'selector' => '{{WRAPPER}} .mk-metro-portfolio .mk-metro-portfolio-title',
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-metro-portfolio-title' => 'margin:0;',
                ],
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-metro-portfolio .mk-metro-portfolio-title,
                    {{WRAPPER}} .mk-metro-portfolio .mk-metro-portfolio-title a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-metro-portfolio .mk-metro-portfolio-title:hover a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'default' => [
                        'top' => '0',
                        'right' => '0',
                        'bottom' => '0',
                        'left' => '0',
                        'isLinked' => true,
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-metro-portfolio .mk-metro-portfolio-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'services_style', 'Services', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'services_typography',
                'selector' => '{{WRAPPER}} .mk-metro-portfolio ul.mk-metro-pf-services li',
            ]);

            $this->add_control('services_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-metro-portfolio ul.mk-metro-pf-services li' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('services_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mk-metro-portfolio ul.mk-metro-pf-services' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'counter_styling', 'Counter', true);

            $this->add_control('counter_on',[
                'label' => esc_html__( 'Counter', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'counter_typography',
                'selector' => '{{WRAPPER}} .mk-metro-portfolio-counter',
            ]);

            $this->add_control('counter_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'  => '#f2f2f2',
                'selectors' => [
                    '{{WRAPPER}} .mk-metro-portfolio-counter' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control( 'counter_display_style', [
                'label' => esc_html__( 'Display Style', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'default' => 'Default',
                    'stroke'  => 'Stroke'
                ],
                'default' => 'stroke',
            ]);

            $this->add_responsive_control('counter_stroke_width', [
                'label' => esc_html__( 'Stroke Width', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'default' => ['size' => '1', 'unit' => 'px'],
                'condition'=> ['counter_display_style' => 'stroke'],
                'selectors' => [
                    '{{WRAPPER}} .mk-metro-portfolio-counter' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('counter_stroke_color',[
                'label' => esc_html__( 'Stroke Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition'=> ['counter_display_style' => 'stroke'],
                'default' => '#000',
                'selectors' => [
                    '{{WRAPPER}} .mk-metro-portfolio-counter' => '-webkit-text-stroke-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'portfolio_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'services_responsive_hide', 'Hide Services At', 'none' );
            mk_elem_hide_ctrl($this, 'counter_responsive_hide', 'Hide Counter At', 'tablet' );
        $this->end_controls_section();

    }

    public function services_list($services) {
        $services_list = '';
        $services = explode(",", $services);

        foreach ( $services as $service ) {
            $services_list .= '<li>' . $service . '</li>';
        }
        return $services_list;
    }

    public function display_style($style, $contentBox,$squareImage, $horImage) {
        switch ( $style ) :
            case 'st2':
                return $horImage . $squareImage . $contentBox;
            case 'st3':
                return $squareImage . $contentBox . $horImage;
            case 'st4':
                return $horImage . $contentBox . $squareImage;
            default:
                return $contentBox . $squareImage . $horImage;
        endswitch;
    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $i = 1;
        $all_content = '';
        $separator = '<div class="mk-metro-pf-separator"><span></span></div>';

        $articles_list = $interactiveList = '';

        foreach ( $settings['list_items'] as $index => $item ) :

            $cursor = $link_start = $link_end = $horImageHtml = $squareImageHtml = $counter = $services_list = $linkHTML = '';

            $separatorHTML = ( 'yes' === $settings['separator_on'] ) ? $separator : '';

            // Link
            if ( ! empty( $item['link']['url'] ) ) {

                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'class', 'mk-metro-pf-link' );

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end   .= '</a>';

                if ( 'yes' === $settings['hover_cursor_on'] ) {
                    $cursor .= ' mk--eye-cursor';
                }

            }

            // horizontal image

            if (  $settings['projects_image_size_hor_size'] == 'custom' ) {
                $horImage = '<img ' . mk_custom_image_size_html($this, $settings, $item['horizontal_image'], $item['horizontal_image']['id'], 'projects_image_size_hor', 'project_img_hor' . $i) . ' />';
            } else {
                $horImage = wp_get_attachment_image( $item['horizontal_image']['id'], $settings['projects_image_size_hor_size']);
            }

            $imgHorUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['horizontal_image']['id'], 'projects_image_size_hor', $settings );

            if ( '' !== $imgHorUrl ) {
                $horImageHtml .= '<div class="mk-metro-pf-image-hor' . $cursor . '"><div class="mk-metro-pf-image-inner mk-metro-pf-img">' . $link_start . $horImage . $link_end . '</div></div>';
            }

            // square image

            $imgSquareUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['square_image']['id'], 'projects_image_size_sq', $settings );

            if (  $settings['projects_image_size_sq_size'] == 'custom' ) {
                $squareImage = '<img ' . mk_custom_image_size_html($this, $settings, $item['square_image'], $item['square_image']['id'], 'projects_image_size_sq', 'project_img_sq' . $i) . ' />';
            } else {
                $squareImage = wp_get_attachment_image( $item['square_image']['id'], $settings['projects_image_size_sq_size']);
            }

            if ( '' !== $imgSquareUrl ) {
                $squareImageHtml .= '<div class="mk-metro-pf-image-square' . $cursor . '"><div class="mk-metro-pf-image-inner mk-metro-pf-img">' . $link_start . $squareImage . $link_end . '</div></div>';
            }

            // content

            $titleHtml = '';

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            if ( ! empty( $item['title_text'] ) ) {
                $titleHtml .= '<'.$titleTagSelector.' class="mk-metro-portfolio-title">' . $link_start . $item['title_text'] . $link_end . '</'.$titleTagSelector . '>';
            }

            if ( ! empty( $item['services_list'] ) ) {
                $services_list .= '<ul class="mk-metro-pf-services swm-hide-'. $settings['services_responsive_hide'] .'">' . $this->services_list($item['services_list']) . '</ul>';
            }

            if ( 'yes' === $settings['counter_on'] ) {
                $counter_number = ( $i < 10 ) ? '0' . $i : $i;
                $counter .= '<div class="mk-metro-portfolio-counter swm-hide-'. $settings['counter_responsive_hide'] .'">'.$counter_number.'</div>';
            }

            $contentBox = '<div class="mk-metro-portfolio-content"><div class="mk-metro-portfolio-top">' . $titleHtml .$services_list . '</div>' . $counter . '</div>';

            // all

            $all_content .= '<div class="mk-metro-portfolio-item mk-metro-pf-' . $item['display_style'] . '">' . $this->display_style($item['display_style'], $contentBox,$squareImageHtml, $horImageHtml) . '<div class="clear"></div></div>' . $separatorHTML;

            $i++;
        endforeach;

        echo '<div class="mk-metro-portfolio">' . $all_content . '</div>';

    }

}