<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Moving_Content extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_moving_content'; }
    public function get_title()          { return esc_html__( 'Moving Content', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-text'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'theme', 'move','scroll','text','content','left','right','animation','moving' ]; }
    public function get_style_depends()  { return [ 'mk-core-main' ]; }
    public function get_script_depends() { return [ 'mk-gsap', 'mk-scroll-trigger', 'mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'content_heading', 'Content');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title', [
                'label' => esc_html__( 'Title', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
                'default' => 'Sample Title Text',
            ]);

            $repeater->add_control('subtitle', [
                'label' => esc_html__( 'Text', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter Summery Text', 'orbius-core' ),
                'default' => 'Summery text example',
            ]);

            $repeater->add_control('margin_left', [
                'label'     => esc_html__( 'Left Margin', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.mk-moving-content-item' => 'margin-left:{{SIZE}}{{UNIT}};',
                    '(tablet){{WRAPPER}} {{CURRENT_ITEM}}.mk-moving-content-item' => 'margin-left: 0;',
                ],
            ]);

            $this->add_control('all_content', [
            'label' => esc_html__( 'Add Content', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'default' => [
                ['title' => 'our mission', 'subtitle' => 'euam sitmet massa sebero aliquet venenat integer nec lacinia tellus sed nulla fringilla suscipit', 'margin_left' => ['size' => '0','unit' => 'px'], ],
                ['title' => 'our vision',  'subtitle' => 'euam sitmet massa sebero aliquet venenat integer nec lacinia tellus sed nulla fringilla suscipit', 'margin_left' => ['size' => '349','unit' => 'px'], ],
                ['title' => 'our awards',  'subtitle' => 'euam sitmet massa sebero aliquet venenat integer nec lacinia tellus sed nulla fringilla suscipit', 'margin_left' => ['size' => '700','unit' => 'px'], ],
            ],
            'title_field' => '{{{ title }}}',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'content_settings', 'Settings');

            $this->add_responsive_control('content_width', [
                'label'     => esc_html__( 'Content Max Width', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-content-item' => 'width:{{SIZE}}{{UNIT}};max-width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('content_space', [
                'label'     => esc_html__( 'Content Spacing', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-content-item' => 'margin-bottom:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'content_border',
                'label'       => esc_html__( 'Items Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-moving-content-item',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styling', 'Title');

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-moving-content-title',
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-content-title,
                    {{WRAPPER}} .mk-moving-content-title:before' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-content-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-content-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('title_tag', [
                'label' => esc_html__( 'Select Tag', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ],
                'default' => 'h4',
            ]);

            $this->add_responsive_control('bullet_size',[
                'label'       => esc_html__( 'Bullet Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-moving-content-title:before' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('bullet_spacing',[
                'label'       => esc_html__( 'Bullet Spacing', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-moving-content-title:before' => 'margin-right:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'text_styling', 'Text');

            $this->add_responsive_control('text_width', [
                'label'     => esc_html__( 'Text Max Width', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-content-text' => 'width:{{SIZE}}{{UNIT}};max-width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'text_typography',
                'selector' => '{{WRAPPER}} .mk-moving-content-text',
            ]);

            $this->add_control('text_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-content-text' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('text_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-content-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('text_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-content-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $content = '';

        $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

        foreach ( $settings['all_content'] as $index => $item ) :

            $titleHTML = ( '' !== $item['title'] ) ? '<' . $titleTagSelector . ' class="mk-moving-content-title">' . $item['title'] . '</' . $titleTagSelector . '>' : '';
            $subtitleHTML = ( '' !== $item['subtitle'] ) ? '<div class="mk-moving-content-text">' . $item['subtitle'] . '</div>' : '';

            $content .= '<div class="mk-moving-content-item elementor-repeater-item-' . $item['_id'] .'">' . $titleHTML . $subtitleHTML . '</div>';

        endforeach;

        echo '<div class="mk-moving-content-holder">
                <div class="mk-moving-content">' . $content . '</div>
            </div>';

    }

}