<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Moving_Gallery extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_moving_gallery'; }
    public function get_title()          { return esc_html__( 'Moving Gallery', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-form-vertical'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'theme','slider','slide show','gallery','image','move','scroll','animation', 'moving' ]; }
    public function get_style_depends()  { return [ 'mk-core-main' ]; }
    public function get_script_depends() { return [ 'mk-gsap', 'mk-scroll-trigger', 'mk-widgets' ]; }
    public function is_reload_preview_required() { return true; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_heading', 'Gallery Images');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('slide_image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'after',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $repeater->add_responsive_control('image_width', [
                'label'      => esc_html__( 'Image Width', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['vw'],
            ]);

            $this->add_control('images', [
                'label' => esc_html__( 'Add Image', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]);

        $this->end_controls_section();


        mk_elem_start_ctrl($this, 'section_slider_style', 'Image');

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'                  => 'gallery_image_size',
                'label'                 => esc_html__( 'Image Size', 'orbius-core' ),
                'default'               => 'full',
            ]);

            $this->add_responsive_control('image_default_width', [
                'label'      => esc_html__( 'Image Width', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['vw','px','%'],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-gallery li' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('img_align', [
                'label'   => esc_html__( 'Image Align', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'flex-start' => esc_html__( 'Top', 'orbius-core' ),
                    'center' => esc_html__( 'Center', 'orbius-core' ),
                    'flex-end' => esc_html__( 'Bottom', 'orbius-core' ),
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-gallery .mk-moving-gallery-list' => 'align-items: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('items_radius', [
                'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-gallery .mk-moving-gallery-list img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('img_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-gallery .mk-moving-gallery-list li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $slideHTML = '';
        $i = 1;

        foreach ( $settings['images'] as $index => $item ) :

            $slide_image = $link_start = $link_end = $imageWidth = '';

            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) { $this->add_render_attribute( $link_key, 'target', '_blank' ); }
                if ( $item['link']['nofollow'] ) { $this->add_render_attribute( $link_key, 'rel', 'nofollow' ); }

                $link_start = '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end = '</a>';
            }

            if (  $settings['gallery_image_size_size'] == 'custom' ) {
                $slide_image = '<img '.mk_custom_image_size_html($this, $settings, $item['slide_image'], $item['slide_image']['id'], 'gallery_image_size', 'carousel_img_' . $i).' />';
            } else {
                $slide_image = wp_get_attachment_image( $item['slide_image']['id'], $settings['gallery_image_size_size']);
            }

            if ( '' !== $item['image_width']['size'] ) {
                $imageWidth .= 'style="width:' . $item['image_width']['size'] . 'vw;"';
            }

            $slideHTML .= '<li ' . $imageWidth . '>' . $link_start . $slide_image . $link_end . '</li>';

            $i++;
        endforeach;

        echo '<div class="mk-moving-gallery">
                <ul class="mk-moving-gallery-list mg-'.$this->get_id().'" id="'.$this->get_id().'">' . $slideHTML . '</ul>
            </div>';

    }

}