<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Moving_Projects extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_moving_projects'; }
    public function get_title()          { return esc_html__( 'Moving Projects', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-text'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'theme', 'move','scroll','moving','content','left','right','animation','projects','portfolio','work' ]; }
    public function get_style_depends()  { return [ 'mk-core-main' ]; }
    public function get_script_depends() { return [ 'mk-gsap', 'mk-splittext', 'mk-scroll-trigger', 'mk-widgets' ]; }

    public function project_items($obj, $num) {

        mk_elem_heading_ctrl($this, 'heading_' . $num, 'Project ' . $num, 'before' );

        $obj->add_control($num . '_project_image', [
            'label'     => esc_html__( 'Image', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::MEDIA,
        ]);

        $obj->add_control($num . '_title', [
            'label' => esc_html__( 'Project Title', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
            'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
            'default' => 'Title Text',
        ]);

        $obj->add_control($num . '_link', [
            'label'       => esc_html__( 'Link', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'label_block' => true,
            'default'  => [
                'url'         => '#',
                'is_external' => '',
            ],
            'dynamic'     => ['active'  => true, ],
            'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
        ]);
    }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'first_row_projects', 'First Row Projects');

            $this->project_items($this, 'one');
            $this->project_items($this, 'two');
            $this->project_items($this, 'three');
            $this->project_items($this, 'four');

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'second_row_projects', 'Second Row Projects');

            $this->project_items($this, 'five');
            $this->project_items($this, 'six');
            $this->project_items($this, 'seven');
            $this->project_items($this, 'eight');

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'content_styling', 'Content Circle', true);

            $this->add_control('featured_projects_title', [
                'label' => esc_html__( 'Featured Projects Text', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Featured Projects', 'orbius-core' ),
                'default' => 'Featured Projects',
            ]);


            $this->add_control('title_color', [
                'label'     => esc_html__( 'Text Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-projects .stat-inner' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('bg_color', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-projects .mk-moving-project-info-bg' => 'background-color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-moving-projects .stat-inner',
            ]);

            $this->add_responsive_control('text_max_width', [
                'label' => esc_html__( 'Text Max Width', 'orbius-core' ),
                'type'  => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 230, ],
                ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-moving-projects .stat-inner,{{WRAPPER}} .mk-moving-projects .stat-main-title' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]);

            mk_elem_heading_ctrl($this, 'heading_mobile_project_title', 'Items on Tablet and Mobile', 'before' );

            $this->add_control('mobile_project_title_color', [
                'label'     => esc_html__( 'Text Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-projects .mk-moving-projects-img .mk-moving-projects-mobile-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('mobile_project_title_bg_color', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-projects .mk-moving-projects-img .mk-moving-projects-mobile-title' => 'background-color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('mobile_item_spacing', [
                'label' => esc_html__( 'Spacing', 'orbius-core' ),
                'type'  => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 230, ],
                ],
                'selectors'   => [
                    '(tablet){{WRAPPER}} .mk-moving-projects .mk-moving-projects-images' => 'grid-gap: {{SIZE}}{{UNIT}}; width:calc(100% - {{SIZE}}{{UNIT}});',
                    '(tablet){{WRAPPER}} .mk-moving-projects .mk-moving-projects-images:first-of-type' => 'margin-bottom:{{SIZE}}{{UNIT}};',
                    '(mobile){{WRAPPER}} .mk-moving-projects .mk-moving-projects-images' => 'grid-gap: {{SIZE}}{{UNIT}}; width:calc(100% - {{SIZE}}{{UNIT}});',
                    '(mobile){{WRAPPER}} .mk-moving-projects .mk-moving-projects-images:first-of-type' => 'margin-bottom:{{SIZE}}{{UNIT}};'
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'image_styling', 'Image', true);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'projects_image_size',
                'label'   => esc_html__( 'Image Size', 'orbius-core' ),
                'default' => 'full',
            ]);

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // FIRST PROJECTS
        $first_all_titles = $first_all_images = '';
        $first_row_items = ['one','two','three','four'];
        $i = 1;

        foreach ( $first_row_items as $item ) :

            $itemImage = $item . '_project_image';
            $itemTitle = $item . '_title';
            $itemLink = $item . '_link';

            $imgHtml = $link_start = $link_end = $imageWidth = '';

            if ( ! empty( $settings[$itemLink]['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $settings[$itemLink]['url'] );
                $this->add_render_attribute( $link_key, 'class', 'mk-moving-projects-link' );

                if ( $settings[$itemLink]['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $settings[$itemLink]['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';
            }

            if (  $settings['projects_image_size_size'] == 'custom' ) {
                $imgHtml = '<img '.mk_custom_image_size_html($this, $settings, $settings[$itemImage], $settings[$itemImage]['id'], 'projects_image_size', 'project_img_f' . $i).' />';
            } else {
                $imgHtml = wp_get_attachment_image( $settings[$itemImage]['id'], $settings['projects_image_size_size']);
            }

            $img_number = ( $i === 1 ) ? 'first' : 'other';
            $randomData = $i . 'fir-' . rand(10,100000);
            $mobileTitle = '<span class="mk-moving-projects-mobile-title">' . $settings[$itemTitle] . '</span>';

            $first_all_images .= '<div class="mk-moving-projects-'.$img_number.'-img"><div class="mk-moving-projects-img" data-projectimage="'.$randomData.'">' . $link_start . $mobileTitle . $imgHtml . $link_end . '</div></div>';
            $first_all_titles .= '<div class="stat-data" data-stat="'.$randomData.'"><span>' . $settings[$itemTitle] . '</span></div>';

            $i++;
        endforeach;


        // SECOND PROJECTS
        $second_all_titles = $second_all_images = '';
        $second_row_items = ['five','six','seven','eight'];
        $j = 1;

        foreach ( $second_row_items as $item_two ) :

            $itemImage_Two = $item_two . '_project_image';
            $itemTitle_Two = $item_two . '_title';
            $itemLink_Two = $item_two . '_link';

            $link_start_two = $link_end_two = $imgHtml = $imageWidth = '';

            if ( ! empty( $settings[$itemLink_Two]['url'] ) ) {
                $link_key = 'link_two_' . $j;

                $this->add_render_attribute( $link_key, 'href', $settings[$itemLink_Two]['url'] );
                $this->add_render_attribute( $link_key, 'class', 'mk-moving-projects-link' );

                if ( $settings[$itemLink_Two]['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $settings[$itemLink_Two]['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start_two .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end_two .= '</a>';
            } else {
                $link_start_two .= '<a href="#" class="mk-moving-projects-link" >';
                $link_end_two .= '</a>';
            }

            if (  $settings['projects_image_size_size'] == 'custom' ) {
                $imgHtml_Two = '<img ' . mk_custom_image_size_html($this, $settings, $settings[$itemImage_Two], $settings[$itemImage_Two]['id'], 'projects_image_size', 'project_img_s' . $j) . ' />';
            } else {
                $imgHtml_Two = wp_get_attachment_image( $settings[$itemImage_Two]['id'], $settings['projects_image_size_size']);
            }

            $img_number_Two = ( $j === 1 ) ? 'first' : 'other';
            $randomDataTwo = $j . 'sec-' . rand(10,100000);

            $mobileTitle_Two = '<span class="mk-moving-projects-mobile-title">' . $settings[$itemTitle_Two] . '</span>';

            $second_all_images .= '<div class="mk-moving-projects-'.$img_number_Two.'-img"><div class="mk-moving-projects-img" data-projectimage="'.$randomDataTwo.'">' . $link_start_two . $imgHtml_Two . $mobileTitle_Two . $link_end_two . '</div></div>';
            $second_all_titles .= '<div class="stat-data" data-stat="'.$randomDataTwo.'"><span>' . $settings[$itemTitle_Two] . '</span></div>';

            $j++;
        endforeach;

        echo '<section class="mk-moving-projects mk-moving-projects-'.$this->get_id().'" id="'.$this->get_id().'">
                <div class="mk-moving-projects-gap"></div>
                <div class="mk-moving-projects-holder">
                    <div class="mk-moving-projects-images"> '.$first_all_images.' </div>
                    <div class="mk-moving-projects-images"> '.$second_all_images.' </div>
                    <div class="mk-moving-project-info">
                        <div class="mk-moving-project-info-bg"></div>
                        <div class="stat-inner">
                            <span class="stat-main-title"><span>' . $settings['featured_projects_title'] . '</span></span>
                            ' . $first_all_titles . $second_all_titles . '
                        </div>
                    </div>
                </div>
            </section>';

    }

}