<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Moving_Services extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_moving_services'; }
    public function get_title()          { return esc_html__( 'Moving Services', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-text'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'theme', 'move','scroll','moving','content','left','right','animation','services','section' ]; }
    public function get_style_depends()  { return [ 'mk-core-main' ]; }
    public function get_script_depends() { return [ 'mk-gsap', 'mk-splittext', 'mk-scroll-trigger', 'mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'content_heading', 'Content');

            $this->add_control('background_text', [
                'label' => esc_html__( 'Background Text', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'services',
            ]);

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title', [
                'label' => esc_html__( 'Title', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
                'default' => 'Sample Title Text',
            ]);

            $repeater->add_control('subtitle', [
                'label' => esc_html__( 'Text', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter Summery Text', 'orbius-core' ),
                'default' => 'Summery text example',
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'dynamic'     => ['active'  => true, ],
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $repeater->add_control('box_position', [
                'label'   => esc_html__( 'Box Position', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'start' => esc_html__( 'Top', 'orbius-core' ),
                    'middle' => esc_html__( 'Center', 'orbius-core' ),
                    'end' => esc_html__( 'Bottom', 'orbius-core' ),
                ],
                'default' => 'middle',
            ]);

            $this->add_control('all_content', [
                'label' => esc_html__( 'Add Content', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['title' => 'graphics', 'subtitle' => 'Curabitur sagittis lectus quis purus interdua vulputate justo hendrerit asellus ullamcorper sem vel tellus ultrices ac suscipit orci tincidunt enean ultrices gravida quam ac sagittis justo fermentum ut.', 'box_position' => 'start' ],
                    ['title' => 'branding', 'subtitle' => 'Curabitur sagittis lectus quis purus interdua vulputate justo hendrerit asellus ullamcorper sem vel tellus ultrices ac suscipit orci tincidunt enean ultrices gravida quam ac sagittis justo fermentum ut.', 'box_position' => 'middle' ],
                    ['title' => 'marketing', 'subtitle' => 'Curabitur sagittis lectus quis purus interdua vulputate justo hendrerit asellus ullamcorper sem vel tellus ultrices ac suscipit orci tincidunt enean ultrices gravida quam ac sagittis justo fermentum ut.', 'box_position' => 'end' ],
                    ['title' => 'animation', 'subtitle' => 'Curabitur sagittis lectus quis purus interdua vulputate justo hendrerit asellus ullamcorper sem vel tellus ultrices ac suscipit orci tincidunt enean ultrices gravida quam ac sagittis justo fermentum ut.', 'box_position' => 'start' ],
                    ['title' => 'printing', 'subtitle' => 'Curabitur sagittis lectus quis purus interdua vulputate justo hendrerit asellus ullamcorper sem vel tellus ultrices ac suscipit orci tincidunt enean ultrices gravida quam ac sagittis justo fermentum ut.', 'box_position' => 'middle' ],
                    ['title' => 'strategy', 'subtitle' => 'Curabitur sagittis lectus quis purus interdua vulputate justo hendrerit asellus ullamcorper sem vel tellus ultrices ac suscipit orci tincidunt enean ultrices gravida quam ac sagittis justo fermentum ut.', 'box_position' => 'end' ],
                ],
                'title_field' => '{{{ title }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'content_settings', 'Content Box', true);

            $this->add_control('box_width', [
                'label'     => esc_html__( 'Width', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-services-item' => 'width:{{SIZE}}{{UNIT}}',
                    '(tablet){{WRAPPER}} .mk-moving-services-item' => 'width:100%',
                ],
            ]);

            $this->add_control('box_left_margin', [
                'label'     => esc_html__( 'Spacing', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-services .mk-moving-services-items>div:not(first-of-type)' => 'margin-left:{{SIZE}}{{UNIT}}',
                    '(tablet){{WRAPPER}} .mk-moving-services .mk-moving-services-items>div:not(first-of-type)' => 'margin-left:0',
                    '(mobile){{WRAPPER}} .mk-moving-services .mk-moving-services-items>div:not(first-of-type)' => 'margin-left:0',
                ],
            ]);

            $this->add_responsive_control('box_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-services-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'box_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-moving-services-item',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
                'name'     => 'box_bg_color',
                'label' => esc_html__( 'Background Color', 'orbius-core' ),
                'types'    => [ 'none','classic','gradient' ],
                'selector' => '{{WRAPPER}} .mk-moving-services-item',
            ]);

            mk_elem_heading_ctrl($this, 'icon_content_box_mobile_heading', 'Content Box (Mobile)', 'before' );

            $this->add_control('box_vertical_margin', [
                'label'     => esc_html__( 'Vertical Spacing', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 25, ], ],
                'description' => esc_html__( 'Space between two boxes in a scroll tab effect.' )
            ]);

            $this->add_control('box_bottom_margin', [
                'label'     => esc_html__( 'Content Bottom Spacing', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1500, ], ],
                'default' => ['size' => '20'],
                'size_units'  => [ '%', 'px','vh','em' ],
                'description' => esc_html__( 'Set the mobile resolution space between boxes and next content section. Test on an actual mobile device or on the frontend with page refresh.', 'orbius-core' )
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'bg_text_styling', 'Background Text', true);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'bg_text_typography',
                'selector' => '{{WRAPPER}} .mk-moving-services-heading,{{WRAPPER}} .mk-moving-services-heading-mobile',
            ]);

            $this->add_control('bg_text_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-services-heading span:nth-of-type(2)' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('bg_text_moving_color', [
                'label'     => esc_html__( 'Moving Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-services-heading span:first-of-type' => 'color: {{VALUE}};',
                ],
            ]);

             $this->add_control( 'title_display_style', [
                       'label' => esc_html__( 'Display Style', 'orbius-core' ),
                       'type' => \Elementor\Controls_Manager::SELECT,
                       'options' => [
                           'default' => 'Default',
                           'stroke'  => 'Stroke'
                       ],
                       'default' => 'stroke',
                   ]);
            $this->add_responsive_control('title_stroke_color',[
                       'label' => esc_html__( 'Stroke Color', 'orbius-core' ),
                       'type' => \Elementor\Controls_Manager::COLOR,
                       'default' => '#000000',
                       'condition'=> ['title_display_style' => 'stroke'],
                       'selectors' => [
                           '{{WRAPPER}} .mk-moving-services-heading span:nth-of-type(2)' => '-webkit-text-stroke-color: {{VALUE}};',
                       ],
                   ]);
            $this->add_responsive_control('title_stroke_width', [
                       'label' => esc_html__( 'Stroke Width', 'orbius-core' ),
                       'type' => \Elementor\Controls_Manager::SLIDER,
                       'size_units' => [ 'px' ],
                       'default' => ['size' => '1', 'unit' => 'px'],
                       'condition'=> ['title_display_style' => 'stroke'],
                       'selectors' => [
                           '{{WRAPPER}} .mk-moving-services-heading span:nth-of-type(2)' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                       ],
                   ]);

            $this->add_control('heading_extra_length', [
                'label'     => esc_html__( 'Extra Length', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 2000, ], ],
                'description' => esc_html__( 'Adjust the length of the background text scroll clip path to match the number of boxes.', 'orbius-core' )
            ]);


            mk_elem_heading_ctrl($this, 'icon_border_outer_heading', 'Background Text (Mobile)', 'before' );

            $this->add_control('bg_text_mobile_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-services-heading-mobile' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('bg_text_mobile_margin', [
                'label'      => esc_html__( 'Margin (mobile text)', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-services-heading-mobile' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);


        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styling', 'Title', true);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-moving-services-title',
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-services-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-services-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-services-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('title_tag', [
                'label' => esc_html__( 'Select Tag', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ],
                'default' => 'h4',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'text_styling', 'Text', true);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'text_typography',
                'selector' => '{{WRAPPER}} .mk-moving-services-text',
            ]);

            $this->add_control('text_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-moving-services-text' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('text_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-services-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('text_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-services-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'counter_styling', 'Counter', true);

            $this->add_control('counter_on',[
                'label' => esc_html__( 'Counter', 'orbius-core' ),
                'type'  => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'      => 'counter_typography',
                'selector'  => '{{WRAPPER}} .mk-moving-services-counter',
                'condition' => ['counter_on' => 'yes']
            ]);

            $this->add_responsive_control('counter_padding', [
                'label'     => esc_html__( 'Padding', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::DIMENSIONS,
                'condition' => ['counter_on' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-services-counter' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('counter_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'condition'  => ['counter_on' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-moving-services-counter' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $content = '';
        $i = 1;

        foreach ( $settings['all_content'] as $index => $item ) :

            $linkHTML = '';

            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );
                $this->add_render_attribute( $link_key, 'class', 'mk-moving-services-link' );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $linkHTML .= '<a ' . $this->get_render_attribute_string( $link_key ) . '></a>';
            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            $titleHTML    = ( '' !== $item['title'] ) ? '<' . $titleTagSelector . ' class="mk-moving-services-title">' . $item['title'] . '</' . $titleTagSelector . '>' : '';
            $subtitleHTML = ( '' !== $item['subtitle'] ) ? '<div class="mk-moving-services-text">' . $item['subtitle'] . '</div>' : '';
            $counterHtml  = ( $settings['counter_on'] === 'yes' ) ? '<span class="mk-moving-services-counter">0' . $i . '</span>' : '';

            $content .= '<div class="mk-moving-services-item-box stack mk-moving-services-item-'. $item['box_position'] .'">
                            ' . $linkHTML . '
                            <article class="mk-moving-services-item">
                                ' . $counterHtml . $titleHTML . $subtitleHTML . '
                            </article>
                        </div>';
            $i++;
        endforeach;

        $background_text = ( '' !== $settings['background_text'] ) ? $settings['background_text'] : '';

        echo '<section class="mk-moving-services" data-vertical-margin ="' . intval($settings['box_vertical_margin']['size']) . '" data-extra-length="' . intval($settings['heading_extra_length']['size']) . '" data-box-margin="' . intval($settings['box_bottom_margin']['size']) . $settings['box_bottom_margin']['unit'] . '" id="mk-moving-services-'.$this->get_id().rand(10,100000).'">
                <div class="mk-moving-services-heading-mobile">' . $background_text . '</div>
                <div class="mk-moving-services-heading-holder">
                    <div class="mk-moving-services-heading"><span>' . $background_text . '</span><span>' . $background_text . '</span></div>
                </div>
                <div class="mk-moving-services-items">' . $content . '</div>
            </section>';

    }

}