<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Off_Canvas extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_off_canvas'; }
	public function get_title()      { return esc_html__( 'Off-Canvas', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-sidebar'; }
	public function get_categories() { return ['mk-sections-elements']; }
	public function get_keywords()   { return [ 'theme','panel','off canvas' ]; }
	public function get_style_depends() { return ['mk-core-main']; }
	public function get_script_depends() { return [ 'mk-widgets' ]; }

	protected function register_controls() {

		$is_edit_mode = mk_elm_is_edit_mode();

		mk_elem_start_ctrl($this, 'section_general', 'Off-Canvas');

		$theme_offcanvas_sections = swm_mk_list_sections_styles('offcanvas', 'ID');

		if ( $theme_offcanvas_sections ) {
			$this->add_control('offcanvas_section', [
				'label' => esc_html__( 'Choose Custom Section', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => $theme_offcanvas_sections,
                'label_block' => true
			]);
		} else {
			$this->add_control('offcanvas_section', [
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' => esc_html__( 'No Off-Canvas sections were found. Create Off-Canvas section from Dashboard &rarr; Sections &rarr; Add New. Select "Off-Canvas" from "Section Type" dropdown.', 'orbius-core' ),
				'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
			]);
		}

        $this->add_control('position', [
            'label' => esc_html__( 'Position', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::CHOOSE,
            'options' => mk_arrays('align_left_right'),
            'default' => 'right',
            'toggle' => false,
            'frontend_available' => true,
        ]);

        $this->add_responsive_control('size', [
                'label' => esc_html__( 'Off-Canvas Width', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%', 'px', 'em'],
                'range' => [
                    '%' => ['min' => 5, 'max' => 100 ],
                    'px' => ['min' => 30, 'max' => 1920 ],
                    'em' => ['min' => 3, 'max' => 300 ]
                ],
                'default' => ['size' => 480, 'unit' => 'px'],
                'tablet_default' => ['unit' => '%', 'size' => 61],
                'mobile_default' => ['unit' => '%', 'size' => 90],
                'selectors' => ['.mk-off-canvas-{{ID}}' => 'width: {{SIZE}}{{UNIT}}']
            ]);

        $this->add_responsive_control('canvas_padding', [
            'label' => esc_html__( 'Padding', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => ['.mk-off-canvas-{{ID}}' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
        ]);

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name' => '',
            'selector' => '.mk-off-canvas-{{ID}}',
        ]);

        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name' => 'canvas_bg',
            'label' => esc_html__( 'Background', 'orbius-core' ),
            'types' => [ 'classic', 'gradient' ],
            'selector' => '.mk-off-canvas-{{ID}}'
        ]);

        $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
            'name' => 'canvas_shadow',
            'selector' => '.mk-off-canvas-{{ID}}'
        ]);

        mk_elem_heading_ctrl($this, 'overlay_headig', 'Overlay', 'before' );

        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name' => 'canvas_overlay_bg',
            'label' => esc_html__( 'Overlay Background', 'orbius-core' ),
            'types' => [ 'classic', 'gradient' ],
            'selector' => '.mk-off-canvas-overlay.mk-off-canvas-{{ID}}.mk-off-canvas-active',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'off_canvas_icon_style', 'Off-Canvas Icon');

        $this->add_control('icon_style', [
            'label'     => esc_html__( 'Icon Style', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::SELECT,
            'default'   => 'default',
            'options'   => [
                'default'  => esc_html__( 'Default', 'orbius-core' ),
                'custom' => esc_html__( 'Custom', 'orbius-core' ),
            ],
        ]);

        $this->add_control('full_screen_icon_color', [
            'label'     => esc_html__( 'Color', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .swm-off-canvas-icon,
                {{WRAPPER}} a.swm-off-canvas-icon' => 'color: {{VALUE}}',
                '{{WRAPPER}} .swm-off-canvas-icon svg' => 'fill: {{VALUE}};',
            '{{WRAPPER}} .mk-hamburger-icon .mk-hamburger-icon-line' => 'background: {{VALUE}}',
            ],
        ]);

        $this->add_control('full_screen_default_icon_bg_color', [
            'label'     => esc_html__( 'Background Color', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'condition' => ['icon_style' => 'default'],
            'selectors' => [
            '{{WRAPPER}} .mk-hamburger-icon-holder' => 'background: {{VALUE}}',
            ],
        ]);

        $this->add_control('off_canvas_icon_bg_color', [
            'label'     => esc_html__( 'Background', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'condition' => ['icon_style' => 'custom'],
            'selectors' => [
                '{{WRAPPER}} a.swm-off-canvas-icon' => 'background: {{VALUE}};',
            ],
        ]);

        $this->add_control('off_canvas_icon', [
            'label' => esc_html__( 'Off-Canvas Icon', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::ICONS,
            'fa4compatibility' => 'icon',
            'default' => [
                'value' => 'fas fa-bars',
                'library' => 'fa-solid',
            ],
            'condition' => ['icon_style' => 'custom'],
            'recommended' => [
                'fa-solid' => ['bars', 'grip-lines','ellipsis-v','ellipsis-h','sliders-h','list-alt','list','stream'],
                'fa-regular' => ['times-circle'],
            ],
            'file' => '',
        ]);

        $this->add_responsive_control('off_canvas_icon_size', [
                'label' => esc_html__( 'Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => ['min' => 6, 'max' => 100 ]
                ],
                'default' => ['size' => 14, 'unit' => 'px'],
                'condition' => ['icon_style' => 'custom'],
                'selectors' => [
                    '{{WRAPPER}} a.swm-off-canvas-icon,
                    {{WRAPPER}} a.swm-off-canvas-icon svg' => 'font-size: {{SIZE}}{{UNIT}}']
            ]);

        $this->add_responsive_control('off_canvas_icon_padding', [
            'label'      => esc_html__( 'Padding', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'condition' => ['icon_style' => 'custom'],
            'selectors'  => [
                '{{WRAPPER}} a.swm-off-canvas-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
        ]);

        $this->add_responsive_control('off_canvas_icon_margin', [
            'label'      => esc_html__( 'Margin', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'condition' => ['icon_style' => 'custom'],
            'selectors'  => [
                '{{WRAPPER}} a.swm-off-canvas-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
        ]);

        $this->add_control('off_canvas_icon_border_radius', [
            'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%' ],
            'condition' => ['icon_style' => 'custom'],
            'selectors'  => [
                '{{WRAPPER}} a.swm-off-canvas-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name'        => 'off_canvas_icon_border',
            'label'       => esc_html__( 'Border', 'orbius-core' ),
            'selector'    => '{{WRAPPER}} a.swm-off-canvas-icon',
            'condition' => ['icon_style' => 'custom'],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_close', 'Close', false);

            $this->add_control('overlay_close',[
                'label'   => esc_html__( 'Close With Click on Overlay', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('esc_key_close',[
                'label'   => esc_html__( 'Close by ESC Button Click', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('close_icon', [
                'label' => esc_html__( 'Close Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'recommended' => [
                    'fa-solid' => ['times', 'times-circle'],
                    'fa-regular' => ['times-circle'],
                ],
                'file' => '',
            ]);

            $this->add_responsive_control('close_btn_size', [
                'label' => esc_html__( 'Close Icon Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => ['min' => 6, 'max' => 100 ]
                ],
                'default' => ['size' => 14, 'unit' => 'px'],
                'selectors' => [
                    '.mk-off-canvas-{{ID}} .mk-off-canvas-close a,
                    .mk-off-canvas-{{ID}} .mk-off-canvas-close a svg' => 'font-size: {{SIZE}}{{UNIT}}']
            ]);

            $this->add_control('close_btn_color', [
                'label'     => esc_html__( 'Close Icon Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '.mk-off-canvas-{{ID}} .mk-off-canvas-close a' => 'color: {{VALUE}}',
                    '.mk-off-canvas-{{ID}} .mk-off-canvas-close a svg' => 'fill: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('close_btn_padding', [
                'label' => esc_html__( 'Close Icon Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '.mk-off-canvas-{{ID}} .mk-off-canvas-close' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]);

        $this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings_for_display();
        $offcanvas_section = $settings['offcanvas_section'];
        $uniqueId = rand(10,100000);

        // Off-canvas icon
        if ( $settings['icon_style'] === 'custom' ) {
            $iconHTML = mk_get_elementor_icons($settings['off_canvas_icon']);
        } else {
            $iconHTML = '<div class="mk-hamburger-icon-holder"><span class="mk-hamburger-icon-lines"><span class="mk-hamburger-icon-line"></span><span class="mk-hamburger-icon-line mk-hamburger-icon-line-m"></span><span class="mk-hamburger-icon-line"></span></span></div>';
        }

        echo '<a href="#' . $uniqueId . '" class="swm-off-canvas-icon mk-hamburger-icon">' . $iconHTML . '</a>';

        // Off-canvas content
		ob_start();

		if ( $settings['overlay_close'] == 'yes' ) {
            echo '<div class="mk-off-canvas-overlay mk-off-canvas-' . $uniqueId . '"></div>';
        }

        $canvasPosition = !empty($settings['position']) ? $settings['position'] : 'right';

        $this->add_render_attribute([
            'canvas-attrs'      => [
                                    'class' => [
                                                'mk-off-canvas',
                                                'mk-off-canvas-' . $uniqueId,
                                                'mk-off-canvas-' . $canvasPosition,
                                                'mk-off-canvas-' . $this->get_id()
                                            ],
            'data-esckey'        => $settings['esc_key_close'],
            'data-offcanvas-id'  => $uniqueId,
            'data-widget-id' => $uniqueId
            ]
        ] );

        $close_icon = mk_get_elementor_icons($settings['close_icon']);

        if ( '' === $close_icon ) {
            $close_icon = mk_get_svg_icon( 'close-alt', 'swm-svg-off-canvas-close-icon' );
        }

		?>
		<div <?php echo $this->get_render_attribute_string( 'canvas-attrs' ); ?>>
			<div class="swm-off-canvas-wrap">
                <div class="mk-off-canvas-close mk-icon"><a href="#"><?php echo $close_icon; ?></a></div>
                <?php
                if ( $offcanvas_section ) {
				    $swm_section_id = swm_mk_get_custom_section_id('offcanvas', $offcanvas_section);
				    do_action( 'swm_action_show_section', $swm_section_id );
                }
				?>
			</div>
		</div>

		<?php
		$output = ob_get_contents();
		ob_end_clean();
		mk_add_inline_html($output);
		echo '<div class="mk_hidden"></div>';

	}

}