<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Page_Titlebar extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_page_titlebar'; }
	public function get_title()      { return esc_html__( 'Page Title Bar', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-header'; }
	public function get_categories() { return ['mk-sections-elements']; }
	public function get_keywords()   { return [ 'theme','title','heading','page title', 'titlebar', 'title bar', 'meta','breadcrumbs' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }
    public function get_script_depends() { return ['mk-widgets']; }

	protected function register_controls() {

		// Register controls
		mk_elem_start_ctrl($this, 'section_title', 'Title Bar');

		$this->add_control('content_align', [
            'label'         => esc_html__( 'Content Style', 'orbius-core' ),
            'type'          => \Elementor\Controls_Manager::CHOOSE,
            'label_block'   => false,
            'options'       => mk_arrays('text_align'),
            'default'       => 'center',
            'prefix_class'  => 'mk-titlebar-align-'
        ]);

        $this->add_control('icon_vertical_align', [
            'label'                 => esc_html__( 'Vertical Alignment', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::CHOOSE,
            'label_block'           => false,
            'default'               => 'middle',
            'options'               => mk_arrays('vertical_alignment'),
            'selectors_dictionary'  => [
                'top'          => 'flex-start',
                'middle'       => 'center',
                'bottom'       => 'flex-end',
            ],
            'selectors' => [
                '{{WRAPPER}} .mk-page-titlebar-content' => 'align-items: {{VALUE}};',
            ],
        ]);

        $this->add_control('appear_animation_on',[
            'label'   => esc_html__( 'Appear Animation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'condition' => ['content_align' => 'left'],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name' => 'bg_image',
            'types' => [ 'classic', 'gradient' ],
            'fields_options' => [
                'background' => [
                    'default' =>'classic',
                ],
                'color' => [
                    'default' => '#ffffff',
                ],
            ],
            'condition' => ['use_featured_image!' => 'yes'],
            'selector' => '{{WRAPPER}} .mk-page-titlebar',
        ]);

        $this->add_control('use_featured_image',[
            'label'   => esc_html__( 'Replace with featured image', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

		$this->add_responsive_control('content_max_width', [
			'label' => esc_html__( 'Content Area Maximum Width', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => ['px', 'em'],
			'range' => [
                'px' => ['min' => 0, 'max' => 4000 ],
                'em' => ['min' => 0, 'max' => 50 ]
            ],
			'selectors' => [
				'{{WRAPPER}} .mk-page-titlebar-content' => 'max-width: {{SIZE}}{{UNIT}};',
			],
		]);

        $this->add_responsive_control('title_bar_padding', [
            'label' => esc_html__( 'Padding', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-page-titlebar-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('title_bar_margin', [
            'label' => esc_html__( 'Margin', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-page-titlebar' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_control('items_border_color', [
            'label'     => esc_html__( 'Border Color', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-page-titlebar:after' => 'background: {{VALUE}};',
            ],
        ]);

        $this->add_responsive_control('border_size',[
            'label'       => esc_html__( 'Border Size', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em' ],
            'range'       => ['px' => ['min' => 0, 'max' => 10, ] ],
            'default'   => ['size' => 0],
            'selectors'   => [
                '{{WRAPPER}} .mk-page-titlebar:after' => 'height:{{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('border_space',[
            'label'       => esc_html__( 'Border Top Space', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em' ],
            'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
            'selectors'   => [
                '{{WRAPPER}} .mk-page-titlebar' => 'padding-bottom:{{SIZE}}{{UNIT}};',
            ],
        ]);

		$this->end_controls_section();

		// ------------------------------------------------------------------------------------------------

		mk_elem_start_ctrl($this, 'heading_title', 'Title');

              $this->add_control('show_title',[
                  'label'   => esc_html__( 'Show Post Title', 'orbius-core' ),
                  'type'    => \Elementor\Controls_Manager::SWITCHER,
                  'default' => 'yes',
              ]);

            $this->add_control( 'title_display_style', [
                'label' => esc_html__( 'Display Style', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                  'default' => 'Default',
                  'mask'    => 'Mask',
                  'stroke'  => 'Stroke'
                ],
                'default' => 'default',
                'condition' => ['show_title' => 'yes'],
            ]);

            $this->add_responsive_control('title_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'condition' => ['show_title' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-page-titlebar:not(.mk-titlebar-title-mask) h1.mk-titlebar-title,
                     {{WRAPPER}} .mk-titlebar-title-container' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('titlebar_color', [
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['show_title' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} h1.mk-titlebar-title,
                     {{WRAPPER}} .mk-titlebar-title-wrap' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(),[
                'name' => 'title_typography',
                'condition' => ['show_title' => 'yes'],
                'selector' => '{{WRAPPER}} h1.mk-titlebar-title,
                               {{WRAPPER}} .mk-titlebar-title-wrap',
            ]);

            $this->add_control('title_stroke_color',[
                'label' => esc_html__( 'Stroke Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition'=> ['title_display_style' => 'stroke','show_title' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-titlebar-title-stroke .mk-titlebar-title' => '-webkit-text-stroke-color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_stroke_width', [
                'label' => esc_html__( 'Stroke Width', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'default' => [
                    'size' => '1',
                    'unit' => 'px'
                ],
                'condition'=> ['title_display_style' => 'stroke','show_title' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-titlebar-title-stroke .mk-titlebar-title' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                ],
            ]);

            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none', '', ['title_display_style' => 'stroke','show_title' => 'yes'] );

		$this->end_controls_section();

		// ------------------------------------------------------------------------------------------------

		mk_elem_start_ctrl($this, 'heading_breadcrumbs', 'Breadcrumbs');

        $this->add_control('show_breadcrumbs',[
            'label'   => esc_html__( 'Show breadcrumbs', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

		  $admin_link = "admin.php?page=swm-theme-panel";
    		$this->add_control('set_permalinks', [
    			'type'            => \Elementor\Controls_Manager::RAW_HTML,
    			'raw'             => sprintf( __( 'Set Posts list and Portfolio list page from Admin > <a href="%s" target="_blank" rel="noopener">Theme Panel > Advanced Settings > Permalinks</a>.', 'orbius-core' ), $admin_link ),
    			'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
    			'condition' => ['show_breadcrumbs' => 'yes'],
    		]);

            $this->add_control('breadcrumbs_color', [
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['show_breadcrumbs' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .swm-breadcrumbs,
                     {{WRAPPER}} .swm-breadcrumbs a,
                     {{WRAPPER}} .swm-bc-sep:before' => 'color: {{VALUE}};',
                ],
              ]);

            $this->add_control('breadcrumbs_link_color', [
                'label' => esc_html__( 'Link Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['show_breadcrumbs' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .swm-breadcrumbs a' => 'color: {{VALUE}};',
                ],
              ]);

            $this->add_control('breadcrumbs_hover_color', [
                'label' => esc_html__( 'Link Hover Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['show_breadcrumbs' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .swm-breadcrumbs a:hover' => 'color: {{VALUE}};',
                ],
              ]);

            $this->add_control('separator_color', [
                'label' => esc_html__( 'Separator Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['show_breadcrumbs' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .swm-bc-sep:before' => 'color: {{VALUE}};',
                ],
              ]);

            $this->add_responsive_control('breadcrumbs_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'condition' => ['show_breadcrumbs' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .swm-breadcrumbs' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('breadcrumbs_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'condition' => ['show_breadcrumbs' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .swm-breadcrumbs' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name' => 'breadcrumb_typography',
                'fields_options' => [
                    'typography' => ['default' =>'custom', ],
                ],
                'condition' => ['show_breadcrumbs' => 'yes'],
                'selector' => '{{WRAPPER}} .swm-breadcrumbs',
            ]);

            mk_elem_hide_ctrl($this, 'breadcrumbs_responsive_hide', 'Hide Breadcrumbs At', 'mobile', '', ['show_breadcrumbs' => 'yes'] );

		$this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings_for_display();
		$show_title = $settings['show_title'];
		$show_breadcrumbs = $settings['show_breadcrumbs'];
        $title_text = '';
        if ( function_exists('swm_get_main_titles_text') ) {
            $title_text = swm_get_main_titles_text();
        }

        $bg_style = '';
        $img = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );

        if ( 'yes' === $settings['use_featured_image'] && !empty($img[0]) ) {
            $bg_style = 'style="background-image:url(' . $img[0] . ');"';
        }

        $appear_animation = ( 'yes' === $settings['appear_animation_on'] ) ? ' mk-scroll--load' : '';

		echo '<div class="mk-page-titlebar swm-anim mk-titlebar-title-' . $settings['title_display_style'] . $appear_animation . '" ' . $bg_style . '>
			<div class="mk-page-titlebar-content">';

		    	if ( 'yes' === $show_title ) {
			        do_action( 'mk_action_before_titlebar_title' );

                    if ( 'mask' == $settings['title_display_style'] ) {
                            echo '<div class="mk-titlebar-title-container swm-hide-'. $settings['title_responsive_hide'] . '">
                                    <div class="mk-titlebar-title-wrap">
                                        <svg class="mk-titlebar-title-svg" height="100" width="100">
                                            <mask id="' . $this->get_id() . '">
                                                <rect x="0" y="0" width="100%" height="100%" fill="#fff" />
                                                <text dominant-baseline="middle" x="0.35em" y="55%" class="mk-titlebar-title-svg-text" fill="#000">' . $title_text . '</text>
                                            </mask>
                                            <rect width="100%" height="100%" fill="currentColor" mask="url(#'.$this->get_id().')"/>
                                        </svg>
                                        <h1 class="mk-titlebar-title">' . $title_text . '</h1>
                                    </div>
                                </div>';
                    } else {
                        echo '<h1 class="mk-titlebar-title swm-hide-'. $settings['title_responsive_hide'] . '">' . $title_text . '</h1>';
                    }

			        do_action( 'mk_action_after_titlebar_title' );
		    	}

		    	if ( 'yes' === $show_breadcrumbs ) {
			        do_action( 'mk_action_before_titlebar_breadcrumbs' );
                    if ( function_exists('swm_breadcrumb_trail') ) {
			             echo swm_breadcrumb_trail($settings['breadcrumbs_responsive_hide']);
                    }
			        do_action( 'mk_action_after_titlebar_breadcrumbs' );
		    	}

		echo '</div>
            </div>';
	}
}