<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Popup extends \Elementor\Widget_Base {

    public function get_name()       { return 'mk_popup'; }
    public function get_title()      { return esc_html__( 'Popup', 'orbius-core' ); }
    public function get_icon()       { return 'mk-el-icon eicon-site-identity'; }
    public function get_categories() { return ['mk-sections-elements']; }
    public function get_keywords()   { return [ 'theme','panel','popup','box','window','lightbox' ]; }
    public function get_style_depends() { return [ 'mk-magnific-popup','mk-core-main' ]; }
    public function get_script_depends() { return [ 'magnific-popup','mk-widgets' ]; }

    protected function register_controls() {

        $is_edit_mode = mk_elm_is_edit_mode();

        mk_elem_start_ctrl($this, 'section_general', 'General');

            $theme_popup_sections = swm_mk_list_sections_styles('popup', 'ID');

            if ( $theme_popup_sections ) {
                $this->add_control('popup_section', [
                    'label' => esc_html__( 'Choose Popup Section', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::SELECT,
                    'options' => $theme_popup_sections,
                ]);
            } else {
                $this->add_control('popup_section', [
                    'type' => \Elementor\Controls_Manager::RAW_HTML,
                    'raw' => esc_html__( 'No custom sections were found. Create custom section from Dashboard &rarr; Sections &rarr; Add New. Select "Custom" from "Section Type" dropdown.', 'orbius-core' ),
                    'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
                ]);
            }

            $this->add_control('show_on', ['label' => esc_html__('Show on', 'orbius-core'),
                'label_block' => false,
                'description' => wp_kses_data( esc_html__('The event by which the popup should be displayed', 'orbius-core') ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => ! $is_edit_mode ? array() : [
                                                            'none'              => esc_html__('Do not show on page loads', 'orbius-core'),
                                                            'on_page_load'      => esc_html__('Every time the page loads', 'orbius-core'),
                                                            'on_page_load_once' => esc_html__('When the page first loads', 'orbius-core'),
                                                            'on_page_close'     => esc_html__('When leaving site', 'orbius-core'),
                                                        ],
                'default' => 'on_page_load',
            ]);

            $this->add_control('popup_bg_skin', [
                'label'        => esc_html__( 'Popup Background Skin', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default' => 'light',
                'options' => [  'light'  => esc_html__( 'Light', 'orbius-core' ),
                                'dark'   => esc_html__( 'Dark', 'orbius-core' ),
                             ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'close_style', 'Close Icon');

            $this->add_responsive_control('close_btn_size', [
                'label' => esc_html__( 'Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => ['min' => 6, 'max' => 100 ]
                ],
                'default' => ['size' => 30, 'unit' => 'px'],
                'selectors' => [
                    '.mk_sections_popup_{{ID}} button.mfp-close' => 'font-size: {{SIZE}}{{UNIT}}']
            ]);

            $this->add_control('close_btn_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#ffffff',
                'selectors' => [
                    '.mk_sections_popup_{{ID}} button.mfp-close' => 'color: {{VALUE}}'],
            ]);

            $this->add_responsive_control('close_btn_padding', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '.mk_sections_popup_{{ID}} button.mfp-close' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]);

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $popup_section = $settings['popup_section'];
        ob_start();

        if ( !empty($popup_section) && 'none' !== $settings['show_on'] ) :

            $this->add_render_attribute([
                'popup-attrs'       => [
                    'class'           => [
                                            'mk_sections_popup',
                                            'mk_sections_popup_' . $this->get_id(),
                                            'mk_sections_show_' . $settings['show_on']
                                        ],
                    'data-id'         => $this->get_id(),
                    'data-trigger-id' => $popup_section,
                    'id'              => $popup_section,
                    'data-skin'       => $settings['popup_bg_skin']
                ]
            ]);
            ?>
            <div <?php echo $this->get_render_attribute_string( 'popup-attrs' ); ?>>
                <div class="swm-popup-wrap">
                    <?php
                    $swm_section_id = swm_mk_get_custom_section_id('popup', $popup_section);
                    do_action( 'swm_action_show_section', $swm_section_id );
                    ?>
                </div>
            </div>

            <?php
        endif;

        $output = ob_get_contents();
        ob_end_clean();
        mk_add_inline_html($output);
        echo '<div class="mk_hidden"></div>';

        if ( \Elementor\Plugin::instance()->editor->is_edit_mode() ) { ?>
            <div class="swm-popup-editor-box"><i class="eicon-site-identity" aria-hidden="true"></i></div>
            <?php
        }

    }

}