<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Portfolio_Modern extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_portfolio_modern'; }
    public function get_title()          { return esc_html__( 'Portfolio - Main', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-gallery-grid'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'theme','grid', 'portfolio','gallery','images','portfolio grid','portfolio modern','photo' ]; }
    public function get_style_depends()  { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-gsap','mk-scroll-trigger','mk-modernizr','isotope','packery','mk-widgets' ]; }
    public function is_reload_preview_required() { return true; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'general_settings', 'General Settings');

            $this->add_control('content_position', [
                'label'              => esc_html__( 'Content Position', 'orbius-core' ),
                'type'               => \Elementor\Controls_Manager::SELECT,
                'default'            => 'below',
                'frontend_available' => true,
                'options'            => array(
                                            'above' => 'Above Image',
                                            'below' => 'Below Image',
                                            'over'  => 'Over Image',
                                            'hover-over' => 'Over on Hover Image'
                                        )
            ]);

            $this->add_responsive_control('columns', [
                'label'              => esc_html__( 'Columns', 'orbius-core' ),
                'type'               => \Elementor\Controls_Manager::SELECT,
                'default'            => '3',
                'tablet_default'     => '2',
                'mobile_default'     => '1',
                'prefix_class'       => 'elementor-grid%s-',
                'frontend_available' => true,
                'options'            => mk_arrays('columns8'),
            ]);

            $this->add_control('masonry_on',[
                'label'     => esc_html__( 'Masonry', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'default'   => 'no',
                'condition' => ['columns!' => '1']
            ]);

            $portfolio_single_start = '<a href="edit.php?post_type=portfolio" target="_blank">';
            $portfolio_single_end = '</a>';

            $this->add_control('custom_top_padding_on',[
                'label'        => esc_html__( 'Custom Padding', 'orbius-core' ),
                'description'  => sprintf( esc_html__( 'Apply custom portfolio items padding which you set in Admin > %sPortfolio%s > Portfolio Item > "Portfolio Options" metabox > Custom Padding.', 'orbius-core' ),$portfolio_single_start, $portfolio_single_end ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'default'      => 'no',
                'condition'    => ['masonry_on' => 'yes']
            ]);

            $this->add_control('parallax_on',[
                'label'   => esc_html__( 'Parallax Scroll Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_responsive_control('column_gap',[
                'label'     => esc_html__( 'Columns Gap', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => ['size' => 40, ],
                'range'     => ['px' => ['min' => 0, 'max' => 100, ], ],
                'condition'  => ['join_items_on!' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-grid-item-wrap' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
                    '{{WRAPPER}} .mk-grid-inner' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
                ],
            ]);

            $this->add_responsive_control('row_gap',[
                'label'     => esc_html__( 'Rows Gap', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => ['size' => 30, ],
                'range'     => ['px' => ['min' => 0, 'max' => 100, ], ],
                'condition'  => ['join_items_on!' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-grid-item-wrap' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_control('join_items_on',[
                'label'   => esc_html__( 'Join Items', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'prefix_class' => 'join-items-'
            ]);

            $this->add_control('hover_cursor_on',[
                'label'   => esc_html__( 'Hover Cursor Box', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_responsive_control('pf_item_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'condition'  => ['join_items_on' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-grid-item-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('pf_item_border', [
                'label'     => esc_html__( 'Border Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition'  => ['join_items_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-grid-item-wrap' => 'border:1px solid {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'posts_query_section', 'Query');

            $this->add_control('posts_per_page', [
                'label' => esc_html__( 'Posts Per Page', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 6,
                'step' => 1,
                'min' => 1,
                'max' => 1000,
            ]);

            $this->add_control('orderby', [
                'label'   => esc_html__( 'Order by', 'renix-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'date',
                'options' => mk_arrays('orderby')
            ]);

            $this->add_control('order', [
                'label'   => esc_html__( 'Order', 'renix-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'DESC',
                'options' => mk_arrays('order')
            ]);

            $this->add_control('additional_params', [
                'label'   => esc_html__( 'Additional Params', 'renix-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => mk_arrays('additional_params')
            ]);

            $this->add_control('include_posts_cat',[
                'label'    => esc_html__( 'Categories', 'renix-core' ),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => mk_get_categories('portfolio_category'),
                'condition'=> ['additional_params' => 'category']
            ]);

            $this->add_control('include_posts',[
                'label'    => esc_html__( 'Posts', 'renix-core' ),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => mk_portfolio_posts_list(),
                'condition'=> ['additional_params' => 'posts']
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'image_style', 'Image' );

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'      => 'post_img',
                'label'     => esc_html__( 'Image Size', 'orbius-core' ),
                'condition'  => [ 'masonry_on!' => 'yes' ],
                'default'   => 'full',
            ]);

            $this->add_control( 'masonry_img', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Image Size', 'orbius-core' ),
                'default'    => 'original',
                'condition'  => [ 'masonry_on' => 'yes' ],
                'description' => esc_html__( 'You can set "Packery" image sizes for each portfolio item from  Admin > Portfolio > Edit Portfolio Item > "Portfolio Options" metabox > "Image Orientation" meta field.', 'orbius-core' ),
                'options'    => [ 'original' => 'Original', 'packery' => 'Packery' ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'image_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-portfolio-image',
            ]);

            $this->add_control('image_hover_zoom',[
                'label'   => esc_html__( 'Hover Image Zoom Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => [ 'parallax_on!' => 'yes', 'masonry_on!' => 'yes' ],
                'prefix_class' => 'mk-portfolio-image-zoom-'
            ]);

            $this->add_responsive_control('image_radius',[
                'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-image,{{WRAPPER}} .mk-portfolio-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('image_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-portfolio-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(),[
                'name'      => 'image_shadow',
                'label'      => esc_html__( 'Box Shadow', 'orbius-core' ),
                'selector'  => '{{WRAPPER}} .mk-portfolio-image',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(),[
                'name'      => 'image_hover_shadow',
                'label'      => esc_html__( 'Hover Box Shadow', 'orbius-core' ),
                'selector'  => '{{WRAPPER}} .mk-portfolio-wrap:hover .mk-portfolio-image',
            ]);


        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'content_style', 'Content Box' );

            $this->add_control('content_width', [
                'label'        => esc_html__( 'Content Box Width', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'      => 'fullwidth',
                'prefix_class' => 'mk-portfolio-c-width-',
                'options' => [  'fullwidth' => esc_html__( 'Full Width', 'orbius-core' ),
                                'custom'    => esc_html__( 'Custom', 'orbius-core' ),
                             ]
            ]);

            $this->add_responsive_control('content_custom_width', [
                'label'     => esc_html__( 'Custom Width', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'default'   => ['size' => 200, ],
                'condition' => ['content_width' => 'custom' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-content' => 'width: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_responsive_control('content_custom_height', [
                'label'     => esc_html__( 'Content Box Height', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-content' => 'height: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_responsive_control('content_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'selectors'  => [
                    '{{WRAPPER}} .mk-portfolio-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('content_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-portfolio-content,
                    {{WRAPPER}} .mk-portfolio-modern .content-position--hover-over .mk-portfolio-image:before' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('content_bg',[
                'label'     => esc_html__( 'Background', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['content_position!' => 'hover-over'],
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-content' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_control('content_bg_hover',[
                'label'     => esc_html__( 'Background', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['content_position' => 'hover-over'],
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-modern .content-position--hover-over .mk-portfolio-content:after' => 'background: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styling', 'Title' );

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title Tag', 'renix-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h3',
            ]);

            $this->add_control('title_length', [
                'label'     => esc_html__( 'Title Text Length', 'renix-core' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'default'   => '100',
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-content .mk-portfolio-title,{{WRAPPER}} .mk-portfolio-content .mk-portfolio-title a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color',[
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-content .mk-portfolio-title a:hover' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_space',[
                'label'     => esc_html__( 'Space', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 100, ], ],
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-portfolio-content .mk-portfolio-title',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'subtitle_styling', 'Subtitle' );

            $this->add_control('show_subtitle',[
                'label'   => esc_html__( 'Show Subtitle', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('subtitle_type', [
                'label'   => esc_html__( 'Subtitle Type', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'category',
                'condition' => ['show_subtitle' => 'yes'],
                'prefix_class' => 'mk-pf-excerpt-',
                'options' => array(
                                'category' => 'Category',
                                'excerpt' => 'Excerpt'
                            ),
            ]);

            $this->add_control('excerpt_length', [
                'label'     => esc_html__( 'Excerpt Text Length', 'renix-core' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'default'   => '107',
                'condition' => ['subtitle_type' => 'excerpt'],
            ]);

            $this->add_control('excerpt_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['show_subtitle' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-content .mk-portfolio-subtitle' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'      => 'excerpt_typography',
                'condition' => ['show_subtitle' => 'yes'],
                'selector' => '{{WRAPPER}} .mk-portfolio-content .mk-portfolio-subtitle',
            ]);

        $this->end_controls_section();

        // Filter Styles
        mk_posts_filter_styles($this,false);

        // Pagination Styles
        mk_posts_pagination_styles($this,false);

    }

    public function get_holder_classes( $atts ) {

        $holder_classes   = array();
        $holder_classes[] = 'mk-p-grid';
        $holder_classes[] = 'mk-portfolio-modern';

        if ( isset($atts['parallax_on']) && '' !== $atts['parallax_on'] ) {
            $holder_classes[] = $atts['parallax_on'];
        }

        if ( isset($atts['masonry_on']) && 'yes' === $atts['masonry_on'] ) {
            $holder_classes[] = 'mk-p-masonry-on';
            if ( isset($atts['masonry_img']) && 'packery' === $atts['masonry_img'] ) {
                $holder_classes[] = 'mk-items--packery';
            }
        }

        if ( isset($atts['enable_filter']) && 'yes' === $atts['enable_filter'] ) {
            $holder_classes[] = 'mk-filter--on';
        }

        if ( ! empty( $atts['pagination_type'] ) ) {
            if ( 'no-pagination' === $atts['pagination_type'] ) {
                $holder_classes[] = 'mk--no-bottom-space';
                $holder_classes[] = 'mk-pagination--off';
            } else {
                $holder_classes[] = 'mk-pagination--on';
                $holder_classes[] = 'mk-pagination-type--' . $atts['pagination_type'];
            }
        }

        $holder_classes = implode( ' ', $holder_classes );

        return $holder_classes;
    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $atts = array();

        if ( '' !== $settings['hover_cursor_on'] ) {
            $atts['hover_cursor_on'] = $settings['hover_cursor_on'];
        }

        if ( isset($settings['parallax_on']) && 'yes' === $settings['parallax_on'] ) {
            $atts['parallax_on'] = 'mk-parallax-scroll-on';
        }

        $atts['portfolio_type'] = 'modern';

        if ( '' !== $settings['masonry_on'] ) {
            $atts['masonry_on']  = $settings['masonry_on'];
            $atts['masonry_img'] = $settings['masonry_img'];
        } else {
            $atts['masonry_on'] = 'off';
        }

        if ( '' !== $settings['enable_filter'] ) {
            $atts['enable_filter']   = $settings['enable_filter'];
            $atts['filter_all_text'] = $settings['filter_all_text'];
        }

        $atts['pagination_type'] = !empty($settings['pagination_type']) ? $settings['pagination_type'] : 'no-pagination';
        $atts['loadmore_button_text'] = ( isset($settings['loadmore_button_text']) && '' !== $settings['loadmore_button_text'] ) ? $settings['loadmore_button_text'] : '';

        // content
        $atts['title_tag']      = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h3';
        $atts['title_length']   = $settings['title_length'];

        if ( 'yes' === $settings['show_subtitle'] ) {
            $atts['show_subtitle']     = $settings['show_subtitle'];
            $atts['subtitle_type']     = $settings['subtitle_type'];
            $atts['excerpt_length']    = $settings['excerpt_length'];
        }

        // image
        $atts['post_img_size']             = $settings['post_img_size'];
        $atts['post_img_custom_dimension'] = $settings['post_img_custom_dimension'];

        if ( isset($settings['hover_cursor_on']) && 'yes' === $settings['hover_cursor_on'] ) {
            $atts['hover_cursor_on'] = $settings['hover_cursor_on'];
        }

        // query
        $atts['post_type']             = 'portfolio';
        $atts['taxonomy_filter']       = 'portfolio_category'; // tax_query [taxonomy => 'xxx']
        $atts['orderby']               = !empty($settings['orderby']) ? $settings['orderby'] : 'date';
        $atts['order']                 = !empty($settings['order']) ? $settings['order'] : 'DESC';
        $atts['posts_per_page']        = $settings['posts_per_page'];

        $atts['additional_params']     = $settings['additional_params'];
        $atts['include_posts_cat']     = $settings['include_posts_cat'];
        $atts['include_posts']         = $settings['include_posts'];

        $atts['custom_top_padding_on'] = $settings['custom_top_padding_on'];
        $atts['content_position']      = $settings['content_position'];
        $atts['additional_query_args'] = array();

        $atts['holder_classes']        = $this->get_holder_classes($atts); //$holder_classes;
        $atts['query_result']          = new \WP_Query( mk_get_query_params( $atts ) );
        $atts['data_attr']             = mk_get_pagination_data( 'post', $atts );
        $atts['this_shortcode']        = $this;

        mk_list_sc_template_part( 'grid/portfolio-main.php', $atts, true );

        if ( \Elementor\Plugin::instance()->editor->is_edit_mode() && 'yes' === $settings['masonry_on'] ) {
            $this->render_editor_script();
        }
    }

    protected function render_editor_script() { ?>
        <script type="text/javascript">
        (function ($) {
            "use strict";
            $(document).ready(function() {

                $('body').find('.mk-p-grid').each(function () {
                    var $this = $(this);
                    $this.find('.mk-grid-item').resize( function() {
                        mk.mkMasonryLayout.reInit();
                    });
                });

            });
        })(jQuery);
        </script>
            <?php
    }

}