<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Portfolio_Slider extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_portfolio_slider'; }
    public function get_title()          { return esc_html__( 'Portfolio Slider', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return [ 'mk-sliders-elements' ]; }
    public function get_keywords()       { return [ 'theme','slider','slide show','portfolio','gallery','horizontal' ]; }
    public function get_style_depends()  { return [ 'swiper','mk-core-main' ]; }
    public function get_script_depends() { return [ 'swiper','mk-widgets' ]; }
    public function is_reload_preview_required() { return true; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_heading', 'Slider Items');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title_text', [
                'label'       => esc_html__( 'Title', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('ocean shine','orbius-core')
            ]);

            $repeater->add_control('services_list', [
                'label'       => esc_html__( 'Services', 'orbius-core' ),
                'description' => esc_html__( 'List the services separated by commas.', 'orbius-core' ),
                'default'     => esc_html__('web design,marketing,animation','orbius-core'),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
            ]);

            $repeater->add_control('project_image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'before',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $this->add_control('slider_items', [
                'label' => esc_html__( 'Slider Items', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title_text }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_items_settings', 'Slider Settings');

        $this->add_control('pf_style', [
            'label'   => esc_html__( 'Display Style', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'default' => 'st1',
            'prefix_class' => 'mk-pf-slider-',
            'options' => array(
                            'st1' => 'Style 1',
                            'st2' => 'Style 2',
                        )
        ]);

        $slides_per_view = range( 1, 5 );
        $slides_per_view = array_combine( $slides_per_view, $slides_per_view );

        $this->add_responsive_control('slides_per_view',[
            'type'                  => \Elementor\Controls_Manager::SELECT,
            'label'                 => esc_html__( 'Slides Per View', 'estra-core' ),
            'options'               => $slides_per_view,
            'default'               => '4',
            'tablet_default'        => '2',
            'mobile_default'        => '1',
            'frontend_available'    => true,
        ]);

        $this->add_control('slide_space', [
            'label' => esc_html__( 'Slide Space', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 40,
            'step' => 1,
            'min' => 0,
            'max' => 1000,
        ]);

        $this->add_control('arrows_on',[
            'label'   => esc_html__( 'Arrow Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('dots_on',[
            'label'   => esc_html__( 'Dots Navigation', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('loop_on',[
            'label'   => esc_html__( 'Continuous Loop', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('mousewheel_on',[
            'label'   => esc_html__( 'Mousewheel Control', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('autoplay_on',[
            'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('drag_icon_on',[
            'label'   => esc_html__( 'Hover Drag Icon', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('hover_pause_on',[
            'label'   => esc_html__( 'Pause on Hover', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'condition' => ['autoplay_on' => 'yes']
        ]);

        $this->add_control('autoplay_speed', [
            'label' => esc_html__( 'Delay', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 5000,
            'step' => 100,
            'min' => 100,
            'max' => 15000,
        ]);

        $this->add_control('speed', [
            'label' => esc_html__( 'Animation Speed', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 1000,
            'step' => 100,
            'min' => 100,
            'max' => 5000,
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_slider_style', 'Slider Holder', true);

            $this->add_responsive_control('sliderheight',[
                'label'       => esc_html__( 'Slider Height', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px' ],
                'range'       => ['px' => ['min' => 0, 'max' => 2000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-portfolio-slider .mk-swiper-item' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('slider_background', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-slider' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('item_padding', [
                    'label' => esc_html__( 'Items Padding', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-portfolio-slider .mk-swiper-item .mk-portfolio-slider-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_image_style', 'Image', true);

        $this->add_control('image_hover_zoom',[
            'label'   => esc_html__( 'Hover Image Zoom Effect', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
            'prefix_class' => 'mk-portfolio-image-zoom-'
        ]);

        $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
            'name'                  => 'slider_image_size',
            'label'                 => esc_html__( 'Background Image Size', 'orbius-core' ),
            'default'               => 'full',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_content_style', 'Content Section', true);

            $this->add_responsive_control('content_padding', [
                    'label' => esc_html__( 'Padding', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', 'em', '%' ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-pf-slider-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_style', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'label'      => esc_html__( 'Title Typography', 'orbius-core' ),
                'selector' => '{{WRAPPER}} .mk-portfolio-slider .mk-pf-slider-title,{{WRAPPER}} .mk-portfolio-slider .mk-pf-slider-title a',
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-pf-slider-title' => 'margin:0;',
                ],
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-slider .mk-pf-slider-title,
                    {{WRAPPER}} .mk-portfolio-slider .mk-pf-slider-title a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-slider .mk-pf-slider-title:hover a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'default' => [
                        'top' => '0',
                        'right' => '0',
                        'bottom' => '0',
                        'left' => '0',
                        'isLinked' => true,
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .mk-portfolio-slider .mk-pf-slider-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'subtitle_style', 'Services', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .mk-portfolio-slider ul.mk-pf-slider-services li',
            ]);

            $this->add_control('subtitle_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-slider ul.mk-pf-slider-services li' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('subtitle_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mk-portfolio-slider ul.mk-pf-slider-services' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_dots_style', 'Slider Navigation', true );

            $this->add_control('nav_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#000000',
                'selectors' => [
                     '{{WRAPPER}} .mk-portfolio-slider .mk-slider-pn,
                     {{WRAPPER}}.mk-pf-slider-st2 .mk-portfolio-slider-holder .mk-slider-pn' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mk-portfolio-slider .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-color: {{VALUE}};',
                    '{{WRAPPER}} .mk-portfolio-slider .swiper-pagination-bullet:before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .mk-portfolio-slider .mk-slider-pn' => 'fill: {{VALUE}}; border-color:{{VALUE}}',
                ],
            ]);

            $this->add_responsive_control('nav_horizontal_offset',[
                'label'       => esc_html__( 'Horizontal Offset', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px','%' ],
                'range'       => ['px' => ['min' => -1000, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-portfolio-slider .mk-slider-prev' => 'left:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-portfolio-slider .mk-slider-next' => 'right:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none');
            mk_elem_hide_ctrl($this, 'services_responsive_hide', 'Hide Services List At', 'none');
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrows Navigation At', 'none');
            mk_elem_hide_ctrl($this, 'dots_responsive_hide', 'Hide Dot Navigation At', 'tablet');
        $this->end_controls_section();

    }

    public function services_list($services) {
        $services_list = '';
        $services = explode(",", $services);

        foreach ( $services as $service ) {
            $services_list .= '<li>' . $service . '</li>';
        }
        return $services_list;
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $sliderSettings = array(
            'direction'              => 'horizontal',
            'parallax'               => 'no',
            'effect'                 => 'slide',
            'arrows_on'              => $settings['arrows_on'],
            'dots'                   => $settings['dots_on'],
            'autoplay'               => $settings['autoplay_on'],
            'autoplay_speed'         => $settings['autoplay_speed'],
            'speed'                  => $settings['speed'],
            'mousewheel'             => $settings['mousewheel_on'],
            'loop'                   => $settings['loop_on'],
            'pause_on_hover'         => $settings['hover_pause_on'],
            'slides_to_show'         => $settings['slides_per_view'],
            'slides_to_show_tablet'  => $settings['slides_per_view_tablet'],
            'slides_to_show_mobile'  => $settings['slides_per_view_mobile'],
            'slider_next'            => '.mk-slider-next',
            'slider_prev'            => '.mk-slider-prev',
            'slider_pagination'      => '.swiper-pagination',
            'centered_slides'        => 'no',
            'video'                  => 'no',
            'image_spacing'          => array(
                                            'unit' => 'px',
                                            'size' => $settings['slide_space'],
                                            'sizes' => []
                                        ),
        );

        $this->add_render_attribute( [
            'slider-attrs'  => [
                'class'          => [ 'swiper', 'swiper-container','mk-portfolio-slider' ],
                'data-settings'  => json_encode( $sliderSettings ),
                'id'             => 'swiper-' .$this->get_id()
            ]
        ] );

        $slideHTML = '';

        $i = 1;

        foreach ( $settings['slider_items'] as $index => $item ) :

            $desc = $project_image = $link_start = $link_end = $title = $bg_image = $services_list = $imageTagHtml = $sliderContent = $image_link = '';

            // link
            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';

                $this->add_render_attribute( $link_key, 'class', 'mk-pf-slider-image-link' );

                $image_link .= '<a ' . $this->get_render_attribute_string( $link_key ) . '></a>';
            }

            // image
            if (  $settings['slider_image_size_size'] == 'custom' ) {
                $imageGetTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $item['project_image'], $item['project_image']['id'], 'slider_image_size', 'slider_img-'.$i).' />';
            } else {
                $imageGetTagHtml = wp_get_attachment_image( $item['project_image']['id'], $settings['slider_image_size_size']);
            }
            $imageTagHtml .= $imageGetTagHtml;

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            if ( ! empty( $item['title_text'] ) ) {
                $title .= '<'.$titleTagSelector.' class="mk-pf-slider-title swm-hide-'. $settings['title_responsive_hide'] .'">' . $link_start . $item['title_text'] . $link_end . '</'.$titleTagSelector . '>';
            }

            if ( ! empty( $item['services_list'] ) ) {
                $services_list .= '<ul class="mk-pf-slider-services swm-hide-'. $settings['services_responsive_hide'] .'">' . $this->services_list($item['services_list']) . '</ul>';
            }

            $sliderContent .= '<div class="mk-pf-slider-content">
                    <div class="mk-pf-slider-title-subtitle">' . $title . $services_list . '</div>
            </div>';

            $bg_image  .= '<div class="mk-portfolio-slider-img-holder">
                                <div class="mk-portfolio-slider-img">' . $imageTagHtml . $image_link . '</div>'
                                . $sliderContent . '
                            </div>';
            $slideHTML .= '<div class="mk-swiper-item swiper-slide"><div class="mk-portfolio-slider-wrapper">' . $bg_image . '</div></div>';

            $i++;
        endforeach;

        $dotNavigation = $arrowLeft = $arrowRight = $navigation = '';

        if ( 'yes' === $settings['arrows_on'] || 'yes' === $settings['dots_on'] ) {

            // arrow navigation
            if ( 'yes' === $settings['arrows_on'] ) {

                $arrowLeft = '<div class="mk-slider-pn mk-slider-prev swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-pf-slider-arrow' ) . '</div>';
                $arrowRight = '<div class="mk-slider-pn mk-slider-next swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-pf-slider-arrow' ) . '</div>';
            }

            // dot navigation
            if ( 'yes' === $settings['dots_on'] ) {
                $dotNavigation =  '<div class="mk-portfolio-slider-navigation swm-hide-'. $settings['dots_responsive_hide']  . ' arrow-nav-' . $settings['arrows_on'] . '"><div class="mk-ps-dots-navigation"><div class="swiper-pagination"></div></div></div>';
            }

            $navigation = $arrowLeft . $arrowRight . $dotNavigation;

        }

        $drag_icon = ( 'yes' === $settings['drag_icon_on'] ) ? ' mk--drag-cursor' : '';

        echo '<div class="mk-portfolio-slider-holder">
                <div ' . $this->get_render_attribute_string( 'slider-attrs' ) . '>
                    <div class="swiper-wrapper' . $drag_icon . '">' . $slideHTML . '</div>
                    ' . $navigation . '
                </div>
        </div>';

    }

}