<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Portfolio_Tooltip extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_portfolio_tooltip'; }
    public function get_title()          { return esc_html__( 'Portfolio - Tooltip', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-gallery-grid'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'theme','grid', 'portfolio','gallery','images','portfolio grid','portfolio tooltip','photo' ]; }
    public function get_style_depends()  { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-gsap','mk-scroll-trigger','mk-modernizr','isotope','packery','tweenmax','mk-widgets' ]; }
    public function is_reload_preview_required() { return true; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'general_settings', 'General Settings');

            $this->add_responsive_control('columns', [
                'label'              => esc_html__( 'Columns', 'orbius-core' ),
                'type'               => \Elementor\Controls_Manager::SELECT,
                'default'            => '3',
                'tablet_default'     => '2',
                'mobile_default'     => '1',
                'prefix_class'       => 'elementor-grid%s-',
                'frontend_available' => true,
                'options'            => mk_arrays('columns8'),
            ]);

            $this->add_control('masonry_on',[
                'label' => esc_html__( 'Masonry', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition'  => ['columns!' => '1'],
            ]);

            $portfolio_single_start = '<a href="edit.php?post_type=portfolio" target="_blank">';
            $portfolio_single_end = '</a>';

            $this->add_control('custom_top_padding_on',[
                'label'        => esc_html__( 'Custom Padding', 'orbius-core' ),
                'description'  => sprintf( esc_html__( 'Apply custom portfolio items padding which you set in Admin > %sPortfolio%s > Portfolio Item > "Portfolio Options" metabox > Custom Padding.', 'orbius-core' ),$portfolio_single_start, $portfolio_single_end ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'default'      => 'no',
                'condition'    => ['masonry_on' => 'yes']
            ]);

            $this->add_control('parallax_on',[
                'label'   => esc_html__( 'Parallax Scroll Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_responsive_control('column_gap',[
                'label'     => esc_html__( 'Columns Gap', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => ['size' => 30, ],
                'range'     => ['px' => ['min' => 0, 'max' => 100, ], ],
                'selectors' => [
                    '{{WRAPPER}} .mk-grid-item-wrap' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
                    '{{WRAPPER}} .mk-grid-inner' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
                ],
            ]);

            $this->add_responsive_control('row_gap',[
                'label'     => esc_html__( 'Rows Gap', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => ['size' => 30, ],
                'range'     => ['px' => ['min' => 0, 'max' => 100, ], ],
                'selectors' => [
                    '{{WRAPPER}} .mk-grid-item-wrap' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'posts_query_section', 'Query');

            $this->add_control('posts_per_page', [
                'label' => esc_html__( 'Posts Per Page', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 6,
                'step' => 1,
                'min' => 1,
                'max' => 1000,
            ]);

            $this->add_control('orderby', [
                'label'   => esc_html__( 'Order by', 'renix-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'date',
                'options' => mk_arrays('orderby')
            ]);

            $this->add_control('order', [
                'label'   => esc_html__( 'Order', 'renix-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'DESC',
                'options' => mk_arrays('order')
            ]);

            $this->add_control('additional_params', [
                'label'   => esc_html__( 'Additional Params', 'renix-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => mk_arrays('additional_params')
            ]);

            $this->add_control('include_posts_cat',[
                'label'    => esc_html__( 'Categories', 'renix-core' ),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => mk_get_categories('portfolio_category'),
                'condition'=> ['additional_params' => 'category']
            ]);

            $this->add_control('include_posts',[
                'label'    => esc_html__( 'Posts', 'renix-core' ),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => mk_portfolio_posts_list(),
                'condition'=> ['additional_params' => 'posts']
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'image_style', 'Image');

            $this->add_control('appear_animation', [
                'label'   => esc_html__( 'Image Appear Animation', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'condition' => ['masonry_on!' => 'yes'],
                'options' => [
                                ''       => 'None',
                                'fade'   => 'Fade',
                                'reveal' => 'Reveal'
                            ],
            ]);

            $this->add_control( 'appear_delay', [
                'label' => esc_html__( 'Appear Delay', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    ''       => esc_html__( 'Default', 'orbius-core' ),
                    'random' => esc_html__( 'Random', 'orbius-core' ),
                    'ms'     => esc_html__( 'Set ms', 'orbius-core' ),
                ],
                'condition' => ['appear_animation!' => '']
            ]);

            $this->add_control('appear_delay_in_ms', [
                'label' => esc_html__( 'Set Appear Delay', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 100,
                'step' => 5,
                'min' => 100,
                'max' => 9999,
                'condition' => ['appear_animation!' => '','appear_delay' => 'ms']
            ]);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'      => 'post_img',
                'label'     => esc_html__( 'Image Size', 'orbius-core' ),
                'condition'  => [ 'masonry_on!' => 'yes' ],
                'default'   => 'full',
            ]);

            $this->add_control( 'masonry_img', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Image Size', 'orbius-core' ),
                'default'    => 'original',
                'condition'  => [ 'masonry_on' => 'yes' ],
                'description' => esc_html__( 'You can set "Packery" image sizes for each portfolio item from  Admin > Portfolio > Edit Portfolio Item > "Portfolio Options" metabox > "Image Orientation" meta field.', 'orbius-core' ),
                'options'    => [ 'original' => 'Original', 'packery' => 'Packery' ],
            ]);

            $this->add_control('image_hover_zoom',[
                'label'   => esc_html__( 'Hover Image Zoom Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => [ 'parallax_on!' => 'yes', 'masonry_on!' => 'yes' ],
                'prefix_class' => 'mk-portfolio-image-zoom-'
            ]);

            $this->add_control('image_hover_shrink',[
                'label'   => esc_html__( 'Hover Shrink Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'prefix_class' => 'mk-portfolio-image-shrink-'
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'content_box_styling', 'Content Box');

            $this->add_responsive_control('content_box_width',[
                'label'     => esc_html__( 'Width', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'selectors' => [
                    '.mk-portfolio-tooptip-box-{{ID}}' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Background::get_type(),[
                'name'     => 'content_box_bg',
                'label'    => esc_html__( 'Background', 'orbius-core' ),
                'types'    => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-wrap,
                                .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-wrap',
            ]);

            $this->add_control('content_box_bg_blur_level', [
                'label'      => esc_html__( 'Background Blur Level', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'range'      => ['px' => ['min'  => 0, 'max'  => 50, 'step' => 1]],
                'selectors'  => ['.mk-portfolio-tooptip-box-{{ID}} .mk-portfolio-tooltip-box-wrap,
                                  .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-wrap' => '-webkit-backdrop-filter: blur({{SIZE}}px); backdrop-filter: blur({{SIZE}}px);'],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Border::get_type(), [
                'name'      => 'item_border',
                'label'     => esc_html__( 'Border', 'renix-core' ),
                'selector'  => '.mk-portfolio-tooptip-box-{{ID}} .mk-portfolio-tooltip-box-wrap,
                                .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-wrap',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styling', 'Title');

            $this->add_control('title_length', [
                'label'     => esc_html__( 'Title Text Length', 'renix-core' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'default'   => '100',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} h4.mk-portfolio-title a,
                    .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-title a',
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} h4.mk-portfolio-title a,
                    .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-title a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-portfolio-tooltip-box-title,
                    .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'subtitle_styling', 'Subtitle');

            $this->add_control('show_subtitle',[
                'label'   => esc_html__( 'Show Subtitle', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('subtitle_type', [
                'label'   => esc_html__( 'Subtitle Type', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'category',
                'condition' => ['show_subtitle' => 'yes'],
                'prefix_class' => 'mk-pf-tooltip-subtitle-',
                'options' => array(
                                'category' => 'Category',
                                'excerpt' => 'Excerpt'
                            ),
            ]);

            $this->add_control('excerpt_length', [
                'label'     => esc_html__( 'Excerpt Text Length', 'renix-core' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'default'   => '107',
                'condition' => ['subtitle_type' => 'excerpt'],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'           => 'excerpt_typography',
                'condition' => ['show_subtitle' => 'yes'],
                'selector' => '{{WRAPPER}} .mk-portfolio-subtitle,
                .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-subtitle',
            ]);

            $this->add_control('excerpt_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['show_subtitle' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-portfolio-subtitle,
                    .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-subtitle' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mk-portfolio-tooptip-box,
                    .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-subtitle:before' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('subtitle_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'condition' => ['show_subtitle' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-portfolio-tooltip-box-title,
                    .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-subtitle' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('subtitle_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'condition' => ['show_subtitle' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-portfolio-tooltip-box-title,
                    .mk-portfolio-tooptip-box-{{ID}}.mk-portfolio-tooptip-box .mk-portfolio-tooltip-box-subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        // Filter Styles
        mk_posts_filter_styles($this,false);

        // Pagination Styles
        mk_posts_pagination_styles($this,false);

    }

    public function get_holder_classes( $atts ) {

        $holder_classes   = array();
        $holder_classes[] = 'mk-p-grid';
        $holder_classes[] = 'mk-portfolio-tooltip';

        if ( isset($atts['parallax_on']) && '' !== $atts['parallax_on'] ) {
            $holder_classes[] = $atts['parallax_on'];
        }

        if ( isset($atts['masonry_on']) && 'yes' === $atts['masonry_on'] ) {
            $holder_classes[] = 'mk-p-masonry-on';
            if ( isset($atts['masonry_img']) && 'packery' === $atts['masonry_img'] ) {
                $holder_classes[] = 'mk-items--packery';
            }
        }

        if ( isset($atts['enable_filter']) && 'yes' === $atts['enable_filter'] ) {
            $holder_classes[] = 'mk-filter--on';
        }

        if ( ! empty( $atts['pagination_type'] ) ) {
            if ( 'no-pagination' === $atts['pagination_type'] ) {
                $holder_classes[] = 'mk--no-bottom-space';
                $holder_classes[] = 'mk-pagination--off';
            } else {
                $holder_classes[] = 'mk-pagination--on';
                $holder_classes[] = 'mk-pagination-type--' . $atts['pagination_type'];
            }
        }

        $holder_classes = implode( ' ', $holder_classes );

        return $holder_classes;
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $atts = array();

        $atts['parallax_on'] = '';

        if ( isset($settings['parallax_on']) && 'yes' === $settings['parallax_on'] ) {
            $atts['parallax_on'] = 'mk-parallax-scroll-on';
        }

        $atts['portfolio_type'] = 'tooltip';

        if ( '' !== $settings['masonry_on'] ) {
            $atts['masonry_on']  = $settings['masonry_on'];
            $atts['masonry_img'] = $settings['masonry_img'];
        } else {
            $atts['masonry_on'] = 'off';
        }

        if ( '' !== $settings['enable_filter'] ) {
            $atts['enable_filter']   = $settings['enable_filter'];
            $atts['filter_all_text'] = $settings['filter_all_text'];
        }

        $atts['pagination_type'] = !empty($settings['pagination_type']) ? $settings['pagination_type'] : 'no-pagination';
        $atts['loadmore_button_text'] = ( isset($settings['loadmore_button_text']) && '' !== $settings['loadmore_button_text'] ) ? $settings['loadmore_button_text'] : '';

        // content
        $atts['title_length']   = $settings['title_length'];

        if ( 'yes' === $settings['show_subtitle'] ) {
            $atts['show_subtitle']     = $settings['show_subtitle'];
            $atts['subtitle_type']     = $settings['subtitle_type'];
            $atts['excerpt_length']    = $settings['excerpt_length'];
        }

        // image
        $atts['post_img_size']             = $settings['post_img_size'];
        $atts['post_img_custom_dimension'] = $settings['post_img_custom_dimension'];
        $atts['appear_animation']      = ( isset($settings['appear_animation']) && '' !== $settings['appear_animation'] ) ? $settings['appear_animation'] : '';

        // appear delay
        $appear_animation = '';
        if ('' != $atts['appear_animation']) {
            if ( 'ms' === $settings['appear_delay'] && $settings['appear_delay_in_ms'] >= 0 ) {
                $appear_animation = ' data-appear-delay="'.$settings['appear_delay_in_ms'].'"';
            } elseif ( 'random' === $settings['appear_delay'] ) {
                $appear_animation = ' data-appear-delay="'.$settings['appear_delay'].'"';
            }
        }
        $atts['appear_delay'] = $appear_animation;

        // query
        $atts['post_type']             = 'portfolio';
        $atts['taxonomy_filter']       = 'portfolio_category'; // tax_query [taxonomy => 'xxx']
        $atts['orderby']               = !empty($settings['orderby']) ? $settings['orderby'] : 'date';
        $atts['order']                 = !empty($settings['order']) ? $settings['order'] : 'DESC';
        $atts['posts_per_page']        = $settings['posts_per_page'];

        $atts['additional_params']     = $settings['additional_params'];
        $atts['include_posts_cat']     = $settings['include_posts_cat'];
        $atts['include_posts']         = $settings['include_posts'];

        $atts['custom_top_padding_on'] = $settings['custom_top_padding_on'];
        $atts['additional_query_args'] = array();

        $atts['holder_classes']        = $this->get_holder_classes($atts); //$holder_classes;
        $atts['query_result']          = new \WP_Query( mk_get_query_params( $atts ) );
        $atts['data_id']               = $this->get_id();
        $atts['data_attr']             = mk_get_pagination_data( 'post', $atts );
        $atts['this_shortcode']        = $this;

        mk_list_sc_template_part( 'grid/portfolio-main.php', $atts, true );

        if ( \Elementor\Plugin::instance()->editor->is_edit_mode() && 'yes' === $settings['masonry_on'] ) {
            $this->render_editor_script();
        }
    }

    protected function render_editor_script() { ?>
        <script type="text/javascript">
        (function ($) {
            "use strict";
            $(document).ready(function() {

                $('body').find('.mk-p-grid').each(function () {
                    var $this = $(this);
                    $this.find('.mk-grid-item').resize( function() {
                        mk.mkMasonryLayout.reInit();
                    });
                });

            });
        })(jQuery);
        </script>
            <?php
    }

}