<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Post_Single_Pagination extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_post_single_pagination'; }
    public function get_title()          { return esc_html__( 'Post Single Pagination', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-navigation-horizontal'; }
    public function get_categories()     { return ['mk-general-elements']; }
    public function get_keywords()       { return [ 'pagination', 'next','prev','project' ]; }
    public function get_style_depends()  { return ['mk-core-main']; }
    public function get_script_depends() { return ['mk-widgets' ]; }

    protected function register_controls() {
        mk_elem_start_ctrl($this, 'general_settings', 'General');

            $this->add_control('post_order', [
                'label'   => esc_html__( 'Post Order', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [  'asc' => esc_html__( 'Ascending', 'orbius-core' ),
                                'desc' => esc_html__( 'Descending', 'orbius-core' ),
                             ]
            ]);

            $this->add_control('post_title_type', [
                'label'   => esc_html__( 'Prev/Next Titles', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'post_names',
                'options' => [  'post_names' => esc_html__( 'Post Names', 'orbius-core' ),
                                'custom'     => esc_html__( 'Custom', 'orbius-core' ),
                             ]
            ]);

            $this->add_control('prev_post_on',[
                'label'   => esc_html__( 'Previous Post', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('prev_post_text', [
                'label'       => esc_html__( 'Previous Post Text', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'condition'   => ['prev_post_on' => 'yes','post_title_type' => 'custom' ],
                'default'     => esc_html__('prev post','orbius-core')
            ]);

            $this->add_control('next_post_on',[
                'label'   => esc_html__( 'Next Post', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('next_post_text', [
                'label'       => esc_html__( 'Next Post Text', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'condition'   => ['next_post_on' => 'yes','post_title_type' => 'custom'],
                'default'     => esc_html__('next post','orbius-core')
            ]);

            $this->add_control('link', [
                'label'       => esc_html__( 'Thumbnail Icon Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'separator'   => 'before',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
                'default'  => [
                    'url'         => '#',
                    'is_external' => '',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_style', 'Navigation Text',true);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-ps-pagination-next a,{{WRAPPER}} .mk-ps-pagination-prev a',
            ]);

            $this->add_control('title_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ps-pagination-next a,
                    {{WRAPPER}} .mk-ps-pagination-prev a' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color',[
                'label' => esc_html__( 'Hover Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ps-pagination-next a:hover,
                    {{WRAPPER}} .mk-ps-pagination-prev a:hover' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('arrow_size', [
                'label'   => esc_html__( 'Arrow Size', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['min' => 0, 'max' => 250],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-ps-pagination-np svg' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('arrow_spacing', [
                'label'   => esc_html__( 'Arrow Spacing', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['min' => 0, 'max' => 250],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-ps-pagination-next svg' => 'margin-left:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-ps-pagination-prev svg' => 'margin-right:{{SIZE}}{{UNIT}};'
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'icon_style', 'Thumbnail Icon',true);

            $this->add_responsive_control('thumbnail_icon_size', [
                'label'   => esc_html__( 'Size', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['min' => 0, 'max' => 250],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-ps-pagination-thumbnails' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('icon_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ps-pagination-thumbnails svg' => 'fill: {{VALUE}};',
                ],
            ]);

            $this->add_control('icon_hover_color',[
                'label' => esc_html__( 'Hover Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ps-pagination-thumbnails:hover svg' => 'fill: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings',true);
            mk_elem_hide_ctrl($this, 'text_responsive_hide', 'Hide Next Previous Post At', 'none' );
            mk_elem_hide_ctrl($this, 'icon_responsive_hide', 'Hide Thumbnail Icon At', 'none' );
        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $swm_prev_post = ( 'asc' === $settings['post_order'] ) ? get_previous_post() : get_next_post();
        $swm_next_post = ( 'asc' === $settings['post_order'] ) ? get_previous_post() : get_next_post();

        if ( 'asc' === $settings['post_order'] ) {
            $swm_prev_post = get_previous_post();
            $swm_next_post = get_next_post();
        } else {
            $swm_prev_post = get_next_post();
            $swm_next_post = get_previous_post();
        }

        $prevPost = $nextPost = $thumbnail = '';

        if ( ! empty( $settings['link']['url'] ) ) {

            $this->add_render_attribute( 'thumbnail_url', 'href', $settings['link']['url'] );

            if ( $settings['link']['is_external'] ) {
                $this->add_render_attribute( 'thumbnail_url', 'target', '_blank' );
            }

            if ( $settings['link']['nofollow'] ) {
                $this->add_render_attribute( 'thumbnail_url', 'rel', 'nofollow' );
            }

            $thumbnail = ( ( 'yes' === $settings['prev_post_on'] && !empty($swm_prev_post) ) && ( 'yes' === $settings['next_post_on'] && !empty($swm_next_post) ) ) ? '<div class="mk-ps-pagination-thumbnails swm-hide-'. $settings['icon_responsive_hide'] .'"><a ' . $this->get_render_attribute_string( 'thumbnail_url' ) . '><span></span><span></span></a></div>' : '';
        }

        if ( 'yes' === $settings['prev_post_on'] && !empty($swm_prev_post) ) {

            if ( $settings['post_title_type'] === 'post_names' ) {
                $prevPostTitle = $swm_prev_post->post_title;
            } else {
                $prevPostTitle = $settings['prev_post_text'];
            }

            $prevPost = '<div class="mk-ps-pagination-prev mk-ps-pagination-np swm-hide-'. $settings['text_responsive_hide'] .'"><a href="'.get_permalink( $swm_prev_post->ID ).'"><span>' . $prevPostTitle . '</span></a></div>';
        }

        if ( 'yes' === $settings['next_post_on'] && !empty($swm_next_post) ) {

            if ( $settings['post_title_type'] === 'post_names' ) {
                $nextPostTitle = $swm_next_post->post_title;
            } else {
                $nextPostTitle = $settings['next_post_text'];
            }

            $nextPost = '<div class="mk-ps-pagination-next mk-ps-pagination-np swm-hide-'. $settings['text_responsive_hide'] .'"><a href="'.get_permalink( $swm_next_post->ID ).'"><span>' . $nextPostTitle . '</span></a></div>';
        }

        $firstLastPost = ( empty($swm_next_post) || empty($swm_prev_post) ) ? ' firstLastPost' : '';

        echo '<div class="mk-post-single-pagination' .$firstLastPost .'">
                ' . $prevPost . $thumbnail . $nextPost . '
            </div>';

    }

}