<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Pricing_Table extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_pricing_table'; }
    public function get_title()          { return esc_html__( 'Price Table', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-price-table'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'price table','pricing', 'price', 'table','box','package' ]; }
    public function get_style_depends()  { return ['mk-core-main']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_title', 'Title');

        $this->add_control('table_title', [
            'label'       => esc_html__( 'Title', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => esc_html__( 'standard package', 'orbius-core' ),
            'title'       => esc_html__( 'Enter table title', 'orbius-core' ),
            'label_block' => 'true'
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_pricing', 'Pricing');

		$this->add_control('currency_symbol', [
			'label'                 => esc_html__( 'Currency Symbol', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SELECT,
			'options'               => [
				'none'             => esc_html__( 'None', 'orbius-core' ),
				'dollar'       => '&#36; ' . esc_html__( 'Dollar', 'orbius-core' ),
				'euro'         => '&#128; ' . esc_html__( 'Euro', 'orbius-core' ),
				'baht'         => '&#3647; ' . esc_html__( 'Baht', 'orbius-core' ),
				'franc'        => '&#8355; ' . esc_html__( 'Franc', 'orbius-core' ),
				'guilder'      => '&fnof; ' . esc_html__( 'Guilder', 'orbius-core' ),
				'krona'        => 'kr ' . esc_html__( 'Krona', 'orbius-core' ),
				'lira'         => '&#8356; ' . esc_html__( 'Lira', 'orbius-core' ),
				'peseta'       => '&#8359 ' . esc_html__( 'Peseta', 'orbius-core' ),
				'peso'         => '&#8369; ' . esc_html__( 'Peso', 'orbius-core' ),
				'pound'        => '&#163; ' . esc_html__( 'Pound Sterling', 'orbius-core' ),
				'real'         => 'R$ ' . esc_html__( 'Real', 'orbius-core' ),
				'ruble'        => '&#8381; ' . esc_html__( 'Ruble', 'orbius-core' ),
				'rupee'        => '&#8360; ' . esc_html__( 'Rupee', 'orbius-core' ),
				'indian_rupee' => '&#8377; ' . esc_html__( 'Rupee (Indian)', 'orbius-core' ),
				'shekel'       => '&#8362; ' . esc_html__( 'Shekel', 'orbius-core' ),
				'yen'          => '&#165; ' . esc_html__( 'Yen/Yuan', 'orbius-core' ),
				'won'          => '&#8361; ' . esc_html__( 'Won', 'orbius-core' ),
				'custom'       => esc_html__( 'Custom', 'orbius-core' ),
			],
			'default'               => 'dollar',
		]);

        $this->add_control('currency_symbol_custom', [
            'label'                 => esc_html__( 'Custom Currency Symbol', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::TEXT,
            'dynamic'               => [
                'active'   => true,
            ],
            'condition'             => [
                'currency_symbol'  => 'custom',
            ],
        ]);

        $this->add_control('currency_symbol_position', [
            'label'                 => esc_html__( 'Currency Symbol Position', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SELECT,
            'options'               => [
                'before'             => esc_html__( 'Before Price', 'orbius-core' ),
                'after'             => esc_html__( 'After Price', 'orbius-core' )
            ],
            'default'               => 'after',
            'condition'             => [
                'currency_symbol!'   => 'none',
            ],
        ]);

        $this->add_control('table_price', [
            'label'                 => esc_html__( 'Price', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::TEXT,
			'dynamic'               => [
				'active'   => true,
			],
            'default'               => '285',
        ]);

        $this->add_control('table_duration', [
            'label'       => esc_html__( 'Duration', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => esc_html__( '/monthly', 'orbius-core' ),
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_features', 'Features');

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('feature_text', [
			'label'               => esc_html__( 'Text', 'orbius-core' ),
			'type'                => \Elementor\Controls_Manager::TEXT,
            'dynamic'             => [
                'active'   => true,
            ],
			'placeholder'         => esc_html__( 'Feature', 'orbius-core' ),
			'default'             => esc_html__( 'Feature', 'orbius-core' ),
		]);

        $repeater->add_control('exclude',[
            'label'   => esc_html__( 'Exclude', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $repeater->add_control('feature_icon', [
			'label'               => esc_html__( 'Icon', 'orbius-core' ),
			'type'                => \Elementor\Controls_Manager::ICONS,
            'default' => [
                'value' => 'fas fa-circle',
                'library' => 'fa-solid',
            ],
		]);

		$repeater->add_control('feature_icon_color', [
			'label'               => esc_html__( 'Icon Color', 'orbius-core' ),
			'type'                => \Elementor\Controls_Manager::COLOR,
            'selectors'           => [
                '{{WRAPPER}} {{CURRENT_ITEM}} .fa' => 'color: {{VALUE}}',
            ],
            'selectors'             => [
                '{{WRAPPER}} {{CURRENT_ITEM}} .mk-pricing-table-fature-icon' => 'color: {{VALUE}}',
                '{{WRAPPER}} {{CURRENT_ITEM}} .mk-pricing-table-fature-icon svg' => 'fill: {{VALUE}}',
            ],
		]);

		$repeater->add_control('feature_text_color', [
			'label'               => esc_html__( 'Text Color', 'orbius-core' ),
			'type'                => \Elementor\Controls_Manager::COLOR,
	        'default'             => '',
            'selectors'           => [
                '{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}',
            ],
		]);

		$repeater->add_control('feature_bg_color', [
			'label'               => esc_html__( 'Background Color', 'orbius-core' ),
			'type'                => \Elementor\Controls_Manager::COLOR,
	        'default'             => '',
            'selectors'           => [
                '{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-color: {{VALUE}}',
            ],
		]);

        $this->add_control('table_features', [
            'label' => esc_html__( 'Features Text', 'orbius-core' ),
    		'type' => \Elementor\Controls_Manager::REPEATER,
    		'fields' => $repeater->get_controls(),
    		'default'               => [
				[
					'feature_text'        => esc_html__( 'Veritatis rtrdr modimodi', 'orbius-core' ),
				],
				[
					'feature_text'        => esc_html__( 'Similique rgjhu pariatur', 'orbius-core' ),
				],
				[
					'feature_text'        => esc_html__( 'Commodi oklgy facilisra', 'orbius-core' ),
				],
                [
                    'feature_text'        => esc_html__( 'Reidis umkol noiupus', 'orbius-core' ),
                ],
			],
    		'title_field' => '{{{ feature_text }}}',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_ribbon', 'Ribbon');

        $this->add_control('show_ribbon',[
            'label'   => esc_html__( 'Ribbon', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('ribbon_style', [
            'label'                => esc_html__( 'Style', 'orbius-core' ),
            'type'                 => \Elementor\Controls_Manager::SELECT,
            'default'              => '1',
            'options'              => [
                '1'         => esc_html__( 'Default', 'orbius-core' ),
                '2'         => esc_html__( 'Circle', 'orbius-core' ),
                '3'         => esc_html__( 'Flag', 'orbius-core' ),
            ],
			'condition'             => [
				'show_ribbon'  => 'yes',
			],
        ]);

        $this->add_control('ribbon_title', [
            'label'                 => esc_html__( 'Title', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::TEXT,
			'dynamic'               => [
				'active'   => true,
			],
            'default'               => '<i class="fas fa-solid fa-star"></i><i class="fas fa-solid fa-star"></i><i class="fas fa-solid fa-star"></i>',
			'condition'             => [
				'show_ribbon'  => 'yes',
			],
        ]);

        $this->add_responsive_control('ribbon_size', [
            'label'                 => esc_html__( 'Size', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'size_units'            => [ 'px', 'em' ],
            'range'                 => [
                'px' => [
                    'min'   => 1,
                    'max'   => 200,
                ],
                'em' => [
                    'min'   => 1,
                    'max'   => 15,
                ],
            ],
			'default'               => [
				'size'      => 4,
				'unit'      => 'em',
			],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-ribbon-2' => 'min-width: {{SIZE}}{{UNIT}}; min-height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
            ],
			'condition'             => [
				'show_ribbon'  => 'yes',
				'ribbon_style' => [ '2' ],
			],
        ]);

        $this->add_responsive_control('top_distance', [
            'label'                 => esc_html__( 'Distance from Top', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'size_units'            => [ 'px', '%' ],
            'range'                 => [
                'px' => [
                    'min'   => 1,
                    'max'   => 200,
                ],
            ],
			'default'               => [
				'size'      => 20,
				'unit'      => '%',
			],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-ribbon' => 'top: {{SIZE}}{{UNIT}};',
            ],
			'condition'             => [
				'show_ribbon'  => 'yes',
				'ribbon_style' => [ '2', '3' ],
			],
        ]);

        $ribbon_distance_transform = is_rtl() ? 'translateY(-50%) translateX({{SIZE}}{{UNIT}}) rotate(-45deg)' : 'translateY(-50%) translateX(-50%) translateX({{SIZE}}{{UNIT}}) rotate(-45deg)';

		$this->add_responsive_control('ribbon_distance', [
			'label'                 => esc_html__( 'Distance', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SLIDER,
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 50,
				],
			],
			'selectors'             => [
				'{{WRAPPER}} .mk-pricing-table-ribbon-inner' => 'margin-top: {{SIZE}}{{UNIT}}; transform: ' . $ribbon_distance_transform,
			],
			'condition'             => [
				'show_ribbon'  => 'yes',
				'ribbon_style' => [ '1' ],
			],
		]);

        $this->add_responsive_control('ribbon_position', [
            'label'   => esc_html__( 'Position', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::CHOOSE,
            'default' => 'right',
            'options' => mk_arrays('align_left_right'),
            'condition' => [
                'show_ribbon'  => 'yes',
                'ribbon_style' => [ '1', '2', '3' ],
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_button', 'Button');

        $this->add_control('table_button_text', [
            'label'                 => esc_html__( 'Button Text', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::TEXT,
			'dynamic'               => [
				'active'   => true,
			],
            'default'               => esc_html__( 'order now', 'orbius-core' ),
        ]);

        $this->add_control('link', [
            'label'                 => esc_html__( 'Link', 'orbius-core' ),
			'label_block'           => false,
            'type'                  => \Elementor\Controls_Manager::URL,
			'dynamic'               => [
				'active'   => true,
			],
            'placeholder'           => 'https://www.your-link.com',
            'default'               => [
                'url' => '#',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_other_info', 'Other Info');

        $this->add_control('table_other_info', [
            'label'                 => esc_html__( 'Other Info', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::TEXTAREA,
			'dynamic'               => [
				'active'   => true,
			],
            'title'                 => esc_html__( 'Other Info', 'orbius-core' ),
            'default'               => 'Aliquam sodales justo amet urna arei auctor scelerisquinterdum leo.'
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_pricing_table_style', 'Pricing Table', true);

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name'        => 'pricing_table_border',
            'label'       => esc_html__( 'Border', 'orbius-core' ),
            'selector'    => '{{WRAPPER}} .mk-pricing-table',
        ]);

        $this->add_control('pricing_table_border_radius', [
            'label'                 => esc_html__( 'Border Radius', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', '%' ],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name' => 'pricing_table_bg',
            'types' => [ 'classic', 'gradient' ],
            'selector' => '{{WRAPPER}} .mk-pricing-table',
        ]);

		$this->add_responsive_control('table_padding', [
			'label'                 => esc_html__( 'Padding', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', '%' ],
			'selectors'             => [
				'{{WRAPPER}} .mk-pricing-table' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
            'name' => 'table_box_shadow',
            'label' => esc_html__( 'Box Shadow', 'orbius-core' ),
            'selector' => '{{WRAPPER}} .mk-pricing-table',
        ]);


        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_title_style', 'Title', true);

        mk_elem_heading_ctrl($this, 'table_title_heading', 'Title', 'before', 'condition' );

        $this->add_control('table_title_color', [
            'label'                 => esc_html__( 'Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-title' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'table_title_typography',
            'selector' => '{{WRAPPER}} .mk-pricing-table-title',
        ]);

        $this->add_control('table_title_html_tag', [
            'label'   => esc_html__( 'Title HTML Tag', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'default' => 'div',
            'options' => [
                'h1'   => esc_html__( 'H1', 'orbius-core' ),
                'h2'   => esc_html__( 'H2', 'orbius-core' ),
                'h3'   => esc_html__( 'H3', 'orbius-core' ),
                'h4'   => esc_html__( 'H4', 'orbius-core' ),
                'h5'   => esc_html__( 'H5', 'orbius-core' ),
                'h6'   => esc_html__( 'H6', 'orbius-core' ),
                'p'    => esc_html__( 'p', 'orbius-core' ),
            ],
        ]);

        $this->add_responsive_control('pricing_title_margin', [
            'label'                 => esc_html__( 'Margin', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', '%' ],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_table_pricing_style', 'Pricing', true);

        mk_elem_heading_ctrl($this, 'table_price_heading', 'Price', 'before' );

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'                  => 'table_pricing_typography',
            'label'                 => esc_html__( 'Typography', 'orbius-core' ),
            'selector'              => '{{WRAPPER}} .mk-pricing-table-price,{{WRAPPER}} .mk-pricing-table-price-value',
            'separator'             => 'before',
        ]);

        $this->add_control('table_price_color_normal', [
            'label'                 => esc_html__( 'Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table .mk-pricing-table-price,
                {{WRAPPER}} .mk-pricing-table .mk-pricing-table-price-prefix,
                {{WRAPPER}} .mk-pricing-table .mk-pricing-table-price-value' => 'color: {{VALUE}}',
            ],
        ]);

		$this->add_responsive_control('table_price_margin', [
			'label'                 => esc_html__( 'Margin', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', '%' ],
			'selectors'             => [
				'{{WRAPPER}} .mk-pricing-table-price' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

        mk_elem_heading_ctrl($this, 'table_curreny_heading', 'Currency Symbol', 'before' );

		$this->add_control('currency_vertical_position', [
			'label'                 => esc_html__( 'Vertical Position', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::CHOOSE,
			'label_block'           => false,
			'options'               => mk_arrays('vertical_alignment'),
			'default'               => 'top',
			'selectors_dictionary'  => [
				'top'      => 'flex-start',
				'middle'   => 'center',
				'bottom'   => 'flex-end',
			],
			'selectors'             => [
				'{{WRAPPER}} .mk-pricing-table-price-prefix' => 'align-self: {{VALUE}}',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'table_currency_symbol_typography',
            'selector' => '{{WRAPPER}} .mk-pricing-table-price-prefix',
        ]);

        $this->add_responsive_control('table_currency_symbol_margin', [
            'label'                 => esc_html__( 'Margin', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', '%' ],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-price-prefix' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        mk_elem_heading_ctrl($this, 'table_duration_heading', 'Duration', 'before' );

        $this->add_control('duration_text_color', [
            'label'                 => esc_html__( 'Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-price-duration' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'table_price_duration_typography',
            'selector' => '{{WRAPPER}} .mk-pricing-table-price-duration',
        ]);

        $this->add_responsive_control('table_price_duration_padding', [
            'label'                 => esc_html__( 'Padding', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', 'em', '%' ],
            'condition'             => [
                'table_button_text!' => '',
            ],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-price-duration' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);


        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_table_features_style', 'Features', true);

        $this->add_control('table_features_text_color', [
            'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-features' => 'color: {{VALUE}}',
            ],
        ]);

		$this->add_responsive_control('table_features_padding', [
			'label'                 => esc_html__( 'Padding', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', '%' ],
			'selectors'             => [
				'{{WRAPPER}} .mk-pricing-table-features' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'table_features_typography',
            'selector' => '{{WRAPPER}} .mk-pricing-table-feature-text',
        ]);

        mk_elem_heading_ctrl($this, 'table_features_icon_heading', 'Icon', 'before' );

        $this->add_control('table_features_icon_color', [
            'label'                 => esc_html__( 'Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-fature-icon' => 'color: {{VALUE}}',
                '{{WRAPPER}} .mk-pricing-table-fature-icon svg' => 'fill: {{VALUE}}',
            ],
        ]);

        $this->add_responsive_control('table_features_icon_size', [
            'label'                 => esc_html__( 'Size', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'range'                 => [
                'px' => [
                    'min'   => 5,
                    'max'   => 100,
                    'step'  => 1,
                ],
            ],
            'size_units'            => [ 'px', 'em' ],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table .mk-pricing-table-features li i' => 'font-size: {{SIZE}}{{UNIT}}',
            ],
        ]);

        $this->add_responsive_control('table_features_icon_spacing', [
            'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'range'                 => [
                'px' => [
                    'min'   => 0,
                    'max'   => 100,
                    'step'  => 1,
                ],
            ],
            'size_units'            => [ 'px' ],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-fature-icon' => 'margin-right: {{SIZE}}{{UNIT}};',
            ],
        ]);

        mk_elem_heading_ctrl($this, 'table_features_rows_heading', 'Rows', 'before' );

        $this->add_responsive_control('table_features_spacing', [
            'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'range'                 => [
                'px' => [
                    'min'   => 0,
                    'max'   => 100,
                    'step'  => 1,
                ],
            ],
            'size_units'            => [ 'px' ],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-features li:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_control('table_features_alternate',[
            'label'   => esc_html__( 'Striped Rows', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $this->add_control('table_minimum_width_rows',[
            'label'   => esc_html__( 'Minimum Width Rows', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

		$this->add_responsive_control('table_features_rows_padding', [
			'label'                 => esc_html__( 'Padding', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', '%' ],
			'selectors'             => [
				'{{WRAPPER}} .mk-pricing-table-features li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition'             => [
				'table_features_alternate' => 'yes',
			],
		]);

        $this->start_controls_tabs( 'tabs_features_style' );

        $this->start_controls_tab('tab_features_even', [
            'label'                 => esc_html__( 'Even', 'orbius-core' ),
			'condition'             => [
				'table_features_alternate' => 'yes',
			],
        ]);

        $this->add_control('table_features_bg_color_even', [
            'label'                 => esc_html__( 'Background Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-features li:nth-child(even)' => 'background-color: {{VALUE}}',
            ],
			'condition'             => [
				'table_features_alternate' => 'yes',
			],
        ]);

        $this->add_control('table_features_text_color_even', [
            'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-features li:nth-child(even)' => 'color: {{VALUE}}',
            ],
			'condition'             => [
				'table_features_alternate' => 'yes',
			],
        ]);

        $this->end_controls_tab();

        $this->start_controls_tab('tab_features_odd', [
            'label'                 => esc_html__( 'Odd', 'orbius-core' ),
			'condition'             => [
				'table_features_alternate' => 'yes',
			],
        ]);

        $this->add_control('table_features_bg_color_odd', [
            'label'                 => esc_html__( 'Background Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-features li:nth-child(odd)' => 'background-color: {{VALUE}}',
            ],
			'condition'             => [
				'table_features_alternate' => 'yes',
			],
        ]);

        $this->add_control('table_features_text_color_odd', [
            'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-features li:nth-child(odd)' => 'color: {{VALUE}}',
            ],
			'condition'             => [
				'table_features_alternate' => 'yes',
			],
        ]);

        $this->end_controls_tab();

        $this->end_controls_tabs();

        mk_elem_heading_ctrl($this, 'table_divider_heading', 'Divider', 'before' );

		$this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
			'name'                  => 'table_feature_divider',
			'label'                 => esc_html__( 'Divider', 'orbius-core' ),
			'placeholder'           => '1px',
			'default'               => '1px',
			'selector'              => '{{WRAPPER}} .mk-pricing-table-features li',
		]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_table_ribbon_style', 'Ribbon', true);

        $this->add_control('ribbon_text_color', [
            'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '#ffffff',
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-ribbon .mk-pricing-table-ribbon-inner' => 'color: {{VALUE}}',
            ],
        ]);

		$this->add_control('ribbon_bg_color', [
			'label'                 => esc_html__( 'Background Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '#000000',
			'selectors'             => [
				'{{WRAPPER}} .mk-pricing-table-ribbon .mk-pricing-table-ribbon-inner' => 'background-color: {{VALUE}}',
				'{{WRAPPER}} .mk-pricing-table-ribbon-3.mk-pricing-table-ribbon-right:before' => 'border-left-color: {{VALUE}}',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'ribbon_typography',
            'selector' => '{{WRAPPER}} .mk-pricing-table-ribbon .mk-pricing-table-ribbon-inner',
        ]);

		$this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(), [
			'name'                  => 'ribbon_box_shadow',
			'selector'              => '{{WRAPPER}} .mk-pricing-table-ribbon .mk-pricing-table-ribbon-inner',
		]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_table_button_style', 'Button', true);

            $this->add_control('button_color', [
                'label'                 => esc_html__( 'Color', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::COLOR,
                'condition'             => [
                    'table_button_text!' => '',
                ],
                'selectors'             => [
                    '{{WRAPPER}} .mk-post-button a,
                    {{WRAPPER}} .mk-post-button-text,
                    {{WRAPPER}} .mk-post-button-arrow-start,
                    {{WRAPPER}} .mk-post-button-arrow-end,
                    {{WRAPPER}} .mk-post-button:hover a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-post-button a ' => 'border-color: {{VALUE}}',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_table_other_info_style', 'Other Info', true, ['table_other_info!' => ''] );

        $this->add_control('other_info_color', [
            'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
			'condition'             => [
				'table_other_info!' => '',
			],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-other-info' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'other_info_typography',
            'selector' => '{{WRAPPER}} .mk-pricing-table-other-info',
        ]);

        $this->add_responsive_control('other_info_margin', [
            'label'                 => esc_html__( 'Margin', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', 'em', '%' ],
            'condition'             => [
                'table_other_info!' => '',
            ],
            'selectors'             => [
                '{{WRAPPER}} .mk-pricing-table-other-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_table_separator_style', 'Separator', true );

            $this->add_control('separator_on',[
                'label' => esc_html__( 'Separator', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'pricing_table_separator_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-pricing-table-price-separator',
                'condition'   => ['separator_on' => 'yes'],
            ]);

            $this->add_responsive_control('separator_margin', [
                'label'                 => esc_html__( 'Margin', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units'            => [ 'px', 'em', '%' ],
                'condition'             => ['separator_on' => 'yes'],
                'selectors'             => [
                    '{{WRAPPER}} .mk-pricing-table-price-separator' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

    }

	private function get_currency_symbol( $symbol_name ) {
		$symbols = [
			'dollar'         => '&#36;',
			'euro'           => '&#128;',
			'franc'          => '&#8355;',
			'pound'          => '&#163;',
			'ruble'          => '&#8381;',
			'shekel'         => '&#8362;',
			'baht'           => '&#3647;',
			'yen'            => '&#165;',
			'won'            => '&#8361;',
			'guilder'        => '&fnof;',
			'peso'           => '&#8369;',
			'peseta'         => '&#8359',
			'lira'           => '&#8356;',
			'rupee'          => '&#8360;',
			'indian_rupee'   => '&#8377;',
			'real'           => 'R$',
			'krona'          => 'kr',
		];
		return isset( $symbols[ $symbol_name ] ) ? $symbols[ $symbol_name ] : '';
	}

    protected function render() {
        $settings = $this->get_settings_for_display();
		$symbol = '';

		if ( 'none' != $settings['currency_symbol'] ) {
			if ( 'custom' !== $settings['currency_symbol'] ) {
				$symbol = $this->get_currency_symbol( $settings['currency_symbol'] );
			} else {
				$symbol = $settings['currency_symbol_custom'];
			}
		}

        $this->add_inline_editing_attributes( 'table_title', 'none' );
        $this->add_render_attribute( 'table_title', 'class', 'mk-pricing-table-title' );

        $this->add_inline_editing_attributes( 'table_price', 'none' );
        $this->add_render_attribute( 'table_price', 'class', 'mk-pricing-table-price-value' );

        $this->add_inline_editing_attributes( 'table_duration', 'none' );
        $this->add_render_attribute( 'table_duration', 'class', 'mk-pricing-table-price-duration' );

        $this->add_inline_editing_attributes( 'table_other_info', 'none' );
        $this->add_render_attribute( 'table_other_info', 'class', 'mk-pricing-table-other-info' );

        $this->add_render_attribute( 'pricing-table', 'class', 'mk-pricing-table' );

        if ( $settings['table_minimum_width_rows'] == 'yes' ) {
            $this->add_render_attribute( 'pricing-table', 'class', 'mk-pricing-table-min-row' );
        }

        $this->add_render_attribute( 'pricing-table-duration', 'class', 'mk-pricing-table-price-duration' );

        $this->add_render_attribute( 'feature-list-item', 'class', '' );

        ?>
        <div class="mk-pricing-table-container">
            <div <?php echo $this->get_render_attribute_string( 'pricing-table' ); ?>>

                <div class="mk-pricing-table-top">

                    <div class="clear"></div>

                    <?php if ( ! empty( $settings['table_title'] ) ) { ?>
                        <<?php echo $settings['table_title_html_tag']; ?> <?php echo $this->get_render_attribute_string( 'table_title' ); ?>><?php echo $settings['table_title']; ?></<?php echo $settings['table_title_html_tag']; ?>>
                    <?php } ?>

                    <?php if ( ! empty( $settings['table_price'] ) ) { ?>
                        <div class="mk-pricing-table-price-wrap">

                            <div class="mk-pricing-table-price">

                                <div class="mk-pricing-table-price-number-duration">
                                    <?php if ( ! empty( $symbol ) && $settings['currency_symbol_position'] == 'before' ) { ?>
                                        <span class="mk-pricing-table-price-prefix"><?php echo $symbol; ?></span>
                                    <?php } ?>
                                    <span <?php echo $this->get_render_attribute_string( 'table_price' ); ?>><?php echo $settings['table_price']; ?></span>
                                    <?php if ( ! empty( $symbol ) && $settings['currency_symbol_position'] == 'after' ) { ?>
                                        <span class="mk-pricing-table-price-prefix"><?php echo $symbol; ?></span>
                                    <?php } ?>
                                    <?php if ( ! empty( $settings['table_duration'] ) ) { ?>
                                        <span <?php echo $this->get_render_attribute_string( 'table_duration' ); ?>><?php echo $settings['table_duration']; ?></span>
                                    <?php } ?>
                                </div>
                            </div>

                            <?php if ( 'yes' === $settings['separator_on'] ) { ?>
                                <div class="mk-pricing-table-price-separator"></div>
                            <?php } ?>



                            <?php if ( ! empty( $settings['table_other_info'] ) ) { ?>
                                <div <?php echo $this->get_render_attribute_string( 'table_other_info' ); ?>><?php echo $this->parse_text_editor( $settings['table_other_info'] ); ?></div>
                            <?php } ?>


                        </div>
                        <div class="clear"></div>
                    <?php } ?>

                    <div class="clear"></div>

                </div>

                <div class="mk-pricing-table-bottom">

                    <ul class="mk-pricing-table-features">
                        <?php foreach ( $settings['table_features'] as $index => $item ) : ?>
                            <?php
                                $feature_key = $this->get_repeater_setting_key( 'feature_text', 'table_features', $index );
                                $this->add_render_attribute( $feature_key, 'class', 'mk-pricing-table-feature-text' );
                                $this->add_inline_editing_attributes( $feature_key, 'none' );

                                $pa_class = '';

                                if ( $item['exclude'] == 'yes' ) {
                                    $pa_class .= ' excluded';
                                } else {
                                    $pa_class .= '';
                                }
                            ?>
                            <li class="elementor-repeater-item-<?php echo $item['_id'] . $pa_class; ?>">
                                <?php
                                    ob_start();
                                    \Elementor\Icons_Manager::render_icon( $item['feature_icon'], [ 'aria-hidden' => 'true' ] );
                                    $button_icon = ob_get_clean();

                                    if ( !empty($button_icon) ) : ?>
                                        <span class="mk-pricing-table-fature-icon mk-icon"><?php echo $button_icon; ?></span>
                                <?php endif; ?>
                                <?php if ( $item['feature_text'] ) { ?>
                                    <span <?php echo $this->get_render_attribute_string( $feature_key ); ?>><?php echo $item['feature_text']; ?></span>
                                <?php } ?>
                            </li>
                        <?php endforeach; ?>
                    </ul>

                    <div class="clear"></div>

                </div>

                <div class="clear"></div>

                <?php
                    // Button
                    if ( ! empty( $settings['table_button_text'] ) ) {

                        if ( ! empty( $settings['link']['url'] ) ) {
                            $this->add_render_attribute( 'table_button_attrs', 'href', $settings['link']['url'] );

                            if ( ! empty( $settings['link']['is_external'] ) ) {
                                $this->add_render_attribute( 'table_button_attrs', 'target', '_blank' );
                            }
                        }
                        ?>
                        <div class="mk-post-button"><a <?php echo $this->get_render_attribute_string( 'table_button_attrs' ); ?> class="mk-pricing-table-button-text"><span class="mk-post-button-arrow-start" ></span><span class="mk-post-button-text" ><?php echo esc_html( $settings['table_button_text'] ); ?></span><span class="mk-post-button-arrow-end" ></span></a></div>

                <?php } ?>

            </div>
            <?php if ( $settings['show_ribbon'] == 'yes' && $settings['ribbon_title'] != '' ) { ?>
                <?php
                    $ribbonStyle = !empty($settings['ribbon_style']) ? $settings['ribbon_style'] : '1';
                    $ribbonPosition = !empty($settings['ribbon_position']) ? $settings['ribbon_position'] : '1';

                    $classes = [
                        'mk-pricing-table-ribbon',
                        'mk-pricing-table-ribbon-' . $ribbonStyle,
                        'mk-pricing-table-ribbon-' . $ribbonPosition,
                    ];
                    $this->add_render_attribute( 'ribbon', 'class', $classes );
                ?>
                <div <?php echo $this->get_render_attribute_string( 'ribbon' ); ?>>
                    <div class="mk-pricing-table-ribbon-inner">
                        <div class="mk-pricing-table-ribbon-title">
                            <?php echo $settings['ribbon_title']; ?>
                        </div>
                    </div>
                </div>
            <?php } ?>
        </div>
        <?php
    }

}