<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Reveal_Services extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_reveal_services'; }
    public function get_title()          { return esc_html__( 'Reveal Services', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return [ 'mk-general-elements' ]; }
    public function get_keywords()       { return [ 'theme', 'move','scroll','reveal','content','left','right','animation','services','section' ]; }
    public function get_style_depends()  { return [ 'mk-core-main' ]; }
    public function get_script_depends() { return [ 'mk-gsap', 'mk-scroll-trigger', 'mk-widgets' ]; }

    public function services_list($obj,$num) {

        $heading = str_replace(' ', '', ucwords(str_replace('_', ' ', $num)));

        mk_elem_start_ctrl($obj, 'service_content'.$num, 'Service '.$heading);

            $obj->add_control('service_title'.$num, [
                'label'       => esc_html__( 'service title', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
                'default'     => 'Sample Title Text',
            ]);

            $obj->add_control('service_text'.$num, [
                'label'       => esc_html__( 'Text', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter Summery Text', 'orbius-core' ),
                'default'     => 'Fusce accumsan tincidunt erat et convallis risus ullamcorper euoled vehicula.',
            ]);

            $obj->add_control('service_link'.$num, [
                'label'         => esc_html__( 'Link', 'orbius-core' ),
                'type'          => \Elementor\Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'orbius-core' ),
                'show_external' => true,
            ]);

            $obj->add_control('service_skin'.$num, [
                'label'   => esc_html__( 'Skin', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'light',
                'options' => [
                    'light' => esc_html__( 'Light', 'orbius-core' ),
                    'dark'  => esc_html__( 'Dark', 'orbius-core' ),
                ],
            ]);

            $obj->add_control('service_icon_type'.$num, [
                'label'       => esc_html__( 'Icon Type', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::CHOOSE,
                'label_block' => false,
                'options'     => [
                    'none'   => ['title' => esc_html__( 'None', 'orbius-core' ),   'icon'  => 'eicon-ban', ],
                    'icon'   => ['title' => esc_html__( 'Icon', 'orbius-core' ),   'icon'  => 'eicon-star-o', ],
                    'image'  => ['title' => esc_html__( 'Image', 'orbius-core' ),  'icon'  => 'eicon-image', ],
                ],
                'default' => 'icon',
            ]);

            $obj->add_control('service_icon'.$num, [
                'label'   => esc_html__( 'Icon', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::ICONS,
                'default' => ['value' => 'fas fa-star', 'library' => 'fa-solid'],
                'condition' => [ 'service_icon_type'.$num => 'icon']
            ]);

            $obj->add_control('service_image'.$num, [
                'label'      => esc_html__( 'Image', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::MEDIA,
                'condition'  => [ 'service_icon_type'.$num => 'image']
            ]);

        $obj->end_controls_section();

    }

    protected function register_controls() {

        $this->services_list($this,'_one');
        $this->services_list($this,'_two');
        $this->services_list($this,'_three');
        $this->services_list($this,'_four');

        mk_elem_start_ctrl($this, 'content_settings', 'Settings', true);

            $this->add_responsive_control('content_height', [
                'label'     => esc_html__( 'Item Height', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 2000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-reveal-services-holder' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('content_padding', [
                'label'     => esc_html__( 'Padding', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 200, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-reveal-service-item' => 'padding:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->start_controls_tabs( 'tabs_features_style' );

                $this->start_controls_tab('light_skin', [
                    'label' => esc_html__( 'Light Skin', 'orbius-core' ),
                ]);

                    $this->add_control('item_title_color_light', [
                        'label'     => esc_html__( 'Title Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-reveal-services-light .mk-reveal-services-title' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('item_text_color_light', [
                        'label'     => esc_html__( 'Text Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-reveal-services-light .mk-reveal-services-text' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('item_icon_color_light', [
                        'label'     => esc_html__( 'Icon Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-reveal-services-light .mk-reveal-services-icon' => 'color: {{VALUE}};fill: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('item_counter_color_light', [
                        'label'     => esc_html__( 'Counter Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-reveal-services-light .mk-reveal-services-counter' => 'color: {{VALUE}};fill: {{VALUE}};',
                        ],
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
                        'name' => 'item_bg_light',
                        'label' => esc_html__( 'Background', 'orbius-core' ),
                        'types' => [ 'classic', 'gradient' ],
                        'selector' => '{{WRAPPER}} .mk-reveal-services-light.mk-reveal-service-item'
                    ]);

                $this->end_controls_tab();

                $this->start_controls_tab('dark_skin', [
                    'label' => esc_html__( 'Dark Skin', 'orbius-core' ),
                ]);

                    $this->add_control('item_title_color_dark', [
                        'label'     => esc_html__( 'Title Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-reveal-services-dark .mk-reveal-services-title' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('item_text_color_dark', [
                        'label'     => esc_html__( 'Text Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-reveal-services-dark .mk-reveal-services-text' => 'color: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('item_icon_color_dark', [
                        'label'     => esc_html__( 'Icon Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-reveal-services-dark .mk-reveal-services-icon' => 'color: {{VALUE}};fill: {{VALUE}};',
                        ],
                    ]);

                    $this->add_control('item_counter_color_dark', [
                        'label'     => esc_html__( 'Counter Color', 'orbius-core' ),
                        'type'      => \Elementor\Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .mk-reveal-services-dark .mk-reveal-services-counter' => 'color: {{VALUE}};fill: {{VALUE}};',
                        ],
                    ]);

                    $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
                        'name' => 'item_bg_dark',
                        'label' => esc_html__( 'Background', 'orbius-core' ),
                        'types' => [ 'classic', 'gradient' ],
                        'selector' => '{{WRAPPER}} .mk-reveal-services-dark.mk-reveal-service-item'
                    ]);

                $this->end_controls_tab();

            $this->end_controls_tabs();

            $this->add_control('item_border_color_light', [
                'label'     => esc_html__( 'Border Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-reveal-services-light.mk-reveal-service-item,
                    {{WRAPPER}} .mk-reveal-services-light.mk-reveal-service-one' => 'border-color: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styling', 'Title', true);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-reveal-services-title',
            ]);

            $this->add_responsive_control('title_width', [
                'label'     => esc_html__( 'Max Width', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-reveal-services-title' => 'width:{{SIZE}}{{UNIT}}; max-width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('title_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-reveal-services-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-reveal-services-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('title_tag', [
                'label' => esc_html__( 'Select Tag', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ],
                'default' => 'h4',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'text_styling', 'Text', true);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'text_typography',
                'selector' => '{{WRAPPER}} .mk-reveal-services-text',
            ]);

            $this->add_responsive_control('text_width', [
                'label'     => esc_html__( 'Max Width', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 1000, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-reveal-services-text' => 'width:{{SIZE}}{{UNIT}}; max-width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('text_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-reveal-services-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('text_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-reveal-services-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'icon_styling', 'Icon/Image', true);

            $this->add_responsive_control('media_size', [
                'label'     => esc_html__( 'Size', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'range'     => ['px' => ['min' => 0, 'max' => 300, ], ],
                'size_units'  => [ '%', 'px','vw','em' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-reveal-services-icon' => 'font-size:{{SIZE}}{{UNIT}};',
                     '{{WRAPPER}} .mk-reveal-services-icon img' => 'width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'media_image_size',
                'label'   => esc_html__( 'Image Size', 'orbius-core' ),
                'default' => 'full',
            ]);

            $this->add_responsive_control('icon_padding', [
                'label'     => esc_html__( 'Padding', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-reveal-services-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('icon_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors'  => [
                    '{{WRAPPER}} .mk-reveal-services-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'counter_styling', 'Counter', true);

            $this->add_control('counter_on',[
                'label' => esc_html__( 'Counter', 'orbius-core' ),
                'type'  => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'      => 'counter_typography',
                'selector'  => '{{WRAPPER}} .mk-reveal-services-counter',
                'condition' => ['counter_on' => 'yes']
            ]);

            $this->add_responsive_control('counter_padding', [
                'label'     => esc_html__( 'Padding', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::DIMENSIONS,
                'condition' => ['counter_on' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-reveal-services-counter' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('counter_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'condition'  => ['counter_on' => 'yes'],
                'selectors'  => [
                    '{{WRAPPER}} .mk-reveal-services-counter' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $all_services = '';
        $all_items = ['_one','_two','_three','_four'];
        $i = 1;

        foreach ( $all_items as $item ) :

            $iconHtml = $imageHtml = $linkHTML = '';

            if ( ! empty( $settings['service_link'.$item]['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $settings['service_link'.$item]['url'] );
                $this->add_render_attribute( $link_key, 'class', 'mk-reveal-service-link' );

                if ( $settings['service_link'.$item]['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $settings['service_link'.$item]['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $linkHTML .= '<a ' . $this->get_render_attribute_string( $link_key ) . '></a>';
            }

            if ( $settings['service_icon_type'.$item] !== 'none' ) {
                if ( $settings['service_icon_type'.$item] === 'icon' ) {
                    ob_start();
                    \Elementor\Icons_Manager::render_icon( $settings['service_icon'.$item], array( 'aria-hidden' => 'true' ) );
                    $iconHtml = ob_get_clean();
                    $iconHtml = '<div class="mk-reveal-services-icon">' . $iconHtml . '</div>';
                } elseif ( $settings['service_icon_type'.$item] === 'image' ) {

                    $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $settings['service_image'.$item]['id'], 'media_image_size', $settings );

                    if (  $settings['media_image_size_size'] == 'custom' ) {
                        $imageTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $settings['service_image'.$item], $settings['service_image'.$item]['id'], 'media_image_size', 'service_image').' />';
                    } else {
                        $imageTagHtml = wp_get_attachment_image( $settings['service_image'.$item]['id'], $settings['media_image_size_size']);
                    }

                    if ( '' !== $imgUrl ) {
                        $iconHtml = $imageTagHtml;
                    }
                    $iconHtml = '<div class="mk-reveal-services-icon">' . $iconHtml . '</div>';

                }
            }

            $number = str_replace('_', '', $item);

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            $titleHtml   = ( $settings['service_title'.$item] !== '' ) ? '<' . $titleTagSelector . ' class="mk-reveal-services-title">' . $settings['service_title'.$item] . '</' . $titleTagSelector . '>': '';
            $textHtml    = ( $settings['service_text'.$item] !== '' ) ? '<div class="mk-reveal-services-text">' . $settings['service_text'.$item] . '</div>' : '';
            $counterHtml = ( $settings['counter_on'] === 'yes' ) ? '<span class="mk-reveal-services-counter">0' . $i . '</span>' : '';

            $all_services .= '<div class="mk-reveal-service-' . $number . ' mk-reveal-service-item mk-reveal-services-' . $settings['service_skin'.$item] . '">' . $linkHTML . $counterHtml . $iconHtml . $titleHtml . $textHtml . '</div>';

            $i++;

        endforeach;

        echo '<div class="mk-reveal-services-holder ">' . $all_services . '</div>';

    }

}