<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Search_Form extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_search_form'; }
	public function get_title()      { return esc_html__( 'Search Form', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-search'; }
	public function get_categories() { return ['mk-sections-elements']; }
	public function get_keywords()   { return [ 'theme','search','form', ' search bar' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }

	protected function register_controls() {
		mk_elem_start_ctrl($this, 'section_content', 'Form');

		$this->add_responsive_control(
		    'width',
		    [
		        'label' => esc_html__( 'Width', 'orbius-core' ),
		        'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', '%','em' ],
		        'default' => [
		            'size' => 200,
		            'unit' => 'px',
		        ],
		        'range' => [
		            'px' => [
		                'min' => 5,
		                'max' => 2000,
		                'step' => 5,
		            ]
		        ],
		        'selectors' => [
		            '{{WRAPPER}} .mk-search-form-wrapper' => 'width: {{SIZE}}{{UNIT}}',
		        ],
		    ]
		);

		$this->add_responsive_control(
		    'height',
		    [
		        'label' => esc_html__( 'Height', 'orbius-core' ),
		        'type' => \Elementor\Controls_Manager::SLIDER,
		        'default' => [
		            'size' => 44,
		            'unit' => 'px',
		        ],
		        'range' => [
		            'px' => [
		                'min' => 1,
		                'max' => 200,
		                'step' => 1,
		            ]
		        ],
		        'size_units' => [ 'px' ],
		        'selectors' => [
		            '{{WRAPPER}} .mk-search-form-wrapper .input-group input' => 'height: {{SIZE}}{{UNIT}}',
		            '{{WRAPPER}} .mk-search-form-wrapper .input-group .input-group-button button' => 'line-height: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}',
		        ],
		    ]
		);

		$this->add_responsive_control(
		    'icon_size',
		    [
		        'label' => esc_html__( 'Icon Size', 'orbius-core' ),
		        'type' => \Elementor\Controls_Manager::SLIDER,
		        'default' => [
		            'size' => 16,
		            'unit' => 'px',
		        ],
		        'range' => [
		            'px' => [
		                'min' => 1,
		                'max' => 50,
		                'step' => 1,
		            ]
		        ],
		        'size_units' => [ 'px' ],
		        'selectors' => [
		            '{{WRAPPER}} .mk-search-form-wrapper .input-group .input-group-button button .swm-svg-search-form-search' => 'font-size: {{SIZE}}{{UNIT}}',
		        ],
		    ]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'search_typography',
				'label' => esc_html__( 'Typography', 'orbius-core' ),
				'selector' => '{{WRAPPER}} .mk-search-form-wrapper input',
			]
		);

		$this->add_control(
			'placeholder',
			[
				'label' => esc_html__( 'Placeholder Text', 'orbius-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Search for anything', 'orbius-core' ),
			]
		);

        $this->add_responsive_control('input_padding', [
                'label' => esc_html__( 'Search Bar Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-search-form-wrapper .input-group input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control('button_padding', [
                'label' => esc_html__( 'Search Icon Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-search-form-wrapper .input-group .input-group-button button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'section_style', 'Styles', true);


            $this->start_controls_tabs( 'icons_style' );

                $this->start_controls_tab('tab_icons_normal', [
                    'label' => esc_html__( 'Normal', 'orbius-core' ),
                ]);

                    $this->add_control(
                        'search_font_color',
                        [
                            'label' => esc_html__( 'Font Color', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper input' => 'color: {{VALUE}}',
                            ],
                        ]
                    );

                    $this->add_control(
                        'search_placeholder_font_color',
                        [
                            'label' => esc_html__( 'Placeholder Font Color', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper input::placeholder' => 'color: {{VALUE}}',
                            ],
                        ]
                    );

                    $this->add_control(
                        'search_bg_color',
                        [
                            'label' => esc_html__( 'Background Color', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper' => 'background-color: {{VALUE}}',
                            ],
                        ]
                    );

                    $this->add_control(
                        'icon_color',
                        [
                            'label' => esc_html__( 'Icon Color', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper .input-group .input-group-button button .swm-svg-search-form-search' => 'fill: {{VALUE}}',
                            ],
                        ]
                    );

                    $this->add_group_control(
                        \Elementor\Group_Control_Box_Shadow::get_type(),
                        [
                            'name' => 'search_box_shadow',
                            'label' => esc_html__( 'Shadow', 'orbius-core' ),
                            'selector' => '{{WRAPPER}} .mk-search-form-wrapper',
                        ]
                    );

                    $this->add_control(
                        'search_border_radius',
                        [
                            'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => [ 'px' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 100,
                                    'step' => 1,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 0,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper' => 'border-radius: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                        'name'        => 'form_border',
                        'label'       => esc_html__( 'Border', 'orbius-core' ),
                        'selector'    => '{{WRAPPER}} .mk-search-form-wrapper',
                    ]);

                $this->end_controls_tab();

                $this->start_controls_tab('tab_icons_hover',[
                    'label' => esc_html__( 'Hover', 'orbius-core' ),
                ]);

                    $this->add_control(
                        'search_hover_font_color',
                        [
                            'label' => esc_html__( 'Font Color', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper:hover input' => 'color: {{VALUE}}',
                            ],
                        ]
                    );

                    $this->add_control(
                        'search_hover_placeholder_font_color',
                        [
                            'label' => esc_html__( 'Placeholder Font Color', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper:hover input::placeholder' => 'color: {{VALUE}}',
                            ],
                        ]
                    );

                    $this->add_control(
                        'search_hover_bg_color',
                        [
                            'label' => esc_html__( 'Background Color', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'default' => '#ffffff',
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper:hover' => 'background-color: {{VALUE}}',
                            ],
                        ]
                    );

                    $this->add_control(
                        'icon_hover_color',
                        [
                            'label' => esc_html__( 'Icon Color', 'orbius-core' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .mk-search-form-wrapper:hover .input-group .input-group-button button .swm-svg-search-form-search' => 'fill: {{VALUE}}',
                            ],
                        ]
                    );

                    $this->add_group_control(
                        \Elementor\Group_Control_Box_Shadow::get_type(),
                        [
                            'name' => 'search_hover_box_shadow',
                            'label' => esc_html__( 'Shadow', 'orbius-core' ),
                            'selector' => '{{WRAPPER}} .mk-search-form-wrapper:hover',
                        ]
                    );

                    $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                        'name'        => 'form_hover_border',
                        'label'       => esc_html__( 'Border', 'orbius-core' ),
                        'selector'    => '{{WRAPPER}} .mk-search-form-wrapper:hover',
                    ]);

                $this->end_controls_tab();
            $this->end_controls_tabs();

		$this->end_controls_section();

	}

	protected function render() {

		$widget_id = $this->get_id();
		$settings = $this->get_settings();
		$redirect_to_page = get_site_url();

		$keyword = '';
		if(isset($_GET['s'])) {
			$keyword = $_GET['s'];
		}
		?>
		<div class="mk-search-form-wrapper">
			<form class="mk-search-form" method="get" action="<?php echo esc_url($redirect_to_page); ?>" >
				<div class="input-group">
					<input name="s" placeholder="<?php echo esc_attr($settings['placeholder']); ?>" value="<?php echo esc_attr($keyword); ?>"/>

					<?php if (function_exists('icl_object_id')) { ?>
					    <input id="lang" name="lang" type="hidden" value="<?php echo esc_attr(ICL_LANGUAGE_CODE); ?>"/>
					<?php } ?>

					<span class="input-group-button">
						<button aria-label="<?php echo esc_attr($settings['placeholder']); ?>" class="mk-search-form-button" type="submit"><?php echo mk_get_svg_icon( 'search', 'swm-svg-search-form-search' ); ?></button>
					</span>
				</div>
			</form>
		</div>
		<?php
	}


}