<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
class Mk_Search extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_search'; }
	public function get_title()      { return esc_html__( 'Search', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-search'; }
	public function get_categories() { return ['mk-sections-elements']; }
	public function get_keywords()   { return [ 'theme','search', 'search bar' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }
	public function get_script_depends() { return [ 'mk-widgets' ]; }

	protected function register_controls() {
		mk_elem_start_ctrl($this, 'section_content', 'Content');

    		$this->add_control('icon', [
    			'label' => esc_html__( 'Search Icon', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::ICONS,
    			'default' => [
    				'value' => 'fas fa-search',
    				'library' => 'solid',
    			],
    		]);

    		$this->add_responsive_control('icon_size', [
    	        'label' => esc_html__( 'Button Icon Size', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::SLIDER,
    	        'default' => ['size' => 16, 'unit' => 'px'],
    	        'range' => [
    	            'px' => ['min' => 1, 'max' => 250, 'step' => 1]
    	        ],
    	        'size_units' => [ 'px' ],
    	        'selectors' => ['{{WRAPPER}} .mk-search-icon a' => 'font-size: {{SIZE}}{{UNIT}}',
                    '{{WRAPPER}} .mk-search-icon a svg' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}'
                ],
    	    ]);

    		mk_elem_heading_ctrl($this, 'search_popup_heading', 'Search Popup', 'before' );

            $this->add_responsive_control('width', [
    	        'label' => esc_html__( 'Search Bar Width', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::SLIDER,
    	        'default' => ['size' => 450, 'unit' => 'px'],
    	        'range' => [
    	            'px' => ['min' => 5, 'max' => 1000, 'step' => 5]
    	        ],
    	        'size_units' => [ 'px' ],
    	        'selectors' => ['{{WRAPPER}} .mk-search-wrapper input' => 'width: {{SIZE}}{{UNIT}}'],
    	    ]);

    		$this->add_group_control(
    			\Elementor\Group_Control_Typography::get_type(), [
    				'name' => 'search_typography',
    				'label' => esc_html__( 'Typography', 'orbius-core' ),
    				'selector' => '{{WRAPPER}} .mk-search-wrapper .input-group input',
    			]);

    		$this->add_control('placeholder', [
    				'label' => esc_html__( 'Placeholder Text', 'orbius-core' ),
    				'type' => \Elementor\Controls_Manager::TEXT,
    				'default' => esc_html__( 'Search for anything', 'orbius-core' ),
    			]);

    		$this->add_responsive_control('search_icon_size', [
    		        'label' => esc_html__( 'Search Icon Size', 'orbius-core' ),
    		        'type' => \Elementor\Controls_Manager::SLIDER,
    		        'default' => ['size' => 26, 'unit' => 'px'],
    		        'range' => [
    		            'px' => ['min' => 1, 'max' => 250, 'step' => 1]
    		        ],
    		        'size_units' => [ 'px' ],
    		        'selectors' => ['{{WRAPPER}} .mk-search-wrapper .input-group .input-group-button button i' => 'font-size: {{SIZE}}{{UNIT}}',
                        '{{WRAPPER}} .mk-search-wrapper .input-group .input-group-button svg' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}'
                        ],
    		    ]);

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'section_style', 'Search Icon', true);

    		$this->add_control('button_search_icon_color', [
    	        'label' => esc_html__( 'Icon Color', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::COLOR,
    	        'selectors' => ['{{WRAPPER}} .mk-search-icon a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-search-icon a svg' => 'fill: {{VALUE}}'
                ],
    	    ]);

    		$this->add_control('button_search_icon_hover_color', [
    	        'label' => esc_html__( 'Icon Hover Color', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::COLOR,
    	        'selectors' => ['{{WRAPPER}} .mk-search-icon a:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-search-icon a:hover svg' => 'fill: {{VALUE}}'
                ],
    	    ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_popup_style', 'Search Popup', true);

    		$this->add_control('search_bg_color', [
    	        'label' => esc_html__( 'Background Color', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::COLOR,
    	        'default' => 'rgba(255,255,255,0.9)',
    	        'selectors' => ['{{WRAPPER}} .mk-search-wrapper' => 'background: {{VALUE}}'],
    	    ]);

            $this->add_control('background_blur_level', [
                'label'      => esc_html__( 'Background Blur Level', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::SLIDER,
                'range'      => ['px' => ['min'  => 0, 'max'  => 50, 'step' => 1]],
                'selectors'  => ['{{WRAPPER}} .mk-search-wrapper' => '-webkit-backdrop-filter: blur({{SIZE}}px); backdrop-filter: blur({{SIZE}}px);'],
            ]);

    		$this->add_control('search_font_color', [
    	        'label' => esc_html__( 'Input Font Color', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::COLOR,
    	        'selectors' => ['{{WRAPPER}} .mk-search-wrapper .input-group input' => 'color: {{VALUE}}'],
    	    ]);

    		$this->add_control('search_placeholder_font_color', [
    	        'label' => esc_html__( 'Input Placeholder Font Color', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::COLOR,
    	        'selectors' => ['{{WRAPPER}} .mk-search-wrapper .input-group input::placeholder' => 'color: {{VALUE}}'],
    	    ]);

    		$this->add_control('search_border_color', [
    	        'label' => esc_html__( 'Search Input Border Color', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::COLOR,
    	        'default' => 'var(--swm-color-border)',
    	        'selectors' => ['{{WRAPPER}} .mk-search-wrapper .input-group' => 'border-color: {{VALUE}}'],
    	    ]);

    		$this->add_control('search_icon_color', [
    	        'label' => esc_html__( 'Search Icon Color', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::COLOR,
    	        'selectors' => ['{{WRAPPER}} .mk-search-wrapper .input-group .input-group-button button' => 'color: {{VALUE}}'],
    	    ]);

    		$this->add_control('close_icon_color', [
    	        'label' => esc_html__( 'Close Icon Color', 'orbius-core' ),
    	        'type' => \Elementor\Controls_Manager::COLOR,
    	        'selectors' => ['{{WRAPPER}} .mk-search-close:before, {{WRAPPER}} .mk-search-close:after' => 'background-color: {{VALUE}}'],
    	    ]);

		$this->end_controls_section();

	}

    protected function render() {

        $widget_id = $this->get_id();
        $settings = $this->get_settings();
        $random_id  = rand(10,100000);

        $redirect_to_page = get_site_url();
        if(!empty($settings['redirect_page'])) {
            $redirect_to_page = get_the_permalink($settings['redirect_page']);
        }

        $keyword = '';
        if(isset($_GET['s'])) {
            $keyword = $_GET['s'];
        } else {
            $redirect_to_page = '';
        }
        ?>
        <div class="mk-search-icon anrc-icon"><a data-open="mk_search_<?php echo esc_attr($widget_id) . $random_id; ?>" href="javascript:;"><?php \Elementor\Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); ?></a></div>

        <div id="mk_search_<?php echo esc_attr($widget_id) . $random_id; ?>" class="mk-search-wrapper no-visibility">

            <div class="mk-search-inner">
                <span class="mk-search-close"></span>

                <form id="mk_search_form_<?php echo esc_attr($widget_id) . $random_id; ?>" class="mk_search_form" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>" data-open="mk_search_<?php echo esc_attr($widget_id) . $random_id; ?>">
                    <div class="input-group">
                        <input name="s" placeholder="<?php echo esc_attr($settings['placeholder']); ?>" value="<?php echo esc_attr($keyword); ?>"/>
                        <?php if (function_exists('icl_object_id')) { ?>
                            <input id="lang" name="lang" type="hidden" value="<?php echo esc_attr(ICL_LANGUAGE_CODE); ?>"/>
                        <?php } ?>
                        <span class="input-group-button">
                            <button aria-label="<?php echo esc_attr($settings['placeholder']); ?>" type="submit"><?php \Elementor\Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); ?></button>
                        </span>
                    </div>
                </form>

            </div>
        </div>

    <?php
    }

}