<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Section_Heading extends \Elementor\Widget_Base {

	public function get_name()          { return 'mk_section_heading'; }
	public function get_title()         { return esc_html__( 'Section Heading', 'orbius-core' ); }
	public function get_icon()          { return 'mk-el-icon eicon-heading'; }
	public function get_categories()    { return ['mk-general-elements']; }
	public function get_keywords()      { return [ 'theme','title', 'subtitle','heading','title','section' ]; }
	public function get_style_depends() { return ['mk-core-main']; }
    public function get_script_depends() { return ['mk-widgets']; }

	protected function register_controls() {

        mk_elem_start_ctrl($this, 'title_content', 'Content');

		$this->add_control('title', [
			'label' => esc_html__( 'Title', 'orbius-core' ),
			'label_block' => true,
			'type' => \Elementor\Controls_Manager::TEXT,
			'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
			'default' => 'title text',
		]);

		$this->add_control('subtitle', [
			'label' => esc_html__( 'Sub Title', 'orbius-core' ),
			'label_block' => true,
			'type' => \Elementor\Controls_Manager::TEXT,
			'placeholder' => esc_html__( 'Enter Sub Title', 'orbius-core' ),
			'default' => 'Sub title text example',
		]);

		$this->end_controls_section();

        mk_elem_start_ctrl($this, 'general_style', 'General', true);

            $this->add_control('appear_animation_on',[
                'label'   => esc_html__( 'Appear Animation', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('items_border_color', [
                'label'     => esc_html__( 'Border Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-section-heading:after' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('border_size',[
                'label'       => esc_html__( 'Border Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 10, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-section-heading:after' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('border_space',[
                'label'       => esc_html__( 'Border Top Space', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-section-heading' => 'padding-bottom:{{SIZE}}{{UNIT}};',
                ],
            ]);


        $this->end_controls_section();

		mk_elem_start_ctrl($this, 'title_style', 'Title', true, ['title!' => '']);

		$this->add_control('title_color',[
			'label' => esc_html__( 'Color', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .mk-section-heading-title' => 'color: {{VALUE}};',
			],
		]);


        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'selector' => '{{WRAPPER}} .mk-section-heading-title',
        ]);

        $this->add_control( 'title_tag', [
            'type'       => \Elementor\Controls_Manager::SELECT,
            'label'      => esc_html__( 'Select Tag', 'orbius-core' ),
            'options'    => mk_arrays('title_tag'),
            'default' => 'h4',
            'selectors' => [
                '{{WRAPPER}} {{VALUE}}.mk-service-list-alt-title' => 'margin:0;',
            ],
        ]);

        $this->add_responsive_control('title_margin', [
            'label' => esc_html__( 'Margin', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'selectors' => [
                '{{WRAPPER}} .mk-section-heading-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

		$this->end_controls_section();

		// SUB TITLE

        mk_elem_start_ctrl($this, 'subtitle_style', 'Sub Title', true, ['subtitle!' => ''] );

    		$this->add_control('subtitle_color', [
    			'label' => esc_html__( 'Text Color', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .mk-section-heading-subtitle' => 'color: {{VALUE}};',
    			],
    		]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .mk-section-heading-subtitle',
            ]);

            $this->add_responsive_control('subtitle_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-section-heading-subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);


		$this->end_controls_section();

        mk_elem_start_ctrl($this, 'responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'subtitle_responsive_hide', 'Hide Subtitle At', 'none' );
        $this->end_controls_section();

	}

	protected function render() {
		$settings     = $this->get_settings_for_display();
        $title_html   = $subtitle_html = '';

        $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

        if ( '' !== $settings['title'] ) :
            $title_html .= '<' . $titleTagSelector . ' class="mk-section-heading-title"><span>' . $settings['title'] . '</span></' . $titleTagSelector . '>';
        endif;

        if ( '' !== $settings['subtitle'] ) :
            $subtitle_html .= '<span class="mk-section-heading-subtitle swm-hide-'. $settings['subtitle_responsive_hide'] .'">' . $settings['subtitle'] . '</span>';
        endif;

        $appear_animation = ( 'yes' === $settings['appear_animation_on'] ) ? ' mk-scroll--load' : '';

        echo '<div class="mk-section-heading' . $appear_animation . '">' . $title_html . $subtitle_html . '</div>';

	}

}