<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Service_List_Alt extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_service_list_alt'; }
	public function get_title()          { return esc_html__( 'Service List 2', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-post-list'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'service list', 'service', 'list', 'info','content','services' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_list', 'List Items');

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('title_text',	[
			'label'       => esc_html__( 'Service Title', 'orbius-core' ),
			'label_block' => true,
			'type'        => \Elementor\Controls_Manager::TEXT,
            'dynamic'     => ['active'  => true, ],
            'default'     => esc_html__('infographic design','orbius-core')
		]);

        $repeater->add_control('subtitle',	[
			'label'       => esc_html__( 'Subtitle', 'orbius-core' ),
			'label_block' => true,
			'type'        => \Elementor\Controls_Manager::TEXT,
            'dynamic'     => ['active'  => true, ],
            'default'     => esc_html__('interface','orbius-core')
		]);

        $repeater->add_control('mk_icon_type', [
			'label'       => esc_html__( 'Icon Type', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::CHOOSE,
            'label_block' => false,
            'options'     => [
                'none' => ['tab_title' => esc_html__( 'None', 'orbius-core' ), 'icon'  => 'eicon-ban', ],
                'icon' => ['tab_title' => esc_html__( 'Icon', 'orbius-core' ), 'icon'  => 'eicon-star', ],
                'image' => ['tab_title' => esc_html__( 'Image', 'orbius-core' ), 'icon'  => 'eicon-image', ],
            ],
            'default'     => 'icon',
		]);

        $repeater->add_control('list_icon', [
    		'label'       => esc_html__( 'Icon', 'elementor' ),
    		'type'        => \Elementor\Controls_Manager::ICONS,
    		'default'     => ['value' => 'far fa-sun', 'library' => 'fa-solid', ],
    		'condition'   => ['mk_icon_type' => 'icon', ],
        ]);

        $repeater->add_control('list_image', [
            'label'     => esc_html__( 'Image', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::MEDIA,
            'condition' => ['mk_icon_type' => 'image'],
        ]);

        $repeater->add_control('link',	[
			'label'   => esc_html__( 'Link', 'orbius-core' ),
			'type'    => \Elementor\Controls_Manager::URL,
            'dynamic' => ['active'  => true, ],
			'label_block' => true,
			'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            'default'     => ['url' => '#', ],
		]);

        $this->add_control('list_items', [
    		'type' => \Elementor\Controls_Manager::REPEATER,
    		'fields' => $repeater->get_controls(),
    		'default'               => [
				['title_text' => 'infographic design',  'subtitle' => 'interface', 'mk_icon_type' => 'icon', 'link' =>  ['url' => '#'], 'list_icon' => 'fa fa-sun' ],
                ['title_text' => 'product photography', 'subtitle' => 'photos',    'mk_icon_type' => 'icon', 'link' =>  ['url' => '#'], 'list_icon' => 'fa fa-sun' ],
				['title_text' => 'creative consulting', 'subtitle' => 'strategy',  'mk_icon_type' => 'icon', 'link' =>  ['url' => '#'], 'list_icon' => 'fa fa-sun' ],
			],
    		'title_field' => '{{{ title_text }}}',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'items_style', 'Items', true);

            $this->add_responsive_control('icon_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('items_border_color', [
                'label'     => esc_html__( 'Border Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-item' => 'border-bottom-color: {{VALUE}};',
                    '{{WRAPPER}} .mk-service-list-alt-item:after' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('border_size',[
                'label'       => esc_html__( 'Border Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 10, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-alt-item:after' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('border_hover_size',[
                'label'       => esc_html__( 'Hover Border Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 10, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-alt-item:hover:after' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'icon_style', 'Icon/Image', true);

            $this->add_control('icon_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-icon, {{WRAPPER}} .mk-service-list-alt-icon i' => 'color: {{VALUE}};fill: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('image_width',[
                'label'       => esc_html__( 'Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-alt-icon' => 'font-size:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-service-list-alt-icon img' => 'width:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'service_image_size',
                'label'   => esc_html__( 'Image Size', 'orbius-core' ),
                'default' => 'full',
            ]);

            $this->add_responsive_control('icon_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styles', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-service-list-alt-title,
                {{WRAPPER}} .mk-service-list-alt-title a',
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-service-list-alt-title' => 'margin:0;',
                ],
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-title a,{{WRAPPER}} .mk-service-list-alt-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-title:hover a,{{WRAPPER}} .mk-service-list-alt-title:hover' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'subtitle_style', 'Subtitle', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .mk-service-list-alt-subtitle',
            ]);

            $this->add_control('subtitle_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-subtitle, {{WRAPPER}} .mk-service-list-alt-subtitle a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mk-service-list-alt-subtitle:before' => 'background-color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('subtitle_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'arrow_style', 'Arrow Icon', true);

            $this->add_control('arrow_on',[
                'label'   => esc_html__( 'Arrow Icon', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_responsive_control('arrow_size',[
                'label'       => esc_html__( 'Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 200, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-alt-arrow .swm-svg-services-list-alt-arrow' => 'font-size:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('arrow_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['arrow_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-arrow .swm-svg-services-list-alt-arrow,
                    {{WRAPPER}} .mk-service-list-alt-arrow a .swm-svg-services-list-alt-arrow' => 'color: {{VALUE}};fill: {{VALUE}};',
                ],
            ]);

            $this->add_control('arrow_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['arrow_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-arrow:hover .swm-svg-services-list-alt-arrow,
                    {{WRAPPER}} .mk-service-list-alt-arrow:hover a .swm-svg-services-list-alt-arrow' => 'color: {{VALUE}};fill: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('arrow_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'condition' => ['arrow_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-alt-arrow' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none' );
            mk_elem_hide_ctrl($this, 'subtitle_responsive_hide', 'Hide Subtitle At', 'none' );
            mk_elem_hide_ctrl($this, 'icon_responsive_hide', 'Hide Icon At', 'none' );
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrow Icon At', 'none' );
        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $serviceItemHTML = '';
        $i = 1;

        foreach ( $settings['list_items'] as $item ) :

            $iconHTML = $link_start = $link_end = $title = $subtitle = $arrow = '';
            $arrow_link_start = '<a href="#">';
            $arrow_link_end = '</a>';

            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $arrow_link_start = $link_start = '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end = '</a>';
            }

            if ( $item['mk_icon_type'] == 'icon' ) {

                ob_start();
                \Elementor\Icons_Manager::render_icon( $item['list_icon'], array( 'aria-hidden' => 'true' ) );
                $icon_tag = ob_get_clean();

                $iconHTML .= '<div class="mk-service-list-alt-icon swm-hide-'. $settings['icon_responsive_hide'] .'">' . $link_start . $icon_tag . $link_end . '</div>';

            } elseif ( $item['mk_icon_type'] == 'image' ) {

                if (  $settings['service_image_size_size'] == 'custom' ) {
                    $imageTag = '<img '.mk_custom_image_size_html($this, $settings, $item['list_image'], $item['list_image']['id'], 'service_image_size', 'service_img_' . $i).' />';
                } else {
                    $imageTag = wp_get_attachment_image( $item['list_image']['id'], $settings['service_image_size_size']);
                }

                $iconHTML .= '<div class="mk-service-list-alt-icon swm-hide-'. $settings['icon_responsive_hide'] .'">' . $link_start . $imageTag . $link_end . '</div>';

            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            // title
            if ( ! empty( $item['title_text'] ) ) {
                $title .= '<'.$titleTagSelector.' class="mk-service-list-alt-title swm-hide-'. $settings['title_responsive_hide'] .'">' . $link_start . $item['title_text'] . $link_end . '</'.$titleTagSelector . '>';
            }

            // subtitle
            $subtitle .= ( !empty( $item['subtitle'] ) ) ? '<div class="mk-service-list-alt-subtitle swm-hide-'. $settings['subtitle_responsive_hide'] .'">' . $link_start . $item['subtitle'] . $link_end . '</div>' : '';

            // arrow
            if ( $settings['arrow_on'] === 'yes' ) {
                $arrow .= '<div class="mk-service-list-alt-arrow swm-hide-'. $settings['arrows_responsive_hide'] .'">' . $link_start . mk_get_svg_icon( 'arrow', 'swm-svg-services-list-alt-arrow' ) . $link_end . '</div>';
            }

            $serviceItemHTML .= '<div class="mk-service-list-alt-item">
                                    ' . $iconHTML . '
                                    <div class="mk-service-list-alt-text">
                                        ' . $subtitle . '
                                        <div class="mk-service-list-alt-title-text">' . $title . $arrow . '</div>
                                    </div>
                                </div>';
            $i++;
        endforeach;

        echo '<div class="mk-service-list-alt">' . $serviceItemHTML . '</div>';

    }


}