<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Service_List_Simple extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_service_list_simple'; }
	public function get_title()          { return esc_html__( 'Service List 3 (Simple)', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-post-list'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'service list', 'service', 'list', 'info','content','services','simple' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_list', 'List Items');

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('title_text',	[
			'label'       => esc_html__( 'Service Title', 'orbius-core' ),
			'label_block' => true,
			'type'        => \Elementor\Controls_Manager::TEXT,
            'dynamic'     => ['active'  => true, ],
            'default'     => esc_html__('infographic design','orbius-core')
		]);

        $repeater->add_control('link',	[
			'label'   => esc_html__( 'Link', 'orbius-core' ),
			'type'    => \Elementor\Controls_Manager::URL,
            'dynamic' => ['active'  => true, ],
			'label_block' => true,
			'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            'default'     => ['url' => '#', ],
		]);

        $this->add_control('list_items', [
    		'type' => \Elementor\Controls_Manager::REPEATER,
    		'fields' => $repeater->get_controls(),
    		'default'               => [
				['title_text' => 'adaptive design solutions',  'link' =>  ['url' => '#'] ],
                ['title_text' => 'diverse portfolio showcase', 'link' =>  ['url' => '#'] ],
				['title_text' => 'prompt project delivery', 'link' =>  ['url' => '#'] ],
			],
    		'title_field' => '{{{ title_text }}}',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'items_style', 'Items', true);

            $this->add_responsive_control('items_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-simple-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_control('items_border_color', [
                'label'     => esc_html__( 'Border Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-simple-item:after' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('border_size',[
                'label'       => esc_html__( 'Border Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 10, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-simple-item:after' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('border_hover_size',[
                'label'       => esc_html__( 'Hover Border Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 10, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-simple-item:hover:after' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_styles', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-service-list-simple-title,
                {{WRAPPER}} .mk-service-list-simple-title a',
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-service-list-simple-title' => 'margin:0;',
                ],
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-simple-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-simple-item:hover .mk-service-list-simple-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-simple-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('bullet_size',[
                'label'       => esc_html__( 'Bullet Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-simple-title:before' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('bullet_hover_size',[
                'label'       => esc_html__( 'Hover Bullet Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-simple-item:hover .mk-service-list-simple-title:before' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('bullet_spacing',[
                'label'       => esc_html__( 'Bullet Spacing', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-simple-title:before' => 'margin-right:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'arrow_style', 'Arrow Icon', true);

            $this->add_control('arrow_on',[
                'label'   => esc_html__( 'Arrow Icon', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_responsive_control('arrow_size',[
                'label'       => esc_html__( 'Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 200, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-simple-arrow .swm-svg-services-list-simple-arrow' => 'font-size:{{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_control('arrow_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['arrow_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-simple-arrow .swm-svg-services-list-simple-arrow' => 'color: {{VALUE}};fill: {{VALUE}};',
                ],
            ]);

            $this->add_control('arrow_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['arrow_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-simple-item:hover .mk-service-list-simple-arrow .swm-svg-services-list-simple-arrow' => 'color: {{VALUE}};fill: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('arrow_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'condition' => ['arrow_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-service-list-simple-arrow' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('arrow_angle',[
                'label'       => esc_html__( 'Arrow Angle', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px'],
                'range'       => ['px' => ['min' => -180, 'max' => 180, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-simple-arrow .swm-svg-services-list-simple-arrow' => 'transform:rotate({{SIZE}}deg);',
                ],
            ]);

            $this->add_responsive_control('arrow_hover_angle',[
                'label'       => esc_html__( 'Hover Arrow Angle', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px'],
                'range'       => ['px' => ['min' => -180, 'max' => 180, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-service-list-simple-item:hover .swm-svg-services-list-simple-arrow' => 'transform:rotate({{SIZE}}deg);',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none' );
            mk_elem_hide_ctrl($this, 'arrows_responsive_hide', 'Hide Arrow Icon At', 'none' );
        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $serviceItemHTML = '';
        $i = 1;

        foreach ( $settings['list_items'] as $item ) :

            $arrow_link = $title = $arrow = '';

            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_link_attributes( $link_key, $item['link'] );

                $arrow_link = '<a ' . $this->get_render_attribute_string( $link_key ) . '></a>';
            }

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

            // title
            if ( ! empty( $item['title_text'] ) ) {
                $title .= '<'.$titleTagSelector.' class="mk-service-list-simple-title swm-hide-'. $settings['title_responsive_hide'] .'">' . $item['title_text'] . '</'.$titleTagSelector . '>';
            }

            // arrow
            if ( $settings['arrow_on'] === 'yes' ) {
                $arrow .= '<div class="mk-service-list-simple-arrow swm-hide-'. $settings['arrows_responsive_hide'] .'">' . mk_get_svg_icon( 'arrow', 'swm-svg-services-list-simple-arrow' ) . '</div>';
            }

            $serviceItemHTML .= '<div class="mk-service-list-simple-item">' . $arrow_link . $title . $arrow . '</div>';

            $i++;
        endforeach;

        echo '<div class="mk-service-list-simple">' . $serviceItemHTML . '</div>';

    }


}