<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Service_List extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_service_list'; }
	public function get_title()          { return esc_html__( 'Service List 1', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-post-list'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'service list', 'service', 'list', 'info','content','services' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_list', 'List Items');

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('text',	[
			'label'       => esc_html__( 'Title', 'orbius-core' ),
			'label_block' => true,
			'type'        => \Elementor\Controls_Manager::TEXT,
            'dynamic'     => [
                'active'  => true,
            ],
            'default'     => esc_html__('List Item Title','orbius-core')
		]);

        $repeater->add_control('title_prefix', [
            'label'       => esc_html__( 'Title Prefix Text', 'orbius-core' ),
            'label_block' => true,
            'type'        => \Elementor\Controls_Manager::TEXT,
            'dynamic'     => [
                'active'  => true,
            ]
        ]);

        $repeater->add_control('description',	[
			'label'       => esc_html__( 'Description', 'orbius-core' ),
			'label_block' => true,
			'type'        => \Elementor\Controls_Manager::WYSIWYG,
            'dynamic'     => [
                'active'  => true,
            ],
            'default'     => esc_html__('List Item Description','orbius-core')
		]);

        $repeater->add_control('mk_icon_type', [
			'label'       => esc_html__( 'Icon Type', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::CHOOSE,
            'label_block' => false,
            'options'     => [
                'none' => [
                    'title' => esc_html__( 'None', 'orbius-core' ),
                    'icon'  => 'eicon-ban',
                ],
                'icon' => [
                    'title' => esc_html__( 'Icon', 'orbius-core' ),
                    'icon'  => 'eicon-star',
                ],
                'image' => [
                    'title' => esc_html__( 'Image', 'orbius-core' ),
                    'icon'  => 'eicon-image',
                ],
                'text' => [
                    'title' => esc_html__( 'Text', 'orbius-core' ),
                    'icon'  => 'eicon-text-area'
                ],
            ],
            'default'       => 'icon',
		]);

        $repeater->add_control('list_icon', [
    		'label' => esc_html__( 'Icon', 'elementor' ),
    		'type' => \Elementor\Controls_Manager::ICONS,
    		'default' => [
    			'value' => 'fas fa-check',
    			'library' => 'fa-solid',
    		],
    		'condition'         => [
                'mk_icon_type' => 'icon',
            ],
        ]);

        $repeater->add_control('list_image', [
            'label'     => esc_html__( 'Image', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::MEDIA,
            'condition' => ['mk_icon_type' => 'image'],
        ]);

        $repeater->add_control('icon_text',	[
			'label'             => esc_html__( 'Icon Text', 'orbius-core' ),
			'label_block'       => false,
			'type'              => \Elementor\Controls_Manager::TEXT,
            'default'           => esc_html__('1','orbius-core'),
	        'condition'         => [
                'mk_icon_type' => 'text',
            ],
		]);

        $repeater->add_control('link_type', [
            'label'             => esc_html__( 'Link Type', 'orbius-core' ),
            'type'              => \Elementor\Controls_Manager::SELECT,
            'options'           => [
                'none'      => esc_html__( 'None', 'orbius-core' ),
                'box'       => esc_html__( 'All Content', 'orbius-core' ),
                'title'     => esc_html__( 'Title', 'orbius-core' ),
                'button'    => esc_html__( 'Button', 'orbius-core' ),
            ],
            'default'           => 'none',
        ]);

        $repeater->add_control('button_text', [
            'label'             => esc_html__( 'Button Text', 'orbius-core' ),
            'type'              => \Elementor\Controls_Manager::TEXT,
            'dynamic'           => [
                'active'    => true,
            ],
            'default'           => esc_html__( 'Get Started', 'orbius-core' ),
            'condition'         => [
                'link_type' => 'button',
            ],
        ]);

        $repeater->add_control('button_icon', [
    		'label' => esc_html__( 'Button Icon', 'elementor' ),
    		'type' => \Elementor\Controls_Manager::ICONS,
    		'default' => [
    			'value' => 'fas fa-star',
    			'library' => 'fa-solid',
    		],
    		'condition'         => [
    		    'link_type' => 'button',
    		],
        ]);

        $repeater->add_control('button_icon_position', [
            'label'             => esc_html__( 'Icon Position', 'orbius-core' ),
            'type'              => \Elementor\Controls_Manager::SELECT,
            'default'           => 'after',
            'options'           => [
                'after'     => esc_html__( 'After', 'orbius-core' ),
                'before'    => esc_html__( 'Before', 'orbius-core' ),
            ],
            'condition'         => [
                'link_type'     => 'button',
                'button_icon!'  => '',
            ],
        ]);

        $repeater->add_control('link',	[
			'label'             => esc_html__( 'Link', 'orbius-core' ),
			'type'              => \Elementor\Controls_Manager::URL,
            'dynamic'           => [
                'active'  => true,
            ],
			'label_block'       => true,
			'placeholder'       => esc_html__( 'http://your-link.com', 'orbius-core' ),
            'default'               => [
                'url' => '#',
            ],
            'conditions'        => [
				'terms' => [
					[
						'name' => 'link_type',
						'operator' => '!=',
						'value' => 'none',
					],
				],
			],
		]);

        $repeater->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name'      => 'icon_bg_unique',
            'label'     => esc_html__( 'Icon Box Background', 'orbius-core' ),
            'types'     => [ 'classic', 'gradient' ],
            'condition'         => [
                'mk_icon_type!' => 'none',
                'mk_icon_type!' => 'image',
            ],
            'selector'  => '{{WRAPPER}} {{CURRENT_ITEM}}.mk-service-list-item-inner .mk-servicelist-icon-wrapper',
        ]);

        $this->add_control('list_items', [
    		'type' => \Elementor\Controls_Manager::REPEATER,
    		'fields' => $repeater->get_controls(),
    		'default'               => [
				[
					'text'      => esc_html__( 'List Item One', 'orbius-core' ),
                    'list_icon' => esc_html__('fa fa-check','orbius-core')
				],
                [
					'text'      => esc_html__( 'List Item Two', 'orbius-core' ),
                    'list_icon' => esc_html__('fa fa-heart','orbius-core')
				],
				[
					'text'      => esc_html__( 'List Item Three', 'orbius-core' ),
                    'list_icon' => esc_html__('eicon-star','orbius-core')
				],
			],
    		'title_field' => '{{{ text }}}',
        ]);


		$this->add_group_control(\Elementor\Group_Control_Image_Size::get_type(),	[
			'name'                  => 'thumbnail',
            'label'                 => esc_html__( 'Image Size', 'orbius-core' ),
            'default'               => 'full',
			'separator'             => 'before',
		]);

        $this->add_control('connector',[
            'label'   => esc_html__( 'Connector', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('corner_lines',[
            'label'   => esc_html__( 'Hide Corner Lines', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
            'condition' => ['connector' => 'yes', ]
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_list_style', 'List', true);

		$this->add_responsive_control('items_spacing',	[
			'label'                 => esc_html__( 'Items Spacing', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SLIDER,
			'default'               => [
                'size' => 15,
            ],
            'range'       => ['px' => ['min' => -100, 'max' => 300, ] ],
			'selectors'             => [
				'{{WRAPPER}}.mk-service-list-icon-left .mk-service-list-item:not(:last-child) .mk-service-list-item-inner, {{WRAPPER}}.mk-service-list-icon-right .mk-service-list-item:not(:last-child) .mk-service-list-item-inner' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}}.mk-service-list-icon-top .mk-service-list-item .mk-service-list-item-inner' => 'margin-right: calc({{SIZE}}{{UNIT}}/2); margin-left: calc({{SIZE}}{{UNIT}}/2);',
				'{{WRAPPER}}.mk-service-list-icon-top .mk-list-items' => 'margin-right: calc(-{{SIZE}}{{UNIT}}/2); margin-left: calc(-{{SIZE}}{{UNIT}}/2);',

				'(tablet){{WRAPPER}}.mk-service-list-stack-tablet.mk-service-list-icon-top .mk-service-list-item .mk-service-list-item-inner' => 'margin-bottom: {{SIZE}}{{UNIT}}; margin-left: 0; margin-right: 0;',
                '(tablet){{WRAPPER}}.mk-service-list-stack-tablet.mk-service-list-icon-top .mk-list-items' => 'margin-right: 0; margin-left: 0;',

				'(mobile){{WRAPPER}}.mk-service-list-stack-mobile.mk-service-list-icon-top .mk-service-list-item .mk-service-list-item-inner' => 'margin-bottom: {{SIZE}}{{UNIT}}; margin-left: 0; margin-right: 0;',
                '(mobile){{WRAPPER}}.mk-service-list-stack-mobile.mk-service-list-icon-top .mk-list-items' => 'margin-right: 0; margin-left: 0;',
			],
		]);

		$this->add_control('icon_position',	[
            'label'                 => esc_html__( 'Position', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::CHOOSE,
			'label_block'           => false,
			'toggle'                => false,
            'default'               => 'left',
            'options'               => [
                'left'      => [
                    'title' => esc_html__( 'Left', 'orbius-core' ),
                    'icon'  => 'eicon-h-align-left',
                ],
                'top'       => [
                    'title' => esc_html__( 'Top', 'orbius-core' ),
                    'icon'  => 'eicon-v-align-top',
                ],
                'right'     => [
                    'title' => esc_html__( 'Right', 'orbius-core' ),
                    'icon'  => 'eicon-h-align-right',
                ],
            ],
			'prefix_class'          => 'mk-service-list-icon-',
		]);

		$this->add_control('responsive_breakpoint',	[
			'label'                 => esc_html__( 'Responsive Breakpoint', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SELECT,
			'label_block'           => false,
			'default'               => 'mobile',
			'options'               => [
				''         => esc_html__( 'None', 'orbius-core' ),
				'tablet'   => esc_html__( 'Tablet', 'orbius-core' ),
				'mobile'   => esc_html__( 'Mobile', 'orbius-core' ),
			],
			'prefix_class'          => 'mk-service-list-stack-',
            'condition'             => [
                'icon_position' => 'top',
            ],
		]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_connector_style', 'Connector', true);

		$this->add_control('connector_color',	[
			'label'                 => esc_html__( 'Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '#e6e6e6',
			'selectors'             => [
				'{{WRAPPER}} .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}} .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-color: {{VALUE}};',
			],
            'condition'             => [
                'connector' => 'yes',
            ],
		]);

		$this->add_control('connector_style',	[
			'label'                 => esc_html__( 'Style', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SELECT,
			'options'               => [
				'solid'    => esc_html__( 'Solid', 'orbius-core' ),
				'double'   => esc_html__( 'Double', 'orbius-core' ),
				'dotted'   => esc_html__( 'Dotted', 'orbius-core' ),
				'dashed'   => esc_html__( 'Dashed', 'orbius-core' ),
			],
			'default'               => 'solid',
			'selectors'             => [
				'{{WRAPPER}}.mk-service-list-icon-left .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-left .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-right-style: {{VALUE}};',
				'{{WRAPPER}}.mk-service-list-icon-right .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-right .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-left-style: {{VALUE}};',
				'{{WRAPPER}}.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-top-style: {{VALUE}};',

				'(tablet){{WRAPPER}}.mk-service-list-stack-tablet.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-right-style: {{VALUE}};',

				'(mobile){{WRAPPER}}.mk-service-list-stack-mobile.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-right-style: {{VALUE}};',
			],
            'condition'             => [
                'connector' => 'yes',
            ],
		]);

		$this->add_responsive_control('connector_width',	[
			'label'                 => esc_html__( 'Width', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SLIDER,
			'default'               => [
				'size' => 1,
			],
			'range'                 => [
				'px' => [
					'min' => 1,
					'max' => 50,
				],
			],
			'selectors'             => [
				'{{WRAPPER}}.mk-service-list-icon-left .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-left .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-right-width: {{SIZE}}px;',
				'{{WRAPPER}}.mk-service-list-icon-right .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-right .mk-servicelist-icon-outer:after' => 'border-left-width: {{SIZE}}px;',
				'{{WRAPPER}}.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-top-width: {{SIZE}}px;',

				'(tablet){{WRAPPER}}.mk-service-list-stack-tablet.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-right-width: {{SIZE}}px;',

				'(mobile){{WRAPPER}}.mk-service-list-stack-mobile.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:before, {{WRAPPER}}.mk-service-list-icon-top .mk-service-list-connector .mk-servicelist-icon-outer:after' => 'border-right-width: {{SIZE}}px;',
			],
            'condition'             => [
                'connector' => 'yes',
            ],
		]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_icon_style', 'Icon', true);

        $this->add_control('icon_vertical_align',	[
			'label'                 => esc_html__( 'Vertical Align', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::CHOOSE,
			'label_block'           => false,
			'toggle'                => false,
			'default'               => 'middle',
			'options'               => mk_arrays('vertical_alignment'),
			'selectors_dictionary'  => [
				'top'          => 'flex-start',
				'middle'       => 'center',
				'bottom'       => 'flex-end',
			],
			'prefix_class'          => 'mk-service-list-icon-vertical-',
            'condition'             => [
                'icon_position' => ['left','right'],
            ],
		]);

        $this->add_control('icon_horizontal_align',	[
			'label'                 => esc_html__( 'Horizontal Align', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::CHOOSE,
			'label_block'           => false,
			'toggle'                => false,
			'options'               => mk_arrays('horizontal_alignment'),
			'default'               => 'left',
            'selectors_dictionary'  => [
				'left'     => 'flex-start',
				'center'   => 'center',
				'right'    => 'flex-end',
			],
			'prefix_class'          => 'mk-service-list-icon-horizontal-',
            'condition'             => [
                'icon_position' => 'top',
            ],
		]);

        $this->add_responsive_control('icon_size', [
            'label'                 => esc_html__( 'Size', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'default'               => [
                'size' => 14,
            ],
            'range'                 => [
                'px' => [
                    'min' => 6,
                    'max' => 200,
                ],
            ],
            'selectors'             => [
                '{{WRAPPER}} .mk-list-items .mk-service-list-icon' => 'font-size: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; width: {{SIZE}}{{UNIT}};',
                '{{WRAPPER}} .mk-list-items .mk-service-list-image img' => 'width: {{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'icon_number_typography',
            'selector' => '{{WRAPPER}} .mk-list-items .mk-service-list-icon.mk-service-list-number',
        ]);

        $this->add_responsive_control('icon_box_size', [
            'label'                 => esc_html__( 'Box Size', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'default'               => [
                'size' => 40,
            ],
            'range'                 => [
                'px' => [
                    'min' => 6,
                    'max' => 200,
                ],
            ],
            'selectors'             => [
                '{{WRAPPER}} .mk-servicelist-icon-wrapper' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
            ],
        ]);

        if ( is_rtl() ) {

            $this->add_responsive_control('icon_spacing',[
                'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::SLIDER,
                'default'               => [
                    'size' => 15,
                ],
                'range'                 => [
                    'px' => [
                        'max' => 200,
                    ],
                ],
                'selectors'             => [
                    '{{WRAPPER}}.mk-service-list-icon-left .mk-servicelist-icon-outer' => 'margin-left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.mk-service-list-icon-right .mk-servicelist-icon-outer' => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.mk-service-list-icon-top .mk-servicelist-icon-outer' => 'margin-bottom: {{SIZE}}{{UNIT}};',

                    '(tablet){{WRAPPER}}.mk-service-list-stack-tablet.mk-service-list-icon-top .mk-servicelist-icon-outer' => 'margin-right: {{SIZE}}{{UNIT}}; margin-bottom: 0;',

                    '(mobile){{WRAPPER}}.mk-service-list-stack-mobile.mk-service-list-icon-top .mk-servicelist-icon-outer' => 'margin-right: {{SIZE}}{{UNIT}}; margin-bottom: 0;',
                ],
            ]);

        } else {

            $this->add_responsive_control(
                'icon_spacing',
                [
                    'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
                    'type'                  => \Elementor\Controls_Manager::SLIDER,
                    'default'               => [
                        'size' => 15,
                    ],
                    'range'                 => [
                        'px' => [
                            'max' => 200,
                        ],
                    ],
                    'selectors'             => [
                        '{{WRAPPER}}.mk-service-list-icon-left .mk-servicelist-icon-outer' => 'margin-right: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}}.mk-service-list-icon-right .mk-servicelist-icon-outer' => 'margin-left: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}}.mk-service-list-icon-top .mk-servicelist-icon-outer' => 'margin-bottom: {{SIZE}}{{UNIT}};',

                        '(tablet){{WRAPPER}}.mk-service-list-stack-tablet.mk-service-list-icon-top .mk-servicelist-icon-outer' => 'margin-right: {{SIZE}}{{UNIT}}; margin-bottom: 0;',

                        '(mobile){{WRAPPER}}.mk-service-list-stack-mobile.mk-service-list-icon-top .mk-servicelist-icon-outer' => 'margin-right: {{SIZE}}{{UNIT}}; margin-bottom: 0;',
                    ],
                ]
            );

        }

        $this->add_control('icon_border_radius', [
            'label'                 => esc_html__( 'Box Border Radius', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', '%' ],
            'default'    => [
                'top'    => '100',
                'bottom' => '100',
                'left'   => '100',
                'right'  => '100',
                'unit'   => '%',
            ],
            'selectors'             => [
                '{{WRAPPER}} .mk-list-items .mk-servicelist-icon-wrapper,
                {{WRAPPER}} .mk-list-items .mk-servicelist-icon-outer,
                {{WRAPPER}} .mk-list-items .mk-servicelist-icon-outer' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_control('img_border_radius', [
            'label'                 => esc_html__( 'Image Border Radius', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units'            => [ 'px', '%' ],
            'selectors'             => [
                '{{WRAPPER}} .mk-list-items .mk-service-list-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->start_controls_tabs( 'tabs_icon_style' );

        $this->start_controls_tab('tab_icon_normal', [
            'label'                 => esc_html__( 'Normal', 'orbius-core' ),
        ]);

		$this->add_control('icon_color',	[
			'label'                 => esc_html__( 'Icon Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-list-items .mk-service-list-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-list-items .mk-service-list-icon svg' => 'fill: {{VALUE}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
            'name'      => 'icon_bg',
            'label'     => esc_html__( 'Icon Box Background', 'orbius-core' ),
            'types'     => [ 'classic', 'gradient' ],
            'fields_options' => [
                'background' => [
                    'default' =>'classic',
                ],
                'color' => [
                    'default' => '#f5f5f5',
                ],
            ],
            'selector'  => '{{WRAPPER}} .mk-list-items .mk-servicelist-icon-wrapper',
        ]);

        mk_elem_heading_ctrl($this, 'icon_border_outer_heading', 'Outside Border', 'before' );

		$this->add_group_control(\Elementor\Group_Control_Border::get_type(),	[
			'name'                  => 'icon_border',
			'label'                 => esc_html__( 'Outside Border', 'orbius-core' ),
			'placeholder'           => '1px',
			'default'               => '1px',
			'selector'              => '{{WRAPPER}} .mk-list-items .mk-servicelist-icon-outer',
		]);

        mk_elem_heading_ctrl($this, 'icon_border_inside_heading', 'Inside Border', 'before' );

        $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
            'name'        => 'icon_border_outside',
            'label'       => esc_html__( 'Inside Border', 'orbius-core' ),
            'selector'    => '{{WRAPPER}} .mk-list-items .mk-servicelist-icon-wrapper',
        ]);

        $this->end_controls_tab();

        $this->start_controls_tab('tab_icon_hover', [
            'label'                 => esc_html__( 'Hover', 'orbius-core' ),
        ]);

		$this->add_control('icon_color_hover',	[
			'label'                 => esc_html__( 'Icon Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-list-items .mk-servicelist-icon-wrapper:hover .mk-service-list-icon' => 'color: {{VALUE}};',
				'{{WRAPPER}} .mk-list-items .mk-servicelist-icon-wrapper:hover .mk-service-list-icon svg' => 'fill: {{VALUE}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Background::get_type(), [
                'name' => 'icon_bg_hover',
                'label' => esc_html__( 'Icon Box Background', 'orbius-core' ),
                'types' => [ 'classic', 'gradient' ],
                'separator'             => 'before',
                'selector' => '{{WRAPPER}} .mk-list-items .mk-servicelist-icon-wrapper:hover',
        ]);

		$this->add_control('icon_border_inside_color_hover',	[
			'label'                 => esc_html__( 'Inside Border Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-list-items .mk-servicelist-icon-wrapper:hover' => 'border-color: {{VALUE}};',
			],
		]);

        $this->add_control('icon_border_outside_color_hover', [
            'label'                 => esc_html__( 'Outside Border Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-list-items .mk-servicelist-icon-outer:hover' => 'border-color: {{VALUE}};',
            ],
        ]);

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_content_style', 'Content', true);

        $this->add_responsive_control('content_align',	[
			'label'                 => esc_html__( 'Alignment', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::CHOOSE,
			'options'               => mk_arrays('text_align_all'),
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-servicelist-content-wrapper' => 'text-align: {{VALUE}};',
			],
		]);

        mk_elem_heading_ctrl($this, 'title_heading', 'Title', 'before' );

		$this->add_control('title_color',	[
			'label'                 => esc_html__( 'Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-service-list-title, {{WRAPPER}} .mk-service-list-title a' => 'color: {{VALUE}};',
			],
		]);

        $this->add_control('title_hover_color',   [
            'label'                 => esc_html__( 'Hover Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-service-list-title a:hover' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_responsive_control('title_spacing', [
            'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::SLIDER,
            'default'               => [
                'size' => 0,
            ],
            'range'                 => [
                'px' => [
                    'min' => -25,
                    'max' => 150,
                ],
            ],
            'selectors'             => [
                '{{WRAPPER}} .mk-service-list-title ' => 'margin-bottom: {{SIZE}}{{UNIT}};'
            ],
        ]);

        $this->add_control('title_tag', [
            'label' => esc_html__( 'Select Tag', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'h2' => 'H2',
                'h3' => 'H3',
                'h4' => 'H4',
                'h5' => 'H5',
                'h6' => 'H6',
                'div' => 'div',
            ],
            'default' => 'h3',
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'                  => 'title_typography',
            'label'                 => esc_html__( 'Typography', 'orbius-core' ),
            'fields_options' => [
                'typography' => [
                    'default' =>'custom',
                ],
                'font_size'   => [
                    'default' => [
                        'size' => '20',
                    ],
                ]
            ],
            'selector'              => '{{WRAPPER}} .mk-service-list-title',
        ]);

        mk_elem_heading_ctrl($this, 'title_prefix_heading', 'Title Prefix', 'before' );

        $this->add_control('title_prefix_color', [
            'label'                 => esc_html__( 'Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-service-list-title span' => 'color: {{VALUE}};',
            ],
        ]);

        if ( is_rtl() ) {

            $this->add_responsive_control('title_prefix_spacing', [
                'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::SLIDER,
                'default'               => [
                    'size' => 15,
                ],
                'range'                 => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'selectors'             => [
                    '{{WRAPPER}} .mk-service-list-title span ' => 'margin-left: {{SIZE}}{{UNIT}};'
                ],
            ]);

        } else {

            $this->add_responsive_control('title_prefix_spacing', [
                'label'                 => esc_html__( 'Spacing', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::SLIDER,
                'default'               => [
                    'size' => 15,
                ],
                'range'                 => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'selectors'             => [
                    '{{WRAPPER}} .mk-service-list-title span ' => 'margin-right: {{SIZE}}{{UNIT}};'
                ],
            ]);

        }

        mk_elem_heading_ctrl($this, 'description_heading', 'Description', 'before' );

		$this->add_control('description_color',	[
			'label'                 => esc_html__( 'Color', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .mk-service-list-description' => 'color: {{VALUE}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'description_typography',
            'selector' => '{{WRAPPER}} .mk-service-list-description',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_service_box_button_style', 'Button', true);

		$this->add_control('button_size',	[
			'label'                 => esc_html__( 'Size', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::SELECT,
			'default'               => 'sm',
			'options'               => [
				'xs' => esc_html__( 'Extra Small', 'orbius-core' ),
				'sm' => esc_html__( 'Small', 'orbius-core' ),
				'md' => esc_html__( 'Medium', 'orbius-core' ),
				'lg' => esc_html__( 'Large', 'orbius-core' ),
				'xl' => esc_html__( 'Extra Large', 'orbius-core' ),
			],
		]);

        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab('tab_button_normal', [
            'label' => esc_html__( 'Normal', 'orbius-core' ),
        ]);

        $this->add_control('button_bg_color_normal', [
            'label'                 => esc_html__( 'Background Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-service-list-button' => 'background-color: {{VALUE}}',
            ],
        ]);

        $this->add_control('button_text_color_normal', [
            'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-service-list-button' => 'color: {{VALUE}}',
                '{{WRAPPER}} .mk-service-list-button svg' => 'fill: {{VALUE}}',
            ],
        ]);

		$this->add_group_control(\Elementor\Group_Control_Border::get_type(),	[
			'name'                  => 'button_border_normal',
			'label'                 => esc_html__( 'Border', 'orbius-core' ),
			'placeholder'           => '1px',
			'default'               => '1px',
			'selector'              => '{{WRAPPER}} .mk-service-list-button',
		]);

		$this->add_control('button_border_radius',	[
			'label'                 => esc_html__( 'Border Radius', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', '%' ],
			'selectors'             => [
				'{{WRAPPER}} .mk-service-list-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'button_typography',
            'selector' => '{{WRAPPER}} .mk-service-list-button',
        ]);

		$this->add_responsive_control('button_padding',	[
			'label'                 => esc_html__( 'Padding', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', 'em', '%' ],
			'selectors'             => [
				'{{WRAPPER}} .mk-service-list-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

		$this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(),	[
			'name'                  => 'button_box_shadow',
			'selector'              => '{{WRAPPER}} .mk-service-list-button',
		]);

        mk_elem_heading_ctrl($this, 'service_box_button_icon_heading', 'Button Icon', 'before' );

		$this->add_responsive_control('button_icon_margin',	[
			'label'                 => esc_html__( 'Margin', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'            => [ 'px', '%' ],
			'placeholder'       => [
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
			],
			'selectors'             => [
				'{{WRAPPER}} .mk-service-list-button .mk-button-icon' => 'margin-top: {{TOP}}{{UNIT}}; margin-left: {{LEFT}}{{UNIT}}; margin-right: {{RIGHT}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
			],
		]);

        $this->end_controls_tab();

        $this->start_controls_tab('tab_button_hover', [
            'label'                 => esc_html__( 'Hover', 'orbius-core' ),
        ]);

        $this->add_control('button_bg_color_hover', [
            'label'                 => esc_html__( 'Background Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-service-list-button:hover' => 'background-color: {{VALUE}}',
            ],
        ]);

        $this->add_control('button_text_color_hover', [
            'label'                 => esc_html__( 'Text Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-service-list-button:hover' => 'color: {{VALUE}}',
                '{{WRAPPER}} .mk-service-list-button:hover svg' => 'fill: {{VALUE}}',
            ],
        ]);

        $this->add_control('button_border_color_hover', [
            'label'                 => esc_html__( 'Border Color', 'orbius-core' ),
            'type'                  => \Elementor\Controls_Manager::COLOR,
            'default'               => '',
            'selectors'             => [
                '{{WRAPPER}} .mk-service-list-button:hover' => 'border-color: {{VALUE}}',
            ],
        ]);

		$this->add_control('button_animation',	[
			'label'                 => esc_html__( 'Animation', 'orbius-core' ),
			'type'                  => \Elementor\Controls_Manager::HOVER_ANIMATION,
		]);

		$this->add_group_control(\Elementor\Group_Control_Box_Shadow::get_type(),	[
			'name'                  => 'button_box_shadow_hover',
			'selector'              => '{{WRAPPER}} .mk-service-list-button:hover',
		]);

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute( [
            'service-list' => [
                'class' => [
                    'mk-service-list-container'
                ]
            ],
            'service-list-items' => [
                'class' => 'mk-list-items'
            ],
            'list-item' => [
                'class' => 'mk-service-list-item'
            ],
            'icon' => [
                'class' => 'mk-service-list-icon'
            ],
            'service-list-button' => [
                'class' => [
                    'mk-service-list-button',
                    'swm-anim',
                    'elementor-size-' . $settings['button_size'],
                ]
            ]
		] );

		if ( $settings['connector'] == 'yes' ) {
            $this->add_render_attribute( 'service-list', 'class', 'mk-service-list-connector' );
			if ( $settings['corner_lines'] == 'yes' ) {
				$this->add_render_attribute( 'service-list', 'class', 'mk-service-list-corners-hide' );
			}
        }

		if ( $settings['button_animation'] ) {
			$this->add_render_attribute( 'service-list-button', 'class', 'elementor-animation-' . $settings['button_animation'] );
		}

        $i = 1;
        ?>
        <div <?php echo $this->get_render_attribute_string( 'service-list' ); ?>>
            <ul <?php echo $this->get_render_attribute_string( 'service-list-items' ); ?>>
                <?php foreach ( $settings['list_items'] as $index => $item ) : ?>
                    <?php if ( $item['text'] || $item['description'] ) {

                        $item_id = 'elementor-repeater-item-' . $item['_id'];
                        ?>
                        <li <?php echo $this->get_render_attribute_string( 'list-item' ); ?>>
                            <div class="mk-service-list-item-inner <?php echo $item_id; ?>">
                            <?php
                                $text_key = $this->get_repeater_setting_key( 'text', 'list_items', $index );
                                $this->add_render_attribute( $text_key, 'class', 'mk-service-list-title swm-anim' );
                                $this->add_inline_editing_attributes( $text_key, 'none' );

                                $description_key = $this->get_repeater_setting_key( 'description', 'list_items', $index );
                                $this->add_render_attribute( $description_key, 'class', 'mk-service-list-description' );
                                $this->add_inline_editing_attributes( $description_key, 'basic' );

                                $button_key = $this->get_repeater_setting_key( 'button-wrap', 'list_items', $index );
                                $this->add_render_attribute( $button_key, 'class', 'mk-service-list-button-wrapper mk-service-list-button-icon-'.$item['button_icon_position'] );

                                if ( ! empty( $item['link']['url'] ) ) {
                                    $link_key = 'link_' . $i;

                                    $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                                    if ( $item['link']['is_external'] ) {
                                        $this->add_render_attribute( $link_key, 'target', '_blank' );
                                    }

                                    if ( $item['link']['nofollow'] ) {
                                        $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                                    }
                                }
                                if ( $item['mk_icon_type'] != 'none' ) {
                                    $icon_key = 'icon_' . $i;

                                    $this->add_render_attribute( [
                                        $icon_key => [
                                            'class' => [
                                                'mk-servicelist-icon-wrapper',
                                                'swm-anim',
                                            ]
                                        ]
                                    ] );
                                    ?>
                                    <div class="mk-servicelist-icon-outer">
                                        <div <?php echo $this->get_render_attribute_string( $icon_key ); ?>>

                                            <?php
                                                if ( $item['mk_icon_type'] == 'icon' ) { ?>
                                                    <span class="mk-service-list-icon mk-icon "><?php \Elementor\Icons_Manager::render_icon( $item['list_icon'], [ 'aria-hidden' => 'true' ] ); ?></span>
    											<?php
                                                } elseif ( $item['mk_icon_type'] == 'image' ) {




                                                    if (  $settings['thumbnail_size'] == 'full' ) {
                                                        $imageTagHtml = wp_get_attachment_image( $item['list_image']['id'], 'full', "", ["alt" => esc_attr( \Elementor\Control_Media::get_image_alt( $item['list_image'] ) ) ]);
                                                    } else {
                                                        $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $item['list_image']['id'], 'thumbnail', $settings );
                                                        if ( ! $imgUrl ) {
                                                            $imgUrl = $item['list_image']['url'];
                                                        }
                                                        $imageTagHtml = '<img src="'.esc_url($imgUrl).'" alt="" />';
                                                    }

                                                    echo '<span class="mk-service-list-image">' . $imageTagHtml . '</span>';

                                                } elseif ( $item['mk_icon_type'] == 'text' ) {
                                                    printf( '<span class="mk-service-list-icon mk-service-list-number">%1$s</span>', esc_attr( $item['icon_text'] ) );
                                                }
                                            ?>
                                        </div>
                                    </div>

                                    <?php
                                }
                            ?>
                            <div class="mk-servicelist-content-wrapper">
                                <?php if ( ! empty( $item['link']['url'] ) && $item['link_type'] == 'box' ) { ?>
                                    <a <?php echo $this->get_render_attribute_string( $link_key ); ?>>
                                <?php }

                                $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h3';

                                ?>
                                <<?php echo $titleTagSelector; ?> <?php echo $this->get_render_attribute_string( $text_key ); ?>>
                                    <?php if ( ! empty( $item['link']['url'] ) && $item['link_type'] == 'title' ) { ?>
                                        <a <?php echo $this->get_render_attribute_string( $link_key ); ?>>
                                    <?php } ?>
                                        <?php if ( '' != $item['title_prefix'] ) { ?><span><?php echo $item['title_prefix']; ?></span><?php } ?><?php echo $item['text']; ?>
                                    <?php if ( ! empty( $item['link']['url'] ) && $item['link_type'] == 'title' ) { ?>
                                        </a>
                                    <?php } ?>
                                </<?php echo $titleTagSelector; ?>>
                                <?php
                                    printf( '<div %1$s>%2$s</div>', $this->get_render_attribute_string( $description_key ), $item['description'] );
                                ?>
                                <?php if ( ! empty( $item['link']['url'] ) && $item['link_type'] == 'button' ) { ?>
                                    <div <?php echo $this->get_render_attribute_string( $button_key ); ?>>
                                        <a <?php echo $this->get_render_attribute_string( $link_key ); ?>>
                                            <div <?php echo $this->get_render_attribute_string( 'service-list-button' ); ?>>
                                                <?php if ( ! empty( $item['button_icon'] ) ) { ?>
                                                    <span class="mk-button-icon mk-icon">
                                                    	<?php \Elementor\Icons_Manager::render_icon( $item['button_icon'], [ 'aria-hidden' => 'true' ] ); ?></span>
                                                <?php } ?>
                                                <?php if ( ! empty( $item['button_text'] ) ) { ?>
                                                    <span <?php echo $this->get_render_attribute_string( 'button_text' ); ?>>
                                                        <?php echo esc_attr( $item['button_text'] ); ?>
                                                    </span>
                                                <?php } ?>
                                            </div>
                                        </a>
                                    </div>
                                <?php } ?>
                                <?php
                                if ( ! empty( $item['link']['url'] ) && $item['link_type'] == 'box' ) {
                                    echo '</a>';
                                }
                                ?>
                            </div>
                            </div>
                        </li>
                    <?php } ?>
                <?php $i++; endforeach; ?>
            </ul>
        </div>
        <?php
    }

}