<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Team extends \Elementor\Widget_Base {

    public function get_name()       { return 'mk_team'; }
    public function get_title()      { return esc_html__( 'Team', 'orbius-core' ); }
    public function get_icon()       { return 'mk-el-icon eicon-person'; }
    public function get_categories() { return ['mk-general-elements']; }
    public function get_keywords()   { return [ 'theme','team member','team','memb er','person','staff' ]; }
    public function get_style_depends() { return ['mk-core-main']; }
    public function get_script_depends() { return [ 'mk-widgets','imagesLoaded', 'isotope','mk-resize' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_content', 'Person');

            $this->add_control('person_image', [
                'label'     => esc_html__( 'Person Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

            $this->add_control('person_name', [
                'label' => esc_html__( 'Person Name', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__('Enter Name', 'orbius-core'),
                'default' => 'amelia reed',
            ]);

            $this->add_control('person_position', [
                'label' => esc_html__( 'Person Position', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__('Enter Position', 'orbius-core'),
                'default' => 'brand strategist',
            ]);

            $this->add_control('person_single_link', [
                'label'    => esc_html__( 'Person Single Page Link', 'orbius-core' ),
                'type'     => \Elementor\Controls_Manager::URL,
                'default'  => ['url'         => '#', 'is_external' => '', ],
                'dynamic'  => ['active' => true, ],
                'selector' => '',
            ]);

            $this->add_control('social_icons_on',[
                'label'   => esc_html__( 'Social Media Sites', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('list_icon',[
                'label' => esc_html__( 'Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fab fa-instagram',
                    'library' => 'fa-brands',
                ],
                'exclude_inline_options' => [ 'svg' ],
                'skin' => 'inline'
            ]);

            $repeater->add_control('social_icon_link', [
                'label' => esc_html__( 'Link', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '#',
            ]);

            $this->add_control('social_icons_list', [
                'label' => esc_html__( 'Social Media Icons', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['list_icon' => ['value' => 'fab fa-instagram', 'library' => 'fa-brands' ] ],
                    ['list_icon' => ['value' => 'fab fa-dribbble', 'library' => 'fa-brands' ] ],
                    ['list_icon' => ['value' => 'fab fa-behance', 'library' => 'fa-brands' ] ],
                    ['list_icon' => ['value' => 'fab fa-pinterest', 'library' => 'fa-brands' ]
                ],
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'content_section_style', 'Content Section', true);

        $this->add_control('team_align', [
            'label'        => esc_html__( 'Alignment', 'orbius-core' ),
            'type'         => \Elementor\Controls_Manager::CHOOSE,
            'label_block'  => false,
            'options'      => mk_arrays('text_align'),
            'default'      => 'left',
            'prefix_class' => 'mk-team-align-'
        ]);

        $this->add_responsive_control('content_padding', [
            'label' => esc_html__( 'Padding', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-team-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'image_style', 'Image', true);

            $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
                'name'    => 'person_image_size',
                'label'   => esc_html__( 'Image Size', 'orbius-core' ),
                'description' => esc_html__( 'Use square image for Display Style 2 team member image.', 'orbius-core' ),
                'default' => 'full'
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'item_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-team-image',
            ]);

            $this->add_control('img_border_radius', [
                'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .mk-team-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'person_name_style', 'Person Name', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'team_name_typography',
                'selector' => '{{WRAPPER}} .mk-team-name-tag, {{WRAPPER}} .mk-team-name-tag a',
            ]);

            $this->add_responsive_control('name_position_gap', [
                'label'     => esc_html__( 'Margin Bottom', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 2,
                ],
                'range'     => ['px' => ['min' => -30, 'max' => 100, ], ],
                'selectors' => [
                    '{{WRAPPER}} .mk-team-name-tag' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ]
            ]);

            $this->add_control('member_name_col', [
                'label' => esc_html__( 'Person Name Text Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-team-name,
                    {{WRAPPER}} .mk-team-name a' => 'color: {{VALUE}}'
                ]
            ]);

            $this->add_control('member_name_html_tag', [
                'label'   => esc_html__( 'Name Text HTML Tag', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'h6',
                'options' => [
                    'h1'   => esc_html__( 'H1', 'orbius-core' ),
                    'h2'   => esc_html__( 'H2', 'orbius-core' ),
                    'h3'   => esc_html__( 'H3', 'orbius-core' ),
                    'h4'   => esc_html__( 'H4', 'orbius-core' ),
                    'h5'   => esc_html__( 'H5', 'orbius-core' ),
                    'h6'   => esc_html__( 'H6', 'orbius-core' ),
                    'div'  => esc_html__( 'div', 'orbius-core' ),
                    'span' => esc_html__( 'span', 'orbius-core' ),
                    'p'    => esc_html__( 'p', 'orbius-core' ),
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'position_style', 'Person Position', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'team_position_typography',
                'selector' => '{{WRAPPER}} .mk-team-position',
            ]);

            $this->add_control('member_position_col', [
                'label' => esc_html__( 'Person Position Text Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-team-position' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-team-position:before' => 'background-color: {{VALUE}}'
                ]
            ]);

            $this->add_responsive_control('position_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-team-position' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'icons_style', 'Social Icons', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'social_typography',
                'selector' => '{{WRAPPER}} .mk-team .mk-team-social a',
            ]);

            $this->add_control('social_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-team .mk-team-social a' => 'color: {{VALUE}};border-color: {{VALUE}};',
                ],
            ]);

            $this->add_control('social_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-team .mk-team-social a:hover' => 'color: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('social_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-team .mk-team-social a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);


        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $data_rtl = is_rtl() ? 'true' : 'false';
        ?>

        <div class="mk-team">
            <?php

            $team_link_key = 'team_link';

            if ( !empty( $settings['person_single_link']['url'] ) ) {

                $this->add_render_attribute( $team_link_key, 'href', esc_url($settings['person_single_link']['url']) );
                $this->add_render_attribute( $team_link_key, 'class', 'mk-team-link' );

                if ( $settings['person_single_link']['is_external'] ) {
                    $this->add_render_attribute( $team_link_key, 'target', '_blank' );
                }
                if ( $settings['person_single_link']['nofollow'] ) {
                    $this->add_render_attribute( $team_link_key, 'rel', 'nofollow' );
                }

                $title_link = $this->get_render_attribute_string( $team_link_key );

            }

            // responsive image
            if (  $settings['person_image_size_size'] == 'custom' ) {
                $imageTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $settings['person_image'], $settings['person_image']['id'], 'person_image_size', 'team_img_attr-'.$i).' />';
            } else {
                $imageTagHtml = wp_get_attachment_image( $settings['person_image']['id'], $settings['person_image_size_size']);
            }

            $socialIconsHtml = '';

            if ( 'yes' == $settings['social_icons_on'] ) :

                $socialIconsHtml .= '<div class="mk-team-social">
                                        <div class="mk-team-social-holder">';

                foreach ( $settings['social_icons_list'] as $index => $item ) :
                    $socialIconsHtml .= '<a href="' . esc_url($item['social_icon_link']) .'" class="" target="_blank">' . mk_get_elementor_icons($item['list_icon']) . '</a>';
                endforeach;

                $socialIconsHtml .= '</div>
                                </div>';

            endif;

            $team_single_link = ( ! empty( $settings['person_single_link']['url'] ) ) ? '<a ' . $title_link . '>' : '';
            $team_single_link_end = ( ! empty( $settings['person_single_link']['url'] ) ) ? '</a>' : '';

            $team_name = '<div class="mk-team-name"><' . $settings['member_name_html_tag'] . ' class="mk-team-name-tag">' . $team_single_link . $settings['person_name'] . $team_single_link_end . '</' . $settings['member_name_html_tag'] . '></div>';

            $team_position = ( '' !== $settings['person_position'] ) ? '<div class="mk-team-position">' . $settings['person_position'] . '</div>' : '';

            echo '<div class="mk-team-item">
                        ' . $team_position . '
                        <div class="mk-team-image">' . $team_single_link . $imageTagHtml . $team_single_link_end . '</div>
                        <div class="mk-team-content swm-anim">' . $team_name . $socialIconsHtml . '</div>
                    </div>
                </div>';

    }

}