<?php
if ( ! defined( 'ABSPATH' ) ) {exit; }

class Mk_Testimonials_Slider extends \Elementor\Widget_Base {

	public function get_name() {return 'mk_testimonials_slider'; }
	public function get_title() {return esc_html__( 'Testimonials Slider', 'orbius-core' ); }
	public function get_icon() {return 'mk-el-icon eicon-testimonial-carousel'; }
	public function get_categories()     { return [ 'mk-sliders-elements' ]; }
	public function get_keywords() {return [ 'testimonials', 'review', 'testimonial','testimonials', 'slider' ]; }
	public function get_style_depends() {return ['swiper', 'mk-core-main' ]; }
    public function get_script_depends() { return [ 'swiper','mk-custom-sliders' ]; }

	protected function register_controls() {

		    mk_elem_start_ctrl($this, 'testimonials_content', 'Testimonials');

    		$repeater = new \Elementor\Repeater();

            $repeater->add_control('image', [
                'label'   => esc_html__( 'Choose Image', 'renix-core' ),
                'type'    => \Elementor\Controls_Manager::MEDIA
            ]);

    		$repeater->add_control('name', [
    			'label' => esc_html__( 'Name', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::TEXT,
    			'placeholder' => esc_html__( 'Enter Name', 'orbius-core' ),
    			'default' => 'Roseline Gray',
    		  ]);

    		$repeater->add_control('position',[
    			'label' => esc_html__( 'Position', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::TEXT,
    			'placeholder' => esc_html__( 'Enter Position', 'orbius-core' ),
    			'default' => 'web designer',
    		  ]);

    		$repeater->add_control('comment', [
    			'label' => esc_html__( 'Comment', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::TEXTAREA,
    			'placeholder' => esc_html__( 'Enter Comment', 'orbius-core' ),
    			'default' => 'Lorem ipsum dolor sit amet saresw consectetur adipis cing elit sed do eiusmod tempor incidi duntut labore etolore magna aliqua ipsum suspen disse ultrices ida commodo.',
    		  ]);

    		$this->add_control('testimonials',[
    			'label' => esc_html__( 'Add Testimonial', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::REPEATER,
    			'fields' => $repeater->get_controls(),
    			'title_field' => '{{{ name }}}',
    		]);

		$this->end_controls_section();

		// Slider Settings
        mk_elem_start_ctrl($this, 'slider_settings', 'Slider Settings');

            $this->add_control('arrow_on',[
                'label'   => esc_html__( 'Arrow Navigation', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('dots_on',[
                'label'   => esc_html__( 'Dots Navigation', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('loop_on',[
                'label'   => esc_html__( 'Continuous Loop', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('mousewheel_on',[
                'label'   => esc_html__( 'Mousewheel Control', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('autoplay_on',[
                'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('hover_pause_on',[
                'label'   => esc_html__( 'Pause on Hover', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => ['autoplay_on' => 'yes']
            ]);

            $this->add_control('autoplay_speed', [
                'label' => esc_html__( 'Delay', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 5000,
                'step' => 100,
                'min' => 100,
                'max' => 15000,
            ]);

        $this->end_controls_section();

        // Comment
        mk_elem_start_ctrl($this, 'content_style', 'Content');

            mk_elem_heading_ctrl($this, 'comment_heading', 'Comment', 'before' );

            $this->add_control('comment_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-testimonials-slider-text' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'comment_typography',
                'selector' => '{{WRAPPER}} .mk-testimonials-slider-text',
            ]);

            mk_elem_heading_ctrl($this, 'name_headings', 'Name', 'before' );

            $this->add_control('name_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-testimonials-slider-name' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'name_typography',
                'selector' => '{{WRAPPER}} .mk-testimonials-slider-name',
            ]);

            // Position
            mk_elem_heading_ctrl($this, 'position_icon', 'Position', 'before' );

            $this->add_control('position_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-testimonials-slider-position' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'position_typography',
                'selector' => '{{WRAPPER}} .mk-testimonials-slider-position',
            ]);

            // Quote
            mk_elem_heading_ctrl($this, 'quote_icon', 'Quote', 'before' );

            $this->add_control('quote_on',[
                'label'   => esc_html__( 'Mousewheel Control', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

            $this->add_control('quote_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['quote_on' => 'yes'],
                'selectors' => [
                    '{{WRAPPER}} .mk-testimonials-slider-quote' => 'fill: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();


        // Arrow
        mk_elem_start_ctrl($this, 'nav_style', 'Navigation');

            $this->add_control('dot_color',[
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#000000',
                'selectors' => [
                    '{{WRAPPER}} .mk-testimonials-slider .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .mk-testimonials-slider .swiper-pagination-bullets .swiper-pagination-bullet-active:after,
                    {{WRAPPER}} .mk-testimonials-slider .swiper-pagination-bullets .swiper-pagination-bullet:hover:after' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .mk-testimonials-slider .mk-slider-pn' => 'fill: {{VALUE}}; border-color: {{VALUE}}',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings');
            mk_elem_hide_ctrl($this, 'image_responsive_hide', 'Hide Image At', 'mobile');
            mk_elem_hide_ctrl($this, 'name_responsive_hide', 'Hide Name At', 'none');
            mk_elem_hide_ctrl($this, 'position_responsive_hide', 'Hide Position At', 'none');
            mk_elem_hide_ctrl($this, 'quote_responsive_hide', 'Hide Quote Icon At', 'none');
            mk_elem_hide_ctrl($this, 'dot_nav_responsive_hide', 'Hide Dot Navigation At', 'mobile');
            mk_elem_hide_ctrl($this, 'arrow_nav_responsive_hide', 'Hide Arrow Navigation At', 'none');
        $this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();  ?>

        <div class="mk-testimonials-slider">
            <?php

            if ( 'yes' === $settings['quote_on'] ) {
                echo '<span class="mk-testimonials-slider-quote swm-hide-'. $settings['quote_responsive_hide'] . '">' . mk_get_svg_icon( 'quote', 'swm-svg-testimonials-quote' ) . '</span>';
            }

            $uniqueId = $this->get_id() . rand(10,100000);

            $sliderSettings = array(
                'arrows_on'         => $settings['arrow_on'],
                'dots'              => $settings['dots_on'],
                'autoplay'          => $settings['autoplay_on'],
                'autoplay_speed'    => $settings['autoplay_speed'],
                'speed'             => 1000,
                'mousewheel'        => $settings['mousewheel_on'],
                'loop'              => $settings['loop_on'],
                'pause_on_hover'    => $settings['hover_pause_on'],
                'slider_next'       => '.swiper-' . $uniqueId . '-next',
                'slider_prev'       => '.swiper-' . $uniqueId . '-prev',
                'slider_pagination' => '.swiper-' . $uniqueId . '-dot',
            );

            $this->add_render_attribute( [ 'slider-attrs'  => [
                    'class'          => [ 'swiper', 'swiper-container','mk-testimonials-slider-content' ],
                    'data-settings'  => json_encode( $sliderSettings ),
                    'id'             => 'swiper-' . $uniqueId
                ]
            ] );
            ?>
             <div <?php echo $this->get_render_attribute_string( 'slider-attrs' ); ?>>

                <div class="swiper-wrapper">
                    <?php
                    foreach ($settings['testimonials'] as $index => $item) : ?>

                        <div class="swiper-slide mk-testimonials-slider-item">
                            <div class="mk-testimonials-slider-item-wrapper">

                                <?php if ($item['comment']): ?>
                                    <div class="mk-testimonials-slider-text">
                                        <?php echo wp_kses( $item['comment'],mk_kses_allowed_textarea() ); ?>
                                    </div>
                                <?php endif; ?>

                                <div class="mk-testimonials-slider-name-image">

                                    <?php if ( $item['image']['url'] ):
                                            $imageTagHtml = wp_get_attachment_image( $item['image']['id'], 'thumbnail', "", ["class" => "mk-testimonials-face","alt" => esc_attr( $item['name'] )]); ?>
                                        <div class="mk-testimonials-slider-image <?php echo 'swm-hide-'. $settings['image_responsive_hide'];?>"><?php echo $imageTagHtml; ?></div>
                                    <?php endif; ?>

                                    <div class="mk-testimonials-slider-name-section">

                                        <?php if ($item['name']): ?>
                                            <span class="mk-testimonials-slider-name <?php echo 'swm-hide-'. $settings['name_responsive_hide'];?>"><?php echo esc_html($item['name']); ?></span>
                                        <?php endif; ?>

                                        <?php if ($item['position']): ?>
                                            <div class="mk-testimonials-pos-com">
                                                <span class="mk-testimonials-slider-position <?php echo 'swm-hide-'. $settings['position_responsive_hide'];?>"><?php echo esc_html($item['position']); ?></span>
                                            </div>
                                        <?php endif; ?>

                                    </div>

                                </div>
                            </div>
                        </div>

                        <?php
                    endforeach; ?>

                </div>

            </div>
            <div class="clear"></div>

            <?php if ( $settings['dots_on'] == 'yes' ) { ?>
                <div class="swiper-pagination <?php echo 'swiper-' . $uniqueId . '-dot';?> <?php echo 'swm-hide-'. $settings['dot_nav_responsive_hide'];?>"></div>
            <?php } ?>
             <?php if ( $settings['arrow_on'] == 'yes' ) { ?>
                <div class="mk-slider-next-prev <?php echo 'swm-hide-'. $settings['arrow_nav_responsive_hide'];?>">
                    <span class="mk-slider-prev swm-ficon mk-slider-pn <?php echo 'swiper-' . $uniqueId . '-prev';?>"><?php echo mk_get_svg_icon( 'arrow', 'swm-svg-testimonials-arrow' ); ?></span>
                    <span class="mk-slider-next swm-ficon mk-slider-pn <?php echo 'swiper-' . $uniqueId . '-next';?>"><?php echo mk_get_svg_icon( 'arrow', 'swm-svg-testimonials-arrow' ); ?></span>
                </div>
            <?php } ?>

        </div>
		<?php
	}

}