<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Text_Marquee extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_text_marquee'; }
	public function get_title()          { return esc_html__( 'Text Marquee', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-animation-text'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return ['theme','text marquee','scroll','scrolling text','auto scroll','running','news','moving text','move' ]; }
	public function get_style_depends()  { return ['mk-core-main']; }
	public function get_script_depends() { return ['typed', 'mk-widgets']; }

	protected function register_controls() {

        mk_elem_start_ctrl($this, 'section_general', 'General');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('item_text', [
                'label' => esc_html__( 'Text', 'orbius-core' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => 'Sample Text',
            ]);

            $repeater->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name' => 'individual_item_typography',
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}.mk-tm-text-item',
            ]);

            $repeater->add_control('individual_separator_icon', [
                'label' => esc_html__( 'Separator Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]);

            $repeater->add_control('individual_color', [
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.mk-tm-text-item' => 'color: {{VALUE}};',
                ],
            ]);

            $repeater->add_control('individual_text_stroke_effect',[
                'label'   => esc_html__( 'Text Stroke Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $repeater->add_control('individual_text_stroke_color', [
                'label' => esc_html__( 'Text Stroke Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.mk-tm-text-item ' => '-webkit-text-stroke-color: {{VALUE}};',
                ],
                'condition' => ['individual_text_stroke_effect' => 'yes'],
            ]);

            $repeater->add_control('individual_text_stroke_width', [
                'label' => esc_html__( 'Text Stroke Width', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 1,
                'step' => 1,
                'min' => 1,
                'max' => 20,
                 'condition' => ['individual_text_stroke_effect' => 'yes'],
                'selectors' => [
                     '{{WRAPPER}} {{CURRENT_ITEM}}.mk-tm-text-item ' => '-webkit-text-stroke-width: {{SIZE}}px;',
                ],
            ]);

            $this->add_control('items', [
                'label' => esc_html__( 'Items', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['item_text' => 'Sample Text One', ],
                    ['item_text' => 'Sample Text Two', ],
                ],
                'title_field' => '{{{ item_text }}}',
            ]);

            $this->add_control('duration', [
                'label' => esc_html__( 'Animation Duration (Seconds)', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 20,
                'step' => 1,
                'min' => 1,
                'max' => 999,
            ]);

            $this->add_control('reverse_direction', [
                'label'        => esc_html__( 'Reverse Direction', 'orbius-core' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'selectors_dictionary' => [
                    'yes' => 'animation:mk-move-horizontal-reverse-text-marquee',
                    '' => 'animation:mk-move-horizontal-normal-text-marquee',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mk-text-marquee .mk-tm-text.mk-text--original' => '{{VALUE}} {{duration.VALUE}}s linear infinite',
                    '{{WRAPPER}} .mk-text-marquee .mk-tm-text.mk-text--copy'     => '{{VALUE}}-copy {{duration.VALUE}}s linear infinite',
                ],
            ]);

            $this->end_controls_section();

            mk_elem_start_ctrl($this, 'text_marquee_style', 'Text');

            $this->add_control('color', [
                'label' => esc_html__( 'Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-tm-text-item' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'text_marquee_typography',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-tm-text-item',
            ]);

            $this->add_control('text_stroke_effect',[
                'label'   => esc_html__( 'Text Stroke Effect', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_control('text_stroke_color', [
                'label' => esc_html__( 'Text Stroke Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-tm-text-item ' => '-webkit-text-stroke-color: {{VALUE}};',
                ],
                'condition' => ['text_stroke_effect' => 'yes'],
            ]);

            $this->add_control('text_stroke_width', [
                'label' => esc_html__( 'Text Stroke Width', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 1,
                'step' => 1,
                'min' => 1,
                'max' => 20,
                'condition' => ['individual_text_stroke_effect' => 'yes'],
                'selectors' => [
                     '{{WRAPPER}} .mk-tm-text-item ' => '-webkit-text-stroke-width: {{SIZE}}px;',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'separator_icon_settings', 'Separator Icon');

            $this->add_control('separator_icon', [
                'label' => esc_html__( 'Separator Icon', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]);

            $this->add_control('icon_color', [
                'label' => esc_html__( 'Icon Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-icon-holder' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('icon_size',[
                'label'     => esc_html__( 'Icon Size', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', 'em'],
                'range'     => ['px' => ['min' => 0, 'max' => 100, ], ],
                'selectors' => [
                    '{{WRAPPER}} .mk-icon-holder' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->add_responsive_control('space_between_items',[
                'label'     => esc_html__( 'Space Between Items', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em'],
                'range'     => ['px' => ['min' => 0, 'max' => 500, ], ],
                'selectors' => [
                    '{{WRAPPER}} .mk-tm-text-item' => 'padding-right: calc({{SIZE}}{{UNIT}}/2); padding-left: calc({{SIZE}}{{UNIT}}/2);',
                ],
            ]);

            $this->add_control('icon_vertical_align',   [
                'label'       => esc_html__( 'Vertical Align', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::CHOOSE,
                'label_block' => false,
                'toggle'      => false,
                'default'     => 'middle',
                'options'     => mk_arrays('vertical_alignment'),
                'selectors_dictionary'  => [
                    'top'    => 'flex-start',
                    'middle' => 'center',
                    'bottom' => 'flex-end',
                ],
                'prefix_class' => 'mk-tm-icon-vertical-',
                'selectors' => [
                    '{{WRAPPER}} .mk-text-marquee .mk-icon-holder' => 'align-self: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('icon_padding', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-text-marquee .mk-icon-holder i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

	}

	public function render() {

        $atts = $this->get_settings_for_display();

        $container_classes = 'mk-text-marquee mk-layout--default';
        $container_classes .= ( 'yes' === $atts['text_stroke_effect'] ) ? ' mk-text-stroke-effect' : '';

        $icon_html = $marquee_text = '';
        $separator_icon = $atts['separator_icon'];

        if ( isset( $separator_icon ) && ! empty( $separator_icon['value'] ) ) {
            ob_start();
            echo '<span class="mk-icon-holder">';
                \Elementor\Icons_Manager::render_icon( $separator_icon, array( 'aria-hidden' => 'true' ) );
            echo '</span>';
            $icon_html = ob_get_clean();
        }

        foreach ( $atts['items'] as $item ) {

            $iconFinalHTML = $individual_separator_icon = $individualIconHTML = '';

            $individual_separator_icon = $item['individual_separator_icon'];

            if ( isset( $individual_separator_icon ) && ! empty( $individual_separator_icon['value'] ) ) {
                ob_start();
                echo '<span class="mk-icon-holder">';
                    \Elementor\Icons_Manager::render_icon( $individual_separator_icon, array( 'aria-hidden' => 'true' ) );
                echo '</span>';
                $individualIconHTML = ob_get_clean();
            }

            $iconFinalHTML = !empty($individualIconHTML) ? $individualIconHTML : $icon_html;

            $marquee_text .= '<span class="mk-tm-text-item elementor-repeater-item-'.$item['_id'].'">'.wp_kses( $item['item_text'],
                array( 'span' => array( 'style' => true ),
                        'a' => array(
                                    'href' => array(),
                                    'title' => array(),
                                    'target' => array(),
                                    'class' => array(),
                                    'id' => array()
                                ),
            )).'</span>'.$iconFinalHTML;
        }

        echo '<div class="'.$container_classes.'">
            <div class="mk-tm-content">
                <div class="mk-tm-text mk-text--original">'.$marquee_text.'</div>
                <div class="mk-tm-text mk-text--copy">'.$marquee_text.'</div>
            </div>
        </div>';

    }

}