<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Thumbnail_Slider extends \Elementor\Widget_Base {

    public function get_name()           { return 'mk_thumbnail_slider'; }
    public function get_title()          { return esc_html__( 'Thumbnail Slider', 'orbius-core' ); }
    public function get_icon()           { return 'mk-el-icon eicon-slider-push'; }
    public function get_categories()     { return [ 'mk-sliders-elements' ]; }
    public function get_keywords()       { return [ 'theme','slider','slide show','thumbnail','project','portfolio' ]; }
    public function get_style_depends()  { return [ 'swiper','mk-core-main']; }
    public function get_script_depends() { return [ 'swiper','mk-widgets' ]; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'slider_items_heading', 'Slider Items');

            $repeater = new \Elementor\Repeater();

            $repeater->add_control('title_text', [
                'label'       => esc_html__( 'Title', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => esc_html__('Title','orbius-core')
            ]);

            $repeater->add_control('category', [
                'label'       => esc_html__( 'Sub Title', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::TEXT,
            ]);

            $repeater->add_control('bg_image', [
                'label'       => esc_html__( 'Large Image', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::MEDIA,
                'default'     => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                 ],
            ]);

            $repeater->add_control('thumb_image', [
                'label'       => esc_html__( 'Thumbnail Image', 'orbius-core' ),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::MEDIA,
                'default'     => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                 ],
            ]);

            $repeater->add_control('link', [
                'label'       => esc_html__( 'Link', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'default'  => [
                                'url'         => '#',
                                'is_external' => '',
                            ],
                'separator'   => 'before',
                'placeholder' => esc_html__( 'http://your-link.com', 'orbius-core' ),
            ]);

            $this->add_control('slider_items', [
                'label' => esc_html__( 'Slider Items', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    ['title_text' => "small village", 'category' => "brand identity", 'link' => ['url' => '#'], ],
                    ['title_text' => "small village", 'category' => "brand identity", 'link' => ['url' => '#'], ],
                    ['title_text' => "small village", 'category' => "brand identity", 'link' => ['url' => '#'], ],
                ],
                'title_field' => '{{{ title_text }}}',
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_items_settings', 'Slider Settings');

        $this->add_responsive_control('sliderheight',[
                'label'       => esc_html__( 'Slider Height', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em', 'vh' ],
                'default'     => ['unit' => 'vh', 'size' => 70, ],
                'range'       => ['px' => ['min' => 0, 'max' => 1000, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .swiper-container' => 'height:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->add_control('loop_on',[
            'label'   => esc_html__( 'Continuous Loop', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('autoplay_on',[
            'label'   => esc_html__( 'Auto Play', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('hover_pause_on',[
            'label'   => esc_html__( 'Pause on Hover', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'condition' => ['autoplay_on' => 'yes']
        ]);

        $this->add_control('autoplay_speed', [
                'label' => esc_html__( 'Delay', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 5000,
                'step' => 100,
                'min' => 1000,
                'max' => 15000,
            ]);

        $this->add_control('speed', [
                'label' => esc_html__( 'Animation Speed', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 1000,
                'step' => 100,
                'min' => 100,
                'max' => 5000,
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'section_slider_style', 'Slider Holder', true);

            $this->add_control('slider_background', [
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-thumbnail-slider' => 'background: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('content_left_margin',[
                'label'       => esc_html__( 'Content Left Margin', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ '%', 'px', 'em', 'vh' ],
                'range'       => ['px' => ['min' => 0, 'max' => 1200, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-thumbnail-slider-content' => 'margin-left:{{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slide_style', 'Large Images', true);

        $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
            'name'                  => 'image',
            'label'                 => esc_html__( 'Background Image Size', 'orbius-core' ),
            'default'               => 'mk_image_size_portrait',
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'thumb_image_style', 'Thumbnail Images', true);

        $this->add_group_control( \Elementor\Group_Control_Image_Size::get_type(), [
            'name'    => 'thumbnail_image_size',
            'label'   => esc_html__( 'Horizontal Image Size', 'orbius-core' ),
            'default' => 'mk_image_size_square',
        ]);

        $this->add_responsive_control('thumb_bullet_size',[
            'label'       => esc_html__( 'Thumbnail Size', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em', 'vh' ],
            'range'       => ['px' => ['min' => 0, 'max' => 300, ] ],
            'selectors'   => [
                '{{WRAPPER}} .mk-thumbnail-slider .slider-navigation .swiper-pagination-bullets .swiper-pagination-bullet' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('thumb_bullet_spacing',[
            'label'       => esc_html__( 'Thumbnails Spacing', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em', 'vh' ],
            'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
            'selectors'   => [
                '{{WRAPPER}} .mk-thumbnail-slider .slider-navigation .swiper-pagination-bullets' => 'gap:{{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('thumb_img_border_radius', [
            'label' => esc_html__( 'Border Radius', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} .mk-thumbnail-slider .mk-thumbnailslider-overlay,
                {{WRAPPER}} .mk-thumbnail-slider .slider-navigation .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $this->add_responsive_control('thumb_bottom_spacing',[
            'label'       => esc_html__( 'Section Spacing', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::SLIDER,
            'size_units'  => [ 'px', 'em', 'vh', '%' ],
            'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
            'selectors'   => [
                '{{WRAPPER}} .mk-thumbnail-slider .slider-navigation' => 'right:{{SIZE}}{{UNIT}};bottom:{{SIZE}}{{UNIT}};',
            ],
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_style', 'Title', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(),[
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .mk-thumbnail-slider-title',
            ]);

            $this->add_control( 'title_tag', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Title HTML Tag', 'orbius-core' ),
                'options'    => mk_arrays('title_tag'),
                'default' => 'h4',
                'selectors' => [
                    '{{WRAPPER}} {{VALUE}}.mk-thumbnail-slider-title' => 'margin:0;',
                ],
            ]);

            $this->add_control('title_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-thumbnail-slider-title a,
                    {{WRAPPER}} .mk-thumbnail-slider-title' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_control('title_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-thumbnail-slider-title:hover a,
                    {{WRAPPER}} .mk-thumbnail-slider-title:hover' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('title_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mk-thumbnail-slider-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'subtitle_style', 'Category', true);

            $this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .mk-thumbnail-slider-subtitle',
            ]);

            $this->add_control('subtitle_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-thumbnail-slider-subtitle,
                    {{WRAPPER}} .mk-thumbnail-slider-subtitle a,
                    {{WRAPPER}} .mk-thumbnail-slider-subtitle a:hover' => 'color: {{VALUE}};',
                ],
            ]);
            $this->add_responsive_control('subtitle_margin', [
                    'label' => esc_html__( 'Margin', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mk-thumbnail-slider-subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control('subtitle_padding', [
                    'label' => esc_html__( 'Padding', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .mk-thumbnail-slider-subtitle' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'slider_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none' );
            mk_elem_hide_ctrl($this, 'subtitle_responsive_hide', 'Hide Subtitle At', 'none' );
            mk_elem_hide_ctrl($this, 'large_image_responsive_hide', 'Hide Large Image At', 'mobile' );
            mk_elem_hide_ctrl($this, 'thumb_image_responsive_hide', 'Hide Thumbs Image At', 'none' );
        $this->end_controls_section();

    }

    protected function render() {

        $settings      = $this->get_settings_for_display();
        $sliderContent = '';
        $thumbImage      = array();
        $title_tag     = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';

        $sliderSettings = array(
            'direction'          => 'horizontal',
            'parallax'           => 'no',
            'effect'             => 'fade',
            'dots'               => 'yes',
            'autoplay'           => $settings['autoplay_on'],
            'autoplay_speed'     => $settings['autoplay_speed'],
            'speed'              => $settings['speed'],
            'mousewheel'         => 'no',
            'loop'               => $settings['loop_on'],
            'pause_on_hover'     => $settings['hover_pause_on'],
            'slides_to_show'     => 1,
            'arrows_on'          => 'no',
            'slider_pagination'  => '.swiper-pagination',
            'video'              => 'no'
        );

        $i = 1;

        foreach ( $settings['slider_items'] as $index => $item ) :

            $thumbImageHtml = $bgImageHtml = $navigation = $link_start = $link_end = $title = $imgUrl = $slide_image = $slideImageURL = '';

            $thumbImageID = $item['thumb_image']['id'];

            if ( '' !== $thumbImageID ) {
                $thumbImage[$i]  = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $thumbImageID, 'thumbnail_image_size', $settings );
            }

            $bgImageID = $item['bg_image']['id'];

            if ( '' !== $bgImageID ) {
                $slideImageURL = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $bgImageID, 'image', $settings );
                $slide_image .= '<div class="mk-thumbnail-slider-img swm-hide-' . $settings['large_image_responsive_hide'] . ' " style="background-image:url(' . $slideImageURL . ');"></div>';
            }

            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $i;

                $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

                if ( $item['link']['is_external'] ) {
                    $this->add_render_attribute( $link_key, 'target', '_blank' );
                }

                if ( $item['link']['nofollow'] ) {
                    $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                }

                $link_start .= '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $link_end .= '</a>';

            }

            if ( ! empty( $item['title_text'] ) ) {
                $title .= '<'.$title_tag.' class="mk-thumbnail-slider-title swm-hide-' . $settings['title_responsive_hide'] . '">' . $link_start . $item['title_text'] . $link_end . '</'.$title_tag . '>';
            }

            $subtitle = ( ! empty( $item['category'] ) ) ? '<div class="mk-thumbnail-slider-subtitle swm-hide-' . $settings['subtitle_responsive_hide'] . '">' . $link_start . $item['category'] . $link_end . '</div>' : '';

            $sliderContent .= '<div class="mk-swiper-item swiper-slide">
                    <div class="mk-thumbnail-slider-overlay"></div>
                    <div class="slide-inner">
                        ' . $slide_image . '
                        <div class="mk-thumbnail-slider-content">
                            ' . $subtitle . '
                            <div class="mk-thumbnail-slider-titleSection">' . $title .'</div>
                        </div>
                    </div>
                </div>';

            $navigation .=  '<div class="slider-navigation swm-hide-' . $settings['thumb_image_responsive_hide'] . '"><div class="swiper-pagination"></div></div>';

            $i++;
        endforeach;

        $this->add_render_attribute( [
            'slider-attrs'  => [
                'class'          => [ 'swiper', 'swiper-container','mk-thumbnail-slider' ],
                'data-settings'  => json_encode( $sliderSettings ),
                'data-thumbimage'  => json_encode( $thumbImage ),
                'id'             => 'swiper-' .$this->get_id()
            ]
        ] );

        echo '<div ' . $this->get_render_attribute_string( 'slider-attrs' ) . '>
                <div class="swiper-wrapper">' . $sliderContent . '</div>'.$navigation.'
            </div>';

    }

}