<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Title extends \Elementor\Widget_Base {

	public function get_name()          { return 'mk_title'; }
	public function get_title()         { return esc_html__( 'Title', 'orbius-core' ); }
	public function get_icon()          { return 'mk-el-icon eicon-heading'; }
	public function get_categories()    { return ['mk-general-elements']; }
	public function get_keywords()      { return [ 'theme','title', 'subtitle','heading','title' ]; }
	public function get_style_depends() { return ['mk-core-main']; }
    public function get_script_depends() { return ['mk-widgets']; }

	protected function register_controls() {

        mk_elem_start_ctrl($this, 'title_content', 'Content');

		$this->add_control('title', [
			'label' => esc_html__( 'Title', 'orbius-core' ),
			'label_block' => true,
			'type' => \Elementor\Controls_Manager::TEXTAREA,
			'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
			'default' => 'Sample Title Text',
		]);

        $this->add_control('title_prefix', [
            'label' => esc_html__( 'Title Prefix Text', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
        ]);

         $this->add_control('title_suffix', [
            'label' => esc_html__( 'Title Suffix Text', 'orbius-core' ),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
        ]);

		$this->add_control('subtitle', [
			'label' => esc_html__( 'Sub Title', 'orbius-core' ),
			'label_block' => true,
			'type' => \Elementor\Controls_Manager::TEXT,
			'placeholder' => esc_html__( 'Enter Sub Title', 'orbius-core' ),
			'default' => 'Sub title text example',
		]);

		$this->add_control('desc', [
			'label' => esc_html__( 'Description', 'orbius-core' ),
			'label_block' => true,
			'type' => \Elementor\Controls_Manager::TEXTAREA,
			'placeholder' => esc_html__( 'Enter Description', 'orbius-core' ),
			'description' => esc_html__( 'You can use HTML.', 'orbius-core' ),
			'default' => 'Lorem ipsum dolor sit amet cotetur adipisicing elit, sed do mod tempor incididunt ut labore etdolore emu some the and one baldbe dear.',
		]);

        $this->add_control('title_link', [
            'label'       => esc_html__( 'Link', 'orbius-core' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => esc_html__( 'https://your-link.com', 'orbius-core' ),
            'condition'   => ['title!' => ''],
            'show_external' => true,
        ]);

		$this->end_controls_section();

        mk_elem_start_ctrl($this, 'general_style', 'General', true);

            $this->add_control('appear_animation_on',[
                'label'   => esc_html__( 'Appear Animation', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'no',
            ]);

            $this->add_responsive_control('title_alignment', [
                'label' => esc_html__( 'Alignment', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => mk_arrays('text_align_all'),
                'default' => 'left',
                'prefix_class' => 'mk-title-align-%s-',
                'selectors' => [
                    '{{WRAPPER}} .mk-title' => 'text-align: {{VALUE}};',
                ],
            ]);

        $this->end_controls_section();

		mk_elem_start_ctrl($this, 'title_style', 'Title', true, ['title!' => '']);

        $this->add_control( 'title_display_style', [
            'label' => esc_html__( 'Display Style', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'default' => 'Default',
                'stroke'  => 'Stroke'
            ],
            'default' => 'default',
        ]);

		$this->add_responsive_control('title_color',[
			'label' => esc_html__( 'Text Color', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::COLOR,
            'default' => 'var(--swm-color-headings)',
			'selectors' => [
				'{{WRAPPER}} .mk-title-heading,
                {{WRAPPER}} .mk-title-heading a' => 'color: {{VALUE}};',
			],
		]);

        $this->add_responsive_control('title_hover_color',[
            'label' => esc_html__( 'Text Hover Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-title-heading:hover,
                {{WRAPPER}} .mk-title-heading:hover a' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_responsive_control('title_stroke_color',[
            'label' => esc_html__( 'Stroke Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'default' => 'var(--swm-color-dark-1)',
            'condition'=> ['title_display_style' => 'stroke'],
            'selectors' => [
                '{{WRAPPER}} .mk-title-stroke .mk-title-heading' => '-webkit-text-stroke-color: {{VALUE}};',
            ],
        ]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'selector' => '{{WRAPPER}} .mk-title-heading',
        ]);

		$this->add_group_control(\Elementor\Group_Control_Text_Shadow::get_type(), [
			'name' => 'title_shadow',
            'selector' => '{{WRAPPER}} .mk-title-heading',
		]);
        $this->add_responsive_control('title_stroke_width', [
            'label' => esc_html__( 'Stroke Width', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px' ],
            'default' => ['size' => '1', 'unit' => 'px'],
            'condition'=> ['title_display_style' => 'stroke'],
            'selectors' => [
                '{{WRAPPER}} .mk-title-stroke .mk-title-heading span' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
            ],
        ]);

		$this->add_responsive_control('title_margin', [
			'label' => esc_html__( 'Margin Bottom', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', 'em', '%' ],
			'default' => [
				'size' => '20',
			],
            'range'                 => [
                'px'   => [
                    'min' => -200,
                    'max' => 200,
                ],
            ],
			'selectors' => [
                '{{WRAPPER}} .mk-title .mk-title-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                '{{WRAPPER}} .mk-title-container' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		]);

        $this->add_responsive_control('title_max_width', [
            'label' => esc_html__( 'Max Width', 'orbius-core' ),
            'type'  => \Elementor\Controls_Manager::SLIDER,
            'range' => [
                'px'        => ['min'   => 0, 'max'   => 2500, 'step'  => 1, ],
            ],
            'size_units' => [ 'px', '%','vw' ],
            'selectors'  => [
                '{{WRAPPER}} .mk-title-heading' => 'max-width: {{SIZE}}{{UNIT}}',
            ],
        ]);

        $this->add_control('title_tag', [
            'label' => esc_html__( 'Select Tag', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'h1' => 'H1',
                'h2' => 'H2',
                'h3' => 'H3',
                'h4' => 'H4',
                'h5' => 'H5',
                'h6' => 'H6',
                'div' => 'div',
            ],
            'default' => 'h2',
        ]);

        $this->start_controls_tabs( 'prefix_suffix_styles' );

            $this->start_controls_tab('prefix_styles',[
                'label' => esc_html__( 'Prefix', 'orbius-core' ),
                'condition' => ['title_prefix!' => ''],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'prefix_typography',
                'selector' => '{{WRAPPER}} .mk-title-prefix',
                'condition' => ['title_prefix!' => ''],
            ]);

            $this->add_control('title_prefix_color',[
                'label' => esc_html__( 'Prefix Text Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['title_prefix!' => ''],
                'selectors' => [
                    '{{WRAPPER}} .mk-title-prefix' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('prefix_spacing', [
                'label' => esc_html__( 'Prefix Spacing', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'vw' ],
                'default' => ['size' => '10', ],
                'range' => [
                    'px'   => ['min' => 0, 'max' => 200, ],
                ],
                'condition' => ['title_prefix!' => ''],
                'selectors' => [
                    '{{WRAPPER}} .mk-title-prefix' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]);

        $this->end_controls_tab();

            $this->start_controls_tab('suffix_styles',[
                'label' => esc_html__( 'Suffix', 'orbius-core' ),
                'condition' => ['title_suffix!' => ''],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'suffix_typography',
                'selector' => '{{WRAPPER}} .mk-title-suffix',
                'condition' => ['title_suffix!' => ''],
            ]);

            $this->add_control('title_suffix_color',[
                'label' => esc_html__( 'Suffix Text Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => ['title_suffix!' => ''],
                'selectors' => [
                    '{{WRAPPER}} .mk-title-suffix' => 'color: {{VALUE}};',
                ],
            ]);

            $this->add_responsive_control('suffix_spacing', [
                'label' => esc_html__( 'Suffix Spacing', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'vw' ],
                'default' => ['size' => '10', ],
                'range' => [
                    'px'   => ['min' => 0, 'max' => 200, ],
                ],
                'condition' => ['title_suffix!' => ''],
                'selectors' => [
                    '{{WRAPPER}} .mk-title-suffix' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
            ]);

            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_control('large_screen_style_on',[
            'label'   => esc_html__( 'Large Screen Styles', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
            'separator' => 'before',
        ]);

        $this->start_controls_tabs( 'title_large_screen_styles' );

            $this->start_controls_tab('tab_icons_large',[
                'label' => esc_html__( 'Large', 'orbius-core' ),
                'condition' => ['large_screen_style_on' => 'yes'],
            ]);

                $this->add_control('screen_size', [
                    'label' => esc_html__( 'Screen Size', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::TEXT,
                    'default' => '1300',
                    'condition' => ['large_screen_style_on' => 'yes'],
                ]);

                $this->add_control('screen_large_fz', [
                    'label' => esc_html__( 'Font Size', 'orbius-core' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => ['min'   => 1, 'max'   => 300, 'step'  => 1, ],
                    ],
                    'size_units' => [ 'px', '%', 'em', 'vw' ],
                    'condition' => ['large_screen_style_on' => 'yes'],
                ]);

               $this->add_control('screen_large_lh', [
                   'label' => esc_html__( 'Line Height', 'orbius-core' ),
                   'type'  => \Elementor\Controls_Manager::SLIDER,
                   'range' => [
                       'px' => ['min' => 1, 'max' => 300, 'step' => 1, ],
                   ],
                   'size_units' => [ 'px', '%', 'em', 'vw' ],
                   'condition' => ['large_screen_style_on' => 'yes'],
               ]);

            $this->end_controls_tab();


            $this->start_controls_tab('tab_icons_large_x',[
                'label' => esc_html__( 'X - Large', 'orbius-core' ),
                'condition' => ['large_screen_style_on' => 'yes'],
            ]);

                $this->add_control('screen_size_x', [
                    'label' => esc_html__( 'Screen Size', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::TEXT,
                    'default' => '1600',
                    'condition' => ['large_screen_style_on' => 'yes'],
                ]);

                $this->add_control('screen_large_fz_x', [
                    'label' => esc_html__( 'Font Size', 'orbius-core' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => ['min' => 1, 'max' => 300, 'step' => 1, ],
                    ],
                    'size_units' => [ 'px', '%', 'em', 'vw' ],
                    'condition' => ['large_screen_style_on' => 'yes'],
                ]);

               $this->add_control('screen_large_lh_x', [
                   'label' => esc_html__( 'Line Height', 'orbius-core' ),
                   'type'  => \Elementor\Controls_Manager::SLIDER,
                   'range' => [
                       'px' => ['min' => 1, 'max' => 300, 'step' => 1, ],
                   ],
                   'size_units' => [ 'px', '%', 'em', 'vw' ],
                   'condition' => ['large_screen_style_on' => 'yes'],
               ]);

            $this->end_controls_tab();


            $this->start_controls_tab('tab_icons_large_xx', [
                'label' => esc_html__( 'XX - Large', 'orbius-core' ),
                'condition' => ['large_screen_style_on' => 'yes'],
            ]);

                $this->add_control('screen_size_xx', [
                    'label' => esc_html__( 'Screen Size', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::TEXT,
                    'default' => '1900',
                    'condition' => ['large_screen_style_on' => 'yes'],
                ]);

                $this->add_control('screen_large_fz_xx', [
                    'label' => esc_html__( 'Font Size', 'orbius-core' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => ['min' => 1, 'max' => 300, 'step' => 1, ],
                    ],
                    'size_units' => [ 'px', '%', 'em', 'vw' ],
                    'condition' => ['large_screen_style_on' => 'yes'],
                ]);

                $this->add_control('screen_large_lh_xx', [
                    'label' => esc_html__( 'Line Height', 'orbius-core' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => ['min' => 1, 'max' => 300, 'step' => 1, ],
                    ],
                    'size_units' => [ 'px', '%', 'em', 'vw' ],
                    'condition' => ['large_screen_style_on' => 'yes'],
                ]);

            $this->end_controls_tab();

        $this->end_controls_tabs();

		$this->end_controls_section();

		// SUB TITLE

        mk_elem_start_ctrl($this, 'subtitle_style', 'Sub Title', true, ['subtitle!' => ''] );

    		$this->add_control('subtitle_color', [
    			'label' => esc_html__( 'Text Color', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .mk-title-subtitle' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mk-title-subtitle:before,
                    {{WRAPPER}} .mk-title-subtitle:after' => 'background: {{VALUE}};',
    			],
    		]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .mk-title-subtitle',
            ]);

    		$this->add_group_control(\Elementor\Group_Control_Text_Shadow::get_type(), [
    			'name' => 'subtitle_shadow',
    			'selector' => '{{WRAPPER}} .mk-title-subtitle',
    		]);

    		$this->add_responsive_control('subtitle_margin', [
    			'label' => esc_html__( 'Margin Bottom', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SLIDER,
    			'size_units' => [ 'px', 'em' ],
    			'default' => [
    				'size' => '9',
    			],
    			'selectors' => [
    				'{{WRAPPER}} .mk-title-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mk-title-subtitle-container' => 'margin-bottom: {{SIZE}}{{UNIT}};',
    			],
    		]);

            $this->add_control('subtitle_tag', [
                'label' => esc_html__( 'Select Tag', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                    'div' => 'div',
                ],
                'default' => 'div',
            ]);

            $this->add_responsive_control('bullet_size',[
                'label'       => esc_html__( 'Bullet Size', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 30, ] ],
                'selectors'   => [
                    '{{WRAPPER}} .mk-title-subtitle:before,
                    {{WRAPPER}} .mk-title-subtitle:after' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                ],
            ]);
            $this->add_responsive_control('bullet_spacing',[
                'label'       => esc_html__( 'Bullet Spacing', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'size_units'  => [ 'px', 'em' ],
                'range'       => ['px' => ['min' => 0, 'max' => 100, ] ],
                'selectors'   => [
                    '{{WRAPPER}}.mk-title-align--left .mk-title-subtitle:before,
                    {{WRAPPER}}.mk-title-align--justify .mk-title-subtitle:before' => 'margin-right:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.mk-title-align--right .mk-title-subtitle:after' => 'margin-left:{{SIZE}}{{UNIT}};',
                ],
            ]);

		$this->end_controls_section();

        // DESCRIPTION

		mk_elem_start_ctrl($this, 'desc_style', 'Description', true, ['desc!' => '']);

		$this->add_control('desc_color', [
			'label' => esc_html__( 'Text Color', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .mk-title-desc' => 'color: {{VALUE}};',
			],
		]);

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'desc_typography',
            'selector' => '{{WRAPPER}} .mk-title-desc',
        ]);

		$this->add_group_control(\Elementor\Group_Control_Text_Shadow::get_type(), [
			'name' => 'desc_shadow',
			'selector' => '{{WRAPPER}} .mk-title-desc',
		]);

		$this->add_responsive_control('desc_width', [
	        'label' => esc_html__( 'Max Width', 'orbius-core' ),
	        'type'  => \Elementor\Controls_Manager::SLIDER,
	        'range' => [
	            'px'        => ['min'   => 0, 'max'   => 2500, 'step'  => 1, ],
	        ],
	        'size_units' => [ 'px', '%','vw' ],
	        'selectors'  => [
	            '{{WRAPPER}} .mk-title-desc span' => 'max-width: {{SIZE}}{{UNIT}}',
	        ],
	        'separator' => 'before',
	    ]);

        $this->add_control('desc_tag', [
            'label' => esc_html__( 'Select Tag', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'h1' => 'H1',
                'h2' => 'H2',
                'h3' => 'H3',
                'h4' => 'H4',
                'h5' => 'H5',
                'h6' => 'H6',
                'div' => 'div',
            ],
            'default' => 'div',
        ]);

        $this->add_responsive_control('desc_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mk-title-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'title_responsive_settings', 'Responsive Settings', true);
            mk_elem_hide_ctrl($this, 'title_responsive_hide', 'Hide Title At', 'none' );
            mk_elem_hide_ctrl($this, 'subtitle_responsive_hide', 'Hide Subtitle At', 'none' );
            mk_elem_hide_ctrl($this, 'desc_responsive_hide', 'Hide Description At', 'none' );
        $this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

        $title_text = $subtitle_text = $subtitle_html = '';

        $title_text     = $settings['title'];
        $subtitle_text  = $settings['subtitle'];
        $prefix_text    = ( !empty($settings['title_prefix'] ) ) ? '<span class="mk-title-prefix"> ' . $settings['title_prefix'] . '</span>' : '';
        $suffix_text    = ( !empty($settings['title_suffix'] ) ) ? '<span class="mk-title-suffix"> ' . $settings['title_suffix'] . '</span>' : '';
        $title_text = $prefix_text . $title_text . $suffix_text;
        $title_link = ( !empty($settings['title_link']['url']) ) ? $settings['title_link']['url'] : '';

        if (!empty($title_link) && $title_text ) {

            $link_key = 'title_link_key';

            $this->add_render_attribute( $link_key, 'href', $title_link );

            if ( $settings['title_link']['is_external'] ) {
                $this->add_render_attribute( $link_key, 'target', '_blank' );
            }

            if ( $settings['title_link']['nofollow'] ) {
                $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
            }

            $title_text = '<a ' . $this->get_render_attribute_string( $link_key ) .'>' . $title_text . '</a>';

        }

        // subtitle html
        if ( $subtitle_text ) :

            $subTitleTagSelector = !empty($settings['subtitle_tag']) ? $settings['subtitle_tag'] : 'div';

            $subtitle_html .= '<' . $subTitleTagSelector . ' class="mk-title-subtitle swm-hide-'. $settings['subtitle_responsive_hide'] .'">' . $subtitle_text . '</' . $subTitleTagSelector . '>';
        endif;

        $appearAnimation = ( 'yes' === $settings['appear_animation_on'] ) ? ' mk-scroll--load' : '';

        $styleHTML = '';
        $selector = '.elementor-element.elementor-element-' . $this->get_id() . ' .mk-title .mk-title-heading';
        $screen_size_xx = ( '' !== $settings['screen_size_xx'] ) ? $settings['screen_size_xx'] : '1900';
        $screen_size_x  = ( '' !== $settings['screen_size_x'] ) ? $settings['screen_size_x'] : '1600';
        $screen_size    = ( '' !== $settings['screen_size'] ) ? $settings['screen_size'] : '1300';

        if ( isset($settings['screen_large_fz_xx']['size']) && '' !== ($settings['screen_large_fz_xx']['size']) ) {
            $screen_large_xx = 'font-size:' . $settings['screen_large_fz_xx']['size'] . $settings['screen_large_fz_xx']['unit'] . ';';

            if ( isset($settings['screen_large_lh_xx']['size']) && '' !== ($settings['screen_large_lh_xx']['size']) ) {
                $screen_large_xx .= 'line-height:' . $settings['screen_large_lh_xx']['size'] . $settings['screen_large_lh_xx']['unit'] . ';';
            }

            $styleHTML .= '@media only screen and (min-width: ' . ( $screen_size_x + 1 ) . 'px) and (max-width: ' . $screen_size_xx . 'px) { ' . $selector . '{' . $screen_large_xx . ' } }';
        }

        if ( isset($settings['screen_large_fz_x']['size']) && '' !== ($settings['screen_large_fz_x']['size']) ) {
            $screen_large_x = 'font-size:' . $settings['screen_large_fz_x']['size'] . $settings['screen_large_fz_x']['unit'] . ';';

            if ( isset($settings['screen_large_lh_x']['size']) && '' !== ($settings['screen_large_lh_x']['size']) ) {
                $screen_large_x .= 'line-height:' . $settings['screen_large_lh_x']['size'] . $settings['screen_large_lh_x']['unit'] . ';';
            }

            $styleHTML .= '@media only screen and (min-width: ' . ( $screen_size + 1 ) . 'px) and (max-width: ' . $screen_size_x . 'px) { ' . $selector . '{' . $screen_large_x . ' } }';
        }

        if ( isset($settings['screen_large_fz']['size']) && '' !== ($settings['screen_large_fz']['size']) ) {
            $screen_large = 'font-size:' . $settings['screen_large_fz']['size'] . $settings['screen_large_fz']['unit'] . ';';

            if ( isset($settings['screen_large_lh']['size']) && '' !== ($settings['screen_large_lh']['size']) ) {
                $screen_large .= 'line-height:' . $settings['screen_large_lh']['size'] . $settings['screen_large_lh']['unit'] . ';';
            }

            $styleHTML .= '@media only screen and (min-width: 1025px) and (max-width: ' . ( $screen_size + 1 ) . 'px) { ' . $selector . '{' . $screen_large . ' } }';
        }

        if ( '' !== $styleHTML ) {
            echo '<style id="mk-title-custom-styles-' . $this->get_id() . '" type="text/css">' . $styleHTML . '</style>';
        }

        echo '<div class="mk-title mk-title-' . $settings['title_display_style'] . $appearAnimation . '">';

			echo $subtitle_html;

            $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h2';

            if ( $title_text ):
                echo '<' . $titleTagSelector . ' class="mk-title-heading swm-hide-'. $settings['title_responsive_hide'] .'"><span>' . $title_text . '</span></' . $titleTagSelector . '>';
			endif;

			if ( $settings['desc'] ):
				echo '<' . $settings['desc_tag'] . ' class="mk-title-desc swm-hide-'. $settings['desc_responsive_hide'] .'"><span>' . $settings['desc'] . '</span></' . $settings['desc_tag'] . '>';
			endif;

		echo '</div>';

	}

}