<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Vertical_Menu extends \Elementor\Widget_Base {

	public function get_name()       { return 'mk_vertical_menu'; }
	public function get_title()      { return esc_html__( 'Vertical Menu', 'orbius-core' ); }
	public function get_icon()       { return 'mk-el-icon eicon-table-of-contents'; }
	public function get_categories() { return ['mk-sections-elements']; }
	public function get_keywords()   { return [ 'theme','menu','navigation','vertical','dropdown' ]; }
	public function get_style_depends() { return ['mk-core-main']; }
    public function get_script_depends() { return ['mk-widgets']; }

    protected function register_controls() {

        mk_elem_start_ctrl($this, 'parent_menu', 'Menu - First Level');

            $this->add_control('menu_list_select', [
                'label' => esc_html__( 'Select Menu', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => mk_wp_menu_names_list(),
            ]);

            $this->add_control('border_color', [
                'label' => esc_html__( 'Border Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu li' => 'border-color: {{VALUE}}',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'parent_typography',
                'selector' => '{{WRAPPER}} .mk-ver-menu > li',
            ]);

            $this->add_responsive_control('parent_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu > li > a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

            $this->add_control('parent_color', [
                'label' => esc_html__( 'Font Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu > li,
                    {{WRAPPER}} .mk-ver-menu > li > a' => 'color: {{VALUE}}',
                ],
            ]);

            $this->add_control('parent_hover_color', [
                'label' => esc_html__( 'Font Hover Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu > li:hover,
                    {{WRAPPER}} .mk-ver-menu > li:hover > a,
                    {{WRAPPER}} .mk-ver-menu > li.swm-m-active > a,
                    {{WRAPPER}} .mk-ver-menu > li.mk-has-sub-active-menu > a' => 'color: {{VALUE}}',
                ],
            ]);

        $this->end_controls_section();


        // Sub Menu -------------------------------------------------------------------------------------------------------------------

        mk_elem_start_ctrl($this, 'sub_menu', 'Menu - Sub Level');

        mk_elem_heading_ctrl($this, 'subbitems_title', 'Sub Menu Items', 'before' );

        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'sub_typography',
            'selector' => '{{WRAPPER}} .mk-ver-menu > li > ul li',
        ]);

        $this->add_control('sub_color', [
            'label' => esc_html__( 'Font Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-ver-menu > li > ul li,
                {{WRAPPER}} .mk-ver-menu > li > ul li a' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_control('sub_hover_color', [
            'label' => esc_html__( 'Font Hover Color', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .mk-ver-menu > li ul > ul li:hover,
                {{WRAPPER}} .mk-ver-menu > li > ul li:hover > a,
                {{WRAPPER}} .mk-ver-menu > li > .sub-menu a:hover,
                {{WRAPPER}} .mk-ver-menu > li > .sub-menu .current-menu-item > a,
                {{WRAPPER}} .mk-ver-menu > li > .sub-menu .current-menu-ancestor > a,
                {{WRAPPER}} .mk-ver-menu > li > .sub-menu .mk-has-sub-active-menu > a' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_responsive_control('sub_one_padding', [
            'label' => esc_html__( 'Padding ( Sub Level 1 )', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} ul.mk-ver-menu ul li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ]
        ]);

        $this->add_responsive_control('sub_two_padding', [
            'label' => esc_html__( 'Padding ( Sub Level 2 )', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} ul.mk-ver-menu ul ul li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ]
        ]);

        $this->add_responsive_control('sub_three_padding', [
            'label' => esc_html__( 'Padding ( Sub Level 3 )', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} ul.mk-ver-menu ul ul ul li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ]
        ]);

        $this->add_responsive_control('sub_four_padding', [
            'label' => esc_html__( 'Padding ( Sub Level 4 )', 'orbius-core' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors' => [
                '{{WRAPPER}} ul.mk-ver-menu ul ul ul ul li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ]
        ]);

        $this->end_controls_section();

        mk_elem_start_ctrl($this, 'submenu_indicator', 'Sub Menu Indicator');

            $this->add_responsive_control('indicator_size', [
                'label' => esc_html__( 'Indicator Size', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%', 'px', 'em'],
                'range' => [
                    '%'  => ['min' => 1, 'max' => 100 ],
                    'px' => ['min' => 5, 'max' => 100 ],
                ],
                'selectors' => ['
                    {{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};'
                ]
            ]);

            $this->add_responsive_control('indicator_margin', [
                'label' => esc_html__( 'Margin', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

            $this->add_responsive_control('indicator_padding', [
                'label' => esc_html__( 'Padding', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]);

            $this->add_control('indicator_color', [
                'label' => esc_html__( 'Icon Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator' => 'fill: {{VALUE}}',
                ]
            ]);

            $this->add_control('indicator_hover_color', [
                'label' => esc_html__( 'Icon Hover Color', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator:hover' => 'fill: {{VALUE}}',
                ]
            ]);

            $this->add_responsive_control('indicator_border_radius', [
                'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'        => 'indicator_border',
                'label'       => esc_html__( 'Border', 'orbius-core' ),
                'selector'    => '{{WRAPPER}} .mk-ver-menu .swm-svg-submenu-indicator',
            ]);

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $menu_list_items = $settings['menu_list_select'];

        if ( $menu_list_items != '' ) {

            $nav_menu = ! empty( $settings['menu_list_select'] ) ? wp_get_nav_menu_object( $settings['menu_list_select'] ) : false;
            if ( ! $nav_menu ) { return; }

            $nav_menu_args = array(
                'fallback_cb' => '',
                'menu_class'  => 'mk-ver-menu',
                'menu'        => $nav_menu,
                'depth'       => 0,
                'echo'        => false,
            );
            ?>

            <div class="mk-vertical-menu-container">
                <div class="mk-ver-menu-wrap"><?php echo wp_nav_menu( $nav_menu_args ); ?></div>
            </div>
            <?php

        }


    }

}