<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

class Mk_Video_Icon extends \Elementor\Widget_Base {

	public function get_name()           { return 'mk_video_icon'; }
	public function get_title()          { return esc_html__( 'Video Icon', 'orbius-core' ); }
	public function get_icon()           { return 'mk-el-icon eicon-play'; }
	public function get_categories()     { return ['mk-general-elements']; }
	public function get_keywords()       { return [ 'theme','video', 'youtube', 'vimeo','icon']; }
    public function get_style_depends()  { return ['mk-magnific-popup','mk-core-main']; }
	public function get_script_depends() { return ['mk-widgets','magnific-popup' ]; }

	protected function register_controls() {

		mk_elem_start_ctrl($this, 'section_video', 'Video Icon');

			$this->add_control(
			    'video_url',
			    [
			        'label' => esc_html__('YouTube/Vimeo Video URL', 'orbius-core'),
			        'type' => \Elementor\Controls_Manager::TEXT,
			        'default' => 'https://www.youtube.com/watch?v=5DDwj97-h3c',
			        'label_block' => true,
			    ]
			);

			$this->add_control('video_icon_type', [
				'label'       => esc_html__( 'Icon Type', 'orbius-core' ),
                'type'        => \Elementor\Controls_Manager::CHOOSE,
                'label_block' => false,
                'options'     => [
                    'icon' => [
                        'title' => esc_html__( 'Icon', 'orbius-core' ),
                        'icon'  => 'eicon-star-o',
                    ],
                    'image' => [
                        'title' => esc_html__( 'Image', 'orbius-core' ),
                        'icon'  => 'eicon-image',
                    ],
                ],
                'default'       => 'icon',
			]);

			$this->add_control('video_play_icon',[
				'label' => esc_html__( 'Play Icon', 'orbius-core' ),
				'type'  => \Elementor\Controls_Manager::ICONS,
		        'default' => [
		            'value' => 'fas fa-play',
		            'library' => 'fa-solid',
		        ],
		        'condition'     => [
                'video_icon_type' => 'icon',
            ],
		    ]);

            $this->add_control('video_play_icon_image', [
                'label'     => esc_html__( 'Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
                'condition' => ['video_icon_type' => 'image'],
            ]);

			$this->add_group_control(
				\Elementor\Group_Control_Image_Size::get_type(),
				[
					'name'                  => 'icon_image_size',
	                'label'                 => esc_html__( 'Icon Image Size', 'orbius-core' ),
	                'default'               => 'full',
				]
			);

            $this->add_control('pulse_animation',[
                'label'   => esc_html__( 'Pulse Animation', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'orbius-core' ),
					'label_block' => true,
					'type' => \Elementor\Controls_Manager::TEXT,
					'placeholder' => esc_html__( 'Enter Title', 'orbius-core' ),
					'default' => 'Sample Title Text',
					'separator' => 'before',
				]
			);

            $this->add_control('bg_image', [
                'label'     => esc_html__( 'Backround Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

	        $this->add_group_control(
	            \Elementor\Group_Control_Image_Size::get_type(),
	            [
					'name'    => 'bg_image_size',
					'label'   => esc_html__( 'Image Size', 'orbius-core' ),
					'default' => 'full',
	            ]
	        );

		$this->end_controls_section();

		mk_elem_start_ctrl($this, 'icon_styling', 'Icon', true);

			$this->add_control(
			    'video_origin',
			    [
			        'label'   => esc_html__( 'Video Icon Position', 'orbius-core' ),
			        'type'    => \Elementor\Controls_Manager::SELECT,
			        'default' => 'center',
			        'options' => mk_position(),
			    ]
			);

			$this->add_responsive_control(
			    'video_icons_size',
			    [
			        'label' => esc_html__( 'Icon Size', 'orbius-core' ),
			        'type' => \Elementor\Controls_Manager::SLIDER,
			        'size_units' => [ 'px', 'em', '%' ],
			        'range' => [
			            'px' => [
			                'min'  => 1,
			                'max'  => 500,
			            ],
			        ],
			        'default' => [
			            'size' => '20',
			        ],
			        'selectors' => [
			            '{{WRAPPER}} .mk-video-icon-element i,{{WRAPPER}} .mk-video-icon-element svg' => 'font-size: {{SIZE}}{{UNIT}};',
			        ],
			    ]
			);

			$this->add_responsive_control(
			    'video_width',
			    [
			        'label' => esc_html__( 'Icon Box Width', 'orbius-core' ),
			        'type'  => \Elementor\Controls_Manager::SLIDER,
			        'size_units' => [ 'px', 'em', '%' ],
			        'range' => [
			            'px' => [
			                'min'  => 1,
			                'max'  => 500,
			            ],
			        ],
			        'default'    => [
			                'size' => 60,
			                'unit' => 'px',
			            ],
			        'selectors' => [
			            '{{WRAPPER}} .mk-video-icon-element,{{WRAPPER}} a.mk-video-icon-element:before' => 'width: {{SIZE}}{{UNIT}};',
			        ],
			    ]
			);

			$this->add_responsive_control(
			    'video_height',
			    [
			        'label' => esc_html__( 'Icon Box Height', 'orbius-core' ),
			        'type'  => \Elementor\Controls_Manager::SLIDER,
			        'size_units' => [ 'px', 'em', '%' ],
			        'range' => [
			            'px' => [
			                'min'  => 1,
			                'max'  => 500,
			            ],
			        ],
			        'default'    => [
			                'size' => 60,
			                'unit' => 'px',
			            ],
			        'selectors' => [
			            '{{WRAPPER}} .mk-video-icon-element,{{WRAPPER}} a.mk-video-icon-element:before' => 'height: {{SIZE}}{{UNIT}};',
			            '{{WRAPPER}} .mk-video-icon-element i' => 'line-height: {{SIZE}}{{UNIT}};',
			            '{{WRAPPER}} .mk-video-icon-element svg' => 'height: {{SIZE}}{{UNIT}};',
			        ],
			    ]
			);

			$this->add_control(
			    'video_border_radius',
			    [
					'label'      => esc_html__( 'Border Radius', 'orbius-core' ),
					'type'       => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%' ],
					'default'    => [
						'top'    => '100',
						'bottom' => '100',
						'left'   => '100',
						'right'  => '100',
						'unit'   => '%',
					],
					'selectors'  => [
			            '{{WRAPPER}} .mk-video-icon-element' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			        ],
			    ]
			);

			$this->add_responsive_control(
			    'video_margin',
			    [
			        'label' => esc_html__( 'Video Margin', 'orbius-core' ),
			        'type' => \Elementor\Controls_Manager::DIMENSIONS,
			        'size_units' => [ 'px', 'em', '%' ],
			        'default' => [
	                    'top' => '10',
	                    'right' => '10',
	                    'bottom' => '10',
	                    'left' => '10',
	                    'isLinked' => true,
                	],
			        'selectors' => [
			            '{{WRAPPER}} .mk-video-icon-element' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			        ],
			    ]
			);

			$this->start_controls_tabs( 'video_style' );

				$this->start_controls_tab(
				    'tab_video_normal',
				    [
				        'label' => esc_html__( 'Normal', 'orbius-core' ),
				    ]
				);

					$this->add_control(
					    'video_color',
					    [
					        'label' => esc_html__( 'Icon Color', 'orbius-core' ),
					        'type' => \Elementor\Controls_Manager::COLOR,
					        'selectors' => [
					            '{{WRAPPER}} a.mk-video-icon-element i' => 'color: {{VALUE}};',
					            '{{WRAPPER}} a.mk-video-icon-element svg' => 'fill: {{VALUE}};',
					        ],
					    ]
					);

					$this->add_group_control(
					    \Elementor\Group_Control_Background::get_type(),
					    [
					        'name' => 'video_background',
					        'label' => esc_html__( 'Background', 'orbius-core' ),
					        'types' => [ 'classic', 'gradient' ],
					        'selector' => '{{WRAPPER}} .mk-video-icon-element',
					    ]
					);

                    $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                        'name'        => 'video_border',
                        'label'       => esc_html__( 'Border', 'orbius-core' ),
                        'selector'    => '{{WRAPPER}} .mk-video-icon-element',
                    ]);

					$this->add_control(
					    'pulse_animation_bg',
					    [
					        'label' => esc_html__( 'Pulse Animation Color', 'orbius-core' ),
					        'type' => \Elementor\Controls_Manager::COLOR,
					        'condition' => [
								'pulse_animation' => 'yes',
							],
					        'selectors' => [
					            '{{WRAPPER}} a.mk-video-icon-element:before' => 'background: {{VALUE}};',
					        ],
					    ]
					);

					$this->add_group_control(
					    \Elementor\Group_Control_Box_Shadow::get_type(),
					    [
							'name'     => 'video_box_shadow',
							'label' => esc_html__( 'Icon Box - Box Shadow', 'orbius-core' ),
							'selector' => '{{WRAPPER}} .mk-video-icon-element,{{WRAPPER}} a.mk-video-icon-element',
					    ]
					);

					$this->end_controls_tab();

					$this->start_controls_tab(
					    'tab_video_hover',
					    [
					        'label' => esc_html__( 'Hover', 'orbius-core' ),
					    ]
					);

					$this->add_control(
					    'video_hover_color',
					    [
					        'label' => esc_html__( 'Icon Color', 'orbius-core' ),
					        'type' => \Elementor\Controls_Manager::COLOR,
					        'selectors' => [
					            '{{WRAPPER}} .mk-video-icon-element:hover i' => 'color: {{VALUE}};',
					            '{{WRAPPER}} .mk-video-icon-element:hover svg' => 'fill: {{VALUE}};',
					        ],
					    ]
					);

					 $this->add_group_control(
					    \Elementor\Group_Control_Background::get_type(),
					    [
					        'name' => 'video_hover_background',
					        'label' => esc_html__( 'Background', 'orbius-core' ),
					        'types' => [ 'classic', 'gradient' ],
					        'selector' => '{{WRAPPER}} .mk-video-icon-element:hover'
					    ]
					);

                     $this->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                        'name' => 'video_border_hover',
                        'selector' => '{{WRAPPER}} .mk-video-icon-element:hover,{{WRAPPER}} a.mk-video-icon-element:hover',
                     ]);

					 $this->add_control(
					    'pulse_animation_bg_hover',
					    [
					        'label' => esc_html__( 'Pulse Animation Color', 'orbius-core' ),
					        'type' => \Elementor\Controls_Manager::COLOR,
					        'condition' => [
								'pulse_animation' => 'yes',
							],
					        'selectors' => [
					            '{{WRAPPER}} a.mk-video-icon-element:hover:before' => 'background: {{VALUE}};',
					        ],
					    ]
					);

					 $this->add_group_control(
					    \Elementor\Group_Control_Box_Shadow::get_type(),
					    [
							'name'     => 'video_hover_box_shadow',
							'label' => esc_html__( 'Icon Box - Box Shadow', 'orbius-core' ),
							'selector' => '{{WRAPPER}} .mk-video-icon-element:hover',
					    ]
					);

				$this->end_controls_tab();
			$this->end_controls_tabs();
		$this->end_controls_section();

	   mk_elem_start_ctrl($this, 'title_styling', 'Title', true);

				$this->add_control('title_position', [
					'label'   => esc_html__( 'Title Text Position', 'orbius-core' ),
					'type'    => \Elementor\Controls_Manager::SELECT,
					'options' => [
						'after'   => esc_html__( 'After Icon', 'orbius-core' ),
						'before'  => esc_html__( 'Before Icon', 'orbius-core' ),
						'above'   => esc_html__( 'Above Icon', 'orbius-core' ),
						'below'   => esc_html__( 'Below Icon', 'orbius-core' ),
					],
					'default' => 'below',
				]);

				$this->add_control(
					'title_tag',
					[
						'label' => esc_html__( 'Select Tag', 'orbius-core' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'options' => [
							'h1' => 'H1',
							'h2' => 'H2',
							'h3' => 'H3',
							'h4' => 'H4',
							'h5' => 'H5',
							'h6' => 'H6',
							'div' => 'div',
						],
						'default' => 'h3',
					]
				);

				$this->add_control(
					'title_color',
					[
						'label' => esc_html__( 'Text Color', 'orbius-core' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'default' => '#ffffff',
						'selectors' => [
							'{{WRAPPER}} .mk-video-icon-title' => 'color: {{VALUE}};',
						],
					]
				);
				$this->add_group_control(
					\Elementor\Group_Control_Typography::get_type(),
					[
						'name' => 'title_typography',
						'selector' => '{{WRAPPER}} .mk-video-icon-title',
					]
				);
				$this->add_group_control(
					\Elementor\Group_Control_Text_Shadow::get_type(),
					[
						'name' => 'title_shadow',
						'selector' => '{{WRAPPER}} .mk-video-icon-title',
					]
				);

				$this->add_responsive_control(
				    'title_margin',
				    [
				        'label' => esc_html__( 'Title Margin', 'orbius-core' ),
				        'type' => \Elementor\Controls_Manager::DIMENSIONS,
				        'size_units' => [ 'px', 'em', '%' ],
				        'default' => [
		                    'top' => '10',
		                    'right' => '10',
		                    'bottom' => '10',
		                    'left' => '10',
		                    'isLinked' => true,
		            	],
				        'selectors' => [
				            '{{WRAPPER}} .mk-video-icon-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				        ],
				    ]
				);

                $this->add_responsive_control('title_alignment', [
                    'label' => esc_html__( 'Alignment', 'orbius-core' ),
                    'type' => \Elementor\Controls_Manager::CHOOSE,
                    'options' => mk_arrays('text_align'),
                    'default' => 'center',
                    'selectors' => [
                        '{{WRAPPER}} .mk-video-icon-title' => 'text-align: {{VALUE}};',
                    ],
                ]);

			$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<div class="mk-video-icon-holder">
			<div class="mk-position-<?php echo $settings['video_origin']; ?> mk-vi-pulse-<?php echo $settings['pulse_animation']; ?> mk-flex mk-vi-title-<?php echo $settings['title_position']; ?>">
				<div>
					<a class="mk-video-icon-element mk-icon mk-video-lightbox swm-anim" href="<?php echo esc_url($settings['video_url']); ?>" ><?php

					if ( $settings['video_icon_type'] == 'icon' || $settings['video_icon_type'] == 'image' ) :

                        if ( $settings['video_icon_type'] == 'icon' ) {

                        	\Elementor\Icons_Manager::render_icon( $settings['video_play_icon'], [ 'aria-hidden' => 'true' ] );

                        } else {

                        if (  $settings['icon_image_size_size'] == 'custom' ) {
                            $iconImageTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $settings['video_play_icon_image'], $settings['video_play_icon_image']['id'], 'icon_image_size', 'video_icon_attr').' />';
                        } else {
                            $iconImageTagHtml = wp_get_attachment_image( $settings['video_play_icon_image']['id'], $settings['icon_image_size_size']);
                        }

                        echo $iconImageTagHtml;

                        }

					endif;

					?>
					</a>
				</div>
				<?php if ( $settings['title'] ):
                        $titleTagSelector = !empty($settings['title_tag']) ? $settings['title_tag'] : 'h4';
                    ?>
					<?php printf( '<div><%1$s class="mk-video-icon-title">%2$s</%1$s></div>', $titleTagSelector, $settings['title'] ); ?>
				<?php endif; ?>
			</div>
			<?php

            if (  $settings['bg_image_size_size'] == 'custom' ) {
                $bg_ImageTagHtml = '<img '.mk_custom_image_size_html($this, $settings, $settings['bg_image'], $settings['bg_image']['id'], 'bg_image_size', 'bg_img_attr').' />';
            } else {
                $bg_ImageTagHtml = wp_get_attachment_image( $settings['bg_image']['id'], $settings['bg_image_size_size']);
            }

            echo $bg_ImageTagHtml;

            ?>
		</div>
		<?php
	}

}