<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if ( !class_exists( 'Mk_Elementor_Elements' ) ) {
    final class Mk_Elementor_Elements {

    	const MINIMUM_ELEMENTOR_VERSION = '3.9.0';
    	const MINIMUM_PHP_VERSION = '7';

    	private static $_instance = null;

    	/* Ensures only one instance of the class is loaded or can be loaded. */
    	public static function instance() { if ( is_null( self::$_instance ) ) { self::$_instance = new self(); } return self::$_instance; }

    	public function __construct() {
    		add_action( 'plugins_loaded', [ $this, 'init' ] );

            add_action( 'init', array( $this, 'init_demo_custom_extenders' ), -999 );
            add_action( 'elementor/editor/after_enqueue_styles', array( $this, 'elementor_editor_sidepanel_css' ) );
    	}

        public function init_demo_custom_extenders() {
            if ( mk_get_ts_option('custom_extenders',true) ) {
                $this->register_extenders();
            }
        }

        private function register_extenders() {
            foreach ( glob( MK_ELEMENTS_DIR . 'extenders/*.php' ) as $file ) {
                include_once $file;
            }
        }

    	/* Warning when the site doesn't have a minimum required Elementor version. */
    	public function admin_notice_minimum_elementor_version() {
    		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

    		$message = sprintf(
    			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
    			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'orbius-core' ),
    			'<strong>' . esc_html__( 'Mk Elements for Elementor', 'orbius-core' ) . '</strong>',
    			'<strong>' . esc_html__( 'Elementor', 'orbius-core' ) . '</strong>',
    			 self::MINIMUM_ELEMENTOR_VERSION
    		);

    		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    	}

    	/* Warning when the site doesn't have a minimum required PHP version. */
    	public function admin_notice_minimum_php_version() {
    		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

    		$message = sprintf(
    			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
    			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'orbius-core' ),
    			'<strong>' . esc_html__( 'Mk Elements for Elementor', 'orbius-core' ) . '</strong>',
    			'<strong>' . esc_html__( 'PHP', 'orbius-core' ) . '</strong>',
    			 self::MINIMUM_PHP_VERSION
    		);

    		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    	}

    	/* Initialize the plugin */
    	public function init() {

            require_once (MK_ELEMENTS_DIR . 'grid-functions.php');
            require_once (MK_ELEMENTS_DIR . 'helpers.php');
            require_once (MK_ELEMENTS_DIR . 'arrays.php');
            require_once (MK_ELEMENTS_DIR . 'elements-fields.php');

    		// Check if Elementor installed and activated
    		if ( ! did_action( 'elementor/loaded' ) ) { return; }

    		// Check for required Elementor version
    		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
    			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
    			return;
    		}

    		// Check for required PHP version
    		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
    			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
    			return;
    		}

    		// Register Widget Category
    		add_action( 'elementor/elements/categories_registered', [ $this, 'widget_category' ] );

    		// Register Widgets
    		add_action( 'elementor/widgets/register', [ $this, 'register_widgets' ] );

    		// Enqueue Widget Styles
    		add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'widget_styles' ] );

    		// Register Widget Scripts
    		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );

    		// Register Elementor Editor Scripts
    		add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'editor_scripts' ] );
    	}

    	public function editor_scripts() {
    	   wp_enqueue_style( 'mk-elementor-editor-style', MK_ELEMENTS_CSS . 'elementor-editor-style.css', '', MK_VERSION );
    	}

    	public function widget_styles() {
	        wp_register_style( 'swiper', MK_DIR_URL .'assets/css/swiper.min.css', NULL, '8.0.6' );
            wp_register_style( 'swiper-circles', MK_ELEMENTS_CSS .'swiper-circles.min.css', NULL, '5.4.5' );

            foreach ( glob( MK_ELEMENTS_DIR . 'extenders/*.php' ) as $file ) {
                include_once $file;
            }

            foreach ( glob( MK_DIR_PATH . 'elements/css/*.css' ) as $file ) {
                $filename = basename($file,'.css');
                wp_register_style( 'mk-' . $filename, MK_ELEMENTS_CSS .$filename.'.css', NULL, MK_VERSION );
            }

            if ( get_theme_mod('swm_display_header','custom') ) {
                wp_enqueue_style( 'mk-core-main' );
            }

            if ( mk_get_ts_option('custom_extenders',true) ) {
                wp_enqueue_style( 'mk-extenders' );
            }

    	}

    	public function widget_scripts() {

            wp_enqueue_script( 'mk-custom-functions', MK_DIR_URL . 'elements/js/custom-functions.min.js',   ['jquery'], MK_VERSION, true );

            foreach ( glob( MK_DIR_PATH . 'elements/js/min/*.js' ) as $file ) {
                $filename = basename($file,'.min.js');
                wp_register_script( $filename, MK_DIR_URL . 'elements/js/min/' . $filename.'.min.js', ['jquery'], MK_VERSION, true );
            }

            wp_register_script( 'mk-video-subscribe','https://apis.google.com/js/platform.js', ['jquery'], MK_VERSION, true );

            $apikey   = mk_get_ts_option( 'mk_map_apikey' );

    		if ( $apikey ) {
    			wp_register_script( 'mk-google-maps-api', 'https://maps.google.com/maps/api/js?key='. $apikey, [], MK_VERSION, true );
    			wp_register_script( 'mk-google-maps-cluster', 'https://developers.google.com/maps/documentation/javascript/examples/markerclusterer/markerclusterer.js', [ 'jquery' ], MK_VERSION, true );
    		}

            wp_localize_script( 'mk-widgets', 'mkWidgetsLocalize', [
                'ajaxURL'             => admin_url( 'admin-ajax.php' ),
                'restUrl'             => esc_url_raw( rest_url() ),
                'restNonce'           => wp_create_nonce( 'wp_rest' ),
                'paginationRestRoute' => mk_rest_namespace() . '/get-posts'
            ] );

            // custom extenders
            if ( mk_get_ts_option('custom_extenders',true) ) {
                wp_enqueue_script( 'mk-tweenmax' );
                wp_enqueue_script( 'mk-gsap' );
                wp_enqueue_script( 'mk-scroll-trigger' );
                wp_enqueue_script( 'mk-anime' );
                wp_enqueue_script( 'theia-sticky-sidebar' );
                wp_enqueue_script( 'mk-parallax-scroll' );
                wp_enqueue_script( 'mk-extenders', MK_DIR_URL . 'elements/js/extenders.js', ['jquery'],MK_VERSION, true );
            }

    	}

    	/* Create widget category */
    	public function widget_category( $elements_manager ) {
    		$elements_manager->add_category('mk-general-elements',  ['title' => esc_html__( 'Theme General Elements', 'orbius-core' ),  'icon' => 'fa fa-plug']);
    		$elements_manager->add_category('mk-sliders-elements',  ['title' => esc_html__( 'Theme Sliders Elements', 'orbius-core' ),  'icon' => 'fa fa-plug']);
            $elements_manager->add_category('mk-sections-elements', ['title' => esc_html__( 'Theme Sections Elements', 'orbius-core' ), 'icon' => 'fa fa-plug']);
    	}

    	/* Register widgets */
    	public function register_widgets( $widgets_manager ) {
            foreach ( glob( MK_ELEMENTS_DIR . 'allelements/*.php' ) as $file_path ) {
                include_once $file_path;
                $widget = $this->generateWidgetName($file_path);
                $widgets_manager->register( new $widget() );
            }
    	}

        // generate widget name from file path
        public function generateWidgetName($file_path) {
            $fileName = basename($file_path);
            $fileName = str_replace('.php', '', $fileName);
            $widgetName = str_replace(' ', '_', ucwords(str_replace('-', ' ', $fileName)) );
            $widget = 'Mk_'.$widgetName;
            return $widget;
        }

        // elementor editor sidebar widgets icon color
        public function elementor_editor_sidepanel_css() {
              echo '<style type="text/css">
            .icon i.mk-el-icon { color:'.get_theme_mod( 'swm_color_dark_1', '#1b1b1b' ).'; }
            #elementor-panel-category-mk-general-elements .elementor-element-wrapper:hover .elementor-element-title-wrapper .title,
            #elementor-panel-category-mk-sections-elements .elementor-element-wrapper:hover .elementor-element-title-wrapper .title,
            #elementor-panel-category-mk-sliders-elements .elementor-element-wrapper:hover .elementor-element-title-wrapper .title { color:'.get_theme_mod( 'swm_color_dark_1', '#1b1b1b' ).'; }
            </style>';
        }

    }

    Mk_Elementor_Elements::instance();
}