<?php
if (!defined('ABSPATH')) { exit; }
class Mk_Background_Colors_Animation{
	private static $instance = null;
	public static function instance() { if ( is_null( self::$instance ) ) {self::$instance = new self(); } return self::$instance; }

	public function __construct() {
		add_action( 'elementor/element/section/section_effects/after_section_end', [$this, 'register_controls'] );
		add_action( 'elementor/frontend/section/before_render', [$this,'before_render'] );
		add_action( 'elementor/section/print_template', [$this, 'print_template'], 10, 2 );

        add_action( 'elementor/element/container/section_effects/after_section_end', [$this, 'register_controls'] );
        add_action( 'elementor/frontend/container/before_render', [$this,'before_render'] );
        add_action( 'elementor/container/print_template', [$this, 'print_template'], 10, 2 );
	}

	public function register_controls($element) {

		$element->start_controls_section('mk_colors_animation',[
			'label' => esc_html__('Custom - Colors Animation', 'orbius-core'),
			'tab' => \Elementor\Controls_Manager::TAB_ADVANCED,
		]);

        $element->add_control('mk_colors_animation_note', [
            'type' => \Elementor\Controls_Manager::RAW_HTML,
            'raw' => esc_html__( 'NOTICE: When you turn enabled or disabled this feature don\'t forget to click the "Apply" button to see the actual result!', 'orbius-core' ),
            'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
        ]);

		$element->add_control('mk_animation_colors_notice',[
			'type' => \Elementor\Controls_Manager::RAW_HTML,
			'raw' => esc_html__( 'NOTICE: Please remove Elementor\'s background image/gradient for this section.', 'orbius-core' ),
			'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
			'condition' => [
				'mk_is_animation' => 'yes',
			],
		]);

		$element->add_control('mk_is_animation',[
			'label' => esc_html__( 'Animation Enable', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::SWITCHER,
			'prefix_class'  => 'mk-colors-anim-',
		]);
		$element->add_control('mk_animation_type',[
			'label' => esc_html__( 'Animation Type', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'fade' => esc_html__( 'Fade', 'orbius-core' ),
				'hor-moving' => esc_html__( 'Horizontal Moving', 'orbius-core' ),
				'ver-moving' => esc_html__( 'Vertical Moving', 'orbius-core' ),
			],
			'default' => 'hor-moving',
			'prefix_class'  => 'mk-colors-anim-',
			'condition' => [
				'mk_is_animation' => 'yes',
			],
		]);
		$element->add_control('mk_animation_duration',[
			'label' => esc_html__( 'Duration', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::NUMBER,
			'step' => 1000,
			'min' => 5000,
			'max' => 60000,
			'default' => 20000,
			'condition' => [
				'mk_is_animation' => 'yes',
			],
			'selectors' => [
				'{{WRAPPER}}' => 'animation-duration: {{VALUE}}ms;',
			],
		]);
		$element->add_control('mk_animation_delay',[
			'label' => esc_html__( 'Delay', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::NUMBER,
			'step' => 100,
			'max' => 60000,
			'default' => 10,
			'condition' => [
				'mk_is_animation' => 'yes',
			],
			'selectors' => [
				'{{WRAPPER}}' => 'animation-delay: {{VALUE}}ms;',
			],
		]);
		$element->add_control('mk_colors_angle',[
			'label' => esc_html__( 'Angle (deg)', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::NUMBER,
			'min' => -180,
			'max' => 180,
			'default' => 90,
			'condition' => [
				'mk_is_animation' => 'yes',
				'mk_animation_type!' => 'fade',
			],
		]);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control('mk_animation_color',[
			'label' => esc_html__( 'Select Color', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::COLOR,
		]);
		$element->add_control('mk_animation_colors',[
			'label' => esc_html__( 'Add color', 'orbius-core' ),
			'type' => \Elementor\Controls_Manager::REPEATER,
			'fields' => $repeater->get_controls(),
			'default' => [
				[
					'mk_animation_color' => '#1085e4',
				],
			],
			'prevent_empty' => true,
			'condition' => [
				'mk_is_animation' => 'yes',
			],
			'title_field' => '{{{ mk_animation_color }}}',
		]);

		$element->add_control('mk_colors_animation_apply', [
            'type' => \Elementor\Controls_Manager::RAW_HTML,
            'raw' => '<div class="elementor-update-preview" style="background: rgba(0,0,0,0);margin-left: 0;margin-right: 0;"><div class="elementor-update-preview-title">Update changes to page</div><div class="elementor-update-preview-button-wrapper"><button class="elementor-update-preview-button elementor-button elementor-button-success">Apply</button></div></div>',
        ]);

		$element->end_controls_section();
	}

	public function before_render( $element ) {
		$data = $element->get_settings_for_display();

		if ( 'yes' == $data['mk_is_animation'] ) {
			$colors = [];
			foreach( $data['mk_animation_colors'] as $color ) {
				$colors[] = $color['mk_animation_color'];
			}

			if ( 'fade' == $data['mk_animation_type'] ) {
				$id = $element->get_id();
				$count = count($colors);
				$step = 100 / $count;
				$pos = 0;
				$bg_colors = '@keyframes mk_colors_anim_fade-'. $id .'{ 0%, 100% {background-color: '. $colors[0] .';} ';

				for ($i = 1; $i < $count ; $i++) {
					$pos += $step;
					$bg_colors .= $pos. '% {background-color: '. $colors[$i] .';} ';
				}
				$bg_colors .= ' }';
				?>
				<style type="text/css">
					.mk-colors-anim-fade.elementor-element-<?php echo esc_attr( $id ); ?>{
						animation-name: mk_colors_anim_fade-<?php echo esc_attr( $id ); ?>;
					}
					<?php echo esc_attr( $bg_colors ); ?>
				</style>
				<?php
			}

			$colors = [
				'type'		=> $data['mk_animation_type'],
				'angle'		=> $data['mk_colors_angle'],
				'colors'	=> $colors
			];

			$element->add_render_attribute( '_wrapper','data-mk-anim-colors', wp_json_encode( $colors ) );
		}

	}

	public function print_template( $template, $elems ) {
		$old_template = $template;
		ob_start();
		?>
		<#
			if ( 'yes' == settings.mk_is_animation ) {
				var type = settings.mk_animation_type;
				var angle = settings.mk_colors_angle;
				var colors = [];
				var id = view.getID();
				var i = 0;
				var bgSize = '100%';

				_.each(settings.mk_animation_colors, function (color, index) {
					colors[i] = color.mk_animation_color;
					i++;
				});

				if ( 'hor-moving' == type ) {
					bgSize = colors.length +'00% 100%';
				} else if ( 'ver-moving' == type ) {
					bgSize = '100% '+ colors.length +'00%';
				}

				if ( 'fade' == type ) {
					var length = colors.length;
					var step = 100 / length;
					var pos = 0;
					var bgColors = '@keyframes mk_colors_anim_fade-'+ id +'{ 0%, 100% {background-color: '+ colors[0] +';} ';

					var j;
					for (j = 1; j < length; j++) {
					    pos += step;
					    bgColors += pos +'% {background-color: '+ colors[j] +';} ';
					}
					bgColors += ' }';
					#>
					<style type="text/css">
						.mk-colors-anim-fade.elementor-element-{{{ id }}} {
							animation-name: mk_colors_anim_fade-{{{ id }}};
						}
						{{{ bgColors }}}
					</style>
					<#
				} else {
					#>
					<style type="text/css">
						.elementor .elementor-element-{{{ id }}}{
							background-color: {{{colors[0]}}};
							background-image : linear-gradient({{{angle}}}deg, {{{colors.toString()}}});
							background-size : {{{bgSize}}};
						}
					</style>
					<#
				}
			}
		#>
		<?php
		$content = ob_get_contents();
		ob_end_clean();

		return $content . $old_template;
	}

}

Mk_Background_Colors_Animation::instance();