<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
Class Mk_Parallax_Animation{

	private static $instance = null;
	public static function instance() { if ( is_null( self::$instance ) ) {self::$instance = new self(); } return self::$instance; }

	public function __construct() {
		add_action( 'elementor/element/section/section_effects/after_section_end', [$this, 'register_controls'] );
		add_action( 'elementor/frontend/section/after_render', [$this, 'render_content'] );
		add_action( 'elementor/section/print_template', [$this, 'print_template'], 10, 2 );

        add_action( 'elementor/element/container/section_effects/after_section_end', [$this, 'register_controls'] );
        add_action( 'elementor/frontend/container/after_render', [$this, 'render_content'] );
        add_action( 'elementor/container/print_template', [$this, 'print_template'], 10, 2 );
	}

	public function register_controls($element) {

		$element->start_controls_section('mk_parallax_animation',[
			'label' => esc_html__('Custom - Parallax (Advanced)', 'orbius-core'),
			'tab' => \Elementor\Controls_Manager::TAB_ADVANCED,
		]);

    		$element->add_control('mk_parallax_note',[
    			'type' => \Elementor\Controls_Manager::RAW_HTML,
    			'raw' => esc_html__( 'NOTICE: When you turn enabled or disabled this feature don\'t forget to click the "Apply" button to see the actual result!', 'orbius-core' ),
    			'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
    		]);

    		$element->add_control('mk_is_parallax',[
    			'label' => esc_html__( 'Parallax Enable', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SWITCHER,
    			'prefix_class'  => 'mk-parallax-',
    		]);

    		$element->add_control('mk_plx_type',[
    			'label' => esc_html__( 'Parallax Type', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SELECT,
    			'options' => [
    				'onscroll' => esc_html__( 'On Scroll', 'orbius-core' ),
    				'mousemove' => esc_html__( 'Mouse Move', 'orbius-core' ),
    			],
    			'default' => 'onscroll',
    			'condition' => [
    				'mk_is_parallax' => 'yes',
    			],
    		]);

    		$element->add_control('mk_plx_wrap_overflow',[
    			'label' => esc_html__( 'Container Overflow', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SELECT,
    			'description' => esc_html__('For large image(s) you can use "hidden" value.', 'orbius-core'),
    			'options' => [
    				'hidden' => esc_html__( 'Hidden', 'orbius-core' ),
    				'inherit' => esc_html__( 'Default', 'orbius-core' ),
    			],
    			'default' => 'inherit',
    			'condition' => ['mk_is_parallax' => 'yes'],
    			'selectors' => ['{{WRAPPER}} > .mk-parallax-wrapper, {{WRAPPER}} > .mk-parallax-wrap' => 'overflow: {{VALUE}};'],
    		]);

    		$element->add_control('mk_plx_wrap_zindex',[
    			'label' => esc_html__( 'Container Z-Index', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::NUMBER,
    			'default' => 1,
    			'condition' => [
    				'mk_is_parallax' => 'yes',
    				'mk_plx_type' => 'mousemove',
    			],
    			'selectors' => ['{{WRAPPER}} > .mk-parallax-wrap' => 'z-index: {{VALUE}};'],
    		]);

    		$repeater = new \Elementor\Repeater();

            $repeater->add_control('mk_plx_zindex',[
                'label' => esc_html__( 'Z-Index', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 0,
                'separator' => 'after',
                'selectors' => ['{{WRAPPER}} > .mk-parallax-wrapper .mk-parallax{{CURRENT_ITEM}}' => 'z-index: {{VALUE}};'],
            ]);

            $repeater->add_control('mk_plx_image', [
                'label'     => esc_html__( 'Choose Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

    		$repeater->start_controls_tabs( 'mk_parallax_tabs' );

    		    $repeater->start_controls_tab('mk_parallax_effects',[
    				'label' => esc_html__( 'Effects', 'orbius-core' ),
    			]);

            		$repeater->add_control('mk_plx_move',[
        				'label' => esc_html__( 'Move', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SELECT,
        				'options' => [
        					'mk-plx-moveTop' => esc_html__( 'Bottom to Top', 'orbius-core' ),
        					'mk-plx-moveRight' => esc_html__( 'Left to Right', 'orbius-core' ),
        					'mk-plx-moveLeft' => esc_html__( 'Right to Left', 'orbius-core' ),
        					'mk-plx-moveBottom' => esc_html__( 'Top to Bottom', 'orbius-core' ),
        					'' => esc_html__( 'None', 'orbius-core' ),
        				],
        				'default' => 'mk-plx-moveTop',
        			]);

            		$repeater->add_control('mk_plx_move_size',[
        				'label' => esc_html__( 'Move Size', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SLIDER,
        				'size_units' => [ 'px' ],
        				'range' => [
        					'px' => ['min' => 0, 'max' => 1000],
        				],
        				'default' => ['unit' => 'px', 'size' => '300'],
        				'condition' => ['mk_plx_move!' => ''],
        			]);

            		$repeater->add_control('mk_plx_zoom',[
        				'label' => esc_html__( 'Zoom', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SELECT,
        				'options' => [
        					'mk-plx-zoomIn' => esc_html__( 'Zoom In', 'orbius-core' ),
        					'mk-plx-zoomOut' => esc_html__( 'Zoom Out', 'orbius-core' ),
        					'' => esc_html__( 'None', 'orbius-core' ),
        				],
        				'default' => '',
        			]);

            		$repeater->add_control('mk_plx_zoom_size',[
        				'label' => esc_html__( 'Zoom Size', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SLIDER,
        				'size_units' => [ 'px' ],
        				'range' => [
        					'px' => [
        						'min' => 1,
        						'max' => 10,
        						'step' => 0.1,
        					],
        				],
        				'default' => ['unit' => 'px', 'size' => '3'],
        				'condition' => ['mk_plx_zoom!' => ''],
        			]);

            		$repeater->add_control('mk_plx_rotate',[
        				'label' => esc_html__( 'Rotate', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SELECT,
        				'options' => [
        					'mk-plx-rotateX' => esc_html__( 'Rotate X Axis', 'orbius-core' ),
        					'mk-plx-rotateY' => esc_html__( 'Rotate Y Axis', 'orbius-core' ),
        					'mk-plx-rotateZ' => esc_html__( 'Rotate Z Axis', 'orbius-core' ),
        					'' => esc_html__( 'None', 'orbius-core' ),
        				],
        				'default' => '',
        			]);

            		$repeater->add_control('mk_plx_rotate_size',[
        				'label' => esc_html__( 'Rotate Size', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SLIDER,
        				'size_units' => [ 'px' ],
        				'range' => [
        					'px' => ['min' => 0, 'max' => 1000],
        				],
        				'default' => ['unit' => 'px', 'size' => '360'],
        				'condition' => ['mk_plx_rotate!' => ''],
        			]);

            		$repeater->add_control('mk_plx_fade',[
        				'label' => esc_html__( 'Fade', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SELECT,
        				'options' => [
        					'mk-plx-fadeIn' => esc_html__( 'Fade In', 'orbius-core' ),
        					'mk-plx-fadeOut' => esc_html__( 'Fade Out', 'orbius-core' ),
        					'' => esc_html__( 'None', 'orbius-core' ),
        				],
        				'default' => '',
        			]);

    		$repeater->end_controls_tab();

        		$repeater->start_controls_tab('mk_parallax_styles',[
        			'label' => esc_html__( 'Styles', 'orbius-core' ),
        		]);

                    $repeater->add_control('mk_plx_width',[
        				'label' => esc_html__( 'Width', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SELECT,
        				'options' => [
        					'' => esc_html__( 'Auto', 'orbius-core' ),
        					'custom' => esc_html__( 'Custom', 'orbius-core' ),
        				],
        				'default' => 'custom',
        			]);

            		$repeater->add_responsive_control('mk_plx_width_size',[
        				'label' => esc_html__( 'Width Size', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::SLIDER,
        				'size_units' => [ '%', 'em', 'px' ],
        				'range' => [
        					'%' => ['max' => 500],
        					'em' => ['max' => 1000],
        					'px' => ['max' => 5000],
        				],
        				'default' => ['unit' => '%', 'size' => '100'],
        				'condition' => ['mk_plx_width' => 'custom'],
        				'selectors' => ['{{WRAPPER}} > .mk-parallax-wrapper .mk-parallax{{CURRENT_ITEM}}' => 'width: {{SIZE}}{{UNIT}};max-width: {{SIZE}}{{UNIT}};'],
        			]);


                    $repeater->add_control('mk_plx_h_align',[
                        'label' => esc_html__( 'Horizontal Align', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::SELECT,
                        'options' => [
                            'left' => esc_html__( 'Left', 'orbius-core' ),
                            'right' => esc_html__( 'Right', 'orbius-core' ),
                        ],
                        'default' => 'left',
                        'selectors' => ['{{WRAPPER}} > .mk-parallax-wrapper .mk-parallax{{CURRENT_ITEM}}' => '{{VALUE}}:0;'],
                    ]);

                    $repeater->add_control('mk_plx_v_align',[
                        'label' => esc_html__( 'Vertical Align', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::SELECT,
                        'options' => [
                            'top' => esc_html__( 'Top', 'orbius-core' ),
                            'bottom' => esc_html__( 'Bottom', 'orbius-core' ),
                        ],
                        'default' => 'top',
                        'selectors' => ['{{WRAPPER}} > .mk-parallax-wrapper .mk-parallax{{CURRENT_ITEM}}' => '{{VALUE}}:0;'],
                    ]);

                    $repeater->add_responsive_control('mk_plx_margin', [
                        'label' => esc_html__( 'Margin', 'orbius-core' ),
                        'type' => \Elementor\Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', 'em', '%' ],
                        'selectors' => [
                            '{{WRAPPER}} > .mk-parallax-wrapper .mk-parallax{{CURRENT_ITEM}}' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                    ]);

            		$element->add_control('mk_plx_images',[
        				'label' => esc_html__( 'Add item', 'orbius-core' ),
        				'type' => \Elementor\Controls_Manager::REPEATER,
        				'fields' => $repeater->get_controls(),
        				'prevent_empty' => false,
        				'condition' => [
        					'mk_is_parallax' => 'yes',
        					'mk_plx_type' => 'onscroll',
        				],
        			]);

    		  $repeater->end_controls_tab();

    		$repeater->end_controls_tabs();

    		$repeater2 = new \Elementor\Repeater();

            $repeater2->add_control('mk_plx_image2', [
                'label'     => esc_html__( 'Choose Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
            ]);

    		$repeater2->add_control('mk_plx_style2',[
    			'label' => esc_html__( 'Styles', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::HEADING,
    			'separator' => 'before',
    		]);

    		$repeater2->add_control('mk_plx_width2',[
    			'label' => esc_html__( 'Width', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SELECT,
    			'options' => [
    				'' => esc_html__( 'Auto', 'orbius-core' ),
    				'custom' => esc_html__( 'Custom', 'orbius-core' ),
    			],
    			'default' => '',
    		]);

    		$repeater2->add_responsive_control('mk_plx_width_size2',[
    			'label' => esc_html__( 'Width Size', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SLIDER,
    			'size_units' => [ '%', 'em', 'px' ],
    			'range' => [
    				'%' => ['max' => 500],
    				'em' => ['max' => 1000],
    				'px' => ['max' => 5000],
    			],
    			'default' => ['unit' => '%', 'size' => '100'],
    			'condition' => ['mk_plx_width2' => 'custom'],
    			'selectors' => ['{{WRAPPER}} > .mk-parallax-wrap .mk-parallax-item{{CURRENT_ITEM}}' => 'width: {{SIZE}}{{UNIT}};max-width: {{SIZE}}{{UNIT}};'],
    		]);

    		$repeater2->add_responsive_control('mk_plx_pos_left2',[
    			'label' => esc_html__( 'Left', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SLIDER,
    			'size_units' => [ '%', 'em', 'px' ],
    			'range' => [
    				'%' => ['max' => 500, 'min' => -500],
    				'em' => ['max' => 1000, 'min' => -1000],
    				'px' => ['max' => 5000, 'min' => -5000],
    			],
    			'default' => ['unit' => '%', 'size' => '10'],
    			'selectors' => ['{{WRAPPER}} > .mk-parallax-wrap .mk-parallax-item{{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}};'],
    		]);

    		$repeater2->add_responsive_control('mk_plx_pos_top2',[
    			'label' => esc_html__( 'Top', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SLIDER,
    			'size_units' => [ '%', 'em', 'px' ],
    			'range' => [
    				'%' => ['max' => 100, 'min' => -100],
    				'em' => ['max' => 200, 'min' => -200],
    				'px' => ['max' => 2000, 'min' => -2000],
    			],
    			'default' => ['unit' => '%', 'size' => '10'],
    			'selectors' => ['{{WRAPPER}} > .mk-parallax-wrap .mk-parallax-item{{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}};'],
    		]);

    		$repeater2->add_control('mk_plx_velocity',[
    			'label' => esc_html__( 'Velocity', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::SLIDER,
    			'size_units' => [ 'px' ],
    			'range' => [
    				'px' => ['max' => 500],
    			],
    			'default' => ['size' => '50'],
    		]);

    		$repeater2->add_control('mk_plx_zindex2',[
    			'label' => esc_html__( 'Z-Index', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::NUMBER,
    			'default' => 0,
    			'selectors' => ['{{WRAPPER}} > .mk-parallax-wrap .mk-parallax-item{{CURRENT_ITEM}}' => 'z-index: {{VALUE}};'],
    		]);

    		$element->add_control('mk_plx_images2',[
    			'label' => esc_html__( 'Add item', 'orbius-core' ),
    			'type' => \Elementor\Controls_Manager::REPEATER,
    			'fields' => $repeater2->get_controls(),
    			'prevent_empty' => false,
    			'condition' => [
    				'mk_is_parallax' => 'yes',
    				'mk_plx_type' => 'mousemove',
    			],
    		]);

    		$element->add_control('mk_parallax_animation_apply', [
                'type' => \Elementor\Controls_Manager::RAW_HTML,
                'raw' => '<div class="elementor-update-preview" style="background: rgba(0,0,0,0);margin-left: 0;margin-right: 0;"><div class="elementor-update-preview-title">Update changes to page</div><div class="elementor-update-preview-button-wrapper"><button class="elementor-update-preview-button elementor-button elementor-button-success">Apply</button></div></div>',
            ]);

		$element->end_controls_section();
	}

	public function render_content($element) {
		$data = $element->get_settings_for_display();

		if ( 'yes' == $data['mk_is_parallax'] ):
			if ( 'onscroll' == $data['mk_plx_type'] ) :
				?>
				<div class="mk-parallax-wrapper mk-parallax-wrap-<?php echo esc_attr( $element->get_id() ); ?>">
					<?php foreach ($data['mk_plx_images'] as $image) :
						$img_alt = \Elementor\Control_Media::get_image_alt( $image['mk_plx_image'] );
						$classes = $image['_id'].' '.$image['mk_plx_move'].' '.$image['mk_plx_rotate'].' '.$image['mk_plx_zoom'].' '.$image['mk_plx_fade']; ?>
						<img class="mk-parallax pos-abs elementor-repeater-item-<?php echo esc_attr($classes); ?>"
						data-move="<?php if (isset($image['mk_plx_move_size']['size'])) { echo esc_attr($image['mk_plx_move_size']['size']); } ?>"
						data-zoom="<?php if (isset($image['mk_plx_zoom_size']['size'])) { echo esc_attr($image['mk_plx_zoom_size']['size']); } ?>"
						data-rotate="<?php if (isset($image['mk_plx_rotate_size']['size'])) { echo esc_attr($image['mk_plx_rotate_size']['size']); } ?>"
						src="<?php if (isset($image['mk_plx_image']['url'])) { echo esc_attr($image['mk_plx_image']['url']); } ?>"
						alt="<?php if (isset($img_alt)) { echo esc_attr($img_alt); } ?>">
					<?php endforeach; ?>
				</div>
			<?php else: ?>
				<div class="mk-parallax-wrap mk-parallax-wrap-<?php echo esc_attr( $element->get_id() ); ?>">
					<?php foreach ($data['mk_plx_images2'] as $image) :
						$img_alt = \Elementor\Control_Media::get_image_alt( $image['mk_plx_image2'] );
						?>
						<img class="mk-parallax-item pos-abs elementor-repeater-item-<?php echo esc_attr($image['_id']); ?>"
						data-velocity="<?php echo esc_attr($image['mk_plx_velocity']['size']); ?>"
						src="<?php echo esc_url( $image['mk_plx_image2']['url'] ); ?>"
						alt="<?php echo esc_attr( $img_alt ); ?>">
					<?php endforeach; ?>
				</div>
			<?php
			endif;
		endif;
	}

	public function print_template( $template, $element ) {
		$old_template = $template;

		ob_start();
		?>
		<# if ('yes' == settings.mk_is_parallax) {
			if ( 'onscroll' == settings.mk_plx_type ) {
				#>
				<div class="mk-parallax-wrapper mk-parallax-wrap-{{{view.getID()}}}">
					<# _.each(settings.mk_plx_images, function (image, index) {
						var classes = image._id +' '+ image.mk_plx_move +' '+ image.mk_plx_rotate +' '+ image.mk_plx_zoom +' '+ image.mk_plx_fade;
						#>
						<img class="mk-parallax pos-abs elementor-repeater-item-{{{classes}}}"
						data-move="{{{image.mk_plx_move_size.size}}}"
						data-zoom="{{{image.mk_plx_zoom_size.size}}}"
						data-rotate="{{{image.mk_plx_rotate_size.size}}}"
						src="{{{image.mk_plx_image.url}}}">
					<# }); #>
				</div>
			<# } else { #>
				<div class="mk-parallax-wrap mk-parallax-wrap-{{{view.getID()}}}">
					<# _.each(settings.mk_plx_images2, function (image, index) { #>
						<img class="mk-parallax-item pos-abs elementor-repeater-item-{{{image._id}}}"
						data-velocity="{{{image.mk_plx_velocity.size}}}"
						src="{{{image.mk_plx_image2.url}}}">
					<# }); #>
				</div>
		<# } } #>
		<?php
		$content = ob_get_contents();
		ob_end_clean();

		return $content . $old_template;
	}

}

Mk_Parallax_Animation::instance();