<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
Class Mk_Parallax_Basic {

    private static $instance = null;
    public static function instance() { if ( is_null( self::$instance ) ) {self::$instance = new self(); } return self::$instance; }

    public function __construct() {
        add_action( 'elementor/element/section/section_effects/after_section_end', [$this, 'register_controls'] );
        add_action( 'elementor/frontend/section/after_render', [$this, 'render_content'] );
        add_action( 'elementor/section/print_template', [$this, 'print_template'], 10, 2 );

        add_action( 'elementor/element/container/section_effects/after_section_end', [$this, 'register_controls'] );
        add_action( 'elementor/frontend/container/after_render', [$this, 'render_content'] );
        add_action( 'elementor/container/print_template', [$this, 'print_template'], 10, 2 );
    }

    public function register_controls($element) {

        $element->start_controls_section('mk_parallax_basic',[
            'label' => esc_html__('Custom - Parallax (Basic)', 'orbius-core'),
            'tab' => \Elementor\Controls_Manager::TAB_ADVANCED,
        ]);

            $element->add_control('mk_is_parallax_basic',[
                'label' => esc_html__( 'Parallax Enable', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'prefix_class'  => 'mk-parallax-basic-',
            ]);

            $element->add_control('mk_parallax_basic_image', [
                'label'     => esc_html__( 'Choose Image', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
                'condition' => ['mk_is_parallax_basic' => 'yes']
            ]);

        $element->end_controls_section();
    }

    public function render_content($element) {
        $data = $element->get_settings_for_display();

        if ( 'yes' == $data['mk_is_parallax_basic'] ):
            ?>
            <div class="mk-parallax-basic-wrap mk-parallax-basic-wrap-<?php echo esc_attr( $element->get_id() ); ?>">
                <div class="mk-parallax-basic-inner">
                    <div class="mk-parallax-basic-img-holder">
                        <?php echo wp_get_attachment_image( $data['mk_parallax_basic_image']['id'], 'full','', array('class' => 'mk-parallax-basic-img') ); ?>
                    </div>
                </div>
            </div>
            <?php
        endif;
    }

    public function print_template( $template, $element ) {
        $old_template = $template;

        ob_start();
        ?>
            <div class="mk-parallax-basic-wrap mk-parallax-basic-wrap-{{{view.getID()}}}">
                <div class="mk-parallax-basic-inner">
                    <div class="mk-parallax-basic-img-holder">
                        <img src="{{{settings.mk_parallax_basic_image.url}}}" class="mk-parallax-basic-img">
                    </div>
                </div>
            </div>
            <?php
        $content = ob_get_contents();
        ob_end_clean();

        return $content . $old_template;
    }

}

Mk_Parallax_Basic::instance();