<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
//------------------------------------------------------------------------------------------------------
//  Grid List
//------------------------------------------------------------------------------------------------------

if ( ! function_exists( 'mk_list_sc_template_part' ) ) {
    function mk_list_sc_template_part( $filename, $params = array(), $echo = true ) {
        $template_file = MK_ABS_PATH . '/elements/parts/' . $filename;
        $html = '';

        if ( ! empty( $template_file ) && file_exists( $template_file ) ) {
            //Extract params so they could be used in template
            if ( is_array( $params ) && count( $params ) ) {
                extract( $params ); // @codingStandardsIgnoreLine
            }
            ob_start();
            include( $template_file );
            $html = ob_get_clean();
        }
        if ($echo) { echo $html; } else { return $html; }
    }
}
if ( ! function_exists( 'mk_get_spinner_svg_icon' ) ) {
    function mk_get_spinner_svg_icon() { return '<p class="mk-pagination-spinner spinner mk-m-pagination-spinner swm-color-headings"><i class="fas fa-spinner"></i></p>'; }
}
if ( ! function_exists( 'mk_add_inline_attr' ) ) {
    function mk_add_inline_attr( $value, $attr ) { return ( '' !== $value ) ? $attr . '="' . esc_attr( $value ) . '"' : ''; }
}
if ( ! function_exists( 'mk_get_filter_items' ) ) {
    function mk_get_filter_items( $params ) {
        $args     = array('taxonomy' => $params['taxonomy_filter'], 'parent' => 0);

        if ( isset( $params['include_posts_cat'] ) ) { $args['include'] = $params['include_posts_cat']; }
        if ( isset( $params['exclude_posts_cat'] ) ) { $args['exclude'] = $params['exclude_posts_cat']; }

        $terms = get_terms( $args );
        $items = ! empty( $terms ) ? $terms : '';

        return apply_filters( 'mk_filter_get_filter_items', $items, $params );
    }
}
if ( ! function_exists( 'mk_get_pagination_data' ) ) {
    function mk_get_pagination_data( $post_type, $params ) {
        $data = array();
        if ( ! empty( $post_type ) && ! empty( $params ) ) {
            $additional_params = array(
                'post_type'     => esc_attr( $post_type ),
                'next_page'     => '2',
                'max_pages_num' => $params['query_result']->max_num_pages,
            );
            unset( $params['query_result'] );
            if ( isset( $params['holder_classes'] ) ) { unset( $params['holder_classes'] ); }
            if ( isset( $params['space'] ) && ! empty( $params['space'] ) ) { $params['space_value'] = 0; }

            $data = json_encode( array_filter( array_merge( $additional_params, $params ) ) );
        }

        return $data;
    }
}

// -----------------------------------------------------------------------------------------------
// REST API
// -----------------------------------------------------------------------------------------------

if ( ! function_exists( 'mk_rest_namespace' ) ) {
    function mk_rest_namespace() { return 'mk/v1'; }
}
if ( ! function_exists( 'register_rest_api_route' ) ) {
    function register_rest_api_route() {
        $routes = apply_filters( 'mk_filter_rest_api_routes', array() );

        if ( ! empty( $routes ) ) {
            foreach ( $routes as $route ) {
                $permission_callback = isset( $route['permission_callback'] ) && ! empty( $route['permission_callback'] ) ? $route['permission_callback'] : '__return_true';

                register_rest_route(mk_rest_namespace(), esc_attr( $route['route'] ), array(
                    'methods'             => $route['methods'],
                    'callback'            => $route['callback'],
                    'permission_callback' => $permission_callback,
                    'args'                => $route['args'],
                ));
            }
        }
    }
    add_action( 'rest_api_init', 'register_rest_api_route' );
}
if ( ! function_exists( 'mk_add_rest_api_pagination_route' ) ) {
    function mk_add_rest_api_pagination_route( $routes ) {
        $routes['pagination'] = array(
            'route'    => 'get-posts',
            'methods'  => WP_REST_Server::READABLE,
            'callback' => 'mk_get_new_posts',
            'args'     => array(
                'options' => array(
                    'required'          => true,
                    'validate_callback' => function ( $param, $request, $key ) {
                        // Simple solution for validation can be 'is_array' value instead of callback function
                        return is_array( $param ) ? $param : (array) $param;
                    },
                    'description'       => esc_html__( 'Options data is array with all selected shortcode parameters value', 'orbius-core' ),
                ),
            ),
        );
        return $routes;
    }
    add_filter( 'mk_filter_rest_api_routes', 'mk_add_rest_api_pagination_route' );
}
if ( ! function_exists( 'mk_get_new_posts' ) ) {
    function mk_get_new_posts() {

        if ( ! isset( $_GET ) || empty( $_GET ) ) {
            mk_get_ajax_status( 'error', esc_html__( 'Get method is invalid', 'orbius-core' ) );
        } else {
            $options = isset( $_GET['options'] ) ? (array) $_GET['options'] : array();

            if ( ! empty( $options ) ) {
                $query_args = mk_get_query_params( $options );

                $options['query_result'] = new \WP_Query( $query_args );
                if ( isset( $options['object_class_name'] ) && ! empty( $options['object_class_name'] ) && class_exists( $options['object_class_name'] ) ) {
                    $options['this_shortcode'] = new $options['object_class_name'](); // needed for pagination loading items since object is not transferred via data params
                }

                ob_start();
                echo mk_list_sc_template_part( 'grid/' . $options['post_type'] . '-loop.php', $options ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

                $html = ob_get_contents();
                ob_end_clean();

                $pagination_html = '';
                if ( 'standard' === $options['pagination_type'] ) {
                    $pagination_html = mk_list_sc_template_part( 'pagination/pagination-standard.php', $options, false ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                }

                $data = apply_filters('mk_filter_pagination_data_return', array(
                        'html'            => $html,
                        'max_pages_num'   => $options['query_result']->max_num_pages,
                        'pagination_html' => $pagination_html,
                    ),
                    $options
                );

                mk_get_ajax_status( 'success', esc_html__( 'Items are loaded', 'orbius-core' ), $data );
            } else {
                mk_get_ajax_status( 'error', esc_html__( 'Options are invalid', 'orbius-core' ) );
            }
        }
    }
}
if ( ! function_exists( 'mk_get_query_params' ) ) {
    function mk_get_query_params( $params ) {
        $post_type      = isset( $params['post_type'] ) && ! empty( $params['post_type'] )           ? $params['post_type']      : 'post';
        $posts_per_page = isset( $params['posts_per_page'] ) && ! empty( $params['posts_per_page'] ) ? intval($params['posts_per_page']) : 12;

        $args = array(
            'post_status'         => 'publish',
            'post_type'           => $post_type,
            'posts_per_page'      => $posts_per_page,
            'orderby'             => $params['orderby'],
            'order'               => $params['order'],
            'ignore_sticky_posts' => 1,
        );

        if ( $post_type == 'post' ) {
            if ( isset( $params['include_posts_cat'] ) ) { $args['cat'] = $params['include_posts_cat']; }
            if ( isset( $params['exclude_posts_cat'] ) ) { $args['category__not_in'] = $params['exclude_posts_cat']; }
        }

        if ( $post_type !== 'post' ) {

            // Show by Post IDs
            if ( ! empty( $params['additional_params'] ) && 'posts' === $params['additional_params'] ) {
                $post_ids         = $params['include_posts'];
                $args['orderby']  = 'post__in';
                $args['post__in'] = $post_ids;
            }

            // Show By Category
            if ( ! empty( $params['additional_params'] ) && 'category' === $params['additional_params'] ) {
                $cat_tax_values = array();

                $params['tax__in'] = $params['include_posts_cat'];

                $cat_list  = isset( $params['tax__in'] ) ? $params['tax__in'] : '';

                if ( ! empty( $cat_list )) {
                    $cat_tax_values['field'] = 'term_id';
                    $cat_tax_values['terms'] = is_array( $cat_list ) ? array_map( 'intval', $cat_list ) : array_map( 'intval', explode( ',', str_replace( ' ', '', $cat_list ) ) );
                }

                if ( ! empty( $cat_tax_values ) ) {
                    $args['tax_query'] = array( array_merge( array( 'taxonomy' => $params['taxonomy_filter'] ), $cat_tax_values ) );
                }
            }

        }

        if ( isset( $params['next_page'] ) && ! empty( $params['next_page'] ) ) {
            $args['paged'] = intval( $params['next_page'] );
        } elseif ( ! empty( max( 1, get_query_var( 'paged' ) ) ) ) {
            $args['paged'] = max( 1, get_query_var( 'paged' ) );
        } else {
            $args['paged'] = 1;
        }

        if ( isset( $params['additional_query_args'] ) && ! empty( $params['additional_query_args'] ) ) {
            foreach ( $params['additional_query_args'] as $key => $value ) {
                $args[ esc_attr( $key ) ] = $value;
            }
        }

        return apply_filters( 'mk_filter_query_params', $args, $params );
    }
}
if ( ! function_exists( 'mk_get_ajax_status' ) ) {
    function mk_get_ajax_status( $status, $message, $data = null, $redirect = '' ) {
        $response = array(
            'status'   => esc_attr( $status ),
            'message'  => esc_html( $message ),
            'data'     => $data,
            'redirect' => ! empty( $redirect ) ? esc_url( $redirect ) : '',
        );
        $output = json_encode( $response );
        exit( $output );
    }
}