<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }


if ( !function_exists( 'mk_short_text' ) ) {
	function mk_short_text($text, $limit) {

	  	$truncate = get_the_excerpt();
		$truncate = preg_replace('@<script[^>]*?>.*?</script>@si', '', $text);
		$truncate = preg_replace('@<style[^>]*?>.*?</style>@si', '', $truncate);
		$truncate = strip_tags($truncate);
		$truncate = $truncate . ' ';
		$truncate = substr($truncate, 0, strrpos(substr($truncate, 0, $limit), ' '));

		return $truncate;
	}
}

/* Get Comments Number */

if( ! function_exists( 'mk_get_comments_number' ) ) {
	function mk_get_comments_number() {

		$mk_num_comments = get_comments_number();

		if ( $mk_num_comments == 0 ) {
			$output =  esc_html__('No Comments','orbius-core');
		} elseif ( $mk_num_comments > 1 ) {
			$output =  $mk_num_comments . esc_html__(' Comments','orbius-core');
		} else {
			$output =  esc_html__('1 Comment','orbius-core');
		}

		return $output;
	}
}


/* Filterable Gallery Category */
if (!function_exists('mk_get_filterable_gallery_cat')) {
    function mk_get_filterable_gallery_cat( $filterable_gallery ) {
    	$category_in = [];

    	foreach ( $filterable_gallery as $item ) {
    		if ( $item['category'] ) {
    			$cat_explode = explode( ',', $item['category'] );

    			foreach ( $cat_explode as $name ) {
    				$category = strtolower( str_replace( ' ', '_', $name ) );

    				if ( !in_array($category, $category_in) ) {
    					$category_in[] = $category;
    				}
    			}
    		}
    	}

    	sort($category_in);

    	return $category_in;
    }
}

/* Get Category */
if (!function_exists('mk_get_categories')) {
    function mk_get_categories($category){
    	$terms = get_terms( [
    		'taxonomy' => $category,
    		'hide_empty' => true,
    	] );

    	$options = [];
    	if ( ! empty( $terms ) && ! is_wp_error( $terms ) ){
    		foreach ( $terms as $term ) {
    			$options[ $term->term_id ] = $term->name;
    		}
    	}
    	return $options;
    }
}

/* Portfolio Category List */
if (!function_exists('get_portfolio_cat_list')) {
    function get_portfolio_cat_list() {

        $args = array(
            'type'     => 'portfolio',
            'taxonomy' => 'portfolio_category' );

        $pf_all_categories = get_categories($args);

        $pf_category_list = array();

        foreach ($pf_all_categories as $category) {
            $taxonomy_term_name = $category->term_id;
            $taxonomy_term_slug = $category->slug;
            $pf_category_list[ $taxonomy_term_name ] = $taxonomy_term_slug;
        }

        return $pf_category_list;

    }
}


/* Portfolio Posts List */
if (!function_exists('mk_portfolio_posts_list')) {
    function mk_portfolio_posts_list() {

        $args = array(
            'post_type' => 'portfolio',
            'numberposts' => '9999',
             );
        $pf_all_pages = get_posts($args);
        $pf_pages_list = array();

        foreach ($pf_all_pages as $page) {
            $taxonomy_term_id = $page->ID;
            $taxonomy_term_title = $page->post_title;
            $pf_pages_list[ $taxonomy_term_id ] = $taxonomy_term_title;
        }
        return $pf_pages_list;

    }
}

/* Get Page Templates */
if (!function_exists('mk_get_page_templates')) {
    function mk_get_page_templates(){
    	$page_templates = get_posts( [
    		'post_type'         => 'elementor_library',
    		'posts_per_page'    => -1
    	] );

    	$options = [];

    	if ( ! empty( $page_templates ) && ! is_wp_error( $page_templates ) ){
    		foreach ( $page_templates as $template ) {
    			$options[ $template->ID ] = $template->post_title;
    		}
    	}
    	return $options;
    }
}

/* Image Caption */
if (!function_exists('get_image_caption')) {
    function get_image_caption( $id, $caption_type = 'caption' ) {

    	if ( empty( $caption_type ) ) {
    		return '';
    	}

        $attachment = get_post( $id );
        $attachment_caption = '';

        if ( $caption_type == 'title' ) {
            $attachment_caption = $attachment->post_title;
        } elseif ( $caption_type == 'caption' ) {
            $attachment_caption = $attachment->post_excerpt;
        }

        return $attachment_caption;
    }
}

/* WordPress Menus List */
if (!function_exists('mk_wp_menu_names_list')) {
    function mk_wp_menu_names_list() {

     	$get_wp_menus_name = get_terms( 'nav_menu', array( 'hide_empty' => false ) );

     	$pf_menu_list = array();

    	foreach ( $get_wp_menus_name as $menu_name ) {
    		$taxonomy_menu_id = $menu_name->term_id;
        	$taxonomy_menu_name = $menu_name->name;
        	$pf_menu_list[ $taxonomy_menu_id ] = $taxonomy_menu_name;
    	}

    	return $pf_menu_list;

    }
}
/* -------------------------------------------
   Arrays
------------------------------------------- */
if (!function_exists('mk_position')) {
    function mk_position() {
    	return array(
    		'top-left'      => esc_html__('Top Left', 'orbius-core') ,
    		'top-center'    => esc_html__('Top Center', 'orbius-core') ,
    		'top-right'     => esc_html__('Top Right', 'orbius-core') ,
    		'center'        => esc_html__('Center', 'orbius-core') ,
    		'center-left'   => esc_html__('Center Left', 'orbius-core') ,
    		'center-right'  => esc_html__('Center Right', 'orbius-core') ,
    		'bottom-left'   => esc_html__('Bottom Left', 'orbius-core') ,
    		'bottom-center' => esc_html__('Bottom Center', 'orbius-core') ,
    		'bottom-right'  => esc_html__('Bottom Right', 'orbius-core') ,
    	);
    }
}
 /* Title Tags  */
if (!function_exists('mk_title_tags')) {
    function mk_title_tags() {
     return array(
         'h1'   => esc_html__( 'H1', 'orbius-core' ),
         'h2'   => esc_html__( 'H2', 'orbius-core' ),
         'h3'   => esc_html__( 'H3', 'orbius-core' ),
         'h4'   => esc_html__( 'H4', 'orbius-core' ),
         'h5'   => esc_html__( 'H5', 'orbius-core' ),
         'h6'   => esc_html__( 'H6', 'orbius-core' ),
         'div'  => esc_html__( 'div', 'orbius-core' ),
         'span' => esc_html__( 'span', 'orbius-core' ),
         'p'    => esc_html__( 'p', 'orbius-core' ),
     );
    }
}

// Ajax update cart numbers and items
if (!function_exists('mk_woocommerce_cart_link')) {
    function mk_woocommerce_cart_link($fragments) {

        ob_start();
        global $woocommerce;
        $cart_contents_count = ( !empty( WC()->cart ) ) ? WC()->cart->cart_contents_count : 0;
        ?>

            <span class="mk-cart-number <?php if ( $cart_contents_count == 0 ) { echo 'hide-number'; }?>"><?php echo $cart_contents_count; ?></span>
        <?php
        $fragments['.mk-cart-number'] = ob_get_clean();

        return $fragments;
    }
    add_filter('woocommerce_add_to_cart_fragments', 'mk_woocommerce_cart_link');
}

// Portfolio image html
if ( !function_exists( 'mk_portfolio_image' ) ) {
    function mk_portfolio_image($post_img_size,  $post_thumbnail_id, $params, $mk_attached_image) {

        $get_portfolio_image = '';

        if (  'custom' === $post_img_size  ) {
            $imgUrl = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $post_thumbnail_id, 'post_img', $params );
            if ( ! $imgUrl ) {
                $imgUrl = $mk_attached_image;
            }

            $get_portfolio_image = '<img src="'.esc_url($imgUrl).'" alt="'.get_post_meta($post_thumbnail_id, '_wp_attachment_image_alt', true).'" loading="lazy" />';
        } else {
            $get_portfolio_image = wp_get_attachment_image( $post_thumbnail_id, $post_img_size);
        }

        return $get_portfolio_image;

    }
}

// custom size image html
if (!function_exists('mk_custom_image_size_html')) {

    function mk_custom_image_size_html($obj, $settings, $image, $image_id, $image_size, $render_attr, $class='') {
        $image_render_attr = '';

        $obj->add_render_attribute( $render_attr, 'src', \Elementor\Group_Control_Image_Size::get_attachment_image_src( $image_id, $image_size, $settings ) );
        $obj->add_render_attribute( $render_attr, 'alt', \Elementor\Control_Media::get_image_alt( $image ) );

        if ('' != $class) {
            $obj->add_render_attribute( $render_attr, 'class', $class );
        }

        $obj->add_render_attribute( $render_attr, 'loading', 'lazy' );

        $image_render_attr .= $obj->get_render_attribute_string( $render_attr );

        return $image_render_attr;
    }
}


// filter styling
if (!function_exists('mk_posts_filter_styles')) {

    function mk_posts_filter_styles($obj,$style = true) {

        mk_elem_start_ctrl($obj, 'filter_styling', 'Filter', $style );

        $obj->add_control('enable_filter',[
            'label'   => esc_html__( 'Enable Filter', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
        ]);

        $obj->add_control('filter_all_text', [
            'label'   => esc_html__( 'Filter "Show All" Text', 'orbius-core' ),
            'type'    => \Elementor\Controls_Manager::TEXT,
            'default' => esc_html__( 'Show All', 'orbius-core' ),
            'condition' => ['enable_filter' => 'yes'],
        ]);

        $obj->add_control('filter_color', [
            'label'     => esc_html__( 'Color', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'condition' => ['enable_filter' => 'yes'],
            'selectors' => [
                '{{WRAPPER}} a.mk-m-filter-item' => 'color: {{VALUE}};',
            ],
        ]);

        $obj->add_control('filter_hover_color',[
            'label'     => esc_html__( 'Hover/Active Color', 'orbius-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'condition' => ['enable_filter' => 'yes'],
            'selectors' => [
                '{{WRAPPER}} a.mk-m-filter-item:hover,
                {{WRAPPER}} a.mk-m-filter-item.mk--active,
                {{WRAPPER}} a.mk-m-filter-item.mk--active:before,
                {{WRAPPER}} a.mk-m-filter-item:hover:before' => 'color: {{VALUE}};',
                '{{WRAPPER}} a.mk-m-filter-item:before' => 'background: {{VALUE}};',
            ],
        ]);

        $obj->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name'           => 'filter_typography',
            'condition' => ['enable_filter' => 'yes'],
            'selector' => '{{WRAPPER}} a.mk-m-filter-item',
        ]);

        $obj->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'label'     => esc_html__( 'Active Typography', 'orbius-core' ),
            'name'           => 'filter_hover_typography',
            'condition' => ['enable_filter' => 'yes'],
            'selector' => '{{WRAPPER}} a.mk-m-filter-item.mk--active',
        ]);

        $obj->add_responsive_control('item_padding', [
            'label'      => esc_html__( 'Items Margin', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%' ],
            'condition' => ['enable_filter' => 'yes'],
            'selectors'  => [
                '{{WRAPPER}} .mk-m-filter-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $obj->add_responsive_control('filter_padding', [
            'label'      => esc_html__( 'Padding', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%' ],
            'condition' => ['enable_filter' => 'yes'],
            'selectors'  => [
                '{{WRAPPER}} .mk-m-filter-items' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);

        $obj->add_responsive_control('filter_margin', [
            'label'      => esc_html__( 'Margin', 'orbius-core' ),
            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%' ],
            'condition' => ['enable_filter' => 'yes'],
            'selectors'  => [
                '{{WRAPPER}} .mk-m-filter' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);



        $obj->end_controls_section();

    }
}

// pagination styling
if (!function_exists('mk_posts_pagination_styles')) {

    function mk_posts_pagination_styles($obj,$style = true) {

        mk_elem_start_ctrl($obj, 'pagination_styling', 'Pagination', $style );

            $obj->add_control( 'pagination_type', [
                'type'       => \Elementor\Controls_Manager::SELECT,
                'label'      => esc_html__( 'Pagination', 'orbius-core' ),
                'default'    => 'no-pagination',
                'options'    => mk_arrays('pagination_type'),
            ]);

            $obj->add_control('loadmore_button_text', [
                'label'   => esc_html__( 'Button Text', 'orbius-core' ),
                'type'    => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Load more', 'orbius-core' ),
                'condition' => ['pagination_type' => 'load-more'],
            ]);

            $obj->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
                'name'     => 'loadmore_button_typography',
                'condition' => ['pagination_type' => 'load-more'],
                'selector' => '{{WRAPPER}} a.mk-load-more-button',
            ]);

            $obj->add_responsive_control('loadmore_button_padding', [
                'label'      => esc_html__( 'Padding', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'condition' => ['pagination_type' => 'load-more'],
                'selectors'  => [
                    '{{WRAPPER}} a.mk-load-more-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $obj->add_group_control(\Elementor\Group_Control_Border::get_type(), [
                'name'     => 'loadmore_button_border',
                'label'    => esc_html__( 'Border', 'orbius-core' ),
                'condition' => ['pagination_type' => 'load-more'],
                'selector' => '{{WRAPPER}} a.mk-load-more-button',
            ]);

            $obj->add_responsive_control('loadmore_button_radius', [
                'label' => esc_html__( 'Border Radius', 'orbius-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} a.mk-load-more-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $obj->add_control('pagination_color', [
                'label'     => esc_html__( 'Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['pagination_type!' => 'infinite-scroll'],
                'selectors' => [
                    '{{WRAPPER}} .mk-m-pagination-item:not(.mk--dots),
                    {{WRAPPER}} a.mk-load-more-button' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mk-m-pagination a.page-numbers:after' => 'background: {{VALUE}};',
                ],
            ]);

            $obj->add_control('pagination_bg_color',[
                'label'     => esc_html__( 'Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['pagination_type' => 'load-more'],
                'selectors' => [
                    '{{WRAPPER}} .mk-m-pagination-item:not(.mk--dots),
                    {{WRAPPER}} a.mk-load-more-button' => 'background: {{VALUE}};',
                ],
            ]);

            $obj->add_control('pagination_border_color',[
                'label'     => esc_html__( 'Border Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['pagination_type' => 'load-more'],
                'selectors' => [
                    '{{WRAPPER}} a.mk-load-more-button' => 'border-color: {{VALUE}};',
                ],
            ]);

            $obj->add_control('pagination_hover_color', [
                'label'     => esc_html__( 'Hover Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['pagination_type!' => 'infinite-scroll'],
                'selectors' => [
                    '{{WRAPPER}} .mk-m-pagination-item.mk--active,
                    {{WRAPPER}} .mk-m-pagination-item:not(.mk--dots):hover,
                    {{WRAPPER}} a.mk-load-more-button:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mk-m-pagination a.page-numbers:hover:after,
                    {{WRAPPER}} .mk-m-pagination .page-numbers.current:after' => 'background: {{VALUE}};',
                ],
            ]);

            $obj->add_control('pagination_active_color', [
                'label'     => esc_html__( 'Active Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['pagination_type' => 'standard'],
                'selectors' => [
                    '{{WRAPPER}} .swm-pagination .page-numbers.current' => 'color: {{VALUE}};',
                ],
            ]);

            $obj->add_control('pagination_bg_hover_color',[
                'label'     => esc_html__( 'Hover Background Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['pagination_type' => 'load-more'],
                'selectors' => [
                    '{{WRAPPER}} .mk-m-pagination-item.mk--active,
                    {{WRAPPER}} .mk-m-pagination-item:not(.mk--dots):hover,
                    {{WRAPPER}} a.mk-load-more-button:hover' => 'background: {{VALUE}};',
                ],
            ]);

            $obj->add_control('pagination_hover_border_color',[
                'label'     => esc_html__( 'Hover Border Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['pagination_type' => 'load-more'],
                'selectors' => [
                    '{{WRAPPER}} a.mk-load-more-button:hover' => 'border-color: {{VALUE}};',
                ],
            ]);

            $obj->add_control('spinner_color', [
                'label'     => esc_html__( 'Spinner Color', 'orbius-core' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'condition' => ['pagination_type' => 'infinite-scroll'],
                'selectors' => [
                    '{{WRAPPER}} .mk-pagination--on .mk-m-pagination-spinner i' => 'color: {{VALUE}};',
                ],
            ]);

            $obj->add_responsive_control('pagination_margin', [
                'label'      => esc_html__( 'Margin', 'orbius-core' ),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .mk-m-pagination' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);

            $obj->add_responsive_control('pagination_alignment', [
                'label'                 => esc_html__( 'Align', 'orbius-core' ),
                'type'                  => \Elementor\Controls_Manager::CHOOSE,
                'options'               => mk_arrays('text_align'),
                'condition' => ['pagination_type' => 'standard'],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .mk-m-pagination.mk--standard' => 'text-align: {{VALUE}};',
                ],
            ]);

        $obj->end_controls_section();

    }
}






