(function ($) {
    'use strict';

    window.mkAddonsCS       = {};
    mkAddonsCS.body         = $( 'body' );
    mkAddonsCS.html         = $( 'html' );

    var tabletBreakPoint = 1024;
    if ( typeof elementorFrontendConfig.breakpoints != "undefined" ) {
        if ( typeof elementorFrontendConfig.breakpoints.lg != "undefined" ) {
            tabletBreakPoint = elementorFrontendConfig.breakpoints.lg - 1;
        }
    }

    function mkSwiperSlider($swiperContainer) {

        if ( ! $swiperContainer ) { $swiperContainer = '.swiper-container'; }

        var $target             = $($swiperContainer).first(),
            settings            = $target.data( 'settings' ) || {},
            tabTitles           = $target.data( 'titles' ) || {},
            tabSubtitles        = $target.data( 'subtitles' ) || {},
            tabImage            = $target.data( 'tabimage' ) || {},
            breakpointsSettings = {},
            breakpoints         = elementorFrontend.config.breakpoints,
            fadeVerticalSwiperBg = '';

        if ( $target.length === 0 ) { return; }

        var swiperOptions = {
            slidesPerView: settings['slides_to_show'],
            loop: 'yes' === settings['loop'],
            speed: settings['speed'],
            keyboard: { enabled: true, onlyInViewport: true },
            parallax: 'yes' === settings['parallax'],
            mousewheel: 'yes' === settings['mousewheel'],
            centeredSlides: 'yes' === settings['centered_slides'],
            on: {
                resize: function () {
                 defaultswiperObj.update(); }
            }
        };

        if ( 'yes' === settings['video'] ) {
            swiperOptions.on.init = function () {
                $('.swiper-slide-active').find('video').each(function() { $(this).get(0).play(); });
            }
            swiperOptions.on.slideChangeTransitionStart = function () {
                $('.swiper-slide-active').find('video').each(function() { $(this).get(0).play(); });
            }
            swiperOptions.on.slideChangeTransitionEnd = function () {
                $('.swiper-slide-prev').find('video').each(function() { $(this).get(0).pause(); });
                $('.swiper-slide-next').find('video').each(function() { $(this).get(0).pause(); });
            }
        }

        if ( settings['direction'] ) { swiperOptions.direction = settings['direction']; }

        // effect
        if ( settings['effect'] ) {
            swiperOptions.effect = settings['effect'];
            if ( 'fade' === settings['effect'] ) { swiperOptions.fadeEffect = { crossFade: true }; }
        }

        // autoplay
        if ( 'yes' === settings['autoplay'] ) {
            swiperOptions.autoplay = { delay: settings['autoplay_speed'] };
            if ( settings['pause_on_hover'] ) {
                $( $target ).on( 'mouseenter', function() { defaultswiperObj.autoplay.stop(); });
                $( $target ).on( 'mouseleave', function() { defaultswiperObj.autoplay.start(); });
            }
        }

        // navigation

        if ( 'yes' === settings['arrows_on'] ) {
            swiperOptions.navigation = { prevEl: settings['slider_prev'], nextEl: settings['slider_next'] };
        }

        if ( 'yes' === settings['dots'] ) {
            swiperOptions.pagination = {
                el: settings['slider_pagination'],
                type: 'bullets',
                clickable: true,
            };

            if ( !isEmptyObj(tabTitles) && !isEmptyObj(tabSubtitles) ) {
                swiperOptions.pagination.renderBullet = function(index, className) {

                    var tabImageHTML = '',
                        thumbURL = tabImage[index + 1];
                    if (thumbURL) {
                        tabImageHTML = '<div class="mk-tabsslider-navImage"><img src="' + tabImage[index + 1] + '" /></div>';
                    }

                    return '<div class="' + className + '">' + tabImageHTML + '<div class="mk-tabsslider-navText"><h4 class="mk-tabsslider-navTitle swm-anim">' + (tabTitles[index + 1]) + '</h4><div class="mk-tabsslider-navSubTitle">' + (tabSubtitles[index + 1]) + '</div></div></div>';
                }
            }

        }

        var numberPagination = 1;
        if( numberPagination != '' && numberPagination != undefined ) {

            swiperOptions['on']['slideChange'] = function () {
                if( $( '.swiper-pagination-current' ).length > 0 ) {
                    $( '.swiper-pagination-current' ).html( pad( this.realIndex + 1, 2 ) );
                }
                if( $( '.swiper-pagination-total' ).length > 0 ) {
                    $( '.swiper-pagination-total' ).html( pad( this.slides.length - 2, 2 ) );
                }
            };
        }

        // image spacing
        if ( typeof( settings['image_spacing'] ) !== 'undefined' && settings['image_spacing']['size'] !== '' && settings['image_spacing']['size'] !== null ) {
            swiperOptions.spaceBetween = settings['image_spacing']['size']
        }

        breakpointsSettings[ breakpoints.lg ] = { slidesPerView: settings['slides_to_show'] || 1 };
        breakpointsSettings[ breakpoints.md ] = { slidesPerView: settings['slides_to_show_tablet'] || 1 };
        breakpointsSettings[ breakpoints.xs ] = { slidesPerView: settings['slides_to_show_mobile'] || 1 };

        if ( $target.hasClass('mk-carousel-slider')) {
            if ( !$target.parents().hasClass('mk-carousel-slider-st1') ) {
                breakpointsSettings[ breakpoints.md ] = { slidesPerView: 'auto' };
                breakpointsSettings[ breakpoints.xs ] = { slidesPerView: 'auto' };
            }
        }

        swiperOptions.breakpoints = breakpointsSettings;

        // Showcase slider
        if ( $target.hasClass('mk-showcase-slider')) {

            var showCaseSliderOptions = {
                speed: settings['speed'],
                loop: 'yes' === settings['loop'],
                effect: settings['effect'],
                direction:settings['direction'],
                parallax:true,
                breakpoints: {}
            }

            var showcaseSliderThumbs = new Swiper(".mk-showcase-slider-bg", showCaseSliderOptions);

            swiperOptions.effect = 'slide';
            swiperOptions.thumbs = { swiper: showcaseSliderThumbs };
            swiperOptions.slidesPerView = 2;
            swiperOptions.centeredSlides = true;
        }

        // Image slider
        if ( $target.hasClass('mk-preview-slider') ) {

            var breakpointsTinySettings = {};

            breakpointsTinySettings[ breakpoints.lg ] = { slidesPerView: $target.data( 'thumb-items' ) || 5 };
            breakpointsTinySettings[ breakpoints.md ] = { slidesPerView: $target.data( 'thumb-items-tablet' ) || 3 };
            breakpointsTinySettings[ breakpoints.xs ] = { slidesPerView: $target.data( 'thumb-items-mobile' ) || 2 };

            var thumbSliderOptions = {
                loop: 'yes' === settings['loop'],
                speed: settings['speed'],
                spaceBetween: $target.data( 'thumb-space' ),
                effect:$target.data( 'thumb-effect' ),
                freeMode: true,
                watchSlidesProgress: true
            }

            thumbSliderOptions.breakpoints = breakpointsTinySettings;

            var imageSliderThumbs = new Swiper($target.data( 'thumb-slider-id' ), thumbSliderOptions);

            swiperOptions.thumbs = { swiper: imageSliderThumbs };
        }

        // call
        var defaultswiperObj = new Swiper( $swiperContainer, swiperOptions );

    };

    // if adminbar - reset slider height
    var mkGetCustomSlider = function ($scope, $) {

        var customSliderHolder   = $scope.find( '.swiper-container' ).eq( 0 ),
            customSliderHolderID = '#' + customSliderHolder.attr( 'id' );

        if ( ! customSliderHolder.length ) { return; }
        mkSwiperSlider(customSliderHolderID);

        var customSliderHolderIDHeight = $(customSliderHolderID).height();

        var $windowHeight = $(window).height();

        if ( customSliderHolderIDHeight == $windowHeight && mkAddonsCS.body.hasClass('admin-bar') ) {

            var $adminbar = jQuery( '#wpadminbar' );

            var adminbarHeight = $adminbar.length === 0 || $adminbar.css( 'display' ) == 'none' || $adminbar.css( 'position' ) == 'absolute' ? 0 : $adminbar.height();

            var customSliderHolderIDHeight = $(customSliderHolderID).height();
            var finalHeight = customSliderHolderIDHeight - adminbarHeight;

            $(customSliderHolderID).css( 'height', finalHeight );
        }

        mkAddonsCS.body.mkCustomCursor.init();

    }

    var mkCustomCursor = {
        cursorApended: false,
        init : function () {
            const $dragSelectors = $('.mk--drag-cursor');

            if ($dragSelectors.length) {

                if (false === mkCustomCursor.cursorApended) {
                    mkAddonsCS.body.append('<div class="mk-custom-cursor"><div class="mk-custom-cursor-inner"><svg enable-background="new 0 0 256 512" viewBox="0 0 256 512" xmlns="http://www.w3.org/2000/svg"><path d="m52.1 245.3 144-160c5.9-6.6 16-7.1 22.6-1.2 6.9 6.3 6.8 16.4 1.2 22.6l-134.4 149.3 134.4 149.3c5.9 6.6 5.4 16.7-1.2 22.6s-16.7 5.4-22.6-1.2l-144-160c-5.5-6.1-5.5-15.3 0-21.4z"/></svg><svg viewBox="0 0 256 512" xmlns="http://www.w3.org/2000/svg"><path d="m219.898 266.719-144.01 159.99c-5.906 6.562-16.031 7.094-22.593 1.187-6.918-6.271-6.784-16.394-1.188-22.625l134.367-149.271-134.367-149.271c-5.877-6.594-5.361-16.688 1.188-22.625 6.562-5.907 16.687-5.375 22.593 1.187l144.01 159.99c5.469 6.125 5.469 15.313 0 21.438z"/></svg></div></div>');
                    mkCustomCursor.cursorApended = true;
                }
                const $cursorHolder = $('.mk-custom-cursor');

                if ( $dragSelectors.hasClass('mk--drag-cursor-light-skin') ) {
                    $cursorHolder.addClass('mk-skin--light');
                }

                if (!mkAddonsCS.html.hasClass('touchevents')) {
                    function handleMoveCursor(event) {
                        $cursorHolder.css({
                            top : event.clientY - 45, // half of svg height
                            left: event.clientX - 45, // half of svg width
                        });
                    }

                    document.addEventListener('pointermove', handleMoveCursor);

                    // reset cursor selectors
                    const resetCursorSelectors =
                            '.mk--drag-cursor .swiper-button-prev,' +
                            '.mk--drag-cursor .swiper-button-next,' +
                            '.mk--drag-cursor a,' +
                            '.mk--drag-cursor .swiper-pagination',
                        $resetCursorSelectors = $(resetCursorSelectors);

                    $resetCursorSelectors.css({cursor: 'pointer'});

                    $(document).on('mouseenter', resetCursorSelectors, function () {
                        $cursorHolder.addClass('mk--hide');
                    }).on('mouseleave', resetCursorSelectors, function () {
                        $cursorHolder.removeClass('mk--hide');
                    });

                    // drag cursor selectors
                    const dragSelectors = '.mk--drag-cursor';

                    $(document).on('mouseenter', dragSelectors, function () {
                        $cursorHolder.addClass('mk--show');
                    }).on('mouseleave', dragSelectors, function () {
                        $cursorHolder.removeClass('mk--show');
                    });

                }
            }
        },
    };

    mkAddonsCS.body.mkCustomCursor = mkCustomCursor;

    $( document ).ready( function () {
        mkCustomCursor.init();
    });

    $(window).on('elementor/frontend/init', function () {
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_basic_slider.default', mkGetCustomSlider);
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_tabs_slider.default', mkGetCustomSlider);
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_carousel_slider.default', mkGetCustomSlider);
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_portfolio_slider.default', mkGetCustomSlider);
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_image_carousel_slider.default', mkGetCustomSlider);
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_services_slider.default', mkGetCustomSlider);
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_image_slider.default', mkGetCustomSlider);
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_showcase_slider.default', mkGetCustomSlider);
        elementorFrontend.hooks.addAction('frontend/element_ready/mk_testimonials.default', mkGetCustomSlider);
    });

})(jQuery);