<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if ( ! function_exists( 'sar_custom_http_request_timeout' ) ) {
    add_filter( 'http_request_timeout', 'sar_custom_http_request_timeout', 9999 );
    function sar_custom_http_request_timeout( $timeout_value ) {
    	return 300; // 30 seconds. Too much for production, only for testing.
    }
}

/* ----------------------------------------------------------------------------------------
    Check Plugin/Theme Installed
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'mk_check_installed' ) ) {
    function mk_check_installed( $plugin ) {
        switch ( $plugin ) :
            case 'theme':
                return class_exists( 'Orbius_Base' );
            case 'gutenberg-page':
                $current_screen = function_exists( 'get_current_screen' ) ? get_current_screen() : array();

                return method_exists( $current_screen, 'is_block_editor' ) && $current_screen->is_block_editor();
            case 'gutenberg-editor':
                return class_exists( 'WP_Block_Type' );
            case 'elementor':
                return defined( 'ELEMENTOR_VERSION' );
            case 'woocommerce':
                return class_exists( 'WooCommerce' );
            case 'contact_form_7':
                return defined( 'WPCF7_VERSION' );
            case 'wpml':
                return defined( 'ICL_SITEPRESS_VERSION' );
            default:
                return apply_filters( 'mk_filter_is_plugin_installed', false, $plugin );

        endswitch;
    }
}

/* ----------------------------------------------------------------------------------------
    Template Part
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'mk_theme_template_part' ) ) {
    function mk_theme_template_part( $module, $template, $params = array() ) {
        echo mk_get_theme_template_part( $module, $template, $params );
    }
}

if ( ! function_exists( 'mk_get_theme_template_part' ) ) {
    function mk_get_theme_template_part( $module, $template, $params = array() ) {
        return mk_check_installed( 'theme' ) ? swm_get_template_part( $module, $template, $params ) : '';
    }
}

/* ----------------------------------------------------------------------------------------
    SVG Icons
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'mk_render_svg_icon' ) ) {
    function mk_render_svg_icon( $name, $class_name = '' ) {
        echo mk_get_svg_icon( $name, $class_name ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    }
}

if ( ! function_exists( 'mk_get_svg_icon' ) ) {
    function mk_get_svg_icon( $name, $class_name = '' ) {
        $class = 'swm-svg--' . $name;
        $class = isset( $class_name ) && ! empty( $class_name ) ? $class . ' ' . $class_name : $class;

        $html = mk_get_theme_template_part( 'svg', $name, array( 'class' => $class ) );

        // remove white spaces from loaded svg markup
        $html = preg_replace( '~>\s+<~', '><', $html );
        $html = trim( $html );

        return apply_filters( 'mk_filter_svg_icon', $html );
    }
}

/* ----------------------------------------------------------------------------------------
    Get Page List
---------------------------------------------------------------------------------------- */

if (!function_exists('mk_get_pages')) {
    function mk_get_pages(){
        $pages = get_pages();

        $options = [];
        if ( ! empty( $pages ) ){
            foreach ( $pages as $page ) {
                $options[ $page->ID ] = $page->post_title;
            }
        }

        return $options;
    }
}

/* ----------------------------------------------------------------------------------------
	Singular Pagination Fix
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'mk_singular_pagination_fix' ) ) {
    function mk_singular_pagination_fix( $redirect_url ) {
    	if ( is_paged() && is_singular() ) {
    		$redirect_url = false;
    	}
    	return $redirect_url;
    }
    add_filter( 'redirect_canonical', 'mk_singular_pagination_fix' );
}

/* ----------------------------------------------------------------------------------------
	KSES allowed tags
---------------------------------------------------------------------------------------- */

if (!function_exists('mk_kses_allowed_textarea')) {
	function mk_kses_allowed_textarea() {

		$output = '';

		$mk_allowed_attr = array( 'class' => true,'style' => true,'id'=> true );

		$output = array(
		    'a' => array(
		        'href' => true,
		        'title' => true,
		        'class' => true,
		        'style' => true,
		        'target' => true,
		        'data-filter' => true,
		        'rel' => true
		    ),
		    'abbr' => array(
		        'title' => true,
		    ),
		    'acronym' => array(
		        'title' => true,
		    ),
		    'b' => array(),
		    'blockquote' => array(
		        'cite' => true,
		        'class' => true,
		        'style' => true,
		        'id'=> true
		    ),
		    'cite' => $mk_allowed_attr,
		    'code' => array(),
		    'del' => array(
		        'datetime' => true,
		    ),
		    'em' => $mk_allowed_attr,
		    'i' => $mk_allowed_attr,
		    'q' => array(
		        'cite' => true,
		    ),
		    'iframe' => array(
		    	'class' => true,
		    	'style' => true,
		    	'id'=> true,
				'src' => true,
				'title' => true,
				'byline' => true,
				'portrait' => true,
				'color' => true,
				'width' => true,
				'height' => true,
				'frameborder' => true,
				'webkitAllowFullScreen' => true,
				'mozallowfullscreen' => true,
				'allowFullScreen' => true,
				'allowfullscreen' => true,
			),
		    'strike' => array(),
		    'strong' => array(),
		    'h1' => $mk_allowed_attr,
		    'h2' => $mk_allowed_attr,
		    'h3' => $mk_allowed_attr,
		    'h4' => $mk_allowed_attr,
		    'h5' => $mk_allowed_attr,
		    'h6' => $mk_allowed_attr,
		    'p' => $mk_allowed_attr,
		    'ul' => $mk_allowed_attr,
		    'ol' => $mk_allowed_attr,
		    'li' => $mk_allowed_attr,
		    'div' => $mk_allowed_attr,
		    'span' => $mk_allowed_attr,
		    'small' => $mk_allowed_attr,
		    'br' => $mk_allowed_attr,
		    'img' => array(
		        'src' => true,
		        'class' => true,
		        'style' => true,
		        'id'=> true,
		        'alt'=> true,
		        'title'=> true
		    	)
			);

		return apply_filters( 'mk_kses_allowed_textarea', $output );
	}
}

// KSES for title or short sentenses ----------------------------------------------------------------------------------------


if (!function_exists('mk_kses_allowed_text')) {
	function mk_kses_allowed_text() {

		$output = '';

		$mk_allowed_attr = array( 'class' => true,'style' => true,'id'=> true );

		$output = array(
		    'a' => array(
		        'href' => true,
		        'title' => true,
		        'class' => true,
		        'style' => true
		    ),
		    'abbr' => array(
		        'title' => true,
		    ),
		    'b' => $mk_allowed_attr,
		    'cite' => $mk_allowed_attr,
		    'em' => $mk_allowed_attr,
		    'i' => $mk_allowed_attr,
		    'strike' => array(),
		    'strong' => array(),
		    'span' => $mk_allowed_attr,
		    'small' => $mk_allowed_attr,
		    'div' => $mk_allowed_attr,
		    'br' => $mk_allowed_attr
			);

		return apply_filters( 'mk_kses_allowed_text', $output );
	}
}

/* ----------------------------------------------------------------------------------------
	Post Author Social Icons : Admin > Users > User Profile page > Contact Info
---------------------------------------------------------------------------------------- */

if (!function_exists('mk_author_social_icons')) {
	function mk_author_social_icons( $contactmethods ) {

	$contactmethods['author-subtitle'] = esc_html__( 'Author Job Title', 'orbius-core' );
	$contactmethods['facebook-f'] = esc_html__( 'Facebook URL', 'orbius-core' );
	$contactmethods['twitter'] = esc_html__( 'Twitter URL', 'orbius-core' );
	$contactmethods['pinterest'] = esc_html__( 'Pinterest URL', 'orbius-core' );
	$contactmethods['linkedin-in'] = esc_html__( 'LinkedIn URL', 'orbius-core' );
	$contactmethods['instagram'] = esc_html__( 'Instagram URL', 'orbius-core' );
	$contactmethods['tumblr'] = esc_html__( 'Tumblr URL', 'orbius-core' );
	$contactmethods['delicious'] = esc_html__( 'Delicious URL', 'orbius-core' );
	$contactmethods['vimeo'] = esc_html__( 'Vimeo URL', 'orbius-core' );
	$contactmethods['youtube-play'] = esc_html__( 'YouTube URL', 'orbius-core' );

	return $contactmethods;

	}

	add_filter('user_contactmethods','mk_author_social_icons',10,1);
}

/* ----------------------------------------------------------------------------------------
	Social Media Meta
---------------------------------------------------------------------------------------- */
if ( ! function_exists( 'mk_og_excerpt' ) ) {
    function mk_og_excerpt($text, $excerpt){
    	if ($excerpt) { return $excerpt; }
    	$text = strip_shortcodes( $text );
    	$text = apply_filters('the_content', $text);
    	$text = str_replace(']]>', ']]&gt;', $text);
    	$text = strip_tags($text);
    	$excerpt_length = apply_filters('excerpt_length', 60);
    	$excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
    	$words = preg_split("/[n
    	]+/", $text, $excerpt_length + 1, PREG_SPLIT_NO_EMPTY);

    	if ( count($words) > $excerpt_length ) {
    		array_pop($words);
    		$text = implode(' ', $words);
    		$text = $text . $excerpt_more;
    	} else {
    		$text = implode(' ', $words);
    	}
    	return apply_filters('wp_trim_excerpt', $text);
    }
}

/* ----------------------------------------------------------------------------------------
	Register Custom Widget
---------------------------------------------------------------------------------------- */
if ( ! function_exists( 'mk_register_custom_widgets' ) ) {
    function mk_register_custom_widgets() {

    	if ( mk_get_ts_option('swm_enable_theme_widgets',true) ) {
            require_once MK_WIDGET_DIR . 'about-author.php';
            require_once MK_WIDGET_DIR . 'social-icons.php';
            require_once MK_WIDGET_DIR . 'recent-posts.php';
    	}

    }
    add_action( 'widgets_init', 'mk_register_custom_widgets' );
}

/* ----------------------------------------------------------------------------------------
	Get Ajax URL
---------------------------------------------------------------------------------------- */
if ( ! function_exists( 'mk_get_current_page_url' ) ) {
    function mk_get_current_page_url() {

    	if ( is_front_page() ) {
    		$current_url = home_url( '/' );
    	} else {
    		$http_host   = sanitize_text_field( $_SERVER['HTTP_HOST'] );
    		$request_uri = sanitize_text_field( $_SERVER['REQUEST_URI'] );
    		$current_url = set_url_scheme( 'http://' . $http_host . untrailingslashit( $request_uri ) );
    	}

    	return apply_filters( 'mk_get_current_page_url', $current_url );
    }
}
if ( ! function_exists( 'mk_get_ajax_url' ) ) {
    function mk_get_ajax_url() {
    	$scheme = defined( 'FORCE_SSL_ADMIN' ) && FORCE_SSL_ADMIN ? 'https' : 'admin';

    	$current_url = mk_get_current_page_url();
    	$ajax_url    = admin_url( 'admin-ajax.php', $scheme );

    	if ( preg_match( '/^https/', $current_url ) && ! preg_match( '/^https/', $ajax_url ) ) {
    		$ajax_url = preg_replace( '/^http/', 'https', $ajax_url );
    	}

    	return apply_filters( 'mk_ajax_url', $ajax_url );
    }
}

/* ----------------------------------------------------------------------------------------
	Get Page/Post Title
---------------------------------------------------------------------------------------- */

if ( ! function_exists('mk_get_the_title') ) {
	function mk_get_the_title() {
		if ( is_front_page() ) {
			$title = esc_html__( 'Home', 'orbius-core' );
		} else if ( is_home() ) {
			$title = get_option( 'page_for_posts' ) == get_queried_object_id()
						? get_the_title( get_queried_object_id() )
						: esc_html__( 'All Posts', 'orbius-core' );
		} else if ( is_author() ) {
			$curauth = (get_query_var('author_name')) ? get_user_by('slug', get_query_var('author_name')) : get_userdata(get_query_var('author'));
			$title = sprintf(esc_html__('Author page: %s', 'orbius-core'), $curauth->display_name);
		} else if ( is_404() ) {
			$title = esc_html__('Page not found', 'orbius-core');
		} else if ( is_search() ) {
			$title = sprintf( esc_html__( 'Search: %s', 'orbius-core' ), get_search_query() );
		} else if ( is_day() ) {
			$title = sprintf( esc_html__( 'Daily Archives: %s', 'orbius-core' ), get_the_date() );
		} else if ( is_month() ) {
			$title = sprintf( esc_html__( 'Monthly Archives: %s', 'orbius-core' ), get_the_date( 'F Y' ) );
		} else if ( is_year() ) {
			$title = sprintf( esc_html__( 'Yearly Archives: %s', 'orbius-core' ), get_the_date( 'Y' ) );
		} else if ( is_category() ) {
			$title = sprintf( esc_html__( '%s', 'orbius-core' ), single_cat_title( '', false ) );
		} else if ( is_tag() ) {
			$title = sprintf( esc_html__( 'Tag: %s', 'orbius-core' ), single_tag_title( '', false ) );
		} else if ( is_tax() ) {
			$title = single_term_title( '', false );
		} else if ( is_post_type_archive() ) {
			$obj = get_queried_object();
			$title = ! empty($obj->labels->all_items)
						? $obj->labels->all_items
						: ( ! empty($obj->post_title)
							? $obj->post_title
							: '' );
		} else if ( is_attachment() ) {
			$title = sprintf( esc_html__( 'Attachment: %s', 'orbius-core' ), get_the_title());
		} else if ( is_single() || is_page() ) {
			$title = get_the_title();
		} else {
			$title = get_the_title();	//get_bloginfo('name', 'raw');
		}

        if ( MK_WOOCOMMERCE_IS_ACTIVE ) {

            if ( is_shop() ) {
                $title = woocommerce_page_title($echo = false);
            } else if ( is_product_category() ) {
                $title = single_cat_title('',false);
            } else if ( is_product_tag() ) {
                $title = sprintf( esc_html__( '%s', 'orbius-core' ), single_tag_title('',false) );
            }

        }

		return apply_filters('mk_filter_get_the_title', $title);
	}
}

/* ----------------------------------------------------------------------------------------
	Translation
---------------------------------------------------------------------------------------- */

// Returns correct ID for any object. Used to fix issues with translation plugins such as WPML & Polylang.
if ( ! function_exists( 'mk_parse_obj_id' ) ) {
    function mk_parse_obj_id( $id = '', $type = 'page', $key = '' ) {

    	// WPML Check
    	if ( MK_WPML_ACTIVE ) {
    		$type = ( 'term' == $type && $key ) ? $key : $type;   // If you want to set type to term and key to category for example

    		// Make sure to grab the correct type. Fixes issues when using templatera for example for the header, footer, etc.
    		if ( 'page' == $type ) { $type = get_post_type( $id ); }
    		$id = apply_filters( 'wpml_object_id', $id, $type, true );  // Get correct ID

    	}

    	// Polylang check
    	elseif ( function_exists( 'pll_get_post' ) ) {
    		$type = taxonomy_exists( $type ) ? 'term' : $type; // Fixes issue where type may be set to 'category' instead of term
    		if ( 'page' == $type || 'post' == $type ) {
    			$id = pll_get_post( $id );
    		} elseif ( 'term' == $type && function_exists( 'pll_get_term' ) ) {
    			$id = pll_get_term( $id );
    		}
    	}

    	return $id;  // Return ID

    }
}
/* ----------------------------------------------------------------------------------------
	Add sections to the headers list
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_mk_list_sections_styles' ) ) {
	function swm_mk_list_sections_styles( $type, $order='ID', $list = array() ) {
			$get_list = array();
			$args = array(
		        'post_type'    => 'cpt_sections',
				'meta_key'     => 'mk_section_type',
				'meta_value'   => $type,
				'orderby'      => $order,
				'order'        => 'asc',
				'not_selected' => false,
				'return'       => 'id',
				'ignore_sticky_posts' => true,
				'posts_per_page'   => 1000,
				'suppress_filters' => false,
	    	);
			$posts = get_posts( $args );
			if ( is_array( $posts ) && count( $posts ) > 0 ) {
				foreach ( $posts as $post ) {
					$get_list[ $post->ID ] = $post->post_title;
				}
			}

			$new_list = array();
			foreach ( $get_list as $id => $title ) {
				if ( 'none' != $id ) {
					$new_list[ $type . '-custom-' . intval( $id ) ] = $title;
				}
			}
			$list = array_merge( $list,$new_list );

		return $list;
	}
}

/* ----------------------------------------------------------------------------------------
Translation
---------------------------------------------------------------------------------------- */

// Returns correct ID for any object. Used to fix issues with translation plugins such as WPML & Polylang.
if ( ! function_exists( 'swm_mk_parse_obj_id' ) ) {
	function swm_mk_parse_obj_id( $id = '', $type = 'page', $key = '' ) {

		// WPML Check
		if ( MK_WPML_ACTIVE ) {
			$type = ( 'term' == $type && $key ) ? $key : $type;   // If you want to set type to term and key to category for example

			// Make sure to grab the correct type. Fixes issues when using templatera for example for the header, footer, etc.
			if ( 'page' == $type ) { $type = get_post_type( $id ); }
			$id = apply_filters( 'wpml_object_id', $id, $type, true );  // Get correct ID

		}

		// Polylang check
		elseif ( function_exists( 'pll_get_post' ) ) {
			$type = taxonomy_exists( $type ) ? 'term' : $type; // Fixes issue where type may be set to 'category' instead of term
			if ( 'page' == $type || 'post' == $type ) {
				$id = pll_get_post( $id );
			} elseif ( 'term' == $type && function_exists( 'pll_get_term' ) ) {
				$id = pll_get_term( $id );
			}
		}

		return $id;  // Return ID

	}
}


/* ----------------------------------------------------------------------------------------
Get Section Id
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_mk_get_custom_section_id' ) ) {
	function swm_mk_get_custom_section_id( $type, $section_style = '' ) {
		$section_id = 0;
		$section_id = str_replace( "{$type}-custom-", '', $section_style );
		$section_id = swm_mk_parse_obj_id($section_id);
		$section_id = apply_filters( 'swm_filter_get_translated_section', $section_id );
		return $section_id;
	}
}

/* ----------------------------------------------------------------------------------------
Print Footer
---------------------------------------------------------------------------------------- */

// Add dynamic HTML to insert it to the footer
if ( ! function_exists('mk_add_inline_html') ) {
	function mk_add_inline_html($html='') {
		global $MK_STORAGE;
		$MK_STORAGE['inline_html'] = (!empty($MK_STORAGE['inline_html']) ? $MK_STORAGE['inline_html'] : '') . $html;
	}
}

// Return dynamic HTML to insert it to the footer
if ( ! function_exists('mk_get_inline_html') ) {
	function mk_get_inline_html() {
		global $MK_STORAGE;
		return !empty($MK_STORAGE['inline_html']) ? $MK_STORAGE['inline_html'] : '';
	}
}

// Load inline html
// Attention! Priority 9 is used because inline html must be loaded before moved scripts
if ( !function_exists( 'mk_put_inline_html' ) ) {
	add_action('wp_footer', 'mk_put_inline_html', 9);
	add_action('admin_footer', 'mk_put_inline_html', 9);
	function mk_put_inline_html() {
		echo mk_get_inline_html();
	}
}

/* ----------------------------------------------------------------------------------------
// Return true if Elementor exists and current mode is edit
---------------------------------------------------------------------------------------- */
// Strip slashes if Magic Quotes is on
if (!function_exists('mk_stripslashes')) {
	function mk_stripslashes($val) {
		static $magic = 0;
		if ($magic === 0) {
			$magic = version_compare(phpversion(), '5.4', '>=')
					|| (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()==1)
					|| (function_exists('get_magic_quotes_runtime') && get_magic_quotes_runtime()==1)
					|| strtolower(ini_get('magic_quotes_sybase'))=='on';
		}
		if (is_array($val)) {
			foreach($val as $k=>$v) {
				$val[$k] = mk_stripslashes($v);
			}
		} else {
			$val = $magic ? stripslashes(trim($val)) : trim($val);
		}
		return $val;
	}
}

// Return GET or POST value
if (!function_exists('mk_get_value_gp')) {
	function mk_get_value_gp($name, $defa='') {
		if (isset($_GET[$name]))		$rez = $_GET[$name];
		else if (isset($_POST[$name]))	$rez = $_POST[$name];
		else							$rez = $defa;
		return mk_stripslashes($rez);
	}
}

// Check if plugin 'Elementor' is installed and activated
if ( !function_exists( 'mk_exists_elementor' ) ) {
	function mk_exists_elementor() {
		return class_exists('Elementor\Plugin');
	}
}

if ( !function_exists( 'mk_elm_is_edit_mode' ) ) {
	function mk_elm_is_edit_mode() {
		static $is_edit_mode = -1;
		if ( $is_edit_mode === -1 ) {
			$is_edit_mode = mk_exists_elementor()
								&& ( \Elementor\Plugin::instance()->editor->is_edit_mode()
									|| ( mk_get_value_gp( 'post' ) > 0
										&& mk_get_value_gp( 'action' ) == 'elementor'
										)
									|| ( is_admin()
										&& in_array( mk_get_value_gp( 'action' ), array( 'elementor', 'elementor_ajax', 'wp_ajax_elementor_ajax' ) )
										)
									);
		}
		return $is_edit_mode;
	}
}

/* ----------------------------------------------------------------------------------------
    Get Queried Object ID
---------------------------------------------------------------------------------------- */

if (!function_exists('mk_get_queried_object_id')) {
    function mk_get_queried_object_id() {
        $mk_get_queried_object_id = get_queried_object_id();
        return $mk_get_queried_object_id;
    }
}

/* ----------------------------------------------------------------------------------------
    Add Mobile Class
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'mk_add_mobile_class' ) ) {
    function mk_add_mobile_class( $classes ) {

        if ( wp_is_mobile() ) {
            $classes[] = 'mk--touch';
        } else {
            $classes[] = 'mk--no-touch';
        }
        return $classes;
    }

    add_filter( 'body_class', 'mk_add_mobile_class' );
}

/* ----------------------------------------------------------------------------------------
    Image Size
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_image_sizes')) {
    function swm_image_sizes() {
        add_image_size('swm_image_size_tiny',100,100,true);
        add_image_size('mk_image_size_square',750,750,true);
        add_image_size('mk_image_size_landscape',1300,750,true);
        add_image_size('mk_image_size_portrait',750,1300,true);
        add_image_size('mk_image_size_large-square',1300,1300,true);

    }
    add_action( 'after_setup_theme', 'swm_image_sizes' );
}

/* ----------------------------------------------------------------------------------------
    Print Elementor Icon
---------------------------------------------------------------------------------------- */

if (!function_exists('mk_get_elementor_icons')) {
    function mk_get_elementor_icons($icon_name) {
        $iconHtml = '';
        ob_start();
        \Elementor\Icons_Manager::render_icon( $icon_name, [ 'aria-hidden' => 'true' ] );
        $iconHtml = ob_get_clean();
        return $iconHtml;
    }
}


/* ----------------------------------------------------------------------------------------
    Check WooCommerc
---------------------------------------------------------------------------------------- */

if (!function_exists('mk_check_shop_pages')) {
    function mk_check_shop_pages() {
        if ( mk_check_installed( 'woocommerce' ) ) {
            if ( is_shop() || is_product_tag() || is_product() || is_cart() || is_checkout() || is_account_page() || is_product_category() )  {
                return true;
            } else {
                return false;
            }
        } else {
            return false;
        }

    }
}

/* ----------------------------------------------------------------------------------------
    Get Widget Areas
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_get_widget_areas' ) ) {
    function swm_get_widget_areas() {
        global $wp_registered_sidebars;
        $widgets_areas = array();
        if ( ! empty( $wp_registered_sidebars ) ) {
            foreach ( $wp_registered_sidebars as $widget_area ) {
                $name = isset ( $widget_area['name'] ) ? $widget_area['name'] : '';
                $id = isset ( $widget_area['id'] ) ? $widget_area['id'] : '';
                if ( $name && $id ) {
                    $widgets_areas[$id] = $name;
                }
            }
        }
        return $widgets_areas;
    }
}

/* ----------------------------------------------------------------------------------------
    Social Media Share Buttons
---------------------------------------------------------------------------------------- */

if ( !function_exists( 'mk_post_share_icons' ) ) {
    function mk_post_share_icons( $postid=false ) {

        if ( post_password_required() ) return;

        global $post;
        $postid = $postid ? $postid :$post->ID;
        if (!$postid) return;

        $mk_psi_source = esc_url(home_url('/'));
        $mk_psi_url = get_permalink($postid);
        $mk_psi_url = urlencode( $mk_psi_url );
        $mk_psi_title = esc_attr( the_title_attribute( 'echo=0' ) );
        $mk_psi_summary = substr(get_the_excerpt(), 0,120);
        $mk_psi_img = wp_get_attachment_url( get_post_thumbnail_id($postid), 'full' );

        $output = '';

        $output .= '<div class="swm_post_share_links orbius-core-share-id-box-'.$postid.'">';
        $output .= '<ul class="swm_post_share_icons_list">';

        if ( mk_get_ts_option('swm_post_share_facebook',true) ) {

            $output .= '<li class="s_facebook"><a href="http://www.facebook.com/share.php?u='.$mk_psi_url.'&amp;t='. urlencode($mk_psi_title) .'" target="_blank" title="'. esc_attr__( 'Share  this post on Facebook', 'orbius-core' ) .'" >' . mk_get_svg_icon('facebook','mk-svg-facebook-icon') . '</a></li>';

        }

        if ( mk_get_ts_option('swm_post_share_twitter',true) ) {

            $output .= '<li class="s_twitter"><a href="http://twitter.com/share?text='. urlencode($mk_psi_title) .'&amp;url='. $mk_psi_url .'" target="_blank" title="'. esc_attr__( 'Share this post on Twitter', 'orbius-core' ) .'" >' . mk_get_svg_icon('twitter','mk-svg-twitter-icon') . '</a></li>';

        }

        if ( mk_get_ts_option('swm_post_share_pinterest',true) ) {

            $output .= '<li class="s_pinterest"><a href="http://pinterest.com/pin/create/button/?url='. $mk_psi_url .'&amp;media='. $mk_psi_img .'&amp;description='. urlencode($mk_psi_summary) .'" target="_blank" title="'. esc_attr__( 'Share this post on Pinterest', 'orbius-core' ) .'" >' . mk_get_svg_icon('pinterest','mk-svg-pinterest-icon') . '</a></li>';

        }

        if ( mk_get_ts_option('swm_post_share_linkedin',true) ) {

            $output .= '<li class="s_linkedin"><a title="'. esc_attr__( 'Share this post on LinkedIn', 'orbius-core' ) .'" rel="external" href="http://www.linkedin.com/shareArticle?mini=true&amp;url='. $mk_psi_url .'&amp;title='. urlencode($mk_psi_title) .'&amp;summary='. urlencode($mk_psi_summary) .'&amp;source='. $mk_psi_source .'" target="_blank" >' . mk_get_svg_icon('linkedin','mk-svg-linkedin-icon') . '</a></li>';

        }

        if ( mk_get_ts_option('swm_post_share_tumblr',true) ) {

            $output .= '<li class="s_tumblr"><a title="'. esc_attr__( 'Share this post on Tumblr', 'orbius-core' ) .'" rel="external" href="http://www.tumblr.com/share/link?url='. $mk_psi_url .'&amp;name='. urlencode($mk_psi_title) .'&amp;description='. urlencode($mk_psi_summary) .'" target="_blank" >' . mk_get_svg_icon('tumblr','mk-svg-tumblr-icon') . '</a></li>';

        }

        $output .= '</ul>';
        $output .= '<div class="clear"></div>';
        $output .= '</div>';

        return apply_filters( 'mk_filter_post_share_icons', $output );

    }
}