<?php

/* Remove slashes from the string or array of strings if magic_quotes_gpc is on */
if ( ! function_exists( 'mk_addons_stripslashes' ) ) {
    function mk_addons_stripslashes( $val ) {
        static $magic = 0;
        if ( $magic === 0 ) {
            $magic = version_compare( phpversion(), '5.4', '>=' )
                    || ( function_exists( 'get_magic_quotes_gpc' ) && get_magic_quotes_gpc() == 1 )
                    || ( function_exists( 'get_magic_quotes_runtime' ) && get_magic_quotes_runtime() == 1 )
                    || strtolower( ini_get( 'magic_quotes_sybase' ) ) == 'on';
        }
        if ( is_array( $val ) ) {
            foreach ( $val as $k => $v ) {
                $val[$k] = mk_addons_stripslashes( $v );
            }
        } else {
            $val = $magic ? stripslashes( trim( $val ) ) : trim( $val );
        }
        return $val;
    }
}

/* Check if current page URL contains specified string */
if ( ! function_exists( 'mk_addons_check_url' ) ) {
    function mk_addons_check_url( $val = '' ) {
        if ( ! is_array( $val ) ) {
            $val = array( $val );
        }
        $rez = false;
        foreach ( $val as $s ) {
            $rez = strpos( $_SERVER['REQUEST_URI'], $s ) !== false;
            if ( $rez ) break;
        }
        return $rez;
    }
}

/* Return GET or POST value */
if ( ! function_exists( 'mk_addons_get_value_gp' ) ) {
    function mk_addons_get_value_gp( $name, $defa = '' ) {
        if ( isset( $_GET[ $name ] ) )          $rez = $_GET[ $name ];
        else if ( isset( $_POST[ $name ] ) )    $rez = $_POST[ $name ];
        else                                    $rez = $defa;
        return mk_addons_stripslashes( $rez );
    }
}

/* Check if plugin 'Elementor' is installed and activated */
if ( ! function_exists( 'mk_addons_exists_elementor' ) ) {
    function mk_addons_exists_elementor() {
        return class_exists( 'Elementor\Plugin' );
    }
}

/* Check if current page is a preview page of Elementor */
if ( ! function_exists( 'mk_addons_elm_is_preview' ) ) {
    function mk_addons_elm_is_preview() {
        static $is_preview = -1;
        if ( $is_preview === -1 ) {
            if ( mk_addons_exists_elementor() ) {
                $elementor = \Elementor\Plugin::instance();
                $is_preview = ( is_object( $elementor ) && ! empty( $elementor->preview ) && is_object( $elementor->preview ) && $elementor->preview->is_preview_mode() )
                            || mk_addons_get_value_gp( 'elementor-preview' ) > 0
                            || ( mk_addons_get_value_gp( 'action' ) == 'elementor' && (int) mk_addons_get_value_gp( 'post' ) > 0 )
                            || ( is_admin() && in_array( mk_addons_get_value_gp( 'action' ), array( 'elementor', 'elementor_ajax', 'wp_ajax_elementor_ajax' ) ) );
            } else {
                $is_preview = false;
            }
        }
        return $is_preview;
    }
}

/* Check if plugin 'Gutenberg' is installed and activated. Attention! Gutenberg is a part of WordPress core since 5.0 */
if ( ! function_exists( 'mk_addons_exists_gutenberg' ) ) {
    function mk_addons_exists_gutenberg() {
        return function_exists( 'register_block_type' );
    }
}

/* Check if current mode is "Block Render" (a new block-based widget management experience) */
if ( ! function_exists( 'mk_addons_gutenberg_is_block_render_action' ) ) {
    function mk_addons_gutenberg_is_block_render_action() {
        return mk_addons_exists_gutenberg()
                && mk_addons_check_url('block-renderer') && !empty($_GET['context']) && $_GET['context']=='edit';
    }
}

/* Check if current page is page for new/edit post  */
if ( ! function_exists( 'mk_addons_is_post_edit' ) ) {
    function mk_addons_is_post_edit() {
        return ( mk_addons_check_url( 'post.php' ) && ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' )
                ||
                mk_addons_check_url( 'post-new.php' )
                ||
                ( ! empty( $_GET['context'] ) && $_GET['context'] == 'edit' )
                ||
                ( mk_addons_check_url( 'admin.php' ) && ! empty( $_GET['page'] ) && $_GET['page'] == 'gutenberg-edit-site' )
                ||
                ( mk_addons_check_url( 'site-editor.php' ) && ! empty( $_GET['postType'] ) )   // || $_GET['postType'] == 'wp_template' ) )
                ||
                mk_addons_check_url( 'widgets.php' );
    }
}

/* Check if current mode is "Widgets Block Editor" (a new block-based widget management experience) */
if ( ! function_exists( 'mk_addons_gutenberg_is_widgets_block_editor' ) ) {
    function mk_addons_gutenberg_is_widgets_block_editor() {
        return is_admin()
                && mk_addons_exists_gutenberg()
                && version_compare( get_bloginfo( 'version' ), '5.8', '>=' )
                && mk_addons_check_url( 'widgets.php' )
                && function_exists( 'wp_use_widgets_block_editor' )
                && wp_use_widgets_block_editor();
    }
}

/* Check if current mode is "Site Editor" (a new full site editing experience with Gutenberg support) */
if ( ! function_exists( 'mk_addons_gutenberg_is_site_editor' ) ) {
    function mk_addons_gutenberg_is_site_editor() {
        return is_admin()
                && mk_addons_exists_gutenberg()
                && version_compare( get_bloginfo( 'version' ), '5.9', '>=' )
                && mk_addons_check_url( 'site-editor.php' )
                && function_exists( 'wp_is_block_theme' )
                && wp_is_block_theme();
    }
}

/* Check if current mode is preview (edit) of the Gutenberg block editor */
if ( ! function_exists( 'mk_addons_gutenberg_is_preview' ) ) {
    function mk_addons_gutenberg_is_preview() {
        return mk_addons_exists_gutenberg()
                && (
                    mk_addons_gutenberg_is_block_render_action()
                    ||
                    mk_addons_is_post_edit()
                    ||
                    mk_addons_gutenberg_is_widgets_block_editor()
                    ||
                    mk_addons_gutenberg_is_site_editor()
                    );
    }
}

/* Check if current page is preview mode of any, elemetor or gutenberg PageBuilder */
if ( ! function_exists( 'mk_addons_is_preview' ) ) {
    function mk_addons_is_preview( $builder = 'any' ) {
        return ( in_array( $builder, array( 'any', 'elm', 'elementor' ) ) && function_exists( 'mk_addons_elm_is_preview' ) && mk_addons_elm_is_preview() )
                ||
                ( in_array( $builder, array( 'any', 'gb', 'gutenberg' ) ) && function_exists( 'mk_addons_gutenberg_is_preview' ) && mk_addons_gutenberg_is_preview() );
    }
}

/* Check if current page URL contains specified string */
if ( ! function_exists( 'mk_addons_check_url' ) ) {
    function mk_addons_check_url( $val = '' ) {
        if ( ! is_array( $val ) ) { $val = array( $val ); }
        $rez = false;
        foreach ( $val as $s ) {
            $rez = strpos( $_SERVER['REQUEST_URI'], $s ) !== false;
            if ( $rez ) break;
        }
        return $rez;
    }
}

/*
Disable grab output for Elementor preview mode and AJAX requests
true if grab output is allowed
*/

if ( ! function_exists( 'mk_addons_elm_disable_grab_output' ) ) {
    add_filter( 'mk_addons_filter_grab_output_allowed', 'mk_addons_elm_disable_grab_output' );
    function mk_addons_elm_disable_grab_output( $allowed ) {
        return $allowed
                // Disable in the Elementor preview mode
                && ! ( function_exists( 'mk_addons_is_preview' ) && mk_addons_is_preview( 'elementor' ) )
                // Disable when a widget from Elementor is requested
                && ! doing_action( 'wp_ajax_elementor_render_widget' )
                && ! doing_action( 'wp_ajax_elementor_ajax' )
                && ! doing_action( 'elementor_ajax' )
                && ! doing_action( 'admin_action_elementor' );
    }
}

//-------------------------------------------------------
//-- Capture 'head' and 'body' output
//-------------------------------------------------------

// Check if capture is enabled
if ( ! function_exists( 'mk_addons_grab_output_allowed' ) ) {
    function mk_addons_grab_output_allowed() {
        return
            // Enable on a page requested via AJAX from frontend
            ( ! is_admin() || wp_doing_ajax() )
            // Disable when a REST API is requested (for example, a block "legacy widget" from a new Widgets Editor)
            && ! mk_addons_check_url( '/wp-json/' )
            // Allow a theme and 3rd-party plugins to disable a page capturing
            && apply_filters( 'mk_addons_filter_grab_output_allowed', true );
    }
}


// Start to capture an output of the page
if ( ! function_exists( 'mk_addons_grab_page_start' ) ) {
    function mk_addons_grab_page_start() {

        if ( ! mk_addons_grab_output_allowed() ) return;

        global $MK_STORAGE;
        $MK_STORAGE['capture_page'] = true;

        ob_start( 'mk_addons_grab_page_end' );
    }
}

// Capture a whole page html output
//-------------------------------------------------------

// New way: Add a hook to start capturing a page.
// A priority 3 is used because an API support are loaded on priority 2
if ( ! function_exists( 'mk_addons_grab_page_start_hook' ) ) {
    add_action( 'after_setup_theme', 'mk_addons_grab_page_start_hook', 3 );
    function mk_addons_grab_page_start_hook() {

        $grab_page_start_action = apply_filters( 'mk_addons_filter_grab_page_start_action', 'after_setup_theme' ); // Was 'wp_head' and 0
        $grab_page_start_priority = apply_filters( 'mk_addons_filter_grab_page_start_priority', 4 );               // and has conflict with the block 'Legacy Widget'

        if ( ! empty( $grab_page_start_action ) ) {
            add_action( $grab_page_start_action, 'mk_addons_grab_page_start', $grab_page_start_priority );
        }
    }
}

// End to capture an output of the page
// and move styles from the 'body' to the 'head'
if ( ! function_exists( 'mk_addons_grab_page_end' ) ) {
    function mk_addons_grab_page_end( $html = '' ) {

        global $MK_STORAGE;
        $MK_STORAGE['capture_page'] = false;

        // Parse a raw html output for the head and the body
        $MK_STORAGE['capture_head_html'] = '';
        $MK_STORAGE['capture_body_html'] = '';
        if ( ! empty( $html ) ) {
            $pos = strpos( $html, '</head>' );
            if ( $pos !== false ) {
                $MK_STORAGE['capture_head_html'] = substr( $html, 0, $pos ); // substr(start, offset, length)
                $MK_STORAGE['capture_body_html'] = substr( $html, $pos ); // substr(start, length)
            }
        }

        // Prepare and output a head and a body (if present)
        if ( ! empty( $MK_STORAGE['capture_head_html'] ) && ! empty( $MK_STORAGE['capture_body_html'] ) ) {

            // Move other styles and links to the head
            mk_addons_move_other_styles_to_head();

            // Replace a buffer with the modified content of the head and the body
            $html = apply_filters( 'mk_addons_filter_page_head', $MK_STORAGE['capture_head_html'] )
                    . apply_filters( 'mk_addons_filter_page_content', $MK_STORAGE['capture_body_html'] );

            $MK_STORAGE['capture_head_html'] = '';
            $MK_STORAGE['capture_body_html'] = '';

        }

        return $html;
    }
}

// Move other styles and links to the head
if ( ! function_exists( 'mk_addons_move_other_styles_to_head' ) ) {
    function mk_addons_move_other_styles_to_head() {
        global $MK_STORAGE;
        // A filter below is used instead an option
        // if ( mk_addons_is_on( mk_addons_get_option( 'move_styles_to_head' ) ) ) {
        if ( apply_filters( 'mk_addons_filter_move_styles_to_head', true ) ) {
            // Collect rest tags <link> and <style> from the body html
            $MK_STORAGE['capture_links'] = '';
            $MK_STORAGE['capture_body_html'] = preg_replace_callback(
                "/<style[^<]*>[\s\S]*<\/style>/Uix",
                function( $matches ) {
                    if ( ! empty( $matches[0] ) ) {
                        global $MK_STORAGE;
                        $MK_STORAGE['capture_links'] .= "\n" . $matches[0];
                    }
                    return '';
                },
                $MK_STORAGE['capture_body_html']
            );
            $MK_STORAGE['capture_body_html'] = preg_replace_callback(
                "/<link [^>]*>/",
                function( $matches ) {
                    if ( ! empty( $matches[0] ) ) {
                        global $MK_STORAGE;
                        $MK_STORAGE['capture_links'] .= "\n" . $matches[0];
                    }
                    return '';
                },
                $MK_STORAGE['capture_body_html']
            );
            // Move rest styles before the theme styles
            if ( ! empty( $MK_STORAGE['capture_links'] ) ) {
                $MK_STORAGE['capture_links_moved'] = false;
                if ( apply_filters( 'mk_addons_filter_move_3rd_party_styles_before_theme_styles', true ) ) {
                    $theme_reg = str_replace( '/', '\\/', get_template() );
                    // Try to insert styles before the main theme tag
                    $MK_STORAGE['capture_head_html'] = preg_replace_callback(
                        '/<link [^>]*(id=[\'"]' . $theme_reg . '-style-css[\'"])[^>]*>/',
                        function( $matches ) {
                            if ( ! empty( $matches[0] ) ) {
                                global $MK_STORAGE;
                                $MK_STORAGE['capture_links_moved'] = true;
                                return $MK_STORAGE['capture_links'] // Prepend styles before the base tag <link>
                                        . "\n" . $matches[0];
                            }
                            return '';
                        },
                        $MK_STORAGE['capture_head_html']
                    );
                }
                // If links are present, but not moved yet - append its to the end of the head output
                if ( ! $MK_STORAGE['capture_links_moved'] ) {
                    $MK_STORAGE['capture_head_html'] .= $MK_STORAGE['capture_links'];
                }
            }
        }
    }
}