<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

if (!function_exists('swm_get_post_postmetas')) {
    function swm_get_post_postmetas() {

        $swm_post_postmetas = array (
            array(
                'title' => esc_html__('Add YouTube video Embed code','orbius-core'),
                'description' => esc_html__('Default embed video width - 616', 'orbius-core'),
                'id' => 'swm_meta_video',
                'type' => 'textarea'
            ),
            array(
                'id'          => 'mk_post_item_image_orientation',
                'title'       => esc_html__('Image Orientation', 'orbius-core' ),
                'description' => esc_html__('Select image orientation for packery layout.', 'orbius-core' ),
                'type'        => 'select',
                'default'     => 'full',
                'options'     => array(
                    'full'         => esc_html__( 'Default', 'orbius-core' ),
                    'horizontal'   => esc_html__( 'Horizontal', 'orbius-core' ),
                    'vertical'     => esc_html__( 'Vertical', 'orbius-core' ),
                    'square'       => esc_html__( 'Square', 'orbius-core' ),
                    'large-square' => esc_html__( 'Large Square', 'orbius-core' )
                )
            ),
            array(
                'id'          => 'swm_meta_blog_single_layout',
                'title'       => esc_html__('Post Display Style', 'orbius-core' ),
                'description' => esc_html__('You can set different post display style for this post single page. ', 'orbius-core' ),
                'type'        => 'select',
                'default'     => 'default',
                'options'     => array(
                                    'default'              => 'Default',
                                    'standard'             => 'Standard',
                                    'standard-alt'         => 'Standard - Alternate',
                                    'fullwidth-image'      => 'Full Width Image',
                                ),
            ),
        );

        return $swm_post_postmetas;
    }
}

if (!function_exists('swm_post_create_meta_box')) {
    function swm_post_create_meta_box() {

        if ( function_exists('add_meta_box') ) {
            add_meta_box( 'post_metabox', 'Post Options', 'swm_post_new_meta_box', array('post'), 'normal', 'default' );
        }

    }
    add_action('admin_menu', 'swm_post_create_meta_box');
}


if (!function_exists('swm_post_new_meta_box')) {
    function swm_post_new_meta_box() {
        global $post;
        $swm_post_postmetas = swm_get_post_postmetas();

        echo '<input type="hidden" name="swm_meta_form" id="swm_meta_form" value="' . wp_create_nonce('swm_once') . '" />';

        $meta_section = '';
        $key = 0;
        foreach ( $swm_post_postmetas as $key => $postmeta ) {

            $meta_id           = $postmeta['id'];
            $meta_title        = $postmeta['title'];
            $meta_description  = (isset($postmeta['description'])) ? $postmeta['description'] :'';
            $meta_default      = (isset($postmeta['default'])) ? $postmeta['default'] :'';
            $meta_class        = (isset($postmeta['class'])) ? $postmeta['class'] :'';
            $meta_section_link = (isset($postmeta['section_link'])) ? $postmeta['section_link'] :'';

            $meta_type = '';
            if(isset($postmeta['type'])) {
                $meta_type = $postmeta['type'];
            }

            //Change underscore to dash
            $postmeta_class = str_replace('_', '-', $meta_id);

            echo '<div id="post-option-'.strtolower($postmeta_class).'" class="post-meta-option page key'.intval($key+1).' '.$meta_type.' '. $meta_class .'">
                    <div class="post-meta-title-wrapper">
                        <strong>'.$meta_title.'</strong>
                        <div class="post-meta-description">'.$meta_description.'</div>
                    </div>';

            echo '<div class="post-meta-title-field">';

            switch ($meta_type) {

                case 'select':

                    echo '<select name="'.$meta_id.'" id="'.$meta_id.'">';

                    if(!empty($postmeta['options'])) {

                        foreach ($postmeta['options'] as $key => $item) :

                            $page_style = get_post_meta($post->ID, $meta_id);

                            $css_string = (isset($page_style[0]) && $key == $page_style[0]) ? 'selected' : '';

                            echo '<option value="'.$key.'" '.$css_string.'>'.$item.'</option>';
                        endforeach;
                    }

                    echo '</select>';
                    echo '<p>'. $meta_section_link .'</p>';

                break;

                case 'textarea':
                    echo '<textarea name="'.$meta_id.'" id="'.$meta_id.'" class="" style="width:100%" rows="7">'.get_post_meta($post->ID, $meta_id, true).'</textarea>';
                    break;

              default:
                echo '<input type="text" name="'.$meta_id.'" id="'.$meta_id.'" class="" value="'.get_post_meta($post->ID, $meta_id, true).'" style="width:100%" />';
            }

            echo '</div>
            </div>';
        }

    }
}

if (!function_exists('swm_post_save_postdata')) {
    function swm_post_save_postdata( $post_id ) {

        $swm_post_postmetas = swm_get_post_postmetas();

        // verify this came from the our screen and with proper authorization,
        // because save_post can be triggered at other times

        if ( isset($_POST['swm_meta_form']) && !wp_verify_nonce( $_POST['swm_meta_form'], 'swm_once' )) {
            return $post_id;
        }

        // verify if this is an auto save routine. If it is our form has not been submitted, so we dont want to do anything
        if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) { return $post_id; }

        // Check permissions
        if ( isset($_POST['post_type']) && 'page' == $_POST['post_type'] ) :
            if ( !current_user_can( 'edit_page', $post_id ) ) {
                return $post_id;
            } else {
                if ( !current_user_can( 'edit_post', $post_id ) ) {
                    return $post_id;
                }
            }
        endif;

        // OK, we're authenticated
        if ( $parent_id = wp_is_post_revision($post_id) ) {
            $post_id = $parent_id;
        }

        if (isset($_POST['swm_meta_form'])) {

            foreach ( $swm_post_postmetas as $postmeta ) {

                if (isset($_POST[$postmeta['id']]) && $_POST[$postmeta['id']]) {
                    swm_post_update_custom_meta($post_id, $_POST[$postmeta['id']], $postmeta['id']);
                }

                if (isset($_POST[$postmeta['id']]) && $_POST[$postmeta['id']] == '') {
                    delete_post_meta($post_id, $postmeta['id']);
                }

                if (!isset($_POST[$postmeta['id']])) {
                    delete_post_meta($post_id, $postmeta['id']);
                }
            }
        }

    }
    add_action('save_post', 'swm_post_save_postdata');
}

if (!function_exists('swm_post_update_custom_meta')) {
    function swm_post_update_custom_meta($postID, $newvalue, $field_name) {

        if (isset($_POST['swm_meta_form'])) :
            if (!get_post_meta($postID, $field_name)) {
                add_post_meta($postID, $field_name, $newvalue);
            } else {
                update_post_meta($postID, $field_name, $newvalue);
            }
        endif;

    }
}