<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if ( !class_exists( 'Mk_Theme_Settings_Interface' ) ) {
    class Mk_Theme_Settings_Interface {

    	// Generates the tabs that are used in the options menu
    	static function mk_ts_tabs() {
    		$options = & Mk_Theme_Settings::_mk_ts_options();
    		$menu = '';
    		$menu .= '<ul>';

    		foreach ( $options as $value ) {
    			if ($value['type'] == "heading") {
    				$jquery_click_hook = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($value['id']) );
    				$menu .= '<li><a id="'.  esc_attr( $jquery_click_hook ) . '_tab" class="mk-ts-tab" title="' . esc_attr( $value['name'] ) . '" href="' . esc_attr( '#'.  $jquery_click_hook ) . '">' . $value['name'] . '</a></li> ';
    			}
    		}
    		$menu .= '</ul>';

    		return $menu;
    	}

    	// Generates the options fields that are used in the form.
    	static function mk_ts_fields() {

    		global $allowedtags;
    		$get_settings_options = get_option('mk_theme_settings');
    		$option_name = $get_settings_options['id'];
    		$settings    = get_option($option_name);
    		$options     = & Mk_Theme_Settings::_mk_ts_options();
    		$counter     = 0;
    		$menu        = '';

    		foreach ( $options as $value ) {

    			$counter++;
    			$val          = '';
    			$select_value = '';
    			$checked 	  = '';
    			$output       = '';

    			// If there is a description save it for labels
    			$desc_text = ( isset( $value['desc'] ) ) ? '<p class="mk-ts-desc">' . $value['desc'] . '</p class="of_desc">' : '';

    			// Wrap all options
    			if ( $value['type'] != "heading" ) {

    				// Keep all ids lowercase with no spaces
    				$value['id'] = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($value['id']) );

    				$id = 'section-' . $value['id'];

    				$condition = empty($value['condition'])? '': 'data-condition="' . esc_attr(json_encode($value['condition'])) . '"';

    				$class = 'section mk-ts-item';
    				if ( isset( $value['type'] ) ) {
    					$class .= ' section-' . $value['type'];
    				}
    				if ( isset( $value['class'] ) ) {
    					$class .= ' ' . $value['class'];
    				}

    				$output .= '<div id="' . esc_attr( $id ) .'" class="' . esc_attr( $class ) . '" ' . $condition . ' >'."\n";
    				if ( isset( $value['name'] ) ) {
    					$output .= '<h4 class="heading">' . esc_html( $value['name'] ) . '</h4>' . "\n";
    				}

    				$getClass = ( isset($value['class']) && '' != $value['class'] ) ? ' ' .$value['class'] : '';

    				$output .= '<div class="controls'.$getClass.'">' . "\n";
    			}

    			// If the option is already saved, override $val
    			if ( ($value['type'] != 'heading') && $value['type'] != 'checkbox' ) {

    				if ( isset( $value['std'] ) ) {
    					$val = $value['std'];   // Set default value to $val
    				}

    				if ( isset( $settings[($value['id'])]) ) {
    					$val = $settings[($value['id'])];
    					if ( !is_array($val) ) {
    						$val = stripslashes( $val ); // Striping slashes of non-array options
    					}
    				}
    			}

    			switch ( $value['type'] ) {

    				case 'text':
    					$output .= '<input data-slug="' . esc_attr($value['id']) . '" id="' . esc_attr( $value['id'] ) . '" class="of-input swm-input1" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" type="text" value="' . esc_attr( $val ) . '" />';
    					break;

    				case 'number':
    					$output .= '<input data-slug="' . esc_attr($value['id']) . '" id="' . esc_attr( $value['id'] ) . '" class="of-input swm-input1" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" type="number" min="0" max="1000000" value="' . esc_attr( $val ) . '" />';
    					break;

    				case 'textarea':
    					$rows = '8';

    					if ( isset( $value['settings']['rows'] ) ) {
    						$custom_rows = $value['settings']['rows'];
    						if ( is_numeric( $custom_rows ) ) {
    							$rows = $custom_rows;
    						}
    					}

    					$val = stripslashes( $val );
    					$output .= '<textarea data-slug="' . esc_attr($value['id']) . '" id="' . esc_attr( $value['id'] ) . '" class="of-input swm-textarea1" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" rows="' . $rows . '">' . esc_textarea( $val ) . '</textarea>';
    					break;

    				case 'select':
    					$output .= '<select class="swm_admin_dropdown" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" id="' . esc_attr( $value['id'] ) . '" data-slug="' . esc_attr($value['id']) . '">';

    					foreach ($value['options'] as $key => $option ) {
    						$selected = '';
    						if ( $val != '' ) {
    							if ( $val == $key) { $selected = ' selected="selected"';}
    						}

    						$output .= '<option'. $selected .' value="' . esc_attr( $key ) . '">' . esc_html( $option ) . '</option>';

    					}
    					$output .= '</select>';
    					if ( isset($value['subdesc']) && '' != $value['subdesc'] ) {
    						$output .= '<span class="mk-ts-subdesc">'.$value['subdesc'].'</span>';
    					}

    					break;

    				case 'radio':
    					$name = $option_name .'['. $value['id'] .']';
    					foreach ($value['options'] as $key => $option) {
    						$id = $option_name . '-' . $value['id'] .'-'. $key;
    						$output .= '<div class="left">';
    						$output .= '<input data-slug="' . esc_attr($value['id']) . '" class="of-input of-radio" type="radio" name="' . esc_attr( $name ) . '" id="' . esc_attr( $id ) . '" value="'. esc_attr( $key ) . '" '. checked( $val, $key, false) .' /><label class="swm-radio-label" for="' . esc_attr( $id ) . '">' . esc_html( $option ) . '</label>';
    						$output .= '</div>';
    					}
    					break;

    				case 'images':
    					$name = $option_name .'['. $value['id'] .']';
    					foreach ( $value['options'] as $key => $option ) {
    						$selected = '';
    						if ( $val != '' && ($val == $key) ) {
    							$selected = ' of-radio-img-selected';
    						}
    						$output .= '<input data-slug="' . esc_attr($value['id']) . '" type="radio" id="' . esc_attr( $value['id'] .'_'. $key) . '" class="of-radio-img-radio" value="' . esc_attr( $key ) . '" name="' . esc_attr( $name ) . '" '. checked( $val, $key, false ) .' />';
    						$output .= '<div class="of-radio-img-label">' . esc_html( $key ) . '</div>';
    						$output .= '<img src="' . esc_url( $option ) . '" alt="' . $option .'" class="of-radio-img-img' . $selected .'" onclick="document.getElementById(\''. esc_attr($value['id'] .'_'. $key) .'\').checked=true;" />';
    					}
    					break;

    				case 'button-regenerate':
    						$output .= '<button class="button mk-button-spinner" id="mk-admin-sync-button">Regenerate Files</button><br/>' . "\n";
    					break;

    				case 'checkbox':

    					$checkbox_val = '';
    					if ( isset( $settings[($value['id'])]) ) {
    						$checkbox_val = $settings[($value['id'])];
    						if ( !is_array($checkbox_val) ) {
    							$checkbox_val = stripslashes( $checkbox_val ); // Striping slashes of non-array options
    						}
    					}elseif( !empty($value['std']) ){
    						$checkbox_val = $value['std'];
    					}

    					$output .= '<label class="mk-switch">
    									 <input data-slug="' . esc_attr($value['id']) . '" class="checkbox of-input checkbox_on_off" type="checkbox" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" ' . checked($checkbox_val,1, false) . ' />
    									 <span class="switcher"></span>
    								</label>';
    					break;

    				case 'multicheck':
    					foreach ($value['options'] as $key => $option) {
    						$checked = '';
    						$label = $option;
    						$option = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($key));

    						$id = $option_name . '-' . $value['id'] . '-'. $option;
    						$name = $option_name . '[' . $value['id'] . '][' . $option .']';

    						if ( isset($val[$option]) ) {
    							$checked = checked($val[$option], 1, false);
    						}

    						$output .= '<input id="' . esc_attr( $id ) . '" class="checkbox of-input" type="checkbox" name="' . esc_attr( $name ) . '" ' . $checked . ' /><label for="' . esc_attr( $id ) . '">' . esc_html( $label ) . '</label>';
    					}
    					break;

    				case "color":
    					$output .= '<div id="' . esc_attr( $value['id'] . '_picker' ) . '" class="colorSelector"><div style="' . esc_attr( 'background-color:' . $val ) . '"></div></div>';
    					$output .= '<input class="of-color" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" id="' . esc_attr( $value['id'] ) . '" type="text" value="' . esc_attr( $val ) . '" />';
    					break;

    				case "upload":
    					$output .= Mk_Theme_Settings_Media_Uploader::mk_ts_uploader( $value['id'], $val, null );
    					break;

    				case 'heading':
    					if ($counter >= 2) {
    						$output .= '</div></div>'."\n"; //  end .mk-ts-group-box, end .mk-ts-group
    					}
    					$jquery_click_hook = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($value['id']) );
    					$menu .= '<li><a id="'.  esc_attr( $jquery_click_hook ) . '_tab" class="mk-ts-tab" title="' . esc_attr( $value['name'] ) . '" href="' . esc_attr( '#'.  $jquery_click_hook ) . '">' . esc_html( $value['name'] ) . '</a> </li>';

    					$output .= '<div class="mk-ts-group" id="' . esc_attr( $jquery_click_hook ) . '">';
    					$output .= '<div class="mk-ts-subheading">';
    					$output .= '<h2>' . $value['sub-title'] . '</h2>';
    					$output .= '<p>' . $value['desc'] . '</p>';
    					$output .= '</div>';

    					$output .= '<div class="mk-ts-group-box">';
    					break;

    			}

    			if ( $value['type'] != 'heading' ) {

    				$output .= '<div class="clear"></div>'."\n";
    				$output .= $desc_text . '</div>';
    				$output .= '</div>'."\n";
    			}

    			echo $output;

    		}

    		echo '</div></div>'; //  end .mk-ts-group-box, end .mk-ts-group
    	}

    }
}