<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

add_filter( 'of_sanitize_text',         'sanitize_text_field' );
add_filter( 'of_sanitize_password',     'sanitize_text_field' );
add_filter( 'of_sanitize_select',       'of_sanitize_enum', 10, 2 );
add_filter( 'of_sanitize_radio',        'of_sanitize_enum', 10, 2 );
add_filter( 'of_sanitize_images',       'of_sanitize_enum', 10, 2 );
add_filter( 'of_sanitize_textarea',     'of_sanitize_textarea' );
add_filter( 'of_sanitize_number',     	'of_sanitize_number' );
add_filter( 'of_sanitize_checkbox',     'of_sanitize_checkbox' );
add_filter( 'of_sanitize_multicheck',   'of_sanitize_multicheck', 10, 2 );
add_filter( 'of_sanitize_upload',       'of_sanitize_upload' );
add_filter( 'of_sanitize_color',        'of_sanitize_hex' );

if ( ! function_exists( 'of_sanitize_textarea' ) ) {
    function of_sanitize_textarea( $input ) {
    	global $allowedposttags;
    	$output = wp_kses( $input, $allowedposttags );
    	return $output;
    }
}

if ( ! function_exists( 'of_sanitize_number' ) ) {
    function of_sanitize_number( $input ) {
    	return intval($input);
    }
}

if ( ! function_exists( 'of_sanitize_checkbox' ) ) {
    function of_sanitize_checkbox( $input ) {
    	if ( $input ) {
    		$output = '1';
    	} else {
    		$output = false;
    	}
    	return $output;
    }
}

if ( ! function_exists( 'of_sanitize_multicheck' ) ) {
    function of_sanitize_multicheck( $input, $option ) {
    	$output = array();
    	if ( is_array( $input ) ) {
    		foreach( $option['options'] as $key => $value ) {
    			$output[$key] = false;
    		}
    		foreach( $input as $key => $value ) {
    			if ( array_key_exists( $key, $option['options'] ) && $value ) {
    				$output[$key] = '1';
    			}
    		}
    	}
    	return $output;
    }
}

if ( ! function_exists( 'of_sanitize_upload' ) ) {
    function of_sanitize_upload( $input ) {
    	$output = '';
    	$filetype = wp_check_filetype( $input );
    	if ( $filetype["ext"] ) {
    		$output = esc_url( $input );
    	}
    	return $output;
    }
}

if ( ! function_exists( 'of_sanitize_enum' ) ) {
    function of_sanitize_enum( $input, $option ) {
    	$output = '';
    	if ( array_key_exists( $input, $option['options'] ) ) {
    		$output = $input;
    	}
    	return $output;
    }
}

if ( ! function_exists( 'of_sanitize_hex' ) ) {
    function of_sanitize_hex( $hex, $default = '' ) {
    	if ( of_validate_hex( $hex ) ) {
    		return $hex;
    	}
    	return $default;
    }
}

if ( ! function_exists( 'of_validate_hex' ) ) {
    function of_validate_hex( $hex ) {
    	$hex = trim( $hex );
    	/* Strip recognized prefixes. */
    	if ( 0 === strpos( $hex, '#' ) ) {
    		$hex = substr( $hex, 1 );
    	}
    	elseif ( 0 === strpos( $hex, '%23' ) ) {
    		$hex = substr( $hex, 3 );
    	}
    	/* Regex match. */
    	if ( 0 === preg_match( '/^[0-9a-fA-F]{6}$/', $hex ) ) {
    		return false;
    	}
    	else {
    		return true;
    	}
    }
}