<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

if ( !class_exists( 'Mk_Theme_Settings_Admin' ) ) {
    class Mk_Theme_Settings_Admin {
        protected $options_screen = null;

        public function init() {
        	$options = & Mk_Theme_Settings::_mk_ts_options();
    		add_action( 'admin_menu',                 array( $this, 'add_custom_options_page' ) );
    		add_action( 'admin_enqueue_scripts',      array( $this, 'enqueue_admin_styles' ) );
    		add_action( 'admin_enqueue_scripts',      array( $this, 'enqueue_admin_scripts' ) );
    		add_action( 'admin_init',                 array( $this, 'settings_init' ) );
    		add_action( 'wp_before_admin_bar_render', array( $this, 'mk_ts_admin_bar' ) );
        }

        public function settings_init() {
    		register_setting( 'mk_theme_settings', MK_THEME . '_theme_settings',  array( $this, 'validate_options' ) );
    		add_action( 'mk_ts_after_validate', array( $this, 'save_options_notice' ) );
        }

    	public function add_custom_options_page() {
            $this->options_screen = add_submenu_page('swm-theme-panel', esc_html__( 'Advanced Settings', 'orbius-core'), esc_html__('Advanced Settings', 'orbius-core'), 'edit_theme_options', 'swm-advanced-settings', [ $this, 'options_page' ] );
    	}

    	// Loads the required stylesheets
    	public function enqueue_admin_styles( $hook ) {
    		if ( $this->options_screen != $hook ) { return; }
    		wp_enqueue_style( 'mk-theme-settings', plugin_dir_url( dirname(__FILE__) ) . 'css/theme-settings.css', array(), MK_VERSION );
    		wp_enqueue_style('color-picker', plugin_dir_url( dirname(__FILE__) ) .'css/colorpicker.css');
    	}

    	// Loads the required javascript
    	public function enqueue_admin_scripts( $hook ) {
    		if ( $this->options_screen != $hook ) { return; }
    		wp_enqueue_script('color-picker', plugin_dir_url( dirname(__FILE__) ) .'js/colorpicker.js', array('jquery'));
    		wp_enqueue_script( 'mk-theme-settings', plugin_dir_url( dirname(__FILE__) ) . 'js/theme-settings.js', array( 'jquery','wp-color-picker' ), MK_VERSION );

    		$data = array(
    			'ajaxUrl' => admin_url( 'admin-ajax.php' ),
    			'mkRegenerateCombineFilesNonce' => wp_create_nonce( 'mk-regenerate-combine-files-nonce' ),
    		);

    		wp_localize_script( 'mk-theme-settings', 'mkThemeSettings', $data );
    	}

    	public function options_page() {
    		?>

    		<div class="mk-ts-wrap">
    			<?php settings_errors( 'theme-settings' ); ?>
    			<form action="options.php" method="post">
    				<div id="swm-main-div">
    					<div id="swm-leftbar">
    						<div class="mk-ts-tabs">
    							<?php echo Mk_Theme_Settings_Interface::mk_ts_tabs(); ?>
    							<div class="mk-ts-notice-box" style="max-width:100%; display:block;">
    							</div>
    						</div>
    					</div>
    					<div id="mk-ts-content">
    						<div id="mk-ts" class="mk-ts">
    							<?php settings_fields('mk_theme_settings'); ?>
    							<?php Mk_Theme_Settings_Interface::mk_ts_fields(); /* Settings */ ?>

    							<div id="mk-ts-submit">
    								<input type="submit" class="button button-primary" name="update" value="<?php echo esc_attr__( 'Save Changes','orbius-core' ); ?>" />
    								<div class="clear"></div>
    							</div>
    						</div> <!-- / #container -->
    					</div> <!--  #swm-content -->
    					<div class="clear"></div>
    				</div> <!-- #swm-main-div -->
    			</form>
    			<?php do_action( 'mk_ts_after' ); ?>
    		</div> <!-- / .wrap -->
    		<?php
    	}

    	public function validate_options( $input ) {

    		if ( isset( $_POST['reset'] ) ) {
    			add_settings_error( 'theme-settings', 'restore_defaults', esc_html__( 'Default options restored.', 'orbius-core' ), 'updated fade' );
    			return $this->get_default_values();
    		}

    		// Update Settings
    		$clean = array();
    		$options = & Mk_Theme_Settings::_mk_ts_options();
    		foreach ( $options as $option ) {
    			if ( ! isset( $option['id'] ) )   { continue; }
    			if ( ! isset( $option['type'] ) ) { continue; }

    			$id = preg_replace( '/[^a-zA-Z0-9._\-]/', '', strtolower( $option['id'] ) );

    			if ( 'checkbox' == $option['type'] && ! isset( $input[$id] ) ) { $input[$id] = false; }  // Set checkbox to false if it wasn't sent in the $_POST

    			// Set each item in the multicheck to false if it wasn't sent in the $_POST
    			if ( 'multicheck' == $option['type'] && ! isset( $input[$id] ) ) {
    				foreach ( $option['options'] as $key => $value ) {
    					$input[$id][$key] = false;
    				}
    			}

    			// For a value to be submitted to database it must pass through a sanitization filter
    			if ( has_filter( 'of_sanitize_' . $option['type'] ) ) {
    				$clean[$id] = apply_filters( 'of_sanitize_' . $option['type'], $input[$id], $option );
    			}
    		}

    		do_action( 'mk_ts_after_validate', $clean ); // Hook to run after validation

    		return $clean;
    	}

    	// Display message when options have been saved
    	public function save_options_notice() {
    		add_settings_error( 'theme-settings', 'save_options', esc_html__( 'Settings Saved!', 'orbius-core' ), 'updated fade' );
    	}

    	public function get_default_values() {
    		$output = array();
    		$config = & Mk_Theme_Settings::_mk_ts_options();
    		foreach ( (array) $config as $option ) {
    			if ( ! isset( $option['id'] ) )   { continue; }
    			if ( ! isset( $option['std'] ) )  { continue; }
    			if ( ! isset( $option['type'] ) ) { continue; }
    			if ( has_filter( 'of_sanitize_' . $option['type'] ) ) {
    				$output[$option['id']] = apply_filters( 'of_sanitize_' . $option['type'], $option['std'], $option );
    			}
    		}
    		return $output;
    	}

    	// Add options menu item to admin bar
    	public function mk_ts_admin_bar() {
    		global $wp_admin_bar;
    		$args = array(
    			'parent' => 'appearance',
    			'id'     => 'swm-theme-panel',
    			'title'  => 'Theme Panel',
    			'href'   => admin_url( 'admin.php?page=swm-theme-panel' )
    		);
    		$wp_admin_bar->add_menu( apply_filters( 'mk_ts_admin_bar', $args ) );
    	}

    }
}