<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

if ( !class_exists( 'Mk_Theme_Settings' ) ) {
    class Mk_Theme_Settings {

    	public function init() {
    		add_action( 'admin_init', array( $this, 'set_theme_option' ) );  // Needs to run every time in case theme has been changed
    	}

        function set_theme_option() {
            $mk_ts_settings = get_option( 'mk_theme_settings', [] ); // Default to an empty array
            $mk_ts_settings['id'] = MK_THEME . '_theme_settings';

            update_option( 'mk_theme_settings', $mk_ts_settings );
            do_action( 'jet-menu/options-page/save' );
        }

    	static function &_mk_ts_options() {

    		$mkGoogleMapLink_start = '<a href="https://developers.google.com/maps/documentation/javascript/get-api-key" target="_blank">';
            $mkGoogleMapLink_end = '</a>';

            $options[] = array('id' => 'mk_sections_settings',           'name' => esc_html__('General', 'orbius-core'),                'type' => 'heading','sub-title' => 'General Settings', 'desc' => 'Set custom sidebars, portfolio posts, widget blocks.' );

            $options[] = array('id' => 'mk_map_apikey',                  'name' => esc_html__('Google Map API Key', 'orbius-core'),     'type' => 'text', 'desc' => sprintf( esc_html__( '%sClick here%s to create your own Google Maps API key', 'orbius-core' ),$mkGoogleMapLink_start, $mkGoogleMapLink_end),  'std' => '');

            $options[] = array('id' => 'swm_enable_add_new_sidebar',       'name' => esc_html__('Custom Sidebar', 'orbius-core'), 'type' => 'checkbox', 'desc' => esc_html__( 'Enable/Disable the "Add New Sidebar" section where you can create a custom widget area. ( Dashboard > Appearance > Widgets > "Add New Sidebar" on Right Side ) ','orbius-core' ), 'std' => '1', );

            $options[] = array('id' => 'swm_disable_widget_blocks',        'name' => esc_html__( 'Widget Blocks', 'orbius-core' ),'type' => 'checkbox','desc' => esc_html__( 'Enable/Disable blocks based widgets editor.','orbius-core' ),  'std'     => '0', );
            $options[] = array('id' => 'swm_enable_one_click_demo_import', 'name' => esc_html__( 'One Click Demo Import', 'orbius-core' ),                       'type' => 'checkbox','desc' => esc_html__( 'Enable/Disable one click demo import feature after demo site content installation.','orbius-core' ),  'std' => '1', );

            $options[] = array('id' => 'swm_enable_theme_widgets', 'name' => esc_html__( 'Custom Widgets', 'orbius-core' ),                       'type' => 'checkbox','desc' => esc_html__( 'Enable/Disable custom widgets e.g. "Recent Posts" , "Social Icons" ( Dashboard > Appearance > Widgets )','orbius-core' ),  'std' => '1', );

            $options[] = array('id' => 'custom_extenders',  'name' =>__('Custom Extenders','orbius-core'),                  'type' => 'checkbox', 'desc' => '
                You can manage custom extenders by enabling or disabling them as needed. <br/>Elementor Editor > Edit Container > "Advanced" Tab > Custom - (Extender Name)',       'std'  => '1', );

            $options[] = array('id' => 'swm_enable_move_css_to_head',  'name' => esc_html__('Move Styles to Head', 'orbius-core'),                        'type' => 'checkbox', 'desc' => esc_html__( 'Optimize page loading by moving CSS code and link from body/footer to the head section for improved performance.','orbius-core' ), 'std' => '1', );

            $options[] = array('id' => 'swm_enable_remove_emoji_scripts',  'name' => esc_html__('Remove Emoji Scripts', 'orbius-core'),                        'type' => 'checkbox', 'desc' => esc_html__( 'WordPress by default supports the use of emojis. However, unless your blog has a personal nature, you might not require feature at all and need to disable it.','orbius-core' ), 'std' => '1', );

            $options[] = array('id' => 'mk_permalinks_settings', 'name' => esc_html__('Permalinks', 'orbius-core'),                     'type' => 'heading', 'desc' => 'Set permalinks for "Page Title Bar" element\'s breadcrumbs section.', 'sub-title' => 'Permalinks Settings'  );

            $options[] = array('id' => 'blog_list_page',           'name' =>__('Posts List Page','orbius-core'),                  'type' => 'radio', 'desc' => esc_html__( 'Set posts "Default" page from Admin > Settings > Reading > Your homepage displays > Posts Page','orbius-core' ),  'std'  => 'default', 'options' => array('default' => 'Default', 'custom' => 'Custom', 'none' => 'None', ) );
            $options[] = array('id' => 'select_blog_page',         'name' =>__('Select Posts List Page','orbius-core'),           'type' => 'select', 'options' => mk_get_pages(), 'condition' => array( 'blog_list_page' => 'custom' ), );
            $options[] = array('id' => 'portfolio_list_page',      'name' =>__('Portfolio Posts List Page','orbius-core'),        'type' => 'radio', 'std'  => 'none', 'options' => array('none' => 'None', 'custom' => 'Custom', ) );
            $options[] = array('id' => 'select_portfolio_page',    'name' =>__('Select Portfolio Posts List Page','orbius-core'), 'type' => 'select', 'options' => mk_get_pages(), 'condition' => array( 'portfolio_list_page' => 'custom' ), );

            $options[] = array('id' => 'mk_social_icons_settings', 'name' => esc_html__('Social Icons', 'orbius-core'),                     'type' => 'heading', 'desc' => esc_html__('Enable or disable social icons for sharing posts on the post detail page','orbius-core'), 'sub-title' => 'Social Icons Settings'  );

            $options[] = array('id' => 'swm_post_share_post_share',  'name' => esc_html__( 'Post Share Section', 'orbius-core' ), 'type' => 'checkbox', 'std' => '1', );
            $options[] = array('id' => 'swm_post_share_facebook',    'name' => esc_html__( 'Facebook', 'orbius-core' ),           'type' => 'checkbox', 'std' => '1', 'condition' => array( 'swm_post_share_post_share' => '1' ));
            $options[] = array('id' => 'swm_post_share_twitter',     'name' => esc_html__( 'Twitter', 'orbius-core' ),            'type' => 'checkbox', 'std' => '1', 'condition' => array( 'swm_post_share_post_share' => '1' ));
            $options[] = array('id' => 'swm_post_share_pinterest',   'name' => esc_html__( 'Pinterest', 'orbius-core' ),          'type' => 'checkbox', 'std' => '1', 'condition' => array( 'swm_post_share_post_share' => '1' ));
            $options[] = array('id' => 'swm_post_share_linkedin',    'name' => esc_html__( 'Linkedin', 'orbius-core' ),           'type' => 'checkbox', 'std' => '1', 'condition' => array( 'swm_post_share_post_share' => '1' ));
            $options[] = array('id' => 'swm_post_share_tumblr',      'name' => esc_html__( 'Tumblr', 'orbius-core' ),             'type' => 'checkbox', 'std' => '1', 'condition' => array( 'swm_post_share_post_share' => '1' ));

    		return $options;

    	}

    }
}