<?php
/*
Plugin Name: Orbius Core
Plugin URI: http://themeforest.net/user/Softwebmedia
Description: Create content with Elements
Version: 1.0.15
Author: SoftWebMedia
Author URI: http://themeforest.net/user/Softwebmedia
Text Domain: orbius-core
Domain Path: /languages/
*/

if ( ! defined( 'ABSPATH' ) ) { exit; }

if(defined('MK_THEME')) {
    die('ERROR: It looks like you have more than one instance of theme core plugin. Please remove additional instances for this plugin to work again.');
}

if ( !class_exists( 'Orbius_Core' ) ) {
	class Orbius_Core {

	   public function __construct() {

	    	define( 'MK_FILE', __FILE__ );
            define( 'MK_ABS_PATH', dirname( __FILE__ ) );

	    	define('MK_DIR_URL',      plugin_dir_url( MK_FILE ));
	    	define('MK_ELEMENTS_CSS', plugin_dir_url( MK_FILE ) .'elements/css/');
	    	define('MK_DIR_PATH',     plugin_dir_path( MK_FILE ));
			define('MK_WIDGET_DIR',   plugin_dir_path( MK_FILE ) .'widgets/');
			define('MK_ELEMENTS_DIR', plugin_dir_path( MK_FILE ) .'elements/');
			define('MK_ADMIN_DIR',    plugin_dir_path( MK_FILE ) .'admin/');
			define('MK_OPTIONS_DIR',  plugin_dir_path( MK_FILE ) .'options/');
			define('MK_VERSION', '1.0.15');
            define('MK_THEME', 'Orbius');
			define('MK_PLUGIN_NAME', 'Orbius Core');
            define('MK_PLUGIN_FOLDER_NAME', 'orbius-core');
			define('MK_WPML_ACTIVE', class_exists( 'SitePress' ) );
			define('MK_ONE_CLICK_DEMO_IMPORT', class_exists( 'OCDI_Plugin' ));
			define('MK_WOOCOMMERCE_IS_ACTIVE', class_exists( 'WooCommerce' ));

			$this->includes();
	        add_action('plugins_loaded',                       [ $this, 'mk_plugins_loaded' ]);
	        add_action('admin_enqueue_scripts',                [ $this, 'mk_backend_scripts_styles' ]);
	        add_action('wp_enqueue_scripts',                   [ $this, 'mk_load_styles' ] );
            add_action('wp_ajax_mk-regenerate-combine-files',  [ $this, 'regenerate_merged_files' ] );

		}

        public function regenerate_merged_files() {
            global $wp_filesystem;
            require_once ABSPATH . '/wp-admin/includes/file.php';
            WP_Filesystem();

            $upload_dir = wp_upload_dir();
            $destination_theme_dir = $upload_dir['basedir'] . '/' . MK_THEME . '/';
            $destination_plugin_dir = $upload_dir['basedir'] . '/' . MK_PLUGIN_FOLDER_NAME . '/';

            $wp_filesystem->delete($destination_theme_dir, true);
            $wp_filesystem->delete($destination_plugin_dir, true);
        }

		public function mk_backend_scripts_styles() {
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script('wp-color-picker');
		}

		public function mk_load_styles() {

            wp_enqueue_script( 'mk-custom-scripts', MK_DIR_URL .'assets/js/custom-scripts.js', ['jquery'], MK_VERSION, true );

			//Localize scripts
			wp_localize_script( 'mk-custom-scripts', 'mk_get_ajax_full_url', array( 'ajaxurl' => mk_get_ajax_url() ) );

			if ( mk_get_ts_option('swm_enable_theme_widgets',true) ) {
				wp_enqueue_style( 'mk-widget-style', MK_DIR_URL . 'widgets/custom-widgets.css', NULL, MK_VERSION, 'all' );
			}

		}

		public function includes() {

			require_once( MK_OPTIONS_DIR .'options.php' );
			require_once( MK_DIR_PATH .'/functions/breadcrumbs.php' );
            require_once( MK_DIR_PATH .'/functions/helpers.php' );

            if ( mk_get_ts_option('swm_enable_move_css_to_head',true) ) {
                require_once( MK_DIR_PATH .'/functions/manage-styles.php' );
            }

            require_once (MK_DIR_PATH . '/meta-box/post-meta-boxes.php');
            require_once (MK_DIR_PATH . '/meta-box/page-meta-boxes.php');

			// portfolio post
			require_once( MK_DIR_PATH .'/post-types/portfolio.php' );
            require_once( MK_DIR_PATH .'/post-types/portfolio-metabox.php' );

			// sidebars
			if ( mk_get_ts_option('swm_enable_add_new_sidebar',true) ) {
				require_once (MK_DIR_PATH . '/sidebars/sidebars.php');
			}

			// elements
			require_once (MK_ELEMENTS_DIR . 'elements.php');

			// remove emoji scripts
			if ( mk_get_ts_option('swm_enable_remove_emoji_scripts',true) ) {
				remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
				remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
				remove_action( 'wp_print_styles', 'print_emoji_styles' );
				remove_action( 'admin_print_styles', 'print_emoji_styles' );
			}
		}


		public function mk_plugins_loaded() {
			// language
			load_plugin_textdomain( 'orbius-core', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );

			global $MK_STORAGE;
			$MK_STORAGE = array(
				'mk_stack' => array(), // Shortcodes stack
			);

			require_once MK_DIR_PATH . 'sections/sections.php';

            // Add Elementor editor support on custom post types ( sections, portfolio )
            //if exists, assign to $cpt_support var
            // Fetch the current elementor_cpt_support option, default to an empty array
            $cpt_support = get_option('elementor_cpt_support', []);
            $cpt_support_posts = array_filter(
                ['page', 'post', 'portfolio', 'cpt_sections'],
                'post_type_exists' // Validate post types
            );

            // Merge arrays and remove duplicates
            $updated_array = array_unique(array_merge($cpt_support, $cpt_support_posts));

            // Update the option only if there are changes
            if ($updated_array !== $cpt_support) {
                update_option('elementor_cpt_support', $updated_array);
            }

		}


	}
	$mk_custom_elements = new Orbius_Core();
}