<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if ( ! function_exists( 'mk_get_portfolio_postmetas' ) ) {
    function mk_get_portfolio_postmetas() {

        $mk_portfolio_postmetas = array (
            array(
                "id"          => "mk_portfolio_item_image_orientation",
                "title"       => esc_html__('Image Orientation', 'orbius-core' ),
                "description" => esc_html__('Select image orientation for "Packery" layout.', 'orbius-core' ),
                "type"        => "select",
                'default'     => 'default',
                "options"     => array(
                    "full"         => esc_html__( 'Default', 'orbius-core' ),
                    "horizontal"   => esc_html__( 'Horizontal', 'orbius-core' ),
                    "vertical"     => esc_html__( 'Vertical', 'orbius-core' ),
                    "square"       => esc_html__( 'Square', 'orbius-core' ),
                    "large-square" => esc_html__( 'Large Square', 'orbius-core' )
                )
            ),

            array(
                "id"          => "mk_portfolio_item_custom_link",
                "title"       => esc_html__('Custom Link URL on Thumbnail/Title ', 'orbius-core' ),
                "description" => esc_html__('Link URL that will be use on portfolio list page for thumbnail, title text or link icon. Leave blank for post URL.', 'orbius-core' ),
                "type"        => "text",
                'default'     => ''
            ),

            array(
                "id"      => "mk_portfolio_item_custom_link_target",
                "title"   => esc_html__('Custom Link Target', 'orbius-core' ),
                "type"    => "select",
                'default' => '_self',
                "options" => array(
                    "_self"  => esc_html__( 'Same Window', 'orbius-core' ),
                    "_blank" => esc_html__( 'New Window', 'orbius-core' ),
                )
            ),

            array(
                "id"      => "mk_portfolio_item_custom_padding",
                "title"   => esc_html__('Custom Padding', 'orbius-core' ),
                'description' => esc_html__('Set custom padding (top, right, bottom, left) when it displays in the portfolio list (e.g. 10px or 10px 20px 10px 20px or 10% 20%)', 'orbius-core' ),
                "type"    => "text",
            ),


        );

        return $mk_portfolio_postmetas;
    }
}

if ( ! function_exists( 'mk_portfolio_new_meta_box' ) ) {
    function mk_portfolio_new_meta_box() {
        global $post;
        $mk_portfolio_postmetas = mk_get_portfolio_postmetas();

        echo '<input type="hidden" name="mk_meta_form" id="mk_meta_form" value="' . wp_create_nonce('mk_once') . '" />';

        $meta_section = '';
        $key = 0;
        foreach ( $mk_portfolio_postmetas as $key => $postmeta ) {

            $meta_id           = $postmeta['id'];
            $meta_title        = $postmeta['title'];
            $meta_description  = (isset($postmeta['description'])) ? $postmeta['description'] :'';
            $meta_default      = (isset($postmeta['default'])) ? $postmeta['default'] :'';
            $meta_class        = (isset($postmeta['class'])) ? $postmeta['class'] :'';
            $meta_section_link = (isset($postmeta['section_link'])) ? $postmeta['section_link'] :'';

            $meta_type = '';
            if(isset($postmeta['type'])) {
                $meta_type = $postmeta['type'];
            }

            //Change underscore to dash
            $postmeta_class = str_replace('_', '-', $meta_id);

            echo '<div id="portfolio-option-'.strtolower($postmeta_class).'" class="post-meta-option page key'.intval($key+1).' '.$meta_type.' '. $meta_class .'">';
            echo "<div class=\"post-meta-title-wrapper\">";
            echo "<strong>".$meta_title."</strong>";

            echo "<div class='post-meta-description'>$meta_description</div>";

            echo "</div>";
            echo "<div class=\"post-meta-title-field\">";

            switch ($meta_type) {

                case "select":

                    echo "<select name='$meta_id' id='$meta_id'>";

                    if(!empty($postmeta['options'])) {

                        foreach ($postmeta['options'] as $key => $item){

                            $page_style = get_post_meta($post->ID, $meta_id);

                            if(isset($page_style[0]) && $key == $page_style[0]) {
                                $css_string = 'selected';
                            } else {
                                $css_string = '';
                            }

                            echo '<option value="'.$key.'" '.$css_string.'>'.$item.'</option>';
                        }
                    }

                    echo "</select>";
                    echo '<p>'. $meta_section_link .'</p>';

                break;

              default:
                echo "<input type='text' name='$meta_id' id='$meta_id' class='' value='".esc_attr(get_post_meta($post->ID, $meta_id, true))."' style='width:100%' />";
            }

            echo '</div>';
            echo '</div>';
        }

    }
}

if ( ! function_exists( 'mk_portfolio_save_postdata' ) ) {
    function mk_portfolio_save_postdata( $post_id ) {

        $mk_portfolio_postmetas = mk_get_portfolio_postmetas();

        // verify this came from the our screen and with proper authorization,
        // because save_post can be triggered at other times

        if ( isset($_POST['mk_meta_form']) && !wp_verify_nonce( $_POST['mk_meta_form'], 'mk_once' )) {
            return $post_id;
        }

        // verify if this is an auto save routine. If it is our form has not been submitted, so we dont want to do anything
        if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) { return $post_id; }

        // Check permissions
        if ( isset($_POST['post_type']) && 'page' == $_POST['post_type'] ) :
            if ( !current_user_can( 'edit_page', $post_id ) ) {
                return $post_id;
            } else {
                if ( !current_user_can( 'edit_post', $post_id ) ) {
                    return $post_id;
                }
            }
        endif;

        // OK, we're authenticated
        if ( $parent_id = wp_is_post_revision($post_id) ) {
            $post_id = $parent_id;
        }

        if (isset($_POST['mk_meta_form'])) {

            foreach ( $mk_portfolio_postmetas as $postmeta ) :

                if (isset($_POST[$postmeta['id']]) && $_POST[$postmeta['id']]) {
                    mk_portfolio_update_custom_meta($post_id, $_POST[$postmeta['id']], $postmeta['id']);
                }

                if (isset($_POST[$postmeta['id']]) && $_POST[$postmeta['id']] == "") {
                    delete_post_meta($post_id, $postmeta['id']);
                }

                if (!isset($_POST[$postmeta['id']])) {
                    delete_post_meta($post_id, $postmeta['id']);
                }
            endforeach;
        }

    }
    add_action('save_post', 'mk_portfolio_save_postdata');
}

if ( ! function_exists( 'mk_portfolio_update_custom_meta' ) ) {
    function mk_portfolio_update_custom_meta($postID, $newvalue, $field_name) {

        if (isset($_POST['mk_meta_form'])) {
            if (!get_post_meta($postID, $field_name)) {
                add_post_meta($postID, $field_name, $newvalue);
            } else {
                update_post_meta($postID, $field_name, $newvalue);
            }
        }

    }
}

if ( ! function_exists( 'mk_page_create_meta_box' ) ) {
    function mk_page_create_meta_box() {
        if ( function_exists('add_meta_box') ) {
            add_meta_box( 'portfolio_metabox', 'Portfolio Options', 'mk_portfolio_new_meta_box', array('portfolio'), 'normal', 'default' );
        }
    }
    add_action('admin_menu', 'mk_page_create_meta_box');
}