<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if (!function_exists('mk_posttype_portfolio')) {
	function mk_posttype_portfolio() {

		// register post types
		$labels = array(
			'name' => esc_html__( 'Portfolio', 'orbius-core'),
			'singular_name' => esc_html__( 'Portfolio', 'orbius-core'),
			'add_new' =>  esc_html__( 'Add New' , 'orbius-core'),
			'add_new_item' => esc_html__('Add New Portfolio', 'orbius-core'),
			'edit_item' => esc_html__('Edit Portfolio', 'orbius-core'),
			'new_item' => esc_html__('New Portfolio Item', 'orbius-core'),
			'view_item' => esc_html__('View Portfolio Item', 'orbius-core'),
			'search_items' => esc_html__('Search Portfolio Items', 'orbius-core'),
			'not_found' =>  esc_html__('No portfolio items found', 'orbius-core'),
			'not_found_in_trash' => esc_html__('No portfolio items found in Trash', 'orbius-core'),
			'parent_item_colon' => ''
		);

		$labels = apply_filters( 'mk_portfolio_labels', $labels );
		$mk_portfolio_slug = 'portfolio-item';
    	$mk_portfolio_slug = apply_filters( 'mk_portfolio_slug', $mk_portfolio_slug );

		$args = array(
			'labels' => $labels,
			'public' => true,
			'exclude_from_search' => false,
			'publicly_queryable' => true,
			'rewrite' => array('slug' => $mk_portfolio_slug),
			'show_ui' => true,
			'query_var' => true,
			'capability_type' => 'post',
			'hierarchical' => false,
			'menu_position' => null,
			'show_in_rest' => true,
			'supports' => array('title','editor','thumbnail','excerpt','revisions','custom-fields','comments','author','page-attributes')
		);

		register_post_type(__( 'portfolio' , 'orbius-core'),$args);

		// register taxonomy
		$mk_portfolio_category_slug	= 'portfolio_category';
    	$mk_portfolio_category_slug	= apply_filters( 'mk_portfolio_category_slug', $mk_portfolio_category_slug );

		$portfolio_categories_name = esc_html__( 'Portfolio Categories', 'orbius-core' );
		$portfolio_categories_name = apply_filters( 'mk_portfolio_categories_name', $portfolio_categories_name );

		register_taxonomy("portfolio_category","portfolio",	array(
				'labels' => array(
					'name' => $portfolio_categories_name,
					'singular_name' => $portfolio_categories_name,
					'menu_name' => $portfolio_categories_name,
					'search_items' => esc_html__( 'Search','orbius-core' ),
					'popular_items' => esc_html__( 'Popular', 'orbius-core' ),
					'all_items' => esc_html__( 'All', 'orbius-core' ),
					'parent_item' => esc_html__( 'Parent', 'orbius-core' ),
					'parent_item_colon' => esc_html__( 'Parent', 'orbius-core' ),
					'edit_item' => esc_html__( 'Edit', 'orbius-core' ),
					'update_item' => esc_html__( 'Update', 'orbius-core' ),
					'add_new_item' => esc_html__( 'Add New', 'orbius-core' ),
					'new_item_name' => esc_html__( 'New', 'orbius-core' ),
					'separate_items_with_commas' => esc_html__( 'Separate with commas', 'orbius-core' ),
					'add_or_remove_items' => esc_html__( 'Add or remove', 'orbius-core' ),
					'choose_from_most_used' => esc_html__( 'Choose from the most used', 'orbius-core' ),
				),
				"hierarchical" => true,
				"query_var" => true,
				'show_in_rest' => true,
				"rewrite" => array(
					'slug' => $mk_portfolio_category_slug,
					'hierarchical' => true,
					'with_front' => false
				)
		));

	}
    add_action( 'init', 'mk_posttype_portfolio' );
}

// register columns
if (!function_exists('mk_posttype_portfolio_edit_columns')) {
	function mk_posttype_portfolio_edit_columns($columns){
		$columns = array(
			"cb" 					=> "<input type=\"checkbox\" />",
			"title" 				=> esc_html__( 'Title' , 'orbius-core'),
			"image" 				=> esc_html__( 'Image' , 'orbius-core'),
			"portfolio_category" 	=> esc_html__( 'Category' , 'orbius-core'),
            "menu_order"            => esc_html__( 'Menu Order' , 'orbius-core'),
			'date' 					=> esc_html__( 'Date', 'orbius-core')
		);
		return $columns;
	}
    add_filter("manage_edit-portfolio_columns", "mk_posttype_portfolio_edit_columns");
}

// display columns
if (!function_exists('mk_custom_posts_display_column')) {
	function mk_custom_posts_display_column($column){
		global $post;
		switch ($column)  {

			case 'portfolio_category':
				echo wp_strip_all_tags( get_the_term_list($post->ID, 'portfolio_category', '', ', ',''));
				break;

            case 'menu_order':
                echo get_post_field( 'menu_order', $post->ID);
                break;

			case 'image':
				echo '<a href="' . get_edit_post_link() . '">' . get_the_post_thumbnail($post->ID, array(80,80)) . '</a>';
				break;

		}
	}
    add_action("manage_posts_custom_column",  "mk_custom_posts_display_column");
}