<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Return url with post edit link
if ( !function_exists( 'mk_elm_post_edit_link' ) ) {
	add_filter( 'mk_filter_post_edit_link', 'mk_elm_post_edit_link', 10, 2 );
	function mk_elm_post_edit_link( $link, $post_id ) {
		// if ( mk_exists_elementor() && \Elementor\Plugin::$instance->documents->get( $post_id )->is_built_with_elementor() ) {
		// 	$link = str_replace( 'action=edit', 'action=elementor', $link );
		// }
		return $link;
	}
}

// Init Elementor's support
//--------------------------------------------------------

// Set apropriate document type on post creation
if (!function_exists('mk_cpt_sections_elm_set_document_type')) {
	add_action( 'wp_insert_post', 'mk_cpt_sections_elm_set_document_type', 10, 2 );
	function mk_cpt_sections_elm_set_document_type( $post_id, $post ) {
		if ( $post->post_type !== 'cpt_sections' ) {
			return;
		}
		// Set apropriate document type
		$documents = Elementor\Plugin::instance()->documents;
		$doc_type  = $documents->get_document_type( 'cpt_sections' );
		update_post_meta( $post_id, $doc_type::TYPE_META_KEY, 'cpt_sections' );
		// Set default section type
		if ( get_post_meta( $post_id, 'mk_section_type', true ) == '' ) {
			update_post_meta( $post_id, 'mk_section_type', 'custom' );
		}
	}
}

// Set apropriate document template for 'Sections' post type
if (!function_exists('mk_cpt_sections_elm_set_post_type_template')) {
	add_action( 'template_include', 'mk_cpt_sections_elm_set_post_type_template', 9999 );
	function mk_cpt_sections_elm_set_post_type_template( $template ) {
		if ( is_singular( 'cpt_sections' ) ) {
			$template = MK_DIR_PATH . "sections/page-templates/tpl.single.php";
			if ( mk_elm_is_preview() ) {
				$template = MK_DIR_PATH . "sections/page-templates/tpl.editor.php";
			}
			return $template;
		}
		return $template;
	}
}

// Load required styles and scripts for the frontend
//--------------------------------------------------------
if ( !function_exists( 'mk_cpt_sections_elm_load_styles_front' ) ) {
	add_action("wp_enqueue_scripts", 'mk_cpt_sections_elm_load_styles_front', MK_ENQUEUE_SCRIPTS_PRIORITY);
	function mk_cpt_sections_elm_load_styles_front() {
		if ( mk_exists_elementor() ) {
			global $MK_STORAGE;
			$MK_STORAGE['cur_page_built_with_elementor'] = is_singular() && \Elementor\Plugin::$instance->documents->get( get_the_ID() )->is_built_with_elementor();

			$MK_STORAGE['force_load_elementor_styles'] = apply_filters('mk_filter_force_load_elementor_styles', false );
			if ( !empty($MK_STORAGE['force_load_elementor_styles']) ) {
				\Elementor\Plugin::instance()->frontend->enqueue_styles();
				\Elementor\Plugin::instance()->frontend->print_fonts_links();
			}
		}
	}
}
if ( !function_exists( 'mk_cpt_sections_elm_load_scripts_front' ) ) {
	add_action("wp_footer", 'mk_cpt_sections_elm_load_scripts_front');
	function mk_cpt_sections_elm_load_scripts_front() {
		if ( mk_exists_elementor() ) {
			global $MK_STORAGE;
			if ( !empty($MK_STORAGE['force_load_elementor_styles']) ) {
				\Elementor\Plugin::instance()->frontend->enqueue_scripts();
			}
		}
	}
}


// PRE-RENDER PROCESSING
//--------------------------------------------------------

// Add 'mk_sections_item' to the classes list of widgets
// view-source: ... <div class="mk_sections_item elementor-element elementor-element-449b50e6...
if ( !function_exists( 'mk_cpt_sections_elm_sc_wrap' ) ) {
	add_action( 'elementor/frontend/widget/before_render', 'mk_cpt_sections_elm_sc_wrap', 10, 1 );
	function mk_cpt_sections_elm_sc_wrap($widget) {
		if (mk_stack_check('show_section')						// Wrap shortcodes in the headers and footers
			&& !mk_stack_check('mk_sc_sections') 				// Don't wrap shortcodes inside content
		) {
			$widget->add_render_attribute( '_wrapper', 'class', 'mk_sections_item' );
		}
	}
}

//  Button "Edit section in the new tab"
//--------------------------------------------------------

// Add button to edit section to the Elementor preview area
if ( !function_exists( 'mk_elm_add_section_editor_link' ) ) {
	add_filter( 'mk_filter_sc_section_content_from_builder', 'mk_elm_add_section_editor_link', 10, 3 );
	function mk_elm_add_section_editor_link($post_content, $post_id, $builder) {
		$output = '';
		if ( $builder == 'elementor' && mk_elm_is_preview() && strpos($post_content, 'mk_section_editor_mask') === false ) {
			$meta = get_post_meta( $post_id, 'mk_section_type', true );
			if ( ! empty( $meta ) ) {
				if ( mk_get_value_gp( 'elementor-preview' ) != $post_id ) {
					$output = '<div class="mk_section_editor_mask">'
								. '<div class="mk_section_editor_selector">'
									. '<a href="' . esc_url( admin_url( sprintf( "post.php?post=%d&amp;action=elementor", $post_id ) ) ) . '"'
										. ' target="_blank"'
										. ' class="mk_section_editor_link"'
										. ' data-section-type="' . esc_attr( $meta ) . '"'
									. '>'
										. sprintf( esc_html__('Edit "%s" Section', 'orbius-core'), get_the_title($post_id) )
									. '</a>';
					$output .= '</div>'
							. '</div>';
				}
			}
		}
		return $post_content . $output;
	}
}

// Generate content to show section
//------------------------------------------------------------------------
if ( !function_exists( 'mk_cpt_sections_elm_section_content' ) ) {
	add_filter( 'mk_filter_sc_section_content', 'mk_cpt_sections_elm_section_content', 11, 3 );
	function mk_cpt_sections_elm_section_content($content, $post_id = 0, $force_styles = false) {
		static $styles_included = array();
		// Check if this post built with Elementor
		if ( mk_exists_elementor() ) {
			if ($post_id == 0) {
				$post_id = mk_get_the_ID();
			}
			$cur_page_built_with_elementor = \Elementor\Plugin::$instance->documents->get( $post_id )->is_built_with_elementor();

			if ( $cur_page_built_with_elementor ) {
				// If caller is a show_section
				if ( mk_stack_check('show_section') ) {
					global $MK_STORAGE;
					mk_stack_push('show_section_elementor');
					$post_content = \Elementor\Plugin::instance()->frontend->get_builder_content( $post_id, $force_styles || ( empty($MK_STORAGE['cur_page_built_with_elementor']) && empty($styles_included[$post_id]) ) );
					mk_stack_pop();
					$styles_included[$post_id] = true;
					if ( ! empty($post_content) ) {
						$content = apply_filters( 'mk_filter_sc_section_content_from_builder', $post_content, $post_id, 'elementor' );
					}

				// Else - caller is content filter - just change previously generated content
				} else {
					$content .= '';
				}
			}
		}
		return $content;
	}
}