<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Store section id to the menu item's post_meta db_id = wp_postmeta > metakey > _menu_item_section_megamenu (post id)
if (!function_exists('mk_cpt_sections_megamenu_save_sections_to_menu_items')) {

    add_action( 'wp_update_nav_menu', 'mk_cpt_sections_megamenu_save_sections_to_menu_items', 10, 1 );

    function mk_cpt_sections_megamenu_save_sections_to_menu_items($nav_menu_selected_id) {
        $menu_items = wp_get_nav_menu_items( $nav_menu_selected_id, array(
                                                                        'orderby' => 'ID',
                                                                        'output' => ARRAY_A,
                                                                        'output_key' => 'ID',
                                                                        'post_status' => 'draft,publish'
                                                                        ) );
        foreach ($menu_items as $item) {
            if (isset($_POST['menu-item-section-megamenu'][$item->db_id])) {
                update_post_meta($item->db_id, '_menu_item_section_megamenu', $_POST['menu-item-section-megamenu'][$item->db_id]);
            }
            if (isset($_POST['menu-item-section-megamenu-custom-width'][$item->db_id])) {
                update_post_meta($item->db_id, '_menu_item_section_megamenu_custom_width', $_POST['menu-item-section-megamenu-custom-width'][$item->db_id]);
            }
            if (isset($_POST['menu-item-section-megamenu-align'][$item->db_id])) {
                update_post_meta($item->db_id, '_menu_item_section_megamenu_align', $_POST['menu-item-section-megamenu-align'][$item->db_id]);
            }
            if (isset($_POST['menu-item-section-megamenu-rel-position'][$item->db_id])) {
                update_post_meta($item->db_id, '_menu_item_section_megamenu_rel_position', $_POST['menu-item-section-megamenu-rel-position'][$item->db_id]);
            }
            if (isset($_POST['menu-item-section-megamenu-parent-class'][$item->db_id])) {
                update_post_meta($item->db_id, '_menu_item_section_megamenu_parent_class', $_POST['menu-item-section-megamenu-parent-class'][$item->db_id]);
            }
            if (isset($_POST['menu-item-section-megamenu-width'][$item->db_id])) {
                update_post_meta($item->db_id, '_menu_item_section_megamenu_width', $_POST['menu-item-section-megamenu-width'][$item->db_id]);
            }
        }
    }
}

// Add section id to the menu item
if (!function_exists('mk_cpt_sections_megamenu_load_sections_to_menu_items')) {

    add_filter( 'wp_setup_nav_menu_item', 'mk_cpt_sections_megamenu_load_sections_to_menu_items' );

    function mk_cpt_sections_megamenu_load_sections_to_menu_items($menu_item) {
        if ( isset( $menu_item->post_type ) && 'nav_menu_item' == $menu_item->post_type ) {

            if ( !isset($menu_item->section_megamenu) ) {
                $menu_item->section_megamenu = get_post_meta( $menu_item->ID, '_menu_item_section_megamenu', true);
            }
            if ( !isset($menu_item->section_megamenu_custom_width) ) {
                $menu_item->section_megamenu_custom_width = get_post_meta( $menu_item->ID, '_menu_item_section_megamenu_custom_width', true);
            }
            if ( !isset($menu_item->section_megamenu_align) ) {
                $menu_item->section_megamenu_align = get_post_meta( $menu_item->ID, '_menu_item_section_megamenu_align', true);
            }
            if ( !isset($menu_item->section_megamenu_rel_position) ) {
                $menu_item->section_megamenu_rel_position = get_post_meta( $menu_item->ID, '_menu_item_section_megamenu_rel_position', true);
            }
            if ( !isset($menu_item->section_megamenu_width) ) {
                $menu_item->section_megamenu_width = get_post_meta( $menu_item->ID, '_menu_item_section_megamenu_width', true);
            }

        }
        return $menu_item;
    }
}

// Add class 'menu-item-has-children' to the items with sections megamenu
if (!function_exists('mk_cpt_sections_megamenu_add_class_has_children_to_menu_items')) {

    add_filter( 'wp_nav_menu_objects', 'mk_cpt_sections_megamenu_add_class_has_children_to_menu_items', 10, 2 );

    function mk_cpt_sections_megamenu_add_class_has_children_to_menu_items($menu_items, $args=array()) {
        if (is_array($menu_items)) {
            foreach($menu_items as $k=>$item ) {
                if (!empty($item->section_megamenu)) {
                    $menu_items[$k]->classes[] = 'menu-item-has-children';
                    $menu_items[$k]->classes[] = 'swm-megamenu-item';
                }
            }
        }
        return $menu_items;
    }
}

// Display Megamenu content
// Add section content to the item's output (if 'sections megamenu' is set for this item)
if (!function_exists('mk_cpt_sections_megamenu_show_section')) {

    add_filter( 'walker_nav_menu_start_el', 'mk_cpt_sections_megamenu_show_section', 10, 4 );

    function mk_cpt_sections_megamenu_show_section( $output, $item, $depth, $args ) {

        $megamenu_id =  ( !empty($item->section_megamenu ) ) ? swm_mk_get_custom_section_id( 'megamenu', $item->section_megamenu ) : '';

        if ( (int) $megamenu_id > 0 && $depth == 0 ) {

            ob_start();
            mk_stack_push( 'mk_sc_sections_megamenu' ); // Start megamenu creation
            mk_stack_push( 'mk_sc_sections' );         // Simulate usage shortcode to prevent wrap widgets to the class 'sc_sections_item'

            mk_cpt_sections_show_section( $megamenu_id );  // Make section with megamenu

            mk_stack_pop(); // End simulation
            mk_stack_pop(); // End megamenu creation

            // Get section and output it (if not empty)
            $megamenu = ob_get_contents();
            ob_end_clean();

            if (!empty($megamenu)) {
                $output .= '<ul class="mk-sections-megamenu no-visibility mm-'. $item->section_megamenu_rel_position .' mm-'. $item->section_megamenu_align .'" data-width="'. $item->section_megamenu_width .'" data-custom-width="'.intval($item->section_megamenu_custom_width).'"><li class="sc_sections_megamenu_wrap">' . trim( $megamenu ) . "</li></ul>";
            }
        }

        return $output;
    }
}

// Substitute standard WordPress menu edit walker
if (!function_exists('mk_cpt_sections_megamenu_set_nav_menu_edit_walker_class')) {
    add_filter( 'wp_edit_nav_menu_walker', 'mk_cpt_sections_megamenu_set_nav_menu_edit_walker_class', 10, 2 );
    function mk_cpt_sections_megamenu_set_nav_menu_edit_walker_class($class='', $menu_id=0) {
        return 'MK_NAV_MENU_EDIT_WALKER';
    }
}

// Standard WordPress Walker_Nav_Menu_Edit class
require_once( ABSPATH . 'wp-admin/includes/class-walker-nav-menu-edit.php' );

if (!class_exists('MK_NAV_MENU_EDIT_WALKER')) {
    class MK_NAV_MENU_EDIT_WALKER extends Walker_Nav_Menu_Edit {

        var $sections = false;

        public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
            if ($this->sections === false) {
                $this->sections = swm_mk_list_sections_styles('megamenu', 'title', array('0' => esc_html__( '- Not Selected -', 'orbius-core' ))); // get array list of all sections posts with 'id' and 'title'
            }
            // Add sections selector if at least one section is present
            // (item 0 is '- Not Selected -')
            if (is_array($this->sections) && count($this->sections) > 1 && $depth == 0) {
                $tmp = $output;
                parent::start_el($output, $item, $depth, $args, $id);
                $item_id = $item->ID;
                $html = '<div class="wpmenu-megamenu-fields">
                            <div class="mkMegamenuFieldTitle iPlus">Mega Menu</div>
                                <div class="mkMegamenuFields" style="display:none;">

                                    <p class="field-section-megamenu">
                        <label for="edit-menu-item-section-megamenu-'.esc_attr($item_id).'">'
                            . '<span class="mk-megamanu-title field-title-section-megamenu">' . esc_html__('Select Mega Menu', 'orbius-core') . '</span>'
                            .'<select id="edit-menu-item-section-megamenu-'.esc_attr($item_id).'" class="edit-menu-item-section-megamenu mk_section_selector" name="menu-item-section-megamenu['.esc_attr($item_id).']">';
                foreach ($this->sections as $id=>$title) {
                    $html .= '<option value="'.esc_attr($id).'"'.(!empty($item->section_megamenu) && $item->section_megamenu == $id ? ' selected="selected"' : '') .'>'
                                . esc_html($title)
                            . '</option>';
                }

                $mk_edit_megamenu_section_url = admin_url( sprintf( "post.php?post=%d&amp;action=edit", $item->section_megamenu) );

                $html .= '</select><br/><small>'
                        . sprintf('<a href="%1$s" class="mk_post_editor mkCustomSectionsLink" target="_blank">%2$s</a>',$mk_edit_megamenu_section_url, esc_html__('Open selected section in a new tab to edit', 'orbius-core')
                                    ). '</small >
                        </label>
                    </p>';

                $html .= '<p class="field-section-megamenu-width">
                            <label for="edit-menu-item-section-megamenu-width-'.esc_attr($item_id).'">
                            <span class="mk-megamanu-title field-title-section-megamenu-width">' . esc_html__('Width', 'orbius-core') . '</span>
                            <select id="edit-menu-item-section-megamenu-width-'.esc_attr($item_id).'" class="edit-menu-item-section-megamenu-width" name="menu-item-section-megamenu-width['.esc_attr($item_id).']">
                                <option value="default_width"' . ($item->section_megamenu_width == 'default_width' ? ' selected="selected"' : '') . '>Default</option>
                                <option value="background_width"' . ($item->section_megamenu_width == 'background_width' ? ' selected="selected"' : '') . '>Background Full Width</option>
                                <option value="fullwidth"' . ($item->section_megamenu_width == 'fullwidth' ? ' selected="selected"' : '') . '>Content Full Width</option>
                                <option value="custom_width"' . ($item->section_megamenu_width == 'custom_width' ? ' selected="selected"' : '') . '>Custom Width</option>
                            </select>
                            </label>
                            </p>';

                $html .= '<div class="mk-customwidth-fields">

                        <p class="field-section-megamenu-custom-width">
                            <label for="edit-menu-item-section-megamenu-custom-width-'.esc_attr($item_id).'">
                            <span class="mk-megamanu-title field-title-section-megamenu-custom-width">' . esc_html__('Custom Width', 'orbius-core') . '</span>

                            <input id="edit-menu-item-section-megamenu-custom-width-' . esc_attr($item_id) . '" class= "edit-menu-item-section-megamenu-custom-width" type="text" name="menu-item-section-megamenu-custom-width[' . esc_attr($item_id) . ']" value="' . esc_html( $item->section_megamenu_custom_width ) . '"/><br/><small>'.esc_html__('Enter custom width in pixels e.g. 1100px','orbius-core').'</small>
                            </label>
                        </p>

                        <p class="field-section-megamenu-align">
                            <label for="edit-menu-item-section-megamenu-align-'.esc_attr($item_id).'">
                            <span class="mk-megamanu-title field-title-section-megamenu-align">' . esc_html__('Menu Align', 'orbius-core') . '</span>
                            <select id="edit-menu-item-section-megamenu-align-'.esc_attr($item_id).'" class="edit-menu-item-section-megamenu-align" name="menu-item-section-megamenu-align['.esc_attr($item_id).']">
                                <option value="left"'   . ($item->section_megamenu_align == 'left'   ? ' selected="selected"' : '') . '>Left</option>
                                <option value="center"' . ($item->section_megamenu_align == 'center' ? ' selected="selected"' : '') . '>Center</option>
                                <option value="right"'  . ($item->section_megamenu_align == 'right'  ? ' selected="selected"' : '') . '>Right</option>
                            </select>
                            <small>'.esc_html__('Set menu position with main menu item.','orbius-core').'</small>
                            </label>
                            </p>

                        <p class="field-section-megamenu-rel-position">
                            <label for="edit-menu-item-section-megamenu-rel-position-'.esc_attr($item_id).'">
                            <span class="mk-megamanu-title field-title-section-megamenu-rel-position">' . esc_html__('Relative Position', 'orbius-core') . '</span>
                            <select id="edit-menu-item-section-megamenu-rel-position-'.esc_attr($item_id).'" class="edit-menu-item-section-megamenu-rel-position" name="menu-item-section-megamenu-rel-position['.esc_attr($item_id).']">
                                <option value="parent_menu_item"'   . ($item->section_megamenu_rel_position == 'parent_menu'   ? ' selected="selected"' : '') . '>Parent Menu Item</option>
                                <option value="site_content"' . ($item->section_megamenu_rel_position == 'site_content' ? ' selected="selected"' : '') . '>Site Content</option>
                            </select>
                            <small>'.esc_html__('Set menu position to parent menu item or content section for medium size menu.','orbius-core').'</small>
                            </label>
                            </p>
                        </div>
                    </div>
                </div>';

                $output = $tmp . str_replace('<fieldset class="field-move', $html . '<fieldset class="field-move', substr($output, strlen($tmp)));
            } else {
                parent::start_el($output, $item, $depth, $args, $id);
            }
        }
    }
}

/*

_background_width  ---  is usded to width menu for 100% full width but content will be in boxed shape  // window_boxed
_fullwidth --  is usded to width menu for 100% full width          // window
_no_width ---- nothing but used for if it doesn't have this class

*/