<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if (!function_exists('mk_post_types_sections')) {

	add_action( 'init', 'mk_post_types_sections' );
	function mk_post_types_sections() {

		// register taxonomy

		register_taxonomy(
			'cpt_sections_group',
			'cpt_sections',
			apply_filters('mk_filter_register_taxonomy',
				array(
					'post_type' 		=> 'cpt_sections',
					'hierarchical'      => true,
					'labels'            => array(
						'name'              => esc_html__( 'Sections Group', 'orbius-core' ),
						'singular_name'     => esc_html__( 'Group', 'orbius-core' ),
						'menu_name'         => esc_html__( 'Section Group', 'orbius-core' ),
						'search_items'      => esc_html__( 'Search Groups', 'orbius-core' ),
						'all_items'         => esc_html__( 'All Groups', 'orbius-core' ),
						'parent_item'       => esc_html__( 'Parent Group', 'orbius-core' ),
						'parent_item_colon' => esc_html__( 'Parent Group:', 'orbius-core' ),
						'edit_item'         => esc_html__( 'Edit Group', 'orbius-core' ),
						'update_item'       => esc_html__( 'Update Group', 'orbius-core' ),
						'add_new_item'      => esc_html__( 'Add New Group', 'orbius-core' ),
						'new_item_name'     => esc_html__( 'New Group Name', 'orbius-core' ),

					),
					'show_ui'           => true,
					'show_admin_column' => true,
					'query_var'         => true,
					'rewrite'           => array(
												'slug'         => 'sections_taxonomy_slug',
												'with_front'   => false,
												'hierarchical' => true
											)
				),
				'cpt_sections',
				'cpt_sections_group'
			)
		);

		// register post types

		register_post_type(
			'cpt_sections',
			apply_filters('mk_filter_register_post_type',
				array(
					'label'               => esc_html__( 'Section', 'orbius-core' ),
					'description'         => esc_html__( 'Section Description', 'orbius-core' ),
					'labels'              => array(
						'name'                => esc_html__( 'Sections', 'orbius-core' ),
						'singular_name'       => esc_html__( 'Section', 'orbius-core' ),
						'menu_name'           => esc_html__( 'Sections', 'orbius-core' ),
						'parent_item_colon'   => esc_html__( 'Parent Item:', 'orbius-core' ),
						'all_items'           => esc_html__( 'All Sections', 'orbius-core' ),
						'view_item'           => esc_html__( 'View Section', 'orbius-core' ),
						'add_new_item'        => esc_html__( 'Add New Section', 'orbius-core' ),
						'add_new'             => esc_html__( 'Add New', 'orbius-core' ),
						'edit_item'           => esc_html__( 'Edit Section', 'orbius-core' ),
						'update_item'         => esc_html__( 'Update Section', 'orbius-core' ),
						'search_items'        => esc_html__( 'Search Section', 'orbius-core' ),
						'not_found'           => esc_html__( 'Not found', 'orbius-core' ),
						'not_found_in_trash'  => esc_html__( 'Not found in Trash', 'orbius-core' ),
					),
					'taxonomies'          => array('cpt_sections_group'),
					'supports'            => array( 'title', 'author'),
					'public'              => true,
					'hierarchical'        => false,
					'has_archive'         => false,
					'can_export'          => true,
					'show_in_admin_bar'   => true,
					'show_ui'             => true,
					'show_in_menu'        => true,
					'exclude_from_search' => true,
					'menu_icon'			  => 'dashicons-align-center',
					'capability_type'     => 'post',
					'rewrite'             => array(
												'slug'         => 'sections',
												'with_front'   => false,
												'hierarchical' => false
												)
				),
				'cpt_sections'
			)
		);

	}
}

// Create additional column in the posts list
if (!function_exists('mk_cpt_sections_add_custom_column')) {
	add_filter('manage_edit-cpt_sections_columns',	'mk_cpt_sections_add_custom_column', 9);
	function mk_cpt_sections_add_custom_column( $columns ){
		if (is_array($columns) && count($columns)>0) {
			$new_columns = array();
			$tmp = '';
			foreach($columns as $k=>$v) {
				if ($k == 'author') {
					$tmp = $v;
					continue;
				} else if ($k == 'date') {
					$new_columns['author'] = $tmp;
				}
				$new_columns[$k] = $v;
				if ($k == 'title') {
					$new_columns['cpt_sections_type'] = esc_html__('Type', 'orbius-core');
				}
			}
			$columns = $new_columns;
		}
		return $columns;
	}
}

// Fill type column in the posts list
if (!function_exists('mk_cpt_sections_fill_custom_column')) {
	add_action('manage_cpt_sections_posts_custom_column', 'mk_cpt_sections_fill_custom_column', 9, 2);
	function mk_cpt_sections_fill_custom_column($column_name='', $post_id=0) {
		if ( $column_name == 'cpt_sections_type' ) {
			$type = get_post_meta( $post_id, 'mk_section_type', true );
			if (!empty($type)) {
				?><div class="mk_meta_row">
					<span class="mk_meta_label"><?php echo ucwords($type); ?></span>
				</div><?php
			}
		}
	}
}
