<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if (!function_exists('mk_get_sections_postmetas')) {
    function mk_get_sections_postmetas() {

        $mk_sections_postmetas = array (
            array(
                "id"          => "mk_section_type",
                "title"       => esc_html__('Section Type', 'orbius-core' ),
                "description" => esc_html__('Type of this section', 'orbius-core'),
                "type"        => "select",
                "default"     => 'custom',
                "options"     => array(
                    'header'    => esc_html__('Header', 'orbius-core'),
                    'titlebar'  => esc_html__('Title Bar', 'orbius-core'),
                    'footer'    => esc_html__('Footer', 'orbius-core'),
                    'megamenu'  => esc_html__('Megamenu', 'orbius-core'),
                    'offcanvas' => esc_html__('Off-Canvas', 'orbius-core'),
                    'popup'     => esc_html__('Popup', 'orbius-core'),
                    'custom'    => esc_html__('Custom', 'orbius-core')
                )
            ),
        );

        return $mk_sections_postmetas;
    }
}

if (!function_exists('mk_sections_meta_box')) {
    function mk_sections_meta_box() {
        global $post;
        $mk_sections_postmetas = mk_get_sections_postmetas();

        echo '<input type="hidden" name="mk_meta_form" id="mk_meta_form" value="' . wp_create_nonce('mk_once') . '" />';

        $meta_section = '';
        $key = 0;
        foreach ( $mk_sections_postmetas as $key => $postmeta ) {

            $meta_id           = $postmeta['id'];
            $meta_title        = $postmeta['title'];
            $meta_description  = (isset($postmeta['description'])) ? $postmeta['description'] :'';
            $meta_default      = (isset($postmeta['default'])) ? $postmeta['default'] :'';
            $meta_class        = (isset($postmeta['class'])) ? $postmeta['class'] :'';
            $meta_section_link = (isset($postmeta['section_link'])) ? $postmeta['section_link'] :'';

            $meta_type = '';
            if(isset($postmeta['type'])) {
                $meta_type = $postmeta['type'];
            }

            //Change underscore to dash
            $postmeta_class = str_replace('_', '-', $meta_id);

            echo '<div id="sections-option-'.strtolower($postmeta_class).'" class="post-meta-option page key'.intval($key+1).' '.$meta_type.' '. $meta_class .'">';
            echo "<div class=\"post-meta-title-wrapper\">";
            echo "<strong>".$meta_title."</strong>";

            echo "<div class='post-meta-description'>$meta_description</div>";

            echo "</div>";
            echo "<div class=\"post-meta-title-field\">";

            switch ($meta_type) {

                case "select":

                    echo "<select name='$meta_id' id='$meta_id'>";

                    if(!empty($postmeta['options'])) {

                        foreach ($postmeta['options'] as $key => $item){

                            $page_style = get_post_meta($post->ID, $meta_id);

                            if(isset($page_style[0]) && $key == $page_style[0]) {
                                $css_string = 'selected';
                            } else {
                                $css_string = '';
                            }

                            echo '<option value="'.$key.'" '.$css_string.'>'.$item.'</option>';
                        }
                    }

                    echo "</select>";
                    echo '<p>'. $meta_section_link .'</p>';

                break;

              default:
                echo "<input type='text' name='$meta_id' id='$meta_id' class='' value='".esc_url(get_post_meta($post->ID, $meta_id, true))."' style='width:100%' />";
            }

            echo '</div>';
            echo '</div>';
        }

    }
}

if (!function_exists('mk_sections_save_postdata')) {
    function mk_sections_save_postdata( $post_id ) {

        $mk_sections_postmetas = mk_get_sections_postmetas();

        // verify this came from the our screen and with proper authorization,
        // because save_post can be triggered at other times

        if ( isset($_POST['mk_meta_form']) && !wp_verify_nonce( $_POST['mk_meta_form'], 'mk_once' )) {
            return $post_id;
        }

        // verify if this is an auto save routine. If it is our form has not been submitted, so we dont want to do anything
        if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) return $post_id;

        // Check permissions
        if ( isset($_POST['post_type']) && 'page' == $_POST['post_type'] ) {
            if ( !current_user_can( 'edit_page', $post_id ) )
                return $post_id;
            } else {
            if ( !current_user_can( 'edit_post', $post_id ) ) {
                return $post_id;
            }
        }

        // OK, we're authenticated
        if ( $parent_id = wp_is_post_revision($post_id) ) {
            $post_id = $parent_id;
        }

        if (isset($_POST['mk_meta_form'])) {

            foreach ( $mk_sections_postmetas as $postmeta ) {

                if (isset($_POST[$postmeta['id']]) && $_POST[$postmeta['id']]) {
                    mk_sections_update_custom_meta($post_id, $_POST[$postmeta['id']], $postmeta['id']);
                }

                if (isset($_POST[$postmeta['id']]) && $_POST[$postmeta['id']] == "") {
                    delete_post_meta($post_id, $postmeta['id']);
                }

                if (!isset($_POST[$postmeta['id']])) {
                    delete_post_meta($post_id, $postmeta['id']);
                }
            }
        }

    }
    add_action('save_post', 'mk_sections_save_postdata');
}

if (!function_exists('mk_sections_update_custom_meta')) {
    function mk_sections_update_custom_meta($postID, $newvalue, $field_name) {

        if (isset($_POST['mk_meta_form'])) {
            if (!get_post_meta($postID, $field_name)) {
                add_post_meta($postID, $field_name, $newvalue);
            } else {
                update_post_meta($postID, $field_name, $newvalue);
            }
        }

    }
}

if (!function_exists('mk_page_create_sections_meta_box')) {
    function mk_page_create_sections_meta_box() {
        if ( function_exists('add_meta_box') ) {
            add_meta_box( 'sections_item_options', 'Item Options', 'mk_sections_meta_box', array('cpt_sections'), 'normal', 'high' );
        }
    }
    add_action('admin_menu', 'mk_page_create_sections_meta_box');
}