<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

if (!defined( 'MK_ENQUEUE_SCRIPTS_PRIORITY' ) ) { define( 'MK_ENQUEUE_SCRIPTS_PRIORITY', 20 ); }

require MK_DIR_PATH . 'sections/helpers.php';
require MK_DIR_PATH . 'sections/post-type.php';
require MK_DIR_PATH . 'sections/sections-metabox.php';
include_once MK_DIR_PATH . 'sections/megamenu.php';
include_once MK_DIR_PATH . 'sections/elementor.php';

// Load required styles and scripts for the frontend
if ( ! function_exists( 'mk_cpt_sections_load_scripts_front' ) ) {
	add_action("wp_enqueue_scripts", 'mk_cpt_sections_load_scripts_front', MK_ENQUEUE_SCRIPTS_PRIORITY);
	function mk_cpt_sections_load_scripts_front() {
		wp_enqueue_style( 'mk-cpt_sections', MK_DIR_URL . 'sections/css/sections-post-type.css', array(), null );
	}
}

// Load required styles and scripts in the admin mode
if ( !function_exists( 'mk_load_scripts_admin' ) ) {
	add_action("admin_enqueue_scripts", 'mk_load_scripts_admin');
	function mk_load_scripts_admin($all=false) {
		wp_enqueue_script( 'mk-admin',  MK_DIR_URL .'sections/js/sections-admin.js', array('jquery'), null, true );
	}
}

//--------------------------------------------------------

// Prepare post content in the blog posts instead 'the_content' filter
// to avoid conflicts with Gutenberg
if ( ! function_exists( 'mk_filter_post_content' ) ) {
	function mk_filter_post_content( $content ) {
		$content = apply_filters( 'mk_filter_sc_section_content', $content );
		global $wp_embed;
		if ( is_object( $wp_embed ) ) {
			$content = $wp_embed->autoembed( $content );
		}
		return do_shortcode( $content );
	}
}

// Show section with specified ID
if ( !function_exists( 'mk_cpt_sections_show_section' ) ) {
	add_action( 'mk_action_show_section', 'mk_cpt_sections_show_section', 10, 2 );
	function mk_cpt_sections_show_section($section_id, $post_id=0, $echo=true) {
		$content = '';
		if ( (int) $section_id > 0 ) {
			$content = '';
			// Create section
			if ( empty( $content ) ) {
				do_action( 'mk_action_before_show_section' );
				$section = get_post($section_id);
				if ( ! empty($section) ) {

					mk_stack_push('show_section');
					// Allow any Page Builder substitute content with its sections
					$content = apply_filters('mk_filter_sc_section_content', $section->post_content, $section->ID/*, $use_cache*/ );
					// If content unchanged - filter it with 'the_content'
					if ($content == $section->post_content) {
						$content = mk_filter_post_content( $content );
					}

					// Restore postdata
					mk_stack_pop();
				}

			}
			if ( $echo && ! empty( $content ) ) {
				if (trim($content) != '') {
					printf("%s",$content);
				}
			}
		}
		return $content;
	}
}

// Redirect action 'show_section' to the plugin
if ( ! function_exists( 'swm_mk_action_show_section' ) ) {
	function swm_mk_action_show_section( $section_id = '', $post_id = 0 ) {
		do_action( 'mk_action_show_section', $section_id, $post_id );
	}
    add_action( 'swm_action_show_section', 'swm_mk_action_show_section', 10, 2 );
}