<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if ( !class_exists( 'mkCustomSidebars' ) ) {
    class mkCustomSidebars {

    	protected $custom_sidebars	= array();
    	protected $orig			= array();

    	public function __construct( $custom_sidebars = array() ) {
    		add_action( 'widgets_init', array( $this, 'register_sidebars' ), 1000 );
    		add_action( 'admin_print_scripts-widgets.php', array( $this, 'add_new_sidebar_box' ) );
    		add_action( 'load-widgets.php', array( $this, 'add_new_sidebar' ), 100 );
    		add_action( 'load-widgets.php', array( $this, 'load_scripts' ), 100 );
    		add_action( 'wp_ajax_mk_delete_custom_sidebar', array( $this, 'mk_delete_custom_sidebar' ) );
    	}

    	/* Add the widget box inside a script */
    	public function add_new_sidebar_box() {
    		$nonce = wp_create_nonce ( 'delete-mk-custom_sidebar-nonce' ); ?>
    		  <script type="text/html" id="mk-add-sidebar-template">
    			<div id="mk-add-sidebar" class="widgets-holder-wrap">
    			 <div class="">
    			  <input type="hidden" name="mk-nonce" value="<?php echo esc_attr( $nonce ); ?>" />
    			  <div class="sidebar-name">
    			   <h3><?php esc_html_e( 'Custom Sidebar', 'orbius-core' ); ?> <span class="spinner"></span></h3>
    			  </div>
    			  <div class="sidebar-description">
    				<form id="add-new-sidebar-form" action="" method="post">
    				  <div class="widget-content">
    					<input id="mk-add-sidebar-input" name="mk-add-sidebar-input" type="text" class="regular-text" title="<?php esc_attr_e( 'Enter New Widget Area Name', 'orbius-core' ); ?>" placeholder="<?php esc_attr_e( 'Sidebar Name', 'orbius-core' ); ?>" />
    				  </div>
    				  <div class="widget-control-actions">
    					  <input class="add-new-sidebar-button button-primary" type="submit" value="<?php esc_attr_e( 'Add', 'orbius-core' ); ?>" />
    				  </div>
    				  <div class="clear"></div>
    				</form>
    			  </div>
    			 </div>
    			</div>
    		  </script>
    		<?php
    	}

    	/* Create new Widget Area */
    	public function add_new_sidebar() {
    		if ( ! empty( $_POST['mk-add-sidebar-input'] ) ) {
    			$this->custom_sidebars = $this->get_custom_sidebars();
    			array_push( $this->custom_sidebars, $this->check_custom_sidebar_name( $_POST['mk-add-sidebar-input'] ) );
    			$this->save_custom_sidebars();
    			wp_redirect( admin_url( 'widgets.php' ) );
    			die();
    		}
    	}

    	/* Before we create a new custom sidebar, verify it doesn't already exist. If it does, append a number to the name. */
    	public function check_custom_sidebar_name( $name ) {
    		if ( empty( $GLOBALS['mk_registered_custom_sidebars'] ) ) {
    			return $name;
    		}

    		$taken = array();
    		foreach ( $GLOBALS['mk_registered_custom_sidebars'] as $custom_sidebar ) {
    			$taken[] = $custom_sidebar['name'];
    		}

    		$taken = array_merge( $taken, $this->custom_sidebars );

    		if ( in_array( $name, $taken ) ) {
    			$counter  = substr( $name, -1 );
    			$new_name = "";

    			if ( ! is_numeric( $counter ) ) {
    				$new_name = $name . " 1";
    			} else {
    				$new_name = substr( $name, 0, -1 ) . ((int) $counter + 1);
    			}

    			$name = $this->check_custom_sidebar_name( $new_name );
    		}
    		echo esc_html( $name );
    		exit();
    	}

    	public function save_custom_sidebars() {
    		set_theme_mod( 'mk_custom_sidebars', array_unique( $this->custom_sidebars ) );
    	}

    	/* Register and display the custom custom_sidebar areas we have set. */
    	public function register_sidebars() {

    		// Register new widget areas from $this->type post type

    		// Get widget areas
    		if ( empty( $this->custom_sidebars ) ) {
    			$this->custom_sidebars = $this->get_custom_sidebars();
    		}

    		// Original widget areas is empty
    		$this->orig = array();

    		// Save widget areas
    		if ( ! empty( $this->orig ) && $this->orig != $this->custom_sidebars ) {
    			$this->custom_sidebars = array_unique( array_merge( $this->custom_sidebars, $this->orig ) );
    			$this->save_custom_sidebars();
    		}

    		// If widget areas are defined add a sidebar area for each
    		if ( is_array( $this->custom_sidebars ) ) {
    			foreach ( array_unique( $this->custom_sidebars ) as $custom_sidebar ) {
    				$args = array(
    					'id'			=> sanitize_key( $custom_sidebar ),
    					'name'			=> $custom_sidebar,
    					'class'			=> 'mk-custom',
    					'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="swm-sidebar-widget-box"><div class="swm-widget-content">',
    					'after_widget' => '<div class="clear"></div></div></div></div>',
    					'before_title' => '<div class="swm-sidebar-ttl"><h4><span>',
    					'after_title' => '</span></h4><div class="clear"></div></div><div class="clear"></div>'
    				);
    				register_sidebar( $args );
    			}
    		}
    	}

    	/* Return the get_custom_sidebars array. */
    	public function get_custom_sidebars() {

    		// If the single instance hasn't been set, set it now.
    		if ( ! empty( $this->custom_sidebars ) ) {
    			return $this->custom_sidebars;
    		}

    		// Create theme mode to save new sidebar
    		$get_custom_sidebars = get_theme_mod( 'mk_custom_sidebars' );

    		// If theme mod isn't empty set to class widget area var
    		if ( ! empty( $get_custom_sidebars ) && is_array( $get_custom_sidebars ) ) {
    			$this->custom_sidebars = array_unique( array_merge( $this->custom_sidebars, $get_custom_sidebars ) );
    		}

    		return $this->custom_sidebars;
    	}

    	public function mk_delete_custom_sidebar() {
    		// Check_ajax_referer('delete-mk-custom_sidebar-nonce');
    		if ( ! empty( $_REQUEST['name'] ) ) {
    			$name = strip_tags( ( stripslashes( $_REQUEST['name'] ) ) );
    			$this->custom_sidebars = $this->get_custom_sidebars();
    			$key = array_search($name, $this->custom_sidebars );
    			if ( $key >= 0 ) {
    				unset( $this->custom_sidebars[$key] );
    				$this->save_custom_sidebars();
    			}
    			echo "custom-sidebar-is-removed";
    		}
    		die();
    	}

    	/* Enqueue JS for the customizer controls */
    	public function load_scripts() {

    		// Load scripts
    		wp_enqueue_style( 'dashicons' );
    		wp_enqueue_script('mk-custom-sidebars', MK_DIR_URL . 'sidebars/sidebars.js', array( 'jquery' ), MK_VERSION, true );
    		wp_enqueue_style('mk-custom-sidebars', MK_DIR_URL . 'sidebars/sidebars.css', false, MK_VERSION );

    		// Get widgets
    		$widgets = array();
    		if ( ! empty( $this->custom_sidebars ) ) {
    			foreach ( $this->custom_sidebars as $widget ) {
    				$widgets[$widget] = 1;
    			}
    		}

    		// Localize script
    		wp_localize_script('mk-custom-sidebars', 'mkLocalizeCustomSidebars', array(
    				'count'   => count( $this->orig ),
    				'widget_id'  => esc_html__( 'Widget ID', 'orbius-core' ),
    				'delete'  => esc_html__( 'Delete', 'orbius-core' ),
    				'confirm' => esc_html__( 'Confirm', 'orbius-core' ),
    				'cancel'  => esc_html__( 'Cancel', 'orbius-core' ),
    			)
    		);
    	}

    }
}
new mkCustomSidebars();