<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if ( !class_exists( 'MkAboutAuthor' ) ) {
	class MkAboutAuthor extends WP_Widget {
	    function __construct() {
			$widget_ops = array('description' => esc_html__('Display about author information', 'orbius-core'));
			parent::__construct('mk_about_author_wid',$name = esc_html__('Custom - About Author', 'orbius-core'),$widget_ops);
	    }

	  	/* Displays the Widget in the front-end */
	    function widget($args, $instance){
			extract($args);
			$title          = !empty($instance['title']) ?  '<h4>' . esc_html__( $instance['title'] ) . '</h4>' : '';
            $subtitle       = !empty($instance['subtitle']) ?  '<p class="autor_position">' . esc_html__( $instance['subtitle'] ) . '</p>' : '';
			$desc           = !empty($instance['desc']) ? '<p>' . esc_html__( $instance['desc'] ) . '</p>' : '' ;
            $image_width    = !empty($instance['image_width']) ? 'width:' . intval($instance['image_width']) . 'px;' : '' ;
            $image_height   = !empty($instance['image_height']) ? 'height:' . intval($instance['image_height']) . 'px;' : '' ;
            $textalign      = isset($instance['textalign']) ? $instance['textalign'] : 'left' ;
            $new_window_open   = !empty( $instance['new_window_open'] ) ? '1' : '0';

            if ( !empty($instance['author_img']) ) {
                $author_img = '<div class="mk-about-author-widget-img"><img src="'.esc_url( $instance['author_img'] ).'" style="' . $image_width . $image_height . '" alt="" /></div>';
            } else {
                $author_img = '';
            }

            $nos = array( 'one','two','three','four','five','six' );
            $target = '_self';

            for ( $i = 0; $i<6; $i++ ) {
                $iconname      = 'icon'.$nos[$i].'_name';
                $iconurl       = 'icon'.$nos[$i].'_url';
                $iconbg        = 'icon'.$nos[$i].'_bg';
                $icon_name[$i] = !empty($instance[$iconname]) ? esc_html($instance[$iconname]) : '' ;
                $icon_url[$i]  = !empty($instance[$iconurl]) ? esc_html($instance[$iconurl]) : '' ;
                $icon_bg[$i]   = !empty($instance[$iconbg]) ? esc_html($instance[$iconbg]) : '';
            }

            if ($new_window_open == 1) {
                $target = 'target="_blank"';
            }

            $smicon = '';
            $smicon_list = '';

            for ( $i = 0; $i<6; $i++ ) {

               if ( $icon_name[$i] != '' ) {
                    $smicon_list .= '<li><a href="'.esc_url($icon_url[$i]).'" '.esc_html($target).'>'.esc_html($icon_name[$i]).'</a></li>';
                }
            }

            if ( '' !== $smicon_list ) {
                $smicon .= '<div class="mk-widget-author-sm-icons highlight-text">
                                <ul>' . $smicon_list . '</ul>
                            </div>
                            <div class="clear"></div>';
            }

			echo $before_widget . '
                    <div class="mk-about-author-widget '.esc_attr($textalign).'">'
                    . $author_img . $title . $subtitle . $desc . $smicon .
                    '</div>'
                . $after_widget;
		}

	  	/*Saves the settings. */
	    function update($new_instance, $old_instance){
			$instance               = $old_instance;
			$instance['title']      = stripslashes($new_instance['title']);
            $instance['subtitle']   = stripslashes($new_instance['subtitle']);
            $instance['desc']       = stripslashes($new_instance['desc']);
            $instance['author_img'] = stripslashes($new_instance['author_img']);
            $instance['textalign'] = $new_instance['textalign'];
            $instance['image_width'] = $new_instance['image_width'];
            $instance['image_height'] = $new_instance['image_height'];
            $instance['new_window_open'] = $new_instance['new_window_open'] ? 1 : 0;

            $nos = array( 'one','two','three','four','five','six' );

            for ( $i = 0; $i<6; $i++ ) {
                $iconname            = 'icon'.$nos[$i].'_name';
                $iconurl             = 'icon'.$nos[$i].'_url';
                $iconbg              = 'icon'.$nos[$i].'_bg';
                $instance[$iconname] =  $new_instance[$iconname];
                $instance[$iconurl]  =  $new_instance[$iconurl];
                $instance[$iconbg]   =  $new_instance[$iconbg];
            }

			return $instance;
		}

	    function form($instance){
			//Defaults
			$instance = wp_parse_args((array) $instance, array(
                'title' => esc_html__('john doe','orbius-core'),
                'subtitle' => esc_html__('web designer','orbius-core'),
                'author_img' => '',
                'desc' => 'John is a passionate photographer and content creator with a deep love for creativity and visual storytelling.',
                'image_width' => '',
                'image_height' => '',
                'textalign' => 'left',
                'iconone_name' => 'fb',
                'icontwo_name' => 'tw',
                'iconthree_name' => 'ln',
                'iconfour_name' => 'pi',
                'iconfive_name' => 'yt',
                'iconsix_name' => 'dr',
                'iconone_url' => '#',
                'icontwo_url' => '#',
                'iconthree_url' => '#',
                'iconfour_url' => '#',
                'iconfive_url' => '#',
                'iconsix_url' => '#',
                'new_window_open' => 1 ) );

            echo '<div>
                <label for="' . $this->get_field_name( 'author_img' ) . '">' . esc_html__('Author Image:','gyan-elements') . '</label><br><br>
                <div class="image-preview"><img style="max-width:100%;" src="' . esc_attr( $instance['author_img'] ) . '" /></div>
                <input class="widefat image-upload-value" id="' . $this->get_field_id( 'author_img' ) . '" name="' . $this->get_field_name( 'author_img' ) . '" type="hidden" value="' . esc_attr( $instance['author_img'] ) . '" />
                <button class="image-upload-button button button-primary">' . esc_html__('Add Image','gyan-elements') . '</button>
                <input type="button" id="$name-remove" class="button image-upload-button-remove" value="Remove" />
            </div>';

			echo '<p><label for="' . $this->get_field_id('title') . '">' . esc_html__('Widget Title:', 'orbius-core') . '</label><input class="widefat" id="' . $this->get_field_id('title') . '" name="' . $this->get_field_name('title') . '" type="text" value="' . esc_attr($instance['title']) . '" /></p>';

            echo '<p><label for="' . $this->get_field_id('subtitle') . '">' . esc_html__('Subtitle:', 'orbius-core') . '</label><input class="widefat" id="' . $this->get_field_id('subtitle') . '" name="' . $this->get_field_name('subtitle') . '" type="text" value="' . esc_attr($instance['subtitle']) . '" /></p>';

            echo '<p><label for="' . $this->get_field_id('desc') . '">' . esc_html__('HTML Content:', '__npo-sites-shortcodes__') . '</label><br />
            <textarea  class="widefat" rows="10" cols="20" id="' . $this->get_field_id('desc') . '" name="' . $this->get_field_name('desc') . '">' . esc_textarea( $instance['desc'] ) . '</textarea></p>';

            $swmFontAwesomeLink_start = '<a href="https://fortawesome.com/sets/font-awesome-5-brands" target="_blank">';
            $swmFontAwesomeLink_end = '</a>';
            ?>

            <hr />
            <p>
                <label for="<?php echo $this->get_field_id('image_width'); ?>"><?php echo esc_html__('Image Width (only Number)', 'orbius-core'); ?></label><br>
                <input class="widefat swmsc-social-wid-color-pick" id="<?php echo $this->get_field_id('image_width'); ?>" name="<?php echo $this->get_field_name('image_width'); ?>" type="text" value="<?php echo esc_attr( $instance['image_width'] ); ?>" />
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('image_height'); ?>"><?php echo esc_html__('Image Height (only Number)', 'orbius-core'); ?></label><br>
                <input class="widefat swmsc-social-wid-color-pick" id="<?php echo $this->get_field_id('image_height'); ?>" name="<?php echo $this->get_field_name('image_height'); ?>" type="text" value="<?php echo esc_attr( $instance['image_height'] ); ?>" />
            </p>

            <hr />

            <p><?php echo sprintf( esc_html__( 'Icon Names Page: %sFont Awesome%s', 'orbius-core' ),$swmFontAwesomeLink_start, $swmFontAwesomeLink_end); ?><br /></p>

            <p>
                <input class="checkbox" type="checkbox" <?php checked($instance['new_window_open'], true) ?> id="<?php echo $this->get_field_id('new_window_open'); ?>" name="<?php echo $this->get_field_name('new_window_open'); ?>" />
                <label for="<?php echo $this->get_field_id('new_window_open'); ?>"><?php esc_html_e('Open social media website in new window', 'orbius-core') ?></label>
            </p>

            <p>
                <label for="<?php echo $this->get_field_id('textalign'); ?>"><?php echo esc_html__('Align Content:', 'orbius-core'); ?></label>
                <select id="<?php echo $this->get_field_id('textalign'); ?>" name="<?php echo $this->get_field_name('textalign'); ?>" class="widefat" style="width:100%;">
                    <option value="left" <?php if ( $instance['textalign'] == 'left') { echo 'selected="selected"'; } ?>><?php echo esc_html__('Left', '__npo-sites-shortcodes__'); ?></option>
                    <option value="center" <?php if ( $instance['textalign'] == 'center') { echo 'selected="selected"'; } ?>><?php echo esc_html__('Center', '__npo-sites-shortcodes__'); ?></option>
                    <option value="right" <?php if ( $instance['textalign'] == 'right') { echo 'selected="selected"'; } ?>><?php echo esc_html__('Right', '__npo-sites-shortcodes__'); ?></option>
                </select>
            </p>
            <hr />

            <?php

            $nos = array( 'one','two','three','four','five','six' );

             for ( $i = 0; $i<6; $i++ ) {

                 $iconname = 'icon'.$nos[$i].'_name';
                 $iconurl  = 'icon'.$nos[$i].'_url';
                 $iconbg   = 'icon'.$nos[$i].'_bg';
                 ?>
                 <p>
                     <label for="<?php echo $this->get_field_id( $iconname ); ?>"><?php printf(esc_html('Social Media %s : Name and URL and Background Color', 'orbius-core'),$i+1) ?></label>
                     <input type="text" id="<?php echo $this->get_field_id( $iconname ); ?>" name="<?php echo $this->get_field_name( $iconname ); ?>" value="<?php echo esc_attr( $instance[$iconname] ); ?>" style="width:95%;" />
                     <input type="text" id="<?php echo $this->get_field_id( $iconurl ); ?>" name="<?php echo $this->get_field_name( $iconurl ); ?>" value="<?php echo esc_attr( $instance[$iconurl] ); ?>" style="width:95%;" />
                 </p>

                 <?php
             }
		}
	}
}

register_widget('MkAboutAuthor');