<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if ( !class_exists( 'MkRecentPosts' ) ) {
	class MkRecentPosts extends WP_Widget {
	    function __construct() {
			$widget_ops = array('description' => esc_html__('Display latest blog posts', 'orbius-core'));
			parent::__construct('mk_recent_posts_wid',$name = esc_html__('Custom - Recent Posts', 'orbius-core'),$widget_ops);
	    }

	  	/* Displays the Widget in the front-end */
	    function widget($args, $instance){
			extract($args);
			$title          = apply_filters('widget_title', !empty($instance['title']) ? $instance['title'] : esc_html__('Recent Posts', 'orbius-core') );
			$no_title_char  = !empty($instance['no_title_char']) ? $instance['no_title_char'] : '40' ;
			$no_of_posts    = !empty($instance['no_of_posts']) ? $instance['no_of_posts'] : '4' ;
			$add_category   = !empty($instance['add_category']) ? $instance['add_category'] : '' ;
			$custom_date    = !empty($instance['custom_date']) ? $instance['custom_date'] : 'M j' ;
            $show_post_meta = !empty( $instance['show_post_meta'] ) ? '1' : '0';
            $texttransform  = isset($instance['texttransform']) ? $instance['texttransform'] : 'none' ;

			echo $before_widget;
			echo $before_title . $title . $after_title;
			echo '<div class="mk-recent-posts-tiny" style="text-transform:' . $texttransform . ';">';
			echo '<ul>';

			$cnt = 0;

			if($add_category != ""){
				$recentposts = new WP_Query('cat='.$add_category.'&posts_per_page='.intval($no_of_posts).'&orderby=date&order=DESC');
			}else{
				$recentposts = new WP_Query('posts_per_page='.intval($no_of_posts).'&orderby=date&order=DESC');
			}

			while($recentposts->have_posts()): $recentposts->the_post();

    			if($cnt < $no_of_posts){
    			?>
    				<li>
    					<?php

    						$format = get_post_format();

    						if ( has_post_thumbnail() ) { ?>
    							<a href="<?php echo get_permalink(); ?>" title="<?php echo esc_attr(strip_tags(get_the_title())); ?>" class="mk-recent-posts-tiny-img animate-in" data-anim-type="fade-in" data-anim-delay="200"><?php

                                $rp_post_thumbnail_url = get_the_post_thumbnail_url( get_the_ID(), 'swm_image_size_tiny' );

                                    if ( $rp_post_thumbnail_url ) {
                                        echo '<img src="'.$rp_post_thumbnail_url.'" loading="lazy">';
                                    }

                                 ?></a>
    							<?php
    						}
    					 ?>

                        <div class="mk-recent-posts-tiny-content">
                             <div class="mk-recent-posts-tiny-title">

                                <?php if ($show_post_meta == 1) { ?>

                                    <div class="mk-tiny-post-meta highlight-text"><?php

                                        echo '<div class="mk-tiny-post-meta-date-separator"></div>' . get_the_term_list( get_the_ID(), 'category', '', '<span class="mk-tiny-post-meta-cat-separator"></span>' ) . '<div class="mk-tiny-post-meta-separator"></div>';

                                        $date_link = empty( get_the_title() ) && ! is_single() ? get_the_permalink() : get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) );
                                        $classes   = '';
                                        if ( is_single() || is_page() || is_archive() ) { // This check is to prevent classes for Gutenberg block
                                            $classes = 'published updated';
                                        }
                                        ?><a href="<?php echo esc_url( $date_link ); ?>" class="entry-date <?php echo esc_attr( $classes ); ?>"><?php echo get_the_date($custom_date) ?></a><div class="mk-tiny-post-meta-separator"></div>
                                    </div>

                                <?php  } ?>
                             <h5><a href="<?php echo get_permalink(); ?>"><?php
                            if ($no_title_char < 299) {
                                echo esc_attr(strip_tags(substr(get_the_title(),0,$no_title_char) )  );
                            } else {
                                echo get_the_title();
                            } ?></a></h5>
                        </div>
                        </div>

    					<div class="clear"></div>
    				</li>

    				<?php

    				$cnt++;
    			}

			endwhile;
			wp_reset_postdata();

			echo '</ul>';
			echo '</div>';
			echo '<div class="clear"></div>';
			echo $after_widget;
		}

	  	/*Saves the settings. */
	    function update($new_instance, $old_instance){
			$instance                    = $old_instance;
			$instance['title']           = stripslashes($new_instance['title']);
			$instance['no_title_char']   = stripslashes($new_instance['no_title_char']);
			$instance['no_of_posts']     = stripslashes($new_instance['no_of_posts']);
			$instance['add_category']    = stripslashes($new_instance['add_category']);
			$instance['custom_date']     = stripslashes($new_instance['custom_date']);
            $instance['show_post_meta']  = $new_instance['show_post_meta'] ? 1 : 0;
            $instance['texttransform']   = $new_instance['texttransform'];

			return $instance;
		}

	    function form($instance){
			//Defaults
			$instance = wp_parse_args( (array) $instance, array('title'=>esc_html__('Recent Posts','orbius-core'),'texttransform' => 'none', 'no_title_char'=>'40','no_of_posts'=>'4','add_category'=>'','show_post_meta' => 1,'custom_date'=>'M j, Y' ) );

			$reference_page = esc_html__('Date Format Reference', 'orbius-core');

			echo '<p><label for="' . $this->get_field_id('title') . '">' . esc_html__('Widget Title:', 'orbius-core') . '</label><input class="widefat" id="' . $this->get_field_id('title') . '" name="' . $this->get_field_name('title') . '" type="text" value="' . esc_attr($instance['title']) . '" /></p>';

			echo '<p><label for="' . $this->get_field_id('no_title_char') . '">' . esc_html__('Title Text Characters Limit:', 'orbius-core') . '</label><input class="widefat" id="' . $this->get_field_id('no_title_char') . '" name="' . $this->get_field_name('no_title_char') . '" type="text" value="' . intval($instance['no_title_char']) . '" /></p>';

			echo '<p><label for="' . $this->get_field_id('no_of_posts') . '">' . esc_html__('Number of Posts to Display:', 'orbius-core') . '</label><input class="widefat" id="' . $this->get_field_id('no_of_posts') . '" name="' . $this->get_field_name('no_of_posts') . '" type="text" value="' . intval($instance['no_of_posts']) . '" /></p>';

			echo '<p><label for="' . $this->get_field_id('add_category') . '">' . esc_html__('Display Specific Categories:', 'orbius-core') . '</label><input class="widefat" id="' . $this->get_field_id('add_category') . '" name="' . $this->get_field_name('add_category') . '" type="text" value="' . esc_attr($instance['add_category']) . '" /><br /><small>' . esc_html__('If you want to display specific category(ies) recent posts only, then add Category IDs with comma seperated (e.g. 1,2,3) or Leave it blank for default.', 'orbius-core') . '</small></p>';

			echo '<p><label for="' . $this->get_field_id('custom_date') . '">' . esc_html__('Date Display Format:', 'orbius-core') . '</label><input class="widefat" id="' . $this->get_field_id('custom_date') . '" name="' . $this->get_field_name('custom_date') . '" type="text" value="' . esc_html($instance['custom_date']) . '" /><br /><small>' . esc_html__('Display custom date format.', 'orbius-core') . ' e.g. "M j, Y" <a href="https://wordpress.org/support/article/formatting-date-and-time/#format-string-examples" target="_blank">' . $reference_page . '</a></small></p>';

            ?>

            <p>
                <input class="checkbox" type="checkbox" <?php checked($instance['show_post_meta'], true) ?> id="<?php echo $this->get_field_id('show_post_meta'); ?>" name="<?php echo $this->get_field_name('show_post_meta'); ?>" />
                <label for="<?php echo $this->get_field_id('show_post_meta'); ?>"><?php esc_html_e('Display Post Meta', 'orbius-core') ?></label>
            </p>

            <p>
                <label for="<?php echo $this->get_field_id('texttransform'); ?>"><?php echo esc_html__('Text Transform:', 'orbius-core'); ?></label>
                <select id="<?php echo $this->get_field_id('texttransform'); ?>" name="<?php echo $this->get_field_name('texttransform'); ?>" class="widefat" style="width:100%;">
                    <option value="none" <?php if ( $instance['texttransform'] == 'none') { echo 'selected="selected"'; } ?>><?php echo esc_html__('None', '__npo-sites-shortcodes__'); ?></option>
                    <option value="uppercase" <?php if ( $instance['texttransform'] == 'uppercase') { echo 'selected="selected"'; } ?>><?php echo esc_html__('Uppercase', '__npo-sites-shortcodes__'); ?></option>
                    <option value="lowercase" <?php if ( $instance['texttransform'] == 'lowercase') { echo 'selected="selected"'; } ?>><?php echo esc_html__('Lowercase', '__npo-sites-shortcodes__'); ?></option>
                </select>
            </p>

            <?php

		}
	}
}

register_widget('MkRecentPosts');








