<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
if ( !class_exists( 'MkSocialIcons' ) ) {
    class MkSocialIcons extends WP_Widget {

        function __construct() {
            $widget_ops = array( 'classname' => 'widget_social', 'description' => esc_html__( 'Display social icons list', 'orbius-core' ) );
            parent::__construct('mk_social', esc_html__('Custom - Social Icons', 'orbius-core'), $widget_ops);
            add_action('admin_enqueue_scripts', array($this, 'upload_scripts'));
        }

        public function upload_scripts() {
            wp_enqueue_script( 'mk-custom-widgets', MK_DIR_URL . 'widgets/custom-widgets.js', array( 'jquery', ),MK_VERSION, TRUE );
        }

        function widget( $args, $instance ) {
            extract( $args );

            $title             = apply_filters('widget_title', empty( $instance['title'] ) ? '' : $instance['title']);
            $new_window_open   = !empty( $instance['new_window_open'] ) ? '1' : '0';
            $no_bg_color       = !empty( $instance['no_bg_color'] ) ? '1' : '0';

            $nos = array( 'one','two','three','four','five','six' );
            $target = '_self';

            for ( $i = 0; $i<5; $i++ ) {
                $iconname      = 'icon'.$nos[$i].'_name';
                $iconurl       = 'icon'.$nos[$i].'_url';
                $iconbg        = 'icon'.$nos[$i].'_bg';
                $icon_name[$i] = !empty($instance[$iconname]) ? esc_html($instance[$iconname]) : '' ;
                $icon_url[$i]  = !empty($instance[$iconurl]) ? esc_html($instance[$iconurl]) : '' ;
                $icon_bg[$i]   = !empty($instance[$iconbg]) ? esc_html($instance[$iconbg]) : '';
            }

            echo '<div class="mk_custom_social_widget">';
            echo $before_widget;
            if ( $title != '' ) {
                echo $before_title . wp_kses($title,mk_kses_allowed_text()) . $after_title;
            }

            if ($new_window_open == 1) {
                $target = 'target="_blank"';
            }
            ?>
            <div class="mk-sm-wid-icons">
                <ul>
                    <?php
                    for ( $i = 0; $i<5; $i++ ) {

                       if ( $icon_name[$i] != '' ) {
                            echo '<li><a href="'.esc_url($icon_url[$i]).'" '.esc_html($target).'><i class="fab fa-'.esc_attr($icon_name[$i]).'"></i></a></li>';
                        }
                    }
                    ?>
                </ul>
            </div>
            <div class="clear"></div>
            <?php

            echo $after_widget;
            echo '</div>';
        }

        function update( $new_instance, $old_instance ) {

            $instance = $old_instance;
            $instance['title'] = wp_kses($new_instance['title'],mk_kses_allowed_text());
            $instance['new_window_open'] = $new_instance['new_window_open'] ? 1 : 0;
            $instance['no_bg_color'] = $new_instance['no_bg_color'] ? 1 : 0;

            $nos = array( 'one','two','three','four','five','six' );

            for ( $i = 0; $i<6; $i++ ) {
                $iconname            = 'icon'.$nos[$i].'_name';
                $iconurl             = 'icon'.$nos[$i].'_url';
                $iconbg              = 'icon'.$nos[$i].'_bg';
                $instance[$iconname] =  $new_instance[$iconname];
                $instance[$iconurl]  =  $new_instance[$iconurl];
                $instance[$iconbg]   =  $new_instance[$iconbg];
            }

            return $instance;
        }

        function form( $instance ) {
            //Defaults
            $instance = wp_parse_args( (array) $instance, array( 'title' => 'Follow Us', 'iconone_name' => 'twitter', 'icontwo_name' => 'facebook-f', 'iconthree_name' => 'instagram', 'iconfour_name' => 'vimeo-v', 'iconfive_name' => 'pinterest-p', 'iconsix_name' => 'dribbble', 'iconone_url' => '#', 'icontwo_url' => '#', 'iconthree_url' => '#', 'iconfour_url' => '#', 'iconfive_url' => '#', 'iconsix_url' => '#', 'new_window_open' => 1 ));

            ?>
            <script type="text/javascript">
                //<![CDATA[
                    jQuery(document).ready(function() {jQuery('#widgets-right .mk-social-wid-color-pick').wpColorPicker(); });
                //]]>
            </script>
            <p>
                <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php echo esc_html__('Widget Title:', 'orbius-core') ?></label>
                <input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" style="width:95%;" />
            </p>

            <br><hr>
            <p>
                <input class="checkbox" type="checkbox" <?php checked($instance['new_window_open'], true) ?> id="<?php echo $this->get_field_id('new_window_open'); ?>" name="<?php echo $this->get_field_name('new_window_open'); ?>" />
                <label for="<?php echo $this->get_field_id('new_window_open'); ?>"><?php esc_html_e('Open social media website in new window', 'orbius-core') ?></label>
            </p>

            <?php
            $swmFontAwesomeLink_start = '<a href="https://fortawesome.com/sets/font-awesome-5-brands" target="_blank">';
            $swmFontAwesomeLink_end = '</a>';
            ?>

            <p><?php echo sprintf( esc_html__( 'Icon Names Page: %sFont Awesome%s', 'orbius-core' ),$swmFontAwesomeLink_start, $swmFontAwesomeLink_end); ?><br /></p>
            <hr />

           <?php
            $nos = array( 'one','two','three','four','five','six' );

            for ( $i = 0; $i<5; $i++ ) {

                $iconname = 'icon'.$nos[$i].'_name';
                $iconurl  = 'icon'.$nos[$i].'_url';
                $iconbg   = 'icon'.$nos[$i].'_bg';
                ?>
                <p>
                    <label for="<?php echo $this->get_field_id( $iconname ); ?>"><?php printf(esc_html('Icon %s : Name, URL and Background Color', 'orbius-core'),$i+1) ?></label>
                    <input type="text" id="<?php echo $this->get_field_id( $iconname ); ?>" name="<?php echo $this->get_field_name( $iconname ); ?>" value="<?php echo esc_attr( $instance[$iconname] ); ?>" style="width:95%;" />
                    <input type="text" id="<?php echo $this->get_field_id( $iconurl ); ?>" name="<?php echo $this->get_field_name( $iconurl ); ?>" value="<?php echo esc_attr( $instance[$iconurl] ); ?>" style="width:95%;" />
                </p>

                <?php
            }

        }

    }
}

register_widget('MkSocialIcons');