<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

if ( !class_exists( 'Swm_Theme_Setup_Admin' ) ) {
    class Swm_Theme_Setup_Admin {
        protected $options_screen = null;

        public function __construct() {
            add_action( 'admin_menu',            array( $this, 'add_custom_options_page' ) );
            add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_styles' ) );
        }

        public function add_custom_options_page() {
            $this->options_screen = add_menu_page( esc_html__('Theme Panel','orbius'), esc_html__('Theme Panel','orbius'), 'edit_theme_options', 'swm-theme-panel', [ $this, 'options_page' ], NULL, 1);

            // parent_slug, page_title, menu_title, capability, menu_slug
            $this->options_screen = add_submenu_page('swm-theme-panel', esc_html__( 'Theme Dashboard', 'orbius'), esc_html__('Theme Dashboard', 'orbius'), 'edit_theme_options', 'swm-theme-panel', [ $this, 'options_page' ], 2 );

            if(class_exists('OCDI_Plugin')){
                add_submenu_page('swm-theme-panel', esc_html__( 'Import Demo', 'orbius'), esc_html__('Import Demo', 'orbius'), 'import', 'swm-one-click-demo-import', 'ocdi/plugin_page_setup', 3  );
            }

            add_submenu_page('swm-theme-panel', esc_html__( 'Theme Options', 'orbius'), esc_html__('Theme Options', 'orbius'), 'edit_theme_options', 'customize.php', NULL, NULL, 4 );

        }

        // Loads the required stylesheets
        public function enqueue_admin_styles( $hook ) {
            if ( $this->options_screen != $hook ) { return; }
            wp_enqueue_style( 'swm-theme-dashboard', SWM_THEME_DIR . '/admin/css/theme-dashboard.css', array(), SWM_THEME_VERSION );
            wp_enqueue_script( 'mk-theme-dashboard', SWM_THEME_DIR . '/admin/js/theme-dashboard.js',['jquery','jquery-ui-accordion'], SWM_THEME_VERSION );
        }

        public function options_page() {

            $doneButton = '<span class="disableBtn">' . esc_html__('Done!', 'orbius') . '</span>';
            ?>
            <div class="wrap swm-theme-dashboard-wrap">
                <div class="swm-theme-dashboard">

                    <div class="swm-theme-setup swm-theme-dashboard-box">
                        <h1><?php echo esc_html__( 'Theme Setup Steps', 'orbius' ); ?></h1>

                        <div class="swm-dashboard-setup-box" data-id="open">

                            <a href="#" class="swm-dashboard-toggle-title swm-db-title-activeX">
                                <span class="swm-db-title-number"><?php echo esc_html__( '1.', 'orbius' ); ?></span>
                                <span class="swm-db-title-text"><?php echo esc_html__( 'Child Theme Installation', 'orbius' ); ?><span class="swm-db-title-text-optional"> <?php echo esc_html__( '(optional)', 'orbius' ); ?></span></span>
                                <span class="swm-db-title-icon"></span>
                            </a>

                            <div class="swm-theme-dashboard-toggle-content">

                                <p><?php echo esc_html__( 'We strongly recommend installing a Child Theme on this step. It saves you from losing any changes you make to the theme files during updates. Even if you\'re not going to do that we still recommend it.', 'orbius' ); ?></p>

                                <ol>
                                    <li><?php echo esc_html__( 'Go to Admin > Appearance > Themes', 'orbius' ); ?></li>
                                    <li><?php echo esc_html__( 'Click on "Add New" button.', 'orbius' ); ?></li>
                                    <li><?php echo esc_html__( 'Click on "Upload Theme" button.', 'orbius' ); ?></li>
                                    <li><?php echo esc_html__( 'Click on "Choose file" button.', 'orbius' ); ?></li>
                                    <li><?php echo esc_html__( 'Select child theme zip file from main downloaded file.', 'orbius' ); ?></li>
                                    <li><?php echo esc_html__( 'Click on "Install Now" button and activate the child theme.', 'orbius' ); ?></li>
                                </ol>

                                <?php
                                if ( is_child_theme() ) {
                                    $childThemeButton = $doneButton;
                                } else {
                                    $childThemeButton = '<a href="'. esc_url( admin_url( 'theme-install.php?browse=popular' ) ) .'" class="setupBtn">' . esc_html__('Install Child Theme', 'orbius') . '</a>';
                                }
                                echo wp_kses( $childThemeButton,swm_kses_allowed_textarea() ); ?>
                            </div>

                        </div>


                        <div class="swm-dashboard-setup-box" data-id="closed">

                            <a href="#" class="swm-dashboard-toggle-title">
                                <span class="swm-db-title-number"><?php echo esc_html__( '2.', 'orbius' ); ?></span>
                                <span class="swm-db-title-text"><?php echo esc_html__( 'Plugins Installation', 'orbius' ); ?></span>
                                <span class="swm-db-title-icon"></span>
                            </a>

                            <div class="swm-theme-dashboard-toggle-content">

                                <p><?php echo esc_html__( 'Install and activate theme-related plugins. You can add and remove plugins later on from within WordPress.', 'orbius' ); ?></p>

                                <ol>
                                    <li><?php echo esc_html__( 'Go to Admin > Appearance > Install Plugins', 'orbius' ); ?></li>
                                    <li><?php echo esc_html__( 'Install and Activate all required plugins.', 'orbius' ); ?></li>
                                </ol>

                                <?php

                                if ( in_array('elementor/elementor.php', apply_filters('active_plugins', get_option( 'active_plugins' )))
                                    && in_array('one-click-demo-import/one-click-demo-import.php', apply_filters('active_plugins', get_option( 'active_plugins' )))
                                    && in_array('contact-form-7/wp-contact-form-7.php', apply_filters('active_plugins', get_option( 'active_plugins' )))
                                    && in_array('orbius-core/orbius-core.php', apply_filters('active_plugins', get_option( 'active_plugins' )))
                                    && in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option( 'active_plugins' ))) ) {

                                    $pluginsButtonHTML = $doneButton;

                                } else {

                                    $pluginsButtonHTML = '<a href="'. esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ) .'" class="setupBtn">' . esc_html__('Install Plugins', 'orbius') . '</a>';

                                }

                                echo wp_kses( $pluginsButtonHTML,swm_kses_allowed_textarea() ); ?>
                            </div>

                        </div>

                        <div class="swm-dashboard-setup-box" data-id="closed">

                            <a href="#" class="swm-dashboard-toggle-title">
                                <span class="swm-db-title-number"><?php echo esc_html__( '3.', 'orbius' ); ?></span>
                                <span class="swm-db-title-text"><?php echo esc_html__( 'Import Demo Content', 'orbius' ); ?></span>
                                <span class="swm-db-title-icon"></span>
                            </a>

                            <div class="swm-theme-dashboard-toggle-content">

                                <p><?php echo esc_html__( 'Importing the theme’s sample content can be helpful to see how the theme works and to have a great starting point to make your website. You’ll be able to delete everything at any time and only keep what you need.', 'orbius' ); ?></p>

                                <ol>
                                    <li><?php echo esc_html__( 'Go to Admin > Appearance > Import Demo Data', 'orbius' ); ?></li>
                                    <li><?php echo esc_html__( 'Click on "Import Demo Data" button.', 'orbius' ); ?></li>
                                    <li><?php echo esc_html__( 'Click on "Continue & Import" button.', 'orbius' ); ?></li>
                                </ol>

                                <?php
                                $swm_demo_import_done = get_site_option( 'swm_demo_import_done', 'no' );
                                $importDemoButton = '';

                                if ( 'yes' == $swm_demo_import_done ) {
                                    $importDemoButton = $doneButton;
                                } else {
                                    if (class_exists( 'OCDI_Plugin' )) {
                                        $importDemoButton = '<a href="'. esc_url( admin_url( 'themes.php?page=swm-one-click-demo-import' ) ) .'" class="setupBtn">' . esc_html__('Import Demo', 'orbius') . '</a>';
                                    }
                                }

                                echo wp_kses( $importDemoButton,swm_kses_allowed_textarea() );
                                ?>
                            </div>

                        </div>

                    </div>

                    <div class="swm-system-requirements swm-theme-dashboard-box">
                        <h2><?php echo esc_html__( 'System Information', 'orbius' ); ?></h2>
                        <p><?php echo esc_html__( 'Here is an overview of your current server configuration info.', 'orbius' ); ?></p>
                        <ul>

                        <?php
                        $system_info = array(
                            'php_version'        => array(
                                'title'    => esc_html__( 'PHP Version', 'orbius' ),
                                'value'    => phpversion(),
                                'required' => '7.0',
                                'compare'  => version_compare( PHP_VERSION, '7.0' ) >= 0,
                            ),
                            'wp_version'        => array(
                                'title'    => esc_html__( 'WordPress Version', 'orbius' ),
                                'value'    => $GLOBALS['wp_version'],
                                'required' => '5.0',
                                'compare'  => version_compare( $GLOBALS['wp_version'], '5.0', '>=' ),
                            ),
                            'max_upload_size'    => array(
                                'title'    => esc_html__( 'Max Upload Size', 'orbius' ),
                                'value'    => size_format( wp_max_upload_size() ),
                                'required' => '64',
                                'compare'  => wp_max_upload_size() >= 67108864,
                                'notice'   => esc_html__( 'The largest filesize that can be uploaded to your WordPress installation. Please adjust this value to 64 in order to meet the theme requirements. ', 'orbius' ),
                            ),
                            'php_post_max_size'  => array(
                                'title'    => esc_html__( 'Post Max Size', 'orbius' ),
                                'value'    => ini_get( 'post_max_size' ),
                                'required' => '64',
                                'compare'  => intval(ini_get( 'post_max_size' )) >= 64,
                                'notice'   => esc_html__( 'The largest filesize that can be contained in one post. Please adjust this value to 64 in order to meet the theme requirements. ', 'orbius' ),
                            ),
                            'php_memory_limit'   => array(
                                'title'    => esc_html__( 'PHP Memory Limit', 'orbius' ),
                                'value'    => size_format( wp_convert_hr_to_bytes( @ini_get( 'memory_limit' ) ) ),
                                'required' => '512',
                                'compare'  => wp_convert_hr_to_bytes( @ini_get( 'memory_limit' ) ) >= 536870912,
                                'notice'   => esc_html__( 'The current value is insufficient to properly support the theme. Please adjust this value to 512 in order to meet the theme requirements. ', 'orbius' ),
                            ),
                            'php_time_limit'     => array(
                                'title'    => esc_html__( 'Max. Execution Time (sec)', 'orbius' ),
                                'value'    => ini_get( 'max_execution_time' ),
                                'required' => '300',
                                'compare'  => ini_get( 'max_execution_time' ) >= 300,
                                'notice'   => esc_html__( 'The amount of time (in seconds) that your site will spend on a single operation before timing out (to avoid server lockups). Please adjust this value to 300 in order to meet the theme requirements. ', 'orbius' ),
                            ),
                            'php_max_input_time'     => array(
                                'title'    => esc_html__( 'Max Input Time', 'orbius' ),
                                'value'    => ini_get( 'max_input_time' ),
                                'required' => '1000',
                                'compare'  => ini_get( 'max_input_time' ) >= 1000,
                                'notice'   => esc_html__( 'The current value is insufficient to properly support the theme. Please adjust this value to 1000 in order to meet the theme requirements. ', 'orbius' ),
                            ),
                            'php_max_input_vars' => array(
                                'title'    => esc_html__( 'PHP Max Input Vars', 'orbius' ),
                                'value'    => ini_get( 'max_input_vars' ),
                                'required' => '5000',
                                'compare'  => ini_get( 'max_input_vars' ) >= 5000,
                                'notice'   => esc_html__( 'The maximum number of variables your server can use for a single function to avoid overloads. Please adjust this value to 5000+ in order to meet the theme requirements. ', 'orbius' ),
                            ),
                            'xml_reader_installed'  => array(
                                'title'    => esc_html__( 'XML Reader Installed', 'orbius' ),
                                'compare'  => ( class_exists( 'XMLReader' ) ),
                                'value'    => '',
                                'required' => '',
                                'notice'   => esc_html__( 'Demo content import requires XMLReader extension to be installed. Please contact your web hosting provider and ask them to install and activate the XMLReader PHP extension.', 'orbius' ),
                                'status-class' => 'xml-reader-status'
                            ),
                        );


                        foreach ( $system_info as $system_info_key => $system_info_value ) : ?>
                            <li <?php
                            if ( isset( $system_info_value['compare'] ) && ! $system_info_value['compare'] ) {
                                echo 'class="error"';
                            } ?>><?php
                            echo esc_html( $system_info_value['title'] ); ?><span <?php
                            if ( isset( $system_info_value['status-class'] ) && '' != $system_info_value['status-class'] ) {
                                echo 'class="'.$system_info_value['status-class'].'"';
                            } ?>><?php
                            if ( $system_info_value['value'] ) {
                                echo wp_kses_post( $system_info_value['value'] );
                            } ?></span>
                                <?php if ( isset( $system_info_value['notice'] ) && ( isset( $system_info_value['compare'] ) && ! $system_info_value['compare'] ) ) { ?>
                                    <p><?php echo esc_html( $system_info_value['notice'] ); ?></p>
                                <?php } ?>
                            </li>
                        <?php endforeach; ?>

                        </ul>
                    </div>

                </div>

                <div>
                    <ul class="swm-theme-dashboard-help">
                        <li><a class="doc" href="https://premiumthemes.in/docs/orbius/index.html" target="_blank">Documentation</a></li>
                        <li><a class="support" href="https://themeforest.net/item/orbius-creative-agency-and-portfolio-theme/51586582/comments" target="_blank">Theme Support</a></li>
                        <li><a class="log" href="https://themeforest.net/item/orbius-creative-agency-and-portfolio-theme/51586582#item-description__changelog" target="_blank">Changelog</a></li>
                    </ul>

                    <h2>Useful Links</h2>
                    <ul class="swm-dashboard-links">
                        <li><a href="https://premiumthemes.in/docs/orbius/index.html#4-one-click-demo-import" target="_blank">Make your site look like a demo preview</a></li>
                        <li><a href="https://premiumthemes.in/docs/orbius/index.html#3-plugins-installation" target="_blank">Install included plugins</a></li>
                        <li><a href="https://premiumthemes.in/docs/common/theme-update/index.html" target="_blank">Updating the theme</a></li>
                        <li><a href="https://premiumthemes.in/docs/common/speed-up/index.html" target="_blank">Speed up your website</a></li>
                    </ul>
                </div>

            </div> <?php
        }

    }
}

$swmThemeSetup = new Swm_Theme_Setup_Admin();