<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

if ( ! function_exists( 'swm_cust_array' ) ) {
    function swm_cust_array( $type ) {
        $options = '';

        switch ( $type ) {

            case 'posts_list':

                $pt_remove  = array('e-landing-page','elementor_library','cpt_sections');
                $args       = array('public' => true, '_builtin' => false );
                $post_types = get_post_types($args, 'objects');
                $posts      = array('post' => 'Post');

                foreach ($post_types as $post_type) {
                    if ( in_array($post_type->name, $pt_remove) ) { continue; }
                    $posts[$post_type->name] = $post_type->labels->singular_name;
                }

                $options = $posts;
                break;

            case 'blog_single_display_style':
                $options = [
                            'standard'             => esc_html__( 'Standard', 'orbius' ),
                            'standard-alt'         => esc_html__( 'Standard - Alternate', 'orbius' ),
                            'fullwidth-image'      => esc_html__( 'Full Width Image', 'orbius' ),
                        ];
                break;

            case 'default_custom':
                $options = [
                            'default' => esc_html__( 'Default', 'orbius' ),
                            'custom' => esc_html__( 'Custom', 'orbius' ),
                            ];
                break;

            case 'progressbar':
                $options = [
                            'global' => esc_html__( 'Entire Site', 'orbius' ),
                            'page'   => esc_html__( 'On All Pages', 'orbius' ),
                            'post'   => esc_html__( 'On All Posts', 'orbius' ),
                        ];
                break;

            case 'preloader':
                $options = [
                            'disable'        => esc_html__( 'Disable', 'orbius' ),
                            'dot_animation'  => esc_html__( 'Dot Animation', 'orbius' ),
                            'fade'           => esc_html__( 'Fade', 'orbius' ),
                        ];
                break;

            case 'font_style':
                $options = [
                            'normal' => esc_html__( 'Normal', 'orbius' ),
                            'italic' => esc_html__( 'Italic', 'orbius' ),
                        ];
                break;

            case 'image_size':
                $options = [
                            'thumbnail' => esc_html__( 'Thumbnail', 'orbius' ),
                            'medium' => esc_html__( 'Medium', 'orbius' ),
                            'large' => esc_html__( 'Large', 'orbius' ),
                        ];
                break;

            case 'thme_fonts':
                $options = [
                            'none'   => esc_html__( 'None', 'orbius' ),
                            'google' => esc_html__( 'Google Fonts', 'orbius' ),
                            'adobe'  => esc_html__( 'Adobe Fonts', 'orbius' ),
                            'custom' => esc_html__( 'Custom', 'orbius' )
                            ];
                break;

            case 'font_weight':
                $options = [
                            '100' => esc_html__( '100 - Thin', 'orbius' ),
                            '200' => esc_html__( '200 - Extra Light', 'orbius' ),
                            '300' => esc_html__( '300 - Light', 'orbius' ),
                            '400' => esc_html__( '400 - Regular', 'orbius' ),
                            '500' => esc_html__( '500 - Medium', 'orbius' ),
                            '600' => esc_html__( '600 - Semi Bold', 'orbius' ),
                            '700' => esc_html__( '700 - Bold', 'orbius' ),
                            '800' => esc_html__( '800 - Extra Bold', 'orbius' ),
                            '900' => esc_html__( '900 - Black', 'orbius' )
                        ];
                break;

            case 'colors':
                $options = [
                            '--swm-color-dark-1'        => esc_html__( 'Dark 1', 'orbius' ),
                            '--swm-color-dark-2'        => esc_html__( 'Dark 2', 'orbius' ),
                            '--swm-color-light-1'       => esc_html__( 'Light 1', 'orbius' ),
                            '--swm-color-light-2'       => esc_html__( 'Light 2', 'orbius' ),
                        ];
                break;

            case 'position_top_bottom':
                $options = [
                        'top' => esc_html__( 'Top', 'orbius' ),
                        'bottom'  => esc_html__( 'Bottom', 'orbius' )
                    ];
                break;

            case 'display_header_content':
                $options = [
                        'default' => esc_html__( 'Default', 'orbius' ),
                        'custom'  => esc_html__( 'Custom', 'orbius' ),
                        'hide'    => esc_html__( 'Hide Header', 'orbius' )
                    ];
                break;

            case 'go_to_scroll_styles':
                $options = [
                            'dark'      => esc_html__( 'Dark', 'orbius' ),
                            'light'     => esc_html__( 'Light', 'orbius' ),
                        ];
                break;

            case 'go_to_scroll_icons':
                $options = [
                            'arrow-up'          => esc_html__( 'Arrow', 'orbius' ),
                            'long-arrow-alt-up' => esc_html__( 'Long Arrow', 'orbius' ),
                            'caret-up'          => esc_html__( 'Caret', 'orbius' ),
                            'chevron-up'        => esc_html__( 'Chevron', 'orbius' ),
                            'angle-up'          => esc_html__( 'Angle', 'orbius' ),
                            'double-angle-up'   => esc_html__( 'Double Angle', 'orbius' ),
                            'hand-point-up'     => esc_html__( 'Hand Point', 'orbius' )
                        ];
                break;

            case 'shop_gallery_postion':
                $options = [
                    'bottom' => esc_html__( 'Bottom', 'orbius' ),
                    'left'   => esc_html__( 'Left', 'orbius' ),
                    'right'  => esc_html__( 'Right', 'orbius' )
                ];
                break;

            case 'text_transform':
                $options = [
                    'none'      => esc_html__( 'None', 'orbius' ),
                    'uppercase' => esc_html__( 'Uppercase', 'orbius' ),
                    'lowercase' => esc_html__( 'Lowercase', 'orbius' )
                ];
                break;

            case 'page_content_layout':
                $options = [
                    'layout-sidebar-right' => esc_html__( 'Content Left - Sidebar Right', 'orbius' ),
                    'layout-sidebar-left'  => esc_html__( 'Content Right - Sidebar Left', 'orbius' ),
                    'layout-full-width'    => esc_html__( 'No Sidebar', 'orbius' ),
                    'layout-full-screen'   => esc_html__( '100% Width - Full Screen', 'orbius' )
                 ];
                break;

            case 'text_align':
                $options = [
                    'left'   => esc_html__( 'Left', 'orbius' ),
                    'center' => esc_html__( 'Center', 'orbius' ),
                    'right'  => esc_html__( 'Right', 'orbius' )
                ];
                break;

            case 'bg_img_styles':
                $options = [
                    ''             => esc_html__( 'Default', 'orbius' ),
                    'cover'        => esc_html__( 'Cover', 'orbius' ),
                    'stretched'    => esc_html__( 'Stretched', 'orbius' ),
                    'repeat'       => esc_html__( 'Repeat', 'orbius' ),
                    'fixed-top'    => esc_html__( 'Fixed Top', 'orbius' ),
                    'fixed'        => esc_html__( 'Fixed Center', 'orbius' ),
                    'fixed-bottom' => esc_html__( 'Fixed Bottom', 'orbius' ),
                    'repeat-x'     => esc_html__( 'Repeat-x', 'orbius' ),
                    'repeat-y'     => esc_html__( 'Repeat-y', 'orbius' ),
                    'inherit'      => esc_html__( 'Inherit', 'orbius' ),
                ];
                break;

            case 'four':
                $options = [
                            '1' => '1',
                            '2' => '2',
                            '3' => '3',
                            '4' => '4'
                        ];
                break;

            case 'two_to_six':
                $options = [
                            '2' => '2',
                            '3' => '3',
                            '4' => '4',
                            '5' => '5',
                            '6' => '6',
                        ];
                break;

            case 'eight':
                $options = [
                            '1' => '1',
                            '2' => '2',
                            '3' => '3',
                            '4' => '4',
                            '5' => '5',
                            '6' => '6',
                            '7' => '7',
                            '8' => '8',
                        ];
                break;

            case 'hundred':          $options = ['min' => '0',  'max' => '100', 'step' => '1'];    break;
            case 'two_hundred':      $options = ['min' => '0',  'max' => '200', 'step' => '1'];    break;
            case 'five_hundred':     $options = ['min' => '0',  'max' => '500', 'step' => '1'];    break;
            case 'thousand':         $options = ['min' => '0',  'max' => '1000','step' => '1'];    break;
            case 'two_thousand':     $options = ['min' => '0',  'max' => '2000','step' => '1'];    break;
            case 'font_size';        $options = ['min' => '6',  'max' => '100', 'step' => '1'];    break;
            case 'letter_space':     $options = ['min' => '-10','max' => '10',  'step' => '0.1'];  break;
            case 'letter_space_alt': $options = ['min' => '-1','max' => '1',  'step' => '.01'];  break;
            case 'layout_max_width': $options = ['min' => '500','max' => '1500','step' => '1'];    break;
            case 'content_width':    $options = ['min' => '60', 'max' => '74',  'step' => '1'];    break;
            case 'menu_resolution':  $options = ['min' => '300','max' => '2000','step' => '1'];    break;
            case 'line_height':      $options = ['min' => '1',  'max' => '5',   'step' => '0.01']; break;
            case 'one_to_twenty':    $options = ['min' => '1',  'max' => '20',  'step' => '1'];    break;
            case 'one_to_hundred':   $options = ['min' => '1',  'max' => '100', 'step' => '1'];    break;
            case 'hundred_digital':  $options = ['min' => '0',  'max' => '100', 'step' => '0.01']; break;

        }

        return $options;
    }
}