<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Increase http request time to fix cURL 28 issue.
if ( ! function_exists( 'swm_custom_http_request_timeout' ) ) {
    function swm_custom_http_request_timeout( $timeout_value ) {
        return 600; // 600 seconds. Too much for production, only for demo import.
    }
    add_filter( 'http_request_timeout', 'swm_custom_http_request_timeout' );
}

if ( ! function_exists( 'swm_ocdi_import_files' ) ) {
    function swm_ocdi_import_files() {
        return [
            [
                'import_file_name'           => 'Orbius',
                'import_file_url'            => 'https://premiumthemes.in/demo-content/orbius/demos.xml',
                'import_widget_file_url'     => 'https://premiumthemes.in/demo-content/orbius/widgets.json',
                'import_customizer_file_url' => 'https://premiumthemes.in/demo-content/orbius/customizer.dat',
                'preview_url'                => 'https://orbius.premiumthemes.in',
                'import_preview_image_url'   => get_template_directory_uri() .'/screenshot.jpg'
            ],
        ];
    }
    add_filter( 'ocdi/import_files', 'swm_ocdi_import_files' );
}

if ( ! function_exists( 'swm_ocdi_after_import_setup' ) ) {
    function swm_ocdi_after_import_setup() {

        // Replace demo site URL with current site URL
        global $wpdb;
        $from = 'https://orbius.premiumthemes.in/'; // with str_replace:---> https:\\/\\/orbius.premiumthemes.in\\/
        $from_url = str_replace( '/', '\\\/', $from );
        $to = home_url().'/';
        $to_url = str_replace( '/', '\\\/', $to );

        $wpdb->query($wpdb->prepare( " UPDATE {$wpdb->postmeta} " . "SET `meta_value` = REPLACE(`meta_value`, '" . $from_url . "', '" . $to_url . "') " . "WHERE `meta_key` = '_elementor_data' AND `meta_value` LIKE '[%' ;") );
        wp_reset_postdata();

        // ELEMENTOR

        update_option( 'elementor_disable_color_schemes', 'no' );
        update_option( 'elementor_disable_typography_schemes', 'yes' );
        update_option( 'elementor_enable_inspector', 'disable' );
        update_option( 'elementor_experiment-e_optimized_css_loading', 'active' );
        update_option( 'elementor_experiment-container', 'active' );
        update_option( 'elementor_experiment-container_grid', 'active' );
        update_option( 'elementor_experiment-editor_v2', 'active' );
        update_option( 'elementor_experiment-nested-elements', 'active' );
        update_option( 'elementor_experiment-additional_custom_breakpoints', 'inactive' );
        update_option( 'elementor_font_display', 'auto' );


        update_option( 'elementor_css_print_method','internal');
        update_option( 'elementor_font_display', 'block');
        update_option( 'elementor_unfiltered_files_upload', 0);
        update_option( 'elementor_experiment-e_font_icon_svg','inactive');
        update_option( 'elementor_experiment-e_optimized_assets_loading', 'inactive' );
        update_option( 'elementor_experiment-e_swiper_latest', 'inactive' );
        update_option( 'elementor_experiment-e_global_styleguide', 'active' );


        // set elementor kit
        $swm_elementor_lib_posts_args = [
            'post_type'      => 'elementor_library',
            'posts_per_page' => 1,
            'post_name__in'  => ['custom-theme-demo-kit'],
            'fields'         => 'ids'
        ];

        $swm_get_elem_lib_demo_kit_id = get_posts( $swm_elementor_lib_posts_args );
        update_option( 'elementor_active_kit', $swm_get_elem_lib_demo_kit_id[0] );

        // if exists, assign to $cpt_support var
        $cpt_support = get_option( 'elementor_cpt_support' );

        // check if option DOESN'T exist in db
        if( ! $cpt_support ) {
            $cpt_support = [ 'page', 'post', 'portfolio','cpt_sections', 'product' ];
            update_option( 'elementor_cpt_support', $cpt_support );
        }

        // if exists, assign to $cpt_support var
        $cpt_support = get_option( 'elementor_cpt_support' );
        $cpt_support_posts = [ 'page', 'post', 'portfolio','cpt_sections', 'product' ];

        if( ! $cpt_support ) {
            update_option( 'elementor_cpt_support', $cpt_support_posts );
        } else {
            $allarray = array_merge($cpt_support,$cpt_support_posts);
            update_option( 'elementor_cpt_support', $allarray );
        }

        if ( ! wp_doing_ajax() || ( defined( 'ELEMENTOR_VERSION' ) && version_compare( ELEMENTOR_VERSION, '3.0.0', '>=' ) ) ) {
            add_filter( 'wxr_importer.pre_process.post_meta', 'swm_ocdi_on_wxr_importer_pre_process_post_meta' );
        }

        update_option( 'elementor_active_kit', $swm_get_elem_lib_demo_kit_id[0] );

        // Logo
        $swm_ocdi_folder_path  = get_template_directory_uri() . '/plugins/one-click-demo-import/';
        $logoimg               = $swm_ocdi_folder_path . 'content/images/logo.png';

        update_option( 'swm_logo_standard', $logoimg );

        // Reset Permalink
        global $wp_rewrite;
        $wp_rewrite->set_permalink_structure( '/%postname%/' );
        $wp_rewrite->flush_rules();


        // Front, Blog Page
        $homepage   = get_page_by_path( '/main-home/', OBJECT, 'page' );
        $blogpage   = get_page_by_path( '/blog/', OBJECT, 'page' );

        if ( $homepage ) {
            update_option( 'page_on_front', $homepage->ID );
            update_option( 'show_on_front', 'page' );
        }

        if ( $blogpage ) {
            update_option( 'page_for_posts', $blogpage->ID );
        }

        update_option( 'posts_per_page', 4 );

        // set custom sections meta values
        update_post_meta( '2518', 'mk_section_type', 'header' );
        update_post_meta( '1382', 'mk_section_type', 'header' );
        update_post_meta( '1383', 'mk_section_type', 'header' );
        update_post_meta( '1384', 'mk_section_type', 'header' );
        update_post_meta( '1381', 'mk_section_type', 'footer' );
        update_post_meta( '1385', 'mk_section_type', 'footer' );
        update_post_meta( '1386', 'mk_section_type', 'footer' );
        update_post_meta( '1387', 'mk_section_type', 'footer' );
        update_post_meta( '1388', 'mk_section_type', 'titlebar' );
        update_post_meta( '1389', 'mk_section_type', 'offcanvas' );
        update_post_meta( '1390', 'mk_section_type', 'megamenu' );


        // update option to show "Done" in Theme Dashboard "Import Demo Content" section
        update_site_option( 'swm_demo_import_done', 'yes' );

    }
    add_action( 'ocdi/after_import', 'swm_ocdi_after_import_setup' );
}

// Process post meta before WXR importer.
// Normalize Elementor post meta on import with the new WP_importer, We need the `wp_slash` in order to avoid the unslashing during the `add_post_meta`.
// Fired by `wxr_importer.pre_process.post_meta` filter.
if ( ! function_exists( 'swm_ocdi_on_wxr_importer_pre_process_post_meta' ) ) {
    function swm_ocdi_on_wxr_importer_pre_process_post_meta( $post_meta ) {
        if ( '_elementor_data' === $post_meta['key'] ) {
            $post_meta['value'] = wp_slash( $post_meta['value'] );
        }
        return $post_meta;
    }
}

// 5 seconds. Set to default WordPress time out value.
if ( ! function_exists( 'swm_custom_http_request_timeout_after' ) ) {
    function swm_custom_http_request_timeout_after( $timeout_value ) {
        return 5;
    }
}

// Remove branding info box after content import
add_filter( 'ocdi/disable_pt_branding', '__return_true' );
if ( ! function_exists( 'swm_recursive_array_replace' ) ) {
    function swm_recursive_array_replace( $find, $replace, $array ) {
        if ( ! is_array( $array ) ) {
            return str_replace( $find, $replace, $array );
        }
        $newArray = array();
        foreach ( $array as $key => $value ) {
            $newArray[ $key ] = swm_recursive_array_replace( $find, $replace, $value );
        }
        return $newArray;
    }
}

// One click demo import plugin configuration

function swm_ocdi_plugin_page_setup( $default_settings ) {
    $default_settings['parent_slug'] = 'themes.php';
    $default_settings['page_title']  = esc_html__( 'One Click Demo Import' , 'orbius' );
    $default_settings['menu_title']  = esc_html__( 'Import Demo Data' , 'orbius' );
    $default_settings['capability']  = 'import';
    $default_settings['menu_slug']   = 'swm-one-click-demo-import';

    return $default_settings;
}
add_filter( 'ocdi/plugin_page_setup', 'swm_ocdi_plugin_page_setup' );

function swm_ocdi_register_plugins( $plugins ) {
  $theme_plugins = [ [
      'name'     => 'Orbius Core',
      'slug'     => 'orbius-core',
      'source'   => get_template_directory() . '/plugins/tgm-plugin-activation/zip/orbius-core.php',
      'required' => false,
    ],[
      'name'     => 'Elementor',
      'slug'     => 'elementor',
      'required' => true,
    ],[
      'name'     => 'Contact Form 7',
      'slug'     => 'contact-form-7',
      'required' => true,
    ] ];

  $plugins = array();

  return array_merge( $plugins, $theme_plugins );
}
add_filter( 'ocdi/register_plugins', 'swm_ocdi_register_plugins' );